// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
try {
  this['Module'] = Module;
  Module.test;
} catch(e) {
  this['Module'] = Module = {};
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
  module.exports = Module;
}
if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  Module['read'] = read;
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
  this['Module'] = Module;
}
if (ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }
  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }
  this['Module'] = Module;
}
if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}
if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...
  var TRY_USE_DUMP = false;
  if (!Module['print']) {
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }
  Module['load'] = importScripts;
}
if (!ENVIRONMENT_IS_WORKER && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_SHELL) {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = globalScope['Module']['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,((Math.min((+(Math.floor((value)/(+(4294967296))))), (+(4294967295))))|0)>>>0],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown
var runtimeInitialized = false;
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function addPreRun(func) {
  if (!Module['preRun']) Module['preRun'] = [];
  else if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
  Module['preRun'].push(func);
}
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 63384;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });
var _stdout;
var _stdin;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stdin = _stdin=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,131,3,0,0,0,0,0,0,130,2,0,0,44,0,0,0,132,4,0,0,4,0,0,0,134,6,0,0,48,0,0,1,132,4,0,0,80,0,0,1,130,2,0,0,46,0,0,1,131,3,0,0,88,0,0,1,134,6,0,0,12,0,0,0,1,2,0,0,24,0,0,0,138,2,0,0,18,0,0,0,129,2,0,0,0,0,0,0,139,2,0,0,20,0,0,0,130,2,0,0,2,0,0,0,2,2,0,0,26,0,0,0,131,2,0,0,4,0,0,0,3,2,0,0,28,0,0,0,132,2,0,0,6,0,0,0,4,2,0,0,30,0,0,0,133,2,0,0,8,0,0,0,5,2,0,0,32,0,0,0,134,2,0,0,10,0,0,0,6,2,0,0,34,0,0,0,135,2,0,0,12,0,0,0,7,2,0,0,36,0,0,0,136,2,0,0,14,0,0,0,8,2,0,0,38,0,0,0,137,2,0,0,16,0,0,1,144,2,0,0,84,0,0,1,135,2,0,0,56,0,0,1,145,2,0,0,86,0,0,1,136,2,0,0,58,0,0,1,146,2,0,0,88,0,0,1,137,2,0,0,60,0,0,1,147,2,0,0,90,0,0,1,138,2,0,0,62,0,0,1,129,2,0,0,22,0,0,1,139,2,0,0,64,0,0,1,130,2,0,0,46,0,0,1,140,2,0,0,66,0,0,1,131,2,0,0,48,0,0,1,141,2,0,0,68,0,0,1,132,2,0,0,50,0,0,1,142,2,0,0,70,0,0,1,133,2,0,0,52,0,0,1,143,2,0,0,72,0,0,1,134,2,0,0,54,0,0,80,0,0,0,0,92,0,0,38,0,0,0,72,0,0,0,8,0,0,0,8,0,0,0,0,168,0,0,168,213,0,0,1,168,0,0,128,213,0,0,2,168,0,0,208,212,0,0,3,168,0,0,96,212,0,0,4,168,0,0,240,211,0,0,5,168,0,0,184,211,0,0,6,168,0,0,96,211,0,0,7,168,0,0,72,211,0,0,8,168,0,0,32,211,0,0,9,168,0,0,8,211,0,0,10,168,0,0,232,210,0,0,11,168,0,0,208,210,0,0,12,168,0,0,80,210,0,0,13,168,0,0,216,209,0,0,14,168,0,0,120,209,0,0,15,168,0,0,96,209,0,0,16,168,0,0,72,209,0,0,17,168,0,0,48,209,0,0,18,168,0,0,16,209,0,0,19,168,0,0,248,208,0,0,20,168,0,0,168,208,0,0,21,168,0,0,144,208,0,0,22,168,0,0,248,207,0,0,23,168,0,0,96,207,0,0,24,168,0,0,192,206,0,0,25,168,0,0,48,206,0,0,26,168,0,0,0,206,0,0,27,168,0,0,232,205,0,0,28,168,0,0,200,205,0,0,29,168,0,0,176,205,0,0,31,168,0,0,88,205,0,0,32,168,0,0,56,205,0,0,33,168,0,0,168,204,0,0,34,168,0,0,240,203,0,0,35,168,0,0,216,203,0,0,38,168,0,0,176,203,0,0,39,168,0,0,136,203,0,0,40,168,0,0,56,203,0,0,41,168,0,0,24,203,0,0,42,168,0,0,200,202,0,0,43,168,0,0,176,202,0,0,44,168,0,0,160,202,0,0,45,168,0,0,96,202,0,0,46,168,0,0,176,201,0,0,47,168,0,0,112,201,0,0,48,168,0,0,72,201,0,0,49,168,0,0,56,201,0,0,51,168,0,0,16,201,0,0,52,168,0,0,224,200,0,0,53,168,0,0,208,200,0,0,54,168,0,0,160,200,0,0,55,168,0,0,144,200,0,0,56,168,0,0,200,199,0,0,57,168,0,0,160,199,0,0,58,168,0,0,136,199,0,0,59,168,0,0,104,199,0,0,60,168,0,0,64,199,0,0,61,168,0,0,48,199,0,0,62,168,0,0,8,199,0,0,63,168,0,0,240,198,0,0,64,168,0,0,168,198,0,0,65,168,0,0,144,198,0,0,66,168,0,0,48,198,0,0,67,168,0,0,216,197,0,0,68,168,0,0,208,197,0,0,69,168,0,0,192,197,0,0,70,168,0,0,176,197,0,0,71,168,0,0,160,197,0,0,72,168,0,0,144,197,0,0,73,168,0,0,128,197,0,0,74,168,0,0,96,197,0,0,75,168,0,0,80,197,0,0,76,168,0,0,232,196,0,0,77,168,0,0,144,196,0,0,78,168,0,0,96,196,0,0,79,168,0,0,240,195,0,0,80,168,0,0,136,195,0,0,81,168,0,0,240,194,0,0,82,168,0,0,144,194,0,0,83,168,0,0,24,194,0,0,84,168,0,0,192,193,0,0,85,168,0,0,160,193,0,0,86,168,0,0,64,193,0,0,88,168,0,0,208,192,0,0,89,168,0,0,184,192,0,0,90,168,0,0,136,192,0,0,91,168,0,0,80,192,0,0,92,168,0,0,56,192,0,0,93,168,0,0,40,192,0,0,94,168,0,0,24,192,0,0,95,168,0,0,248,191,0,0,96,168,0,0,216,191,0,0,97,168,0,0,144,191,0,0,98,168,0,0,24,191,0,0,99,168,0,0,8,191,0,0,100,168,0,0,240,190,0,0,101,168,0,0,216,190,0,0,102,168,0,0,192,190,0,0,103,168,0,0,176,190,0,0,104,168,0,0,128,190,0,0,105,168,0,0,96,190,0,0,106,168,0,0,80,190,0,0,107,168,0,0,8,190,0,0,108,168,0,0,192,189,0,0,109,168,0,0,160,189,0,0,110,168,0,0,128,189,0,0,111,168,0,0,88,189,0,0,112,168,0,0,48,189,0,0,113,168,0,0,16,189,0,0,114,168,0,0,248,188,0,0,115,168,0,0,200,188,0,0,116,168,0,0,184,188,0,0,117,168,0,0,112,188,0,0,118,168,0,0,16,188,0,0,119,168,0,0,248,187,0,0,120,168,0,0,200,187,0,0,121,168,0,0,184,187,0,0,122,168,0,0,168,187,0,0,123,168,0,0,136,187,0,0,124,168,0,0,120,187,0,0,125,168,0,0,88,187,0,0,125,168,0,0,64,187,0,0,126,168,0,0,0,187,0,0,127,168,0,0,192,186,0,0,128,168,0,0,176,186,0,0,129,168,0,0,160,186,0,0,130,168,0,0,152,186,0,0,131,168,0,0,128,186,0,0,132,168,0,0,96,186,0,0,133,168,0,0,72,186,0,0,134,168,0,0,40,186,0,0,135,168,0,0,16,186,0,0,136,168,0,0,208,185,0,0,137,168,0,0,128,185,0,0,138,168,0,0,112,185,0,0,139,168,0,0,80,185,0,0,140,168,0,0,64,185,0,0,141,168,0,0,48,185,0,0,142,168,0,0,32,185,0,0,143,168,0,0,16,185,0,0,144,168,0,0,224,184,0,0,145,168,0,0,216,184,0,0,146,168,0,0,184,184,0,0,147,168,0,0,96,184,0,0,148,168,0,0,88,184,0,0,149,168,0,0,64,184,0,0,150,168,0,0,56,184,0,0,151,168,0,0,48,184,0,0,152,168,0,0,240,183,0,0,153,168,0,0,224,183,0,0,154,168,0,0,200,183,0,0,155,168,0,0,192,183,0,0,156,168,0,0,152,183,0,0,157,168,0,0,80,183,0,0,158,168,0,0,64,183,0,0,159,168,0,0,40,183,0,0,160,168,0,0,32,183,0,0,161,168,0,0,16,183,0,0,162,168,0,0,240,182,0,0,163,168,0,0,224,182,0,0,164,168,0,0,160,182,0,0,165,168,0,0,144,182,0,0,166,168,0,0,104,182,0,0,167,168,0,0,32,182,0,0,168,168,0,0,8,182,0,0,169,168,0,0,240,181,0,0,170,168,0,0,224,181,0,0,171,168,0,0,208,181,0,0,172,168,0,0,192,181,0,0,173,168,0,0,176,181,0,0,174,168,0,0,152,181,0,0,175,168,0,0,136,181,0,0,176,168,0,0,104,181,0,0,177,168,0,0,0,181,0,0,178,168,0,0,208,180,0,0,179,168,0,0,144,180,0,0,180,168,0,0,120,180,0,0,181,168,0,0,0,180,0,0,182,168,0,0,160,179,0,0,183,168,0,0,56,179,0,0,184,168,0,0,248,178,0,0,185,168,0,0,232,178,0,0,186,168,0,0,160,178,0,0,187,168,0,0,88,178,0,0,188,168,0,0,64,178,0,0,189,168,0,0,24,178,0,0,190,168,0,0,0,178,0,0,191,168,0,0,216,177,0,0,192,168,0,0,192,177,0,0,193,168,0,0,176,177,0,0,194,168,0,0,160,177,0,0,195,168,0,0,144,177,0,0,196,168,0,0,112,177,0,0,197,168,0,0,24,177,0,0,198,168,0,0,232,176,0,0,199,168,0,0,200,176,0,0,200,168,0,0,184,176,0,0,201,168,0,0,168,176,0,0,202,168,0,0,144,176,0,0,203,168,0,0,104,176,0,0,204,168,0,0,80,176,0,0,205,168,0,0,64,176,0,0,206,168,0,0,24,176,0,0,207,168,0,0,192,175,0,0,208,168,0,0,168,175,0,0,209,168,0,0,144,175,0,0,210,168,0,0,128,175,0,0,211,168,0,0,112,175,0,0,212,168,0,0,64,175,0,0,213,168,0,0,48,175,0,0,214,168,0,0,16,175,0,0,215,168,0,0,0,175,0,0,216,168,0,0,200,174,0,0,217,168,0,0,80,174,0,0,218,168,0,0,72,174,0,0,219,168,0,0,40,174,0,0,220,168,0,0,24,174,0,0,221,168,0,0,8,174,0,0,222,168,0,0,232,173,0,0,223,168,0,0,224,173,0,0,224,168,0,0,200,173,0,0,225,168,0,0,184,173,0,0,226,168,0,0,80,173,0,0,227,168,0,0,16,173,0,0,228,168,0,0,8,173,0,0,229,168,0,0,232,172,0,0,230,168,0,0,208,172,0,0,231,168,0,0,200,172,0,0,232,168,0,0,168,172,0,0,233,168,0,0,152,172,0,0,234,168,0,0,120,172,0,0,235,168,0,0,112,172,0,0,236,168,0,0,80,172,0,0,237,168,0,0,8,172,0,0,238,168,0,0,248,171,0,0,239,168,0,0,208,171,0,0,240,168,0,0,192,171,0,0,241,168,0,0,176,171,0,0,242,168,0,0,144,171,0,0,243,168,0,0,120,171,0,0,244,168,0,0,96,171,0,0,245,168,0,0,40,171,0,0,246,168,0,0,16,171,0,0,247,168,0,0,224,170,0,0,248,168,0,0,216,170,0,0,249,168,0,0,192,170,0,0,250,168,0,0,184,170,0,0,251,168,0,0,176,170,0,0,252,168,0,0,160,170,0,0,253,168,0,0,152,170,0,0,254,168,0,0,96,170,0,0,255,168,0,0,80,170,0,0,0,169,0,0,64,170,0,0,1,169,0,0,216,169,0,0,2,169,0,0,192,169,0,0,3,169,0,0,160,169,0,0,4,169,0,0,144,169,0,0,5,169,0,0,128,169,0,0,6,169,0,0,104,169,0,0,7,169,0,0,88,169,0,0,8,169,0,0,232,168,0,0,9,169,0,0,224,168,0,0,10,169,0,0,160,168,0,0,11,169,0,0,72,168,0,0,12,169,0,0,56,168,0,0,13,169,0,0,24,168,0,0,14,169,0,0,16,168,0,0,15,169,0,0,8,168,0,0,16,169,0,0,240,167,0,0,17,169,0,0,224,167,0,0,18,169,0,0,200,167,0,0,19,169,0,0,184,167,0,0,20,169,0,0,152,167,0,0,21,169,0,0,96,167,0,0,22,169,0,0,248,166,0,0,23,169,0,0,200,166,0,0,24,169,0,0,168,166,0,0,25,169,0,0,152,166,0,0,26,169,0,0,32,166,0,0,27,169,0,0,192,165,0,0,28,169,0,0,96,165,0,0,29,169,0,0,72,165,0,0,30,169,0,0,24,165,0,0,31,169,0,0,208,164,0,0,32,169,0,0,184,164,0,0,33,169,0,0,144,164,0,0,34,169,0,0,112,164,0,0,35,169,0,0,80,164,0,0,36,169,0,0,40,164,0,0,37,169,0,0,24,164,0,0,38,169,0,0,0,164,0,0,39,169,0,0,240,163,0,0,40,169,0,0,200,163,0,0,41,169,0,0,168,163,0,0,42,169,0,0,80,163,0,0,43,169,0,0,48,163,0,0,44,169,0,0,32,163,0,0,45,169,0,0,16,163,0,0,46,169,0,0,232,162,0,0,47,169,0,0,192,162,0,0,48,169,0,0,168,162,0,0,49,169,0,0,160,162,0,0,50,169,0,0,80,162,0,0,51,169,0,0,24,162,0,0,52,169,0,0,232,161,0,0,53,169,0,0,200,161,0,0,54,169,0,0,184,161,0,0,55,169,0,0,168,161,0,0,56,169,0,0,144,161,0,0,57,169,0,0,104,161,0,0,58,169,0,0,72,161,0,0,59,169,0,0,56,161,0,0,60,169,0,0,0,161,0,0,61,169,0,0,216,160,0,0,62,169,0,0,208,160,0,0,63,169,0,0,176,160,0,0,64,169,0,0,160,160,0,0,65,169,0,0,136,160,0,0,66,169,0,0,112,160,0,0,67,169,0,0,96,160,0,0,68,169,0,0,72,160,0,0,69,169,0,0,56,160,0,0,70,169,0,0,32,160,0,0,71,169,0,0,240,159,0,0,72,169,0,0,224,159,0,0,73,169,0,0,192,159,0,0,74,169,0,0,176,159,0,0,75,169,0,0,160,159,0,0,76,169,0,0,136,159,0,0,77,169,0,0,120,159,0,0,78,169,0,0,96,159,0,0,79,169,0,0,80,159,0,0,80,169,0,0,48,159,0,0,81,169,0,0,16,159,0,0,82,169,0,0,0,159,0,0,83,169,0,0,216,158,0,0,84,169,0,0,200,158,0,0,85,169,0,0,184,158,0,0,86,169,0,0,160,158,0,0,87,169,0,0,144,158,0,0,88,169,0,0,120,158,0,0,89,169,0,0,104,158,0,0,90,169,0,0,24,158,0,0,91,169,0,0,8,158,0,0,92,169,0,0,248,157,0,0,93,169,0,0,216,157,0,0,94,169,0,0,200,157,0,0,95,169,0,0,184,157,0,0,96,169,0,0,160,157,0,0,97,169,0,0,144,157,0,0,98,169,0,0,112,157,0,0,99,169,0,0,96,157,0,0,100,169,0,0,72,157,0,0,101,169,0,0,24,157,0,0,102,169,0,0,8,157,0,0,103,169,0,0,224,156,0,0,104,169,0,0,208,156,0,0,105,169,0,0,192,156,0,0,106,169,0,0,168,156,0,0,107,169,0,0,152,156,0,0,108,169,0,0,112,156,0,0,109,169,0,0,96,156,0,0,110,169,0,0,72,156,0,0,111,169,0,0,40,156,0,0,112,169,0,0,24,156,0,0,113,169,0,0,248,155,0,0,114,169,0,0,232,155,0,0,115,169,0,0,216,155,0,0,116,169,0,0,200,155,0,0,117,169,0,0,184,155,0,0,118,169,0,0,128,155,0,0,119,169,0,0,112,155,0,0,120,169,0,0,88,155,0,0,121,169,0,0,24,155,0,0,122,169,0,0,224,154,0,0,123,169,0,0,168,154,0,0,124,169,0,0,144,154,0,0,125,169,0,0,112,154,0,0,126,169,0,0,40,154,0,0,127,169,0,0,200,153,0,0,128,169,0,0,104,153,0,0,129,169,0,0,80,153,0,0,130,169,0,0,40,153,0,0,131,169,0,0,248,152,0,0,132,169,0,0,224,152,0,0,133,169,0,0,192,152,0,0,134,169,0,0,168,152,0,0,135,169,0,0,136,152,0,0,136,169,0,0,112,152,0,0,137,169,0,0,96,152,0,0,138,169,0,0,64,152,0,0,139,169,0,0,48,152,0,0,140,169,0,0,16,152,0,0,141,169,0,0,184,151,0,0,142,169,0,0,136,151,0,0,143,169,0,0,112,151,0,0,144,169,0,0,96,151,0,0,145,169,0,0,80,151,0,0,146,169,0,0,56,151,0,0,147,169,0,0,16,151,0,0,148,169,0,0,248,150,0,0,149,169,0,0,232,150,0,0,150,169,0,0,160,150,0,0,151,169,0,0,120,150,0,0,152,169,0,0,96,150,0,0,153,169,0,0,64,150,0,0,154,169,0,0,48,150,0,0,155,169,0,0,32,150,0,0,156,169,0,0,8,150,0,0,157,169,0,0,248,149,0,0,158,169,0,0,208,149,0,0,159,169,0,0,192,149,0,0,160,169,0,0,168,149,0,0,161,169,0,0,80,149,0,0,162,169,0,0,64,149,0,0,163,169,0,0,32,149,0,0,164,169,0,0,16,149,0,0,165,169,0,0,0,149,0,0,166,169,0,0,208,148,0,0,167,169,0,0,192,148,0,0,168,169,0,0,152,148,0,0,169,169,0,0,136,148,0,0,170,169,0,0,112,148,0,0,171,169,0,0,80,148,0,0,172,169,0,0,64,148,0,0,173,169,0,0,32,148,0,0,174,169,0,0,16,148,0,0,175,169,0,0,0,148,0,0,176,169,0,0,232,147,0,0,177,169,0,0,216,147,0,0,178,169,0,0,192,147,0,0,179,169,0,0,176,147,0,0,180,169,0,0,144,147,0,0,181,169,0,0,96,147,0,0,182,169,0,0,80,147,0,0,183,169,0,0,40,147,0,0,184,169,0,0,24,147,0,0,185,169,0,0,8,147,0,0,186,169,0,0,240,146,0,0,187,169,0,0,232,146,0,0,188,169,0,0,200,146,0,0,189,169,0,0,184,146,0,0,190,169,0,0,152,146,0,0,191,169,0,0,40,146,0,0,192,169,0,0,24,146,0,0,193,169,0,0,0,146,0,0,194,169,0,0,248,145,0,0,195,169,0,0,232,145,0,0,196,169,0,0,208,145,0,0,197,169,0,0,192,145,0,0,198,169,0,0,168,145,0,0,199,169,0,0,152,145,0,0,200,169,0,0,136,145,0,0,201,169,0,0,104,145,0,0,202,169,0,0,96,145,0,0,203,169,0,0,64,145,0,0,204,169,0,0,48,145,0,0,205,169,0,0,32,145,0,0,206,169,0,0,16,145,0,0,207,169,0,0,0,145,0,0,208,169,0,0,200,144,0,0,209,169,0,0,184,144,0,0,210,169,0,0,160,144,0,0,211,169,0,0,112,144,0,0,212,169,0,0,104,144,0,0,213,169,0,0,80,144,0,0,214,169,0,0,72,144,0,0,215,169,0,0,56,144,0,0,216,169,0,0,32,144,0,0,217,169,0,0,16,144,0,0,218,169,0,0,248,143,0,0,219,169,0,0,240,143,0,0,220,169,0,0,208,143,0,0,221,169,0,0,128,143,0,0,222,169,0,0,104,143,0,0,223,169,0,0,64,143,0,0,224,169,0,0,24,143,0,0,225,169,0,0,232,142,0,0,226,169,0,0,168,142,0,0,227,169,0,0,96,142,0,0,228,169,0,0,216,141,0,0,229,169,0,0,192,141,0,0,230,169,0,0,160,141,0,0,231,169,0,0,120,141,0,0,232,169,0,0,104,141,0,0,233,169,0,0,80,141,0,0,234,169,0,0,56,141,0,0,235,169,0,0,32,141,0,0,235,169,0,0,16,141,0,0,236,169,0,0,0,141,0,0,236,169,0,0,192,140,0,0,237,169,0,0,184,140,0,0,238,169,0,0,144,140,0,0,239,169,0,0,104,140,0,0,240,169,0,0,56,140,0,0,241,169,0,0,24,140,0,0,242,169,0,0,16,140,0,0,243,169,0,0,8,140,0,0,244,169,0,0,248,139,0,0,245,169,0,0,184,139,0,0,246,169,0,0,120,139,0,0,247,169,0,0,104,139,0,0,248,169,0,0,80,139,0,0,249,169,0,0,24,139,0,0,250,169,0,0,8,139,0,0,251,169,0,0,224,138,0,0,252,169,0,0,208,138,0,0,253,169,0,0,192,138,0,0,254,169,0,0,176,138,0,0,255,169,0,0,152,138,0,0,0,170,0,0,96,138,0,0,1,170,0,0,80,138,0,0,3,170,0,0,56,138,0,0,4,170,0,0,8,138,0,0,5,170,0,0,248,137,0,0,6,170,0,0,216,137,0,0,7,170,0,0,200,137,0,0,8,170,0,0,184,137,0,0,9,170,0,0,168,137,0,0,10,170,0,0,120,137,0,0,11,170,0,0,56,137,0,0,12,170,0,0,40,137,0,0,13,170,0,0,16,137,0,0,14,170,0,0,216,136,0,0,15,170,0,0,200,136,0,0,16,170,0,0,184,136,0,0,17,170,0,0,152,136,0,0,18,170,0,0,136,136,0,0,19,170,0,0,120,136,0,0,20,170,0,0,96,136,0,0,21,170,0,0,64,136,0,0,22,170,0,0,48,136,0,0,23,170,0,0,24,136,0,0,24,170,0,0,232,135,0,0,25,170,0,0,216,135,0,0,26,170,0,0,192,135,0,0,27,170,0,0,168,135,0,0,28,170,0,0,152,135,0,0,29,170,0,0,136,135,0,0,30,170,0,0,112,135,0,0,31,170,0,0,80,135,0,0,33,170,0,0,72,135,0,0,34,170,0,0,40,135,0,0,35,170,0,0,248,134,0,0,36,170,0,0,232,134,0,0,37,170,0,0,216,134,0,0,38,170,0,0,184,134,0,0,39,170,0,0,168,134,0,0,40,170,0,0,152,134,0,0,41,170,0,0,128,134,0,0,42,170,0,0,56,134,0,0,43,170,0,0,40,134,0,0,44,170,0,0,232,133,0,0,45,170,0,0,176,133,0,0,46,170,0,0,160,133,0,0,47,170,0,0,144,133,0,0,48,170,0,0,112,133,0,0,49,170,0,0,80,133,0,0,50,170,0,0,64,133,0,0,51,170,0,0,40,133,0,0,52,170,0,0,248,132,0,0,53,170,0,0,232,132,0,0,54,170,0,0,208,132,0,0,55,170,0,0,160,132,0,0,56,170,0,0,144,132,0,0,57,170,0,0,128,132,0,0,58,170,0,0,96,132,0,0,59,170,0,0,88,132,0,0,60,170,0,0,72,132,0,0,61,170,0,0,48,132,0,0,62,170,0,0,24,132,0,0,63,170,0,0,8,132,0,0,64,170,0,0,240,131,0,0,65,170,0,0,200,131,0,0,66,170,0,0,176,131,0,0,67,170,0,0,160,131,0,0,68,170,0,0,88,131,0,0,69,170,0,0,72,131,0,0,70,170,0,0,16,131,0,0,71,170,0,0,208,130,0,0,72,170,0,0,120,130,0,0,73,170,0,0,96,130,0,0,74,170,0,0,64,130,0,0,75,170,0,0,248,129,0,0,76,170,0,0,224,129,0,0,77,170,0,0,200,129,0,0,78,170,0,0,152,129,0,0,79,170,0,0,120,129,0,0,80,170,0,0,104,129,0,0,81,170,0,0,80,129,0,0,82,170,0,0,232,128,0,0,96,170,0,0,216,128,0,0,97,170,0,0,192,128,0,0,98,170,0,0,160,128,0,0,99,170,0,0,120,128,0,0,100,170,0,0,104,128,0,0,101,170,0,0,72,128,0,0,102,170,0,0,56,128,0,0,103,170,0,0,32,128,0,0,104,170,0,0,224,127,0,0,0,0,0,0,0,0,0,0,0,160,0,0,96,163,0,0,1,160,0,0,32,212,0,0,2,160,0,0,184,189,0,0,3,160,0,0,184,175,0,0,4,160,0,0,248,161,0,0,5,160,0,0,112,150,0,0,6,160,0,0,0,139,0,0,7,160,0,0,104,127,0,0,8,160,0,0,112,122,0,0,9,160,0,0,216,118,0,0,10,160,0,0,24,225,0,0,11,160,0,0,168,221,0,0,12,160,0,0,80,217,0,0,13,160,0,0,192,214,0,0,14,160,0,0,208,211,0,0,15,160,0,0,136,209,0,0,16,160,0,0,120,206,0,0,17,160,0,0,200,203,0,0,18,160,0,0,120,201,0,0,19,160,0,0,120,199,0,0,20,160,0,0,200,197,0,0,21,160,0,0,56,196,0,0,22,160,0,0,152,192,0,0,23,160,0,0,0,191,0,0,24,160,0,0,152,189,0,0,25,160,0,0,232,187,0,0,26,160,0,0,168,186,0,0,27,160,0,0,96,185,0,0,28,160,0,0,80,184,0,0,29,160,0,0,56,183,0,0,30,160,0,0,0,182,0,0,31,160,0,0,168,180,0,0,32,160,0,0,32,178,0,0,33,160,0,0,216,176,0,0,34,160,0,0,152,175,0,0,35,160,0,0,56,174,0,0,36,160,0,0,248,172,0,0,37,160,0,0,224,171,0,0,38,160,0,0,200,170,0,0,39,160,0,0,176,169,0,0,40,160,0,0,40,168,0,0,41,160,0,0,216,166,0,0,42,160,0,0,160,164,0,0,43,160,0,0,64,163,0,0,44,160,0,0,216,161,0,0,45,160,0,0,192,160,0,0,46,160,0,0,208,159,0,0,47,160,0,0,232,158,0,0,48,160,0,0,232,157,0,0,49,160,0,0,248,156,0,0,50,160,0,0,8,156,0,0,51,160,0,0,184,154,0,0,52,160,0,0,200,152,0,0,53,160,0,0,128,151,0,0,54,160,0,0,80,150,0,0,56,160,0,0,48,149,0,0,57,160,0,0,48,148,0,0,58,160,0,0,56,147,0,0,59,160,0,0,16,146,0,0,60,160,0,0,80,145,0,0,61,160,0,0,88,144,0,0,62,160,0,0,80,143,0,0,63,160,0,0,88,141,0,0,64,160,0,0,40,140,0,0,65,160,0,0,240,138,0,0,66,160,0,0,232,137,0,0,67,160,0,0,168,136,0,0,68,160,0,0,184,135,0,0,69,160,0,0,200,134,0,0,70,160,0,0,128,133,0,0,71,160,0,0,112,132,0,0,72,160,0,0,152,131,0,0,73,160,0,0,192,129,0,0,74,160,0,0,88,128,0,0,75,160,0,0,88,127,0,0,76,160,0,0,224,126,0,0,77,160,0,0,40,126,0,0,78,160,0,0,168,125,0,0,79,160,0,0,56,125,0,0,80,160,0,0,0,125,0,0,81,160,0,0,144,124,0,0,82,160,0,0,88,124,0,0,84,160,0,0,104,123,0,0,85,160,0,0,224,122,0,0,86,160,0,0,96,122,0,0,87,160,0,0,24,122,0,0,88,160,0,0,224,121,0,0,89,160,0,0,176,121,0,0,90,160,0,0,136,121,0,0,91,160,0,0,88,121,0,0,92,160,0,0,248,120,0,0,93,160,0,0,144,120,0,0,94,160,0,0,136,119,0,0,95,160,0,0,32,119,0,0,96,160,0,0,200,118,0,0,97,160,0,0,160,118,0,0,98,160,0,0,112,118,0,0,99,160,0,0,40,118,0,0,100,160,0,0,232,117,0,0,101,160,0,0,152,117,0,0,102,160,0,0,232,226,0,0,103,160,0,0,160,226,0,0,104,160,0,0,192,225,0,0,105,160,0,0,104,225,0,0,106,160,0,0,8,225,0,0,108,160,0,0,224,224,0,0,109,160,0,0,176,224,0,0,110,160,0,0,112,224,0,0,111,160,0,0,72,224,0,0,112,160,0,0,24,224,0,0,113,160,0,0,216,223,0,0,114,160,0,0,192,223,0,0,117,160,0,0,200,222,0,0,118,160,0,0,88,222,0,0,119,160,0,0,208,221,0,0,120,160,0,0,72,221,0,0,121,160,0,0,0,221,0,0,122,160,0,0,96,220,0,0,123,160,0,0,184,219,0,0,124,160,0,0,144,219,0,0,125,160,0,0,64,219,0,0,126,160,0,0,24,219,0,0,127,160,0,0,64,218,0,0,128,160,0,0,192,217,0,0,129,160,0,0,104,217,0,0,130,160,0,0,48,217,0,0,131,160,0,0,192,216,0,0,132,160,0,0,160,216,0,0,133,160,0,0,136,216,0,0,134,160,0,0,104,216,0,0,135,160,0,0,64,216,0,0,136,160,0,0,24,216,0,0,138,160,0,0,192,215,0,0,139,160,0,0,32,215,0,0,141,160,0,0,216,214,0,0,143,160,0,0,168,214,0,0,144,160,0,0,136,214,0,0,145,160,0,0,96,214,0,0,146,160,0,0,40,214,0,0,152,160,0,0,232,213,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,216,216,0,0,44,0,0,0,96,192,0,0,18,0,0,0,232,177,0,0,78,0,0,0,96,164,0,0,94,0,0,0,152,152,0,0,30,0,0,0,40,141,0,0,84,0,0,0,136,129,0,0,98,0,0,0,64,123,0,0,96,0,0,0,120,119,0,0,6,0,0,0,176,225,0,0,12,0,0,0,112,222,0,0,76,0,0,0,232,217,0,0,34,0,0,0,88,215,0,0,2,0,0,0,120,212,0,0,50,0,0,0,240,209,0,0,100,0,0,0,120,207,0,0,66,0,0,0,16,204,0,0,16,0,0,0,192,201,0,0,80,0,0,0,176,199,0,0,42,0,0,0,224,197,0,0,62,0,0,0,168,196,0,0,10,0,0,0,232,192,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,43,48,42,47,4,53,41,46,12,58,3,52,25,9,40,45,55,14,11,57,32,30,2,51,28,17,24,8,21,63,39,44,49,5,54,13,59,26,10,56,15,33,31,29,18,22,1,50,6,60,27,16,34,19,23,7,61,35,20,62,36,37,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,124,0,0,128,120,0,0,144,226,0,0,136,223,0,0,184,218,0,0,0,0,0,0,83,79,70,84,87,65,82,69,32,80,73,82,65,84,69,83,80,155,0,0,32,153,0,0,240,151,0,0,152,150,0,0,128,245,0,0,144,149,0,0,104,148,0,0,120,147,0,0,104,146,0,0,128,145,0,0,136,144,0,0,160,143,0,0,208,141,0,0,144,141,0,0,128,140,0,0,112,130,0,0,56,139,0,0,32,138,0,0,160,123,0,0,248,136,0,0,0,136,0,0,200,119,0,0,128,245,0,0,24,135,0,0,88,165,0,0,208,133,0,0,184,132,0,0,16,226,0,0,224,131,0,0,24,130,0,0,192,222,0,0,128,245,0,0,184,128,0,0,96,153,0,0,128,127,0,0,248,126,0,0,56,218,0,0,64,126,0,0,200,125,0,0,184,215,0,0,80,125,0,0,24,125,0,0,136,156,0,0,184,208,0,0,56,186,0,0,112,171,0,0,128,157,0,0,136,155,0,0,240,144,0,0,16,133,0,0,176,124,0,0,48,121,0,0,192,245,0,0,8,224,0,0,0,219,0,0,80,216,0,0,184,213,0,0,248,210,0,0,184,208,0,0,80,208,0,0,104,205,0,0,192,245,0,0,104,205,0,0,184,202,0,0,192,245,0,0,176,200,0,0,184,198,0,0,104,197,0,0,208,193,0,0,0,192,0,0,112,190,0,0,208,188,0,0,104,187,0,0,184,208,0,0,232,185,0,0,8,185,0,0,208,183,0,0,176,182,0,0,0,1,59,2,60,40,54,3,61,32,49,41,55,19,35,4,62,52,30,33,50,12,14,42,56,16,27,20,36,23,44,5,63,58,39,53,31,48,18,34,51,29,11,13,15,26,22,43,57,38,47,17,28,10,25,21,37,46,9,24,45,8,7,6,63,0,0,0,224,196,0,0,0,0,0,0,40,193,0,0,98,0,1,0,128,191,0,0,0,190,0,0,72,188,0,0,66,0,2,0,240,186,0,0,192,185,0,0,160,184,0,0,99,0,1,0,144,183,0,0,96,182,0,0,72,181,0,0,100,0,1,0,152,178,0,0,96,182,0,0,72,177,0,0,105,0,1,0,8,176,0,0,96,182,0,0,152,174,0,0,73,0,1,0,64,173,0,0,96,182,0,0,40,172,0,0,108,0,1,0,8,171,0,0,96,182,0,0,32,170,0,0,112,0,1,0,168,219,0,0,96,182,0,0,136,168,0,0,113,0,0,0,144,167,0,0,0,0,0,0,248,164,0,0,114,0,0,0,192,163,0,0,0,0,0,0,48,162,0,0,82,0,0,0,240,160,0,0,0,0,0,0,8,160,0,0,115,0,1,0,40,159,0,0,56,158,0,0,48,157,0,0,116,0,1,0,56,156,0,0,96,182,0,0,40,155,0,0,118,0,0,0,16,153,0,0,0,0,0,0,200,151,0,0,86,0,0,0,136,150,0,0,0,0,0,0,104,149,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,205,0,0,80,205,0,0,232,204,0,0,8,204,0,0,232,203,0,0,192,203,0,0,152,203,0,0,72,203,0,0,40,203,0,0,8,203,0,0,192,202,0,0,168,202,0,0,112,202,0,0,184,201,0,0,168,201,0,0,104,201,0,0,56,214,0,0,240,213,0,0,208,213,0,0,152,213,0,0,80,213,0,0,112,212,0,0,24,212,0,0,200,211,0,0,160,211,0,0,88,211,0,0,48,211,0,0,24,211,0,0,0,211,0,0,224,210,0,0,152,210,0,0,232,209,0,0,184,209,0,0,112,209,0,0,88,209,0,0,64,209,0,0,32,209,0,0,8,209,0,0,192,208,0,0,160,208,0,0,40,208,0,0,112,207,0,0,40,207,0,0,56,206,0,0,16,206,0,0,248,205,0,0,216,205,0,0,192,205,0,0,152,219,0,0,96,219,0,0,48,219,0,0,152,218,0,0,224,217,0,0,152,217,0,0,64,217,0,0,208,216,0,0,176,216,0,0,144,216,0,0,120,216,0,0,88,216,0,0,40,216,0,0,232,215,0,0,56,215,0,0,0,215,0,0,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,29,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,240,191,0,0,2,0,0,0,184,217,0,0,3,0,0,0,200,192,0,0,4,0,0,0,80,178,0,0,5,0,0,0,200,164,0,0,6,0,0,0,240,152,0,0,7,0,0,0,112,141,0,0,8,0,0,0,240,129,0,0,9,0,0,0,128,123,0,0,10,0,0,0,168,119,0,0,11,0,0,0,232,225,0,0,12,0,0,0,160,222,0,0,13,0,0,0,24,218,0,0,14,0,0,0,144,215,0,0,14,0,0,0,176,212,0,0,15,0,0,0,32,210,0,0,15,0,0,0,168,207,0,0,16,0,0,0,48,204,0,0,17,0,0,0,224,201,0,0,17,0,0,0,240,199,0,0,18,0,0,0,0,198,0,0,19,0,0,0,208,196,0,0,20,0,0,0,24,193,0,0,21,0,0,0,112,191,0,0,22,0,0,0,248,189,0,0,23,0,0,0,56,188,0,0,24,0,0,0,224,186,0,0,25,0,0,0,176,185,0,0,26,0,0,0,144,184,0,0,27,0,0,0,128,183,0,0,28,0,0,0,80,182,0,0,28,0,0,0,56,181,0,0,29,0,0,0,144,178,0,0,29,0,0,0,64,177,0,0,30,0,0,0,248,175,0,0,31,0,0,0,144,174,0,0,32,0,0,0,56,173,0,0,33,0,0,0,32,172,0,0,34,0,0,0,0,171,0,0,35,0,0,0,24,170,0,0,36,0,0,0,128,168,0,0,37,0,0,0,136,167,0,0,38,0,0,0,240,164,0,0,39,0,0,0,184,163,0,0,40,0,0,0,40,162,0,0,41,0,0,0,232,160,0,0,42,0,0,0,248,159,0,0,42,0,0,0,32,159,0,0,43,0,0,0,40,158,0,0,43,0,0,0,40,157,0,0,44,0,0,0,48,156,0,0,45,0,0,0,64,155,0,0,46,0,0,0,24,153,0,0,47,0,0,0,232,151,0,0,48,0,0,0,144,150,0,0,49,0,0,0,136,149,0,0,50,0,0,0,96,148,0,0,51,0,0,0,112,147,0,0,52,0,0,0,96,146,0,0,53,0,0,0,120,145,0,0,54,0,0,0,128,144,0,0,55,0,0,0,144,143,0,0,55,0,0,0,136,141,0,0,56,0,0,0,120,140,0,0,56,0,0,0,40,139,0,0,56,0,0,0,24,138,0,0,57,0,0,0,232,136,0,0,57,0,0,0,248,135,0,0,58,0,0,0,8,135,0,0,58,0,0,0,200,133,0,0,59,0,0,0,176,132,0,0,59,0,0,0,216,131,0,0,60,0,0,0,16,130,0,0,61,0,0,0,176,128,0,0,62,0,0,0,120,127,0,0,63,0,0,0,240,126,0,0,64,0,0,0,56,126,0,0,66,0,0,0,192,125,0,0,65,0,0,0,72,125,0,0,67,0,0,0,16,125,0,0,67,0,0,0,160,124,0,0,68,0,0,0,112,124,0,0,68,0,0,0,144,123,0,0,69,0,0,0,16,123,0,0,69,0,0,0,120,122,0,0,71,0,0,0,40,122,0,0,71,0,0,0,232,121,0,0,73,0,0,0,192,121,0,0,73,0,0,0,152,121,0,0,72,0,0,0,104,121,0,0,72,0,0,0,8,121,0,0,72,0,0,0,176,120,0,0,74,0,0,0,184,119,0,0,75,0,0,0,80,119,0,0,75,0,0,0,224,118,0,0,76,0,0,0,176,118,0,0,77,0,0,0,128,118,0,0,78,0,0,0,64,118,0,0,79,0,0,0,240,117,0,0,79,0,0,0,168,117,0,0,79,0,0,0,248,226,0,0,80,0,0,0,192,226,0,0,81,0,0,0,248,225,0,0,82,0,0,0,136,225,0,0,83,0,0,0,32,225,0,0,84,0,0,0,232,224,0,0,85,0,0,0,192,224,0,0,86,0,0,0,144,224,0,0,87,0,0,0,88,224,0,0,88,0,0,0,40,224,0,0,89,0,0,0,232,223,0,0,90,0,0,0,168,223,0,0,91,0,0,0,176,222,0,0,92,0,0,0,72,222,0,0,93,0,0,0,200,221,0,0,94,0,0,0,40,221,0,0,95,0,0,0,200,220,0,0,96,0,0,0,32,220,0,0,97,0,0,0,176,219,0,0,98,0,0,0,128,219,0,0,99,0,0,0,56,219,0,0,100,0,0,0,240,218,0,0,101,0,0,0,40,218,0,0,102,0,0,0,176,217,0,0,103,0,0,0,96,217,0,0,104,0,0,0,232,216,0,0,105,0,0,0,184,216,0,0,106,0,0,0,152,216,0,0,107,0,0,0,128,216,0,0,108,0,0,0,96,216,0,0,109,0,0,0,56,216,0,0,110,0,0,0,0,216,0,0,111,0,0,0,168,215,0,0,112,0,0,0,24,215,0,0,113,0,0,0,208,214,0,0,114,0,0,0,160,214,0,0,115,0,0,0,120,214,0,0,116,0,0,0,80,214,0,0,117,0,0,0,0,214,0,0,118,0,0,0,216,213,0,0,119,0,0,0,160,213,0,0,120,0,0,0,104,213,0,0,121,0,0,0,192,212,0,0,122,0,0,0,72,212,0,0,123,0,0,0,224,211,0,0,124,0,0,0,176,211,0,0,0,0,0,0,0,0,0,0,86,0,0,0,115,0,0,0,87,0,0,0,62,0,0,0,88,0,0,0,116,0,0,0,90,0,0,0,59,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,60,0,0,0,93,0,0,0,119,0,0,0,94,0,0,0,61,0,0,0,95,0,0,0,121,0,0,0,97,0,0,0,114,0,0,0,98,0,0,0,117,0,0,0,96,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,89,0,0,0,87,0,0,0,91,0,0,0,88,0,0,0,92,0,0,0,90,0,0,0,86,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,88,0,0,0,93,0,0,0,83,0,0,0,94,0,0,0,84,0,0,0,95,0,0,0,85,0,0,0,97,0,0,0,82,0,0,0,98,0,0,0,65,0,0,0,96,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,53,0,0,0,2,0,0,0,122,0,0,0,3,0,0,0,120,0,0,0,4,0,0,0,99,0,0,0,5,0,0,0,118,0,0,0,6,0,0,0,96,0,0,0,7,0,0,0,97,0,0,0,8,0,0,0,98,0,0,0,9,0,0,0,100,0,0,0,10,0,0,0,101,0,0,0,11,0,0,0,109,0,0,0,12,0,0,0,103,0,0,0,13,0,0,0,111,0,0,0,17,0,0,0,50,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,23,0,0,0,22,0,0,0,24,0,0,0,26,0,0,0,25,0,0,0,28,0,0,0,26,0,0,0,25,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,27,0,0,0,29,0,0,0,24,0,0,0,30,0,0,0,51,0,0,0,31,0,0,0,48,0,0,0,32,0,0,0,12,0,0,0,33,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,35,0,0,0,15,0,0,0,36,0,0,0,17,0,0,0,37,0,0,0,16,0,0,0,38,0,0,0,32,0,0,0,39,0,0,0,34,0,0,0,40,0,0,0,31,0,0,0,41,0,0,0,35,0,0,0,42,0,0,0,33,0,0,0,43,0,0,0,30,0,0,0,57,0,0,0,42,0,0,0,45,0,0,0,57,0,0,0,46,0,0,0,0,0,0,0,47,0,0,0,1,0,0,0,48,0,0,0,2,0,0,0,49,0,0,0,3,0,0,0,50,0,0,0,5,0,0,0,51,0,0,0,4,0,0,0,52,0,0,0,38,0,0,0,53,0,0,0,40,0,0,0,54,0,0,0,37,0,0,0,55,0,0,0,41,0,0,0,56,0,0,0,39,0,0,0,44,0,0,0,36,0,0,0,58,0,0,0,56,0,0,0,60,0,0,0,6,0,0,0,61,0,0,0,7,0,0,0,62,0,0,0,8,0,0,0,63,0,0,0,9,0,0,0,64,0,0,0,11,0,0,0,66,0,0,0,45,0,0,0,65,0,0,0,46,0,0,0,67,0,0,0,43,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,44,0,0,0,70,0,0,0,56,0,0,0,71,0,0,0,54,0,0,0,72,0,0,0,58,0,0,0,74,0,0,0,58,0,0,0,75,0,0,0,55,0,0,0,76,0,0,0,49,0,0,0,77,0,0,0,55,0,0,0,81,0,0,0,54,0,0,0,99,0,0,0,114,0,0,0,100,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,102,0,0,0,117,0,0,0,103,0,0,0,119,0,0,0,104,0,0,0,121,0,0,0,105,0,0,0,62,0,0,0,106,0,0,0,59,0,0,0,108,0,0,0,60,0,0,0,107,0,0,0,61,0,0,0,82,0,0,0,71,0,0,0,83,0,0,0,75,0,0,0,84,0,0,0,67,0,0,0,86,0,0,0,89,0,0,0,87,0,0,0,91,0,0,0,88,0,0,0,92,0,0,0,85,0,0,0,78,0,0,0,90,0,0,0,86,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,88,0,0,0,89,0,0,0,69,0,0,0,93,0,0,0,83,0,0,0,94,0,0,0,84,0,0,0,95,0,0,0,85,0,0,0,96,0,0,0,76,0,0,0,97,0,0,0,82,0,0,0,98,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,1,0,0,0,58,4,0,0,2,0,0,0,59,4,0,0,3,0,0,0,60,4,0,0,4,0,0,0,61,4,0,0,5,0,0,0,62,4,0,0,6,0,0,0,63,4,0,0,7,0,0,0,64,4,0,0,8,0,0,0,65,4,0,0,9,0,0,0,66,4,0,0,10,0,0,0,67,4,0,0,11,0,0,0,68,4,0,0,12,0,0,0,69,4,0,0,13,0,0,0,70,4,0,0,14,0,0,0,71,4,0,0,15,0,0,0,72,4,0,0,16,0,0,0,96,0,0,0,17,0,0,0,49,0,0,0,18,0,0,0,50,0,0,0,19,0,0,0,51,0,0,0,20,0,0,0,52,0,0,0,21,0,0,0,53,0,0,0,22,0,0,0,54,0,0,0,23,0,0,0,55,0,0,0,24,0,0,0,56,0,0,0,25,0,0,0,57,0,0,0,26,0,0,0,48,0,0,0,27,0,0,0,45,0,0,0,28,0,0,0,61,0,0,0,29,0,0,0,187,0,0,0,29,0,0,0,8,0,0,0,30,0,0,0,9,0,0,0,31,0,0,0,113,0,0,0,32,0,0,0,119,0,0,0,33,0,0,0,101,0,0,0,34,0,0,0,114,0,0,0,35,0,0,0,116,0,0,0,36,0,0,0].concat([121,0,0,0,37,0,0,0,117,0,0,0,38,0,0,0,105,0,0,0,39,0,0,0,111,0,0,0,40,0,0,0,112,0,0,0,41,0,0,0,91,0,0,0,42,0,0,0,93,0,0,0,43,0,0,0,13,0,0,0,44,0,0,0,57,4,0,0,45,0,0,0,97,0,0,0,46,0,0,0,115,0,0,0,47,0,0,0,100,0,0,0,48,0,0,0,102,0,0,0,49,0,0,0,103,0,0,0,50,0,0,0,104,0,0,0,51,0,0,0,106,0,0,0,52,0,0,0,107,0,0,0,53,0,0,0,108,0,0,0,54,0,0,0,59,0,0,0,55,0,0,0,186,0,0,0,55,0,0,0,39,0,0,0,56,0,0,0,92,0,0,0,57,0,0,0,220,0,0,0,57,0,0,0,225,4,0,0,58,0,0,0,60,0,0,0,59,0,0,0,122,0,0,0,60,0,0,0,120,0,0,0,61,0,0,0,99,0,0,0,62,0,0,0,118,0,0,0,63,0,0,0,98,0,0,0,64,0,0,0,110,0,0,0,66,0,0,0,109,0,0,0,65,0,0,0,44,0,0,0,67,0,0,0,46,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,229,4,0,0,70,0,0,0,224,4,0,0,71,0,0,0,227,4,0,0,73,0,0,0,227,4,0,0,72,0,0,0,226,4,0,0,75,0,0,0,1,5,0,0,74,0,0,0,32,0,0,0,76,0,0,0,230,4,0,0,77,0,0,0,231,4,0,0,78,0,0,0,231,4,0,0,79,0,0,0,118,4,0,0,80,0,0,0,228,4,0,0,81,0,0,0,83,4,0,0,82,0,0,0,84,4,0,0,83,0,0,0,85,4,0,0,84,0,0,0,86,4,0,0,85,0,0,0,95,4,0,0,86,0,0,0,96,4,0,0,87,0,0,0,97,4,0,0,88,0,0,0,87,4,0,0,89,0,0,0,92,4,0,0,90,0,0,0,93,4,0,0,91,0,0,0,94,4,0,0,92,0,0,0,89,4,0,0,93,0,0,0,90,4,0,0,94,0,0,0,91,4,0,0,95,0,0,0,88,4,0,0,96,0,0,0,98,4,0,0,97,0,0,0,99,4,0,0,98,0,0,0,73,4,0,0,99,0,0,0,74,4,0,0,100,0,0,0,75,4,0,0,101,0,0,0,127,0,0,0,102,0,0,0,77,4,0,0,103,0,0,0,78,4,0,0,104,0,0,0,82,4,0,0,105,0,0,0,80,4,0,0,106,0,0,0,81,4,0,0,107,0,0,0,79,4,0,0,108,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,101,0,0,0,0,0,0,0,1,0,229,0,0,0,0,0,0,0,18,0,0,0,1,0,37,0,0,0,0,0,0,0,1,0,165,0,0,0,0,0,0,0,19,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,20,0,0,0,1,0,41,0,0,0,0,0,0,0,1,0,169,0,0,0,0,0,0,0,21,0,0,0,1,0,43,0,0,0,0,0,0,0,1,0,171,0,0,0,0,0,0,0,22,0,0,0,1,0,47,0,0,0,0,0,0,0,1,0,175,0,0,0,0,0,0,0,23,0,0,0,1,0,45,0,0,0,0,0,0,0,1,0,173,0,0,0,0,0,0,0,24,0,0,0,1,0,53,0,0,0,0,0,0,0,1,0,181,0,0,0,0,0,0,0,25,0,0,0,1,0,57,0,0,0,0,0,0,0,1,0,185,0,0,0,0,0,0,0,26,0,0,0,1,0,51,0,0,0,0,0,0,0,1,0,179,0,0,0,0,0,0,0,27,0,0,0,1,0,59,0,0,0,0,0,0,0,1,0,187,0,0,0,0,0,0,0,28,0,0,0,1,0,55,0,0,0,0,0,0,0,1,0,183,0,0,0,0,0,0,0,29,0,0,0,1,0,49,0,0,0,0,0,0,0,1,0,177,0,0,0,0,0,0,0,30,0,0,0,1,0,103,0,0,0,0,0,0,0,1,0,231,0,0,0,0,0,0,0,31,0,0,0,1,0,97,0,0,0,0,0,0,0,1,0,225,0,0,0,0,0,0,0,32,0,0,0,1,0,25,0,0,0,0,0,0,0,1,0,153,0,0,0,0,0,0,0,33,0,0,0,1,0,27,0,0,0,0,0,0,0,1,0,155,0,0,0,0,0,0,0,34,0,0,0,1,0,29,0,0,0,0,0,0,0,1,0,157,0,0,0,0,0,0,0,35,0,0,0,1,0,31,0,0,0,0,0,0,0,1,0,159,0,0,0,0,0,0,0,36,0,0,0,1,0,35,0,0,0,0,0,0,0,1,0,163,0,0,0,0,0,0,0,37,0,0,0,1,0,33,0,0,0,0,0,0,0,1,0,161,0,0,0,0,0,0,0,38,0,0,0,1,0,65,0,0,0,0,0,0,0,1,0,193,0,0,0,0,0,0,0,39,0,0,0,1,0,69,0,0,0,0,0,0,0,1,0,197,0,0,0,0,0,0,0,40,0,0,0,1,0,63,0,0,0,0,0,0,0,1,0,191,0,0,0,0,0,0,0,41,0,0,0,1,0,71,0,0,0,0,0,0,0,1,0,199,0,0,0,0,0,0,0,42,0,0,0,1,0,67,0,0,0,0,0,0,0,1,0,195,0,0,0,0,0,0,0,43,0,0,0,1,0,61,0,0,0,0,0,0,0,1,0,189,0,0,0,0,0,0,0,57,0,0,0,1,0,85,0,0,0,0,0,0,0,1,0,213,0,0,0,0,0,0,0,44,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,45,0,0,0,1,0,115,0,0,0,0,0,0,0,1,0,243,0,0,0,0,0,0,0,46,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,129,0,0,0,0,0,0,0,47,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,131,0,0,0,0,0,0,0,48,0,0,0,1,0,5,0,0,0,0,0,0,0,1,0,133,0,0,0,0,0,0,0,49,0,0,0,1,0,7,0,0,0,0,0,0,0,1,0,135,0,0,0,0,0,0,0,50,0,0,0,1,0,11,0,0,0,0,0,0,0,1,0,139,0,0,0,0,0,0,0,51,0,0,0,1,0,9,0,0,0,0,0,0,0,1,0,137,0,0,0,0,0,0,0,52,0,0,0,1,0,77,0,0,0,0,0,0,0,1,0,205,0,0,0,0,0,0,0,53,0,0,0,1,0,81,0,0,0,0,0,0,0,1,0,209,0,0,0,0,0,0,0,54,0,0,0,1,0,75,0,0,0,0,0,0,0,1,0,203,0,0,0,0,0,0,0,55,0,0,0,1,0,83,0,0,0,0,0,0,0,1,0,211,0,0,0,0,0,0,0,56,0,0,0,1,0,79,0,0,0,0,0,0,0,1,0,207,0,0,0,0,0,0,0,58,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,70,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,60,0,0,0,1,0,13,0,0,0,0,0,0,0,1,0,141,0,0,0,0,0,0,0,61,0,0,0,1,0,15,0,0,0,0,0,0,0,1,0,143,0,0,0,0,0,0,0,62,0,0,0,1,0,17,0,0,0,0,0,0,0,1,0,145,0,0,0,0,0,0,0,63,0,0,0,1,0,19,0,0,0,0,0,0,0,1,0,147,0,0,0,0,0,0,0,64,0,0,0,1,0,23,0,0,0,0,0,0,0,1,0,151,0,0,0,0,0,0,0,66,0,0,0,1,0,91,0,0,0,0,0,0,0,1,0,219,0,0,0,0,0,0,0,65,0,0,0,1,0,93,0,0,0,0,0,0,0,1,0,221,0,0,0,0,0,0,0,67,0,0,0,1,0,87,0,0,0,0,0,0,0,1,0,215,0,0,0,0,0,0,0,68,0,0,0,1,0,95,0,0,0,0,0,0,0,1,0,223,0,0,0,0,0,0,0,69,0,0,0,1,0,89,0,0,0,0,0,0,0,1,0,217,0,0,0,0,0,0,0,71,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,81,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,75,0,0,0,1,0,111,0,0,0,0,0,0,0,1,0,239,0,0,0,0,0,0,0,77,0,0,0,1,0,105,0,0,0,0,0,0,0,1,0,233,0,0,0,0,0,0,0,76,0,0,0,1,0,99,0,0,0,0,0,0,0,1,0,227,0,0,0,0,0,0,0,82,0,0,0,2,0,121,15,0,0,0,0,0,0,2,0,121,143,0,0,0,0,0,0,83,0,0,0,3,0,113,121,27,0,0,0,0,0,3,0,121,155,241,0,0,0,0,0,84,0,0,0,3,0,113,121,5,0,0,0,0,0,3,0,121,133,241,0,0,0,0,0,85,0,0,0,2,0,121,29,0,0,0,0,0,0,2,0,121,157,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,89,0,0,0,3,0,113,121,13,0,0,0,0,0,3,0,121,141,241,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,101,0,0,0,0,0,0,0,1,0,229,0,0,0,0,0,0,0,18,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,19,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,20,0,0,0,1,0,41,0,0,0,0,0,0,0,1,0,169,0,0,0,0,0,0,0,21,0,0,0,1,0,43,0,0,0,0,0,0,0,1,0,171,0,0,0,0,0,0,0,22,0,0,0,1,0,47,0,0,0,0,0,0,0,1,0,175,0,0,0,0,0,0,0,23,0,0,0,1,0,45,0,0,0,0,0,0,0,1,0,173,0,0,0,0,0,0,0,24,0,0,0,1,0,53,0,0,0,0,0,0,0,1,0,181,0,0,0,0,0,0,0,25,0,0,0,1,0,57,0,0,0,0,0,0,0,1,0,185,0,0,0,0,0,0,0,26,0,0,0,1,0,51,0,0,0,0,0,0,0,1,0,179,0,0,0,0,0,0,0,27,0,0,0,1,0,59,0,0,0,0,0,0,0,1,0,187,0,0,0,0,0,0,0,28,0,0,0,1,0,55,0,0,0,0,0,0,0,1,0,183,0,0,0,0,0,0,0,29,0,0,0,1,0,49,0,0,0,0,0,0,0,1,0,177,0,0,0,0,0,0,0,30,0,0,0,1,0,103,0,0,0,0,0,0,0,1,0,231,0,0,0,0,0,0,0,31,0,0,0,1,0,97,0,0,0,0,0,0,0,1,0,225,0,0,0,0,0,0,0,32,0,0,0,1,0,25,0,0,0,0,0,0,0,1,0,153,0,0,0,0,0,0,0,33,0,0,0,1,0,27,0,0,0,0,0,0,0,1,0,155,0,0,0,0,0,0,0,34,0,0,0,1,0,29,0,0,0,0,0,0,0,1,0,157,0,0,0,0,0,0,0,35,0,0,0,1,0,31,0,0,0,0,0,0,0,1,0,159,0,0,0,0,0,0,0,36,0,0,0,1,0,35,0,0,0,0,0,0,0,1,0,163,0,0,0,0,0,0,0,37,0,0,0,1,0,33,0,0,0,0,0,0,0,1,0,161,0,0,0,0,0,0,0,38,0,0,0,1,0,65,0,0,0,0,0,0,0,1,0,193,0,0,0,0,0,0,0,39,0,0,0,1,0,69,0,0,0,0,0,0,0,1,0,197,0,0,0,0,0,0,0,40,0,0,0,1,0,63,0,0,0,0,0,0,0,1,0,191,0,0,0,0,0,0,0,41,0,0,0,1,0,71,0,0,0,0,0,0,0,1,0,199,0,0,0,0,0,0,0,42,0,0,0,1,0,67,0,0,0,0,0,0,0,1,0,195,0,0,0,0,0,0,0,43,0,0,0,1,0,61,0,0,0,0,0,0,0,1,0,189,0,0,0,0,0,0,0,44,0,0,0,1,0,85,0,0,0,0,0,0,0,1,0,213,0,0,0,0,0,0,0,45,0,0,0,1,0,115,0,0,0,0,0,0,0,1,0,243,0,0,0,0,0,0,0,46,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,129,0,0,0,0,0,0,0,47,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,131,0,0,0,0,0,0,0,48,0,0,0,1,0,5,0,0,0,0,0,0,0,1,0,133,0,0,0,0,0,0,0,49,0,0,0,1,0,7,0,0,0,0,0,0,0,1,0,135,0,0,0,0,0,0,0,50,0,0,0,1,0,11,0,0,0,0,0,0,0,1,0,139,0,0,0,0,0,0,0,51,0,0,0,1,0,9,0,0,0,0,0,0,0,1,0,137,0,0,0,0,0,0,0,52,0,0,0,1,0,77,0,0,0,0,0,0,0,1,0,205,0,0,0,0,0,0,0,53,0,0,0,1,0,81,0,0,0,0,0,0,0,1,0,209,0,0,0,0,0,0,0,54,0,0,0,1,0,75,0,0,0,0,0,0,0,1,0,203,0,0,0,0,0,0,0,55,0,0,0,1,0,83,0,0,0,0,0,0,0,1,0,211,0,0,0,0,0,0,0,56,0,0,0,1,0,79,0,0,0,0,0,0,0,1,0,207,0,0,0,0,0,0,0,57,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,58,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,70,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,59,0,0,0,1,0,13,0,0,0,0,0,0,0,1,0,141,0,0,0,0,0,0,0,60,0,0,0,1,0,15,0,0,0,0,0,0,0,1,0,143,0,0,0,0,0,0,0,61,0,0,0,1,0,17,0,0,0,0,0,0,0,1,0,145,0,0,0,0,0,0,0,62,0,0,0,1,0,19,0,0,0,0,0,0,0,1,0,147,0,0,0,0,0,0,0,63,0,0,0,1,0,23,0,0,0,0,0,0,0,1,0,151,0,0,0,0,0,0,0,64,0,0,0,1,0,91,0,0,0,0,0,0,0,1,0,219,0,0,0,0,0,0,0,66,0,0,0,1,0,93,0,0,0,0,0,0,0,1,0,221,0,0,0,0,0,0,0,65,0,0,0,1,0,87,0,0,0,0,0,0,0,1,0,215,0,0,0,0,0,0,0,67,0,0,0,1,0,95,0,0,0,0,0,0,0,1,0,223,0,0,0,0,0,0,0,68,0,0,0,1,0,89,0,0,0,0,0,0,0,1,0,217,0,0,0,0,0,0,0,69,0,0,0,1,0,21,0,0,0,0,0,0,0,1,0,149,0,0,0,0,0,0,0,71,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,81,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,75,0,0,0,1,0,111,0,0,0,0,0,0,0,1,0,239,0,0,0,0,0,0,0,77,0,0,0,1,0,99,0,0,0,0,0,0,0,1,0,227,0,0,0,0,0,0,0,76,0,0,0,1,0,105,0,0,0,0,0,0,0,1,0,233,0,0,0,0,0,0,0,82,0,0,0,2,0,121,15,0,0,0,0,0,0,2,0,121,143,0,0,0,0,0,0,83,0,0,0,3,0,113,121,27,0,0,0,0,0,3,0,121,155,241,0,0,0,0,0,84,0,0,0,3,0,113,121,5,0,0,0,0,0,3,0,121,133,241,0,0,0,0,0,85,0,0,0,2,0,121,29,0,0,0,0,0,0,2,0,121,157,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,89,0,0,0,3,0,113,121,13,0,0,0,0,0,3,0,121,141,241,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,229,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,87,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,88,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,90,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,91,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,92,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,93,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,94,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,95,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,97,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,98,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,96,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,100,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,105,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,101,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,106,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,108,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,103,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,107,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,104,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,99,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,102,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,41,1,0,14,17,1,0,52,248,0,0,102,223,0,0,150,198,0,0,0,0,0,0,230,41,1,0,14,17,1,0,52,248,0,0,102,223,0,0,150,198,0,0,0,0,0,0,150,151,154,155,157,158,159,166,167,171,172,173,174,175,178,179,180,181,182,183,185,186,187,188,189,190,191,203,205,206,207,211,214,215,217,218,219,220,221,222,223,229,230,231,233,234,235,236,237,238,239,242,243,244,245,246,247,249,250,251,252,253,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,255,255,2,3,255,4,5,6,255,255,255,255,255,255,7,8,255,255,255,9,10,11,12,13,255,255,14,15,16,17,18,19,255,20,21,22,23,24,25,26,255,255,255,255,255,255,255,255,255,255,255,27,255,28,29,30,255,255,255,31,255,255,32,33,255,34,35,36,37,38,39,40,255,255,255,255,255,41,42,43,255,44,45,46,47,48,49,50,255,255,51,52,53,54,55,56,255,57,58,59,60,61,62,63,242,1,0,0,190,1,0,0,246,1,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,200,0,0,0,96,0,0,0,46,0,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,236,1,0,0,180,1,0,0,126,0,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,62,1,0,0,126,1,0,0,178,1,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,86,0,0,0,152,0,0,0,234,1,0,0,34,1,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,210,1,0,0,242,0,0,0,166,1,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,100,0,0,0,50,0,0,0,4,2,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,194,1,0,0,252,1,0,0,36,1,0,0,0,0,0,0,186,0,0,0,110,0,0,0,16,0,0,0,32,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,0,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,160,0,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,90,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,22,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,134,0,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,152,1,0,0,12,0,0,0,174,1,0,0,120,0,0,0,54,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,56,1,0,0,120,1,0,0,212,1,0,0,104,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,132,1,0,0,74,0,0,0,254,1,0,0,176,1,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,194,0,0,0,128,0,0,0,42,0,0,0,66,1,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,250,0,0,0,176,0,0,0,98,0,0,0,82,1,0,0,0,0,0,0,0,0,0,0,208,0,0,0,244,1,0,0,24,0,0,0,102,0,0,0,40,1,0,0,248,1,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,0,0,0,0,0,0,0,0,6,2,0,0,138,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,0,0,0,0,84,1,0,0,28,0,0,0,92,1,0,0,0,0,0,0,0,0,0,0,208,0,0,0,26,1,0,0,68,1,0,0,252,0,0,0,88,0,0,0,60,0,0,0,218,1,0,0,192,1,0,0,78,1,0,0,148,0,0,0,68,1,0,0,252,0,0,0,88,0,0,0,94,1,0,0,218,1,0,0,192,1,0,0,78,1,0,0,48,0,0,0,68,1,0,0,252,0,0,0,88,0,0,0,204,0,0,0,218,1,0,0,192,1,0,0,78,1,0,0,52,1,0,0,68,1,0,0,252,0,0,0,88,0,0,0,182,0,0,0,218,1,0,0,192,1,0,0,78,1,0,0,172,1,0,0,68,1,0,0,252,0,0,0,88,0,0,0,106,1,0,0,218,1,0,0,192,1,0,0,78,1,0,0,136,1,0,0,68,1,0,0,252,0,0,0,88,0,0,0,84,0,0,0,218,1,0,0,192,1,0,0,78,1,0,0,234,0,0,0,68,1,0,0,252,0,0,0,88,0,0,0,202,0,0,0,218,1,0,0,192,1,0,0,78,1,0,0,116,0,0,0,68,1,0,0,252,0,0,0,88,0,0,0,238,0,0,0,218,1,0,0,192,1,0,0,78,1,0,0,142,1,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,46,1,0,0,46,1,0,0,46,1,0,0,46,1,0,0,118,0,0,0,118,0,0,0,118,0,0,0,118,0,0,0,224,1,0,0,224,1,0,0,224,1,0,0,224,1,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,186,1,0,0,186,1,0,0,186,1,0,0,186,1,0,0,30,1,0,0,30,1,0,0,30,1,0,0,30,1,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,240,0,0,0,68,0,0,0,68,0,0,0,68,0,0,0,68,0,0,0,254,0,0,0,254,0,0,0,254,0,0,0,254,0,0,0,64,1,0,0,64,1,0,0,64,1,0,0,64,1,0,0,130,0,0,0,130,0,0,0,130,0,0,0,130,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,162,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,6,1,0,0,80,1,0,0,114,0,0,0,154,1,0,0,182,1,0,0,26,0,0,0,232,1,0,0,220,1,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,196,1,0,0,94,0,0,0,44,0,0,0,244,0,0,0,78,0,0,0,140,0,0,0,226,0,0,0,212,0,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,128,1,0,0,188,1,0,0,250,1,0,0,228,1,0,0,224,0,0,0,20,1,0,0,230,1,0,0,62,0,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,150,0,0,0,228,0,0,0,30,0,0,0,170,1,0,0,162,1,0,0,8,1,0,0,202,1,0,0,216,1,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,118,1,0,0,58,1,0,0,14,0,0,0,34,0,0,0,210,0,0,0,48,1,0,0,174,0,0,0,64,0,0,0,184,0,0,0,106,0,0,0,20,0,0,0,40,0,0,0,36,0,0,0,4,1,0,0,190,0,0,0,214,1,0,0,184,0,0,0,106,0,0,0,20,0,0,0,24,1,0,0,36,0,0,0,4,1,0,0,190,0,0,0,52,0,0,0,184,0,0,0,106,0,0,0,20,0,0,0,172,0,0,0,36,0,0,0,4,1,0,0,190,0,0,0,76,0,0,0,184,0,0,0,106,0,0,0,20,0,0,0,184,1,0,0,36,0,0,0,4,1,0,0,190,0,0,0,32,1,0,0,184,0,0,0,106,0,0,0,20,0,0,0,0,0,0,0,36,0,0,0,4,1,0,0,190,0,0,0,0,0,0,0,184,0,0,0,106,0,0,0,20,0,0,0,0,0,0,0,36,0,0,0,4,1,0,0,190,0,0,0,0,0,0,0,184,0,0,0,106,0,0,0,20,0,0,0,0,0,0,0,36,0,0,0,4,1,0,0,190,0,0,0,0,0,0,0,184,0,0,0,106,0,0,0,20,0,0,0,0,0,0,0,36,0,0,0,4,1,0,0,190,0,0,0,0,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0])
.concat([18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,56,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,22,0,0,0,24,0,0,0,24,0,0,0,24,0,0,0,24,0,0,0,24,0,0,0,24,0,0,0,24,0,0,0,46,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,32,0,0,0,30,0,0,0,58,0,0,0,60,0,0,0,16,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,10,0,0,0,230,0,0,0,192,0,0,0,88,0,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,30,0,0,0,106,0,0,0,16,1,0,0,20,1,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,14,0,0,0,50,0,0,0,100,0,0,0,182,0,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,146,0,0,0,102,0,0,0,250,0,0,0,110,0,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,96,0,0,0,40,0,0,0,180,0,0,0,10,1,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,234,0,0,0,196,0,0,0,140,0,0,0,110,0,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,12,0,0,0,52,1,0,0,92,0,0,0,110,0,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,46,1,0,0,16,0,0,0,54,0,0,0,80,1,0,0,186,0,0,0,130,0,0,0,72,0,0,0,18,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,114,0,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,144,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,50,1,0,0,28,0,0,0,242,0,0,0,74,0,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,120,0,0,0,60,0,0,0,20,0,0,0,154,0,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,228,0,0,0,188,0,0,0,74,1,0,0,72,1,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,24,0,0,0,66,0,0,0,22,1,0,0,56,0,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,166,0,0,0,214,0,0,0,4,1,0,0,64,1,0,0,110,0,0,0,110,0,0,0,126,0,0,0,48,1,0,0,156,0,0,0,210,0,0,0,84,0,0,0,62,0,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,28,1,0,0,68,1,0,0,134,0,0,0,6,1,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,110,0,0,0,22,0,0,0,172,0,0,0,80,1,0,0,110,0,0,0,110,0,0,0,126,0,0,0,136,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,174,0,0,0,218,0,0,0,24,1,0,0,68,0,0,0,56,1,0,0,254,0,0,0,208,0,0,0,68,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,8,0,0,0,90,0,0,0,78,1,0,0,34,0,0,0,112,0,0,0,80,0,0,0,224,0,0,0,14,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,30,1,0,0,32,0,0,0,6,0,0,0,48,0,0,0,200,0,0,0,12,1,0,0,108,0,0,0,2,1,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,58,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,244,0,0,0,60,1,0,0,26,0,0,0,236,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,152,0,0,0,202,0,0,0,66,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,104,0,0,0,148,0,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,248,0,0,0,26,1,0,0,150,0,0,0,38,0,0,0,122,0,0,0,176,0,0,0,36,0,0,0,62,1,0,0,94,0,0,0,124,0,0,0,178,0,0,0,52,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,8,1,0,0,94,0,0,0,124,0,0,0,178,0,0,0,220,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,170,0,0,0,94,0,0,0,124,0,0,0,178,0,0,0,158,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,164,0,0,0,94,0,0,0,124,0,0,0,178,0,0,0,138,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,76,0,0,0,94,0,0,0,124,0,0,0,178,0,0,0,78,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,86,0,0,0,94,0,0,0,124,0,0,0,178,0,0,0,58,1,0,0,212,0,0,0,162,0,0,0,116,0,0,0,44,0,0,0,94,0,0,0,124,0,0,0,178,0,0,0,226,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,110,0,0,0,94,0,0,0,124,0,0,0,178,0,0,0,216,0,0,0,212,0,0,0,162,0,0,0,116,0,0,0,198,0,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,0,0,0,198,1,0,0,214,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,1,0,0,164,1,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,72,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,42,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,226,1,0,0,70,0,0,0,70,0,0,0,70,0,0,0,70,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,180,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,54,1,0,0,54,1,0,0,54,1,0,0,54,1,0,0,146,0,0,0,146,0,0,0,146,0,0,0,146,0,0,0,18,1,0,0,18,1,0,0,18,1,0,0,18,1,0,0,158,1,0,0,158,1,0,0,158,1,0,0,158,1,0,0,72,0,0,0,72,0,0,0,72,0,0,0,72,0,0,0,86,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,138,1,0,0,138,1,0,0,138,1,0,0,138,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,194,0,0,2,0,0,0,216,179,0,0,2,0,0,0,96,166,0,0,8,0,0,0,0,0,0,0,0,0,0,0,224,213,0,0,16,0,0,0,224,221,0,0,14,0,0,0,112,196,0,0,10,0,0,0,224,180,0,0,10,0,0,0,8,167,0,0,12,0,0,0,240,154,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,80,0,0,0,1,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,160,5,0,80,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,178,5,0,81,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,196,5,0,82,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,214,5,0,83,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,64,6,0,80,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,84,6,0,81,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,104,6,0,82,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,124,6,0,83,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,224,6,0,80,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,246,6,0,81,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,12,7,0,82,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,34,7,0,83,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,0,10,0,80,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,64,11,0,80,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,100,11,0,81,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,136,11,0,82,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,172,11,0,83,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,128,12,0,80,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,168,12,0,81,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,208,12,0,82,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,248,12,0,83,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,192,13,0,80,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,236,13,0,81,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,24,14,0,82,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,68,14,0,83,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,2,0,40,0,0,0,1,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,208,2,0,40,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,5,0,40,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,160,5,0,40,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,10,0,80,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,64,11,0,80,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,128,12,0,80,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,192,18,0,80,0,0,0,2,0,0,0,15,0,0,0,0,2,0,0,2,128,0,0,0,128,22,0,80,0,0,0,2,0,0,0,18,0,0,0,0,2,0,0,2,128,0,0,0,0,45,0,80,0,0,0,2,0,0,0,36,0,0,0,0,2,0,0,2,128,0,0,0,64,19,0,77,0,0,0,2,0,0,0,8,0,0,0,0,4,0,0,2,128,0,0,0,233,3,0,77,0,0,0,1,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,210,7,0,77,0,0,0,2,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,85,83,69,0,0,0,0,67,77,80,46,76,0,0,0,83,116,97,99,107,83,112,97,99,101,0,0,0,0,0,0,83,116,97,114,116,82,105,103,104,116,0,0,0,0,0,0,110,111,110,101,0,0,0,0,42,42,42,32,82,65,77,32,110,111,116,32,102,111,117,110,100,32,97,116,32,48,48,48,48,48,48,10,0,0,0,0,67,77,80,65,46,87,0,0,77,111,118,101,72,72,105,0,83,117,112,101,114,82,105,103,104,116,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,99,112,117,32,109,111,100,101,108,32,40,37,115,41,10,0,0,0,0,0,69,79,82,46,66,0,0,0,77,97,120,65,112,112,108,90,111,110,101,0,0,0,0,0,45,40,65,37,117,41,0,0,77,101,116,97,82,105,103,104,116,0,0,0,0,0,0,0,109,111,100,101,108,61,37,115,32,115,112,101,101,100,61,37,100,10,0,0,0,0,0,0,67,77,80,77,46,66,0,0,80,117,114,103,101,83,112,97,99,101,0,0,0,0,0,0,65,108,116,82,105,103,104,116,0,0,0,0,0,0,0,0,67,80,85,58,0,0,0,0,69,79,82,46,87,0,0,0,77,97,120,66,108,111,99,107,0,0,0,0,0,0,0,0,83,112,97,99,101,0,0,0,115,112,101,101,100,0,0,0,67,77,80,77,46,87,0,0,72,70,83,68,105,115,112,97,116,99,104,0,0,0,0,0,68,101,108,101,116,101,0,0,65,108,116,0,0,0,0,0,99,112,117,0,0,0,0,0,115,111,110,121,58,32,99,104,115,32,101,114,114,111,114,32,40,98,108,107,61,37,108,117,44,32,108,98,97,61,37,108,117,41,10,0,0,0,0,0,69,79,82,46,76,0,0,0,78,77,82,101,109,111,118,101,0,0,0,0,0,0,0,0,115,99,115,105,58,32,114,101,97,100,32,101,114,114,111,114,32,97,116,32,37,108,117,32,43,32,37,108,117,10,0,0,65,108,116,76,101,102,116,0,97,108,116,101,114,110,97,116,101,32,115,111,117,110,100,32,98,117,102,102,101,114,10,0,67,77,80,77,46,76,0,0,101,109,117,46,105,119,109,46,114,111,0,0,0,0,0,0,78,77,73,110,115,116,97,108,108,0,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,70,57,0,0,0,0,0,0,33,61,0,0,0,0,0,0,77,111,100,101,0,0,0,0,123,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,109,97,105,110,32,115,111,117,110,100,32,98,117,102,102,101,114,10,0,0,0,0,0,0,98,105,110,0,0,0,0,0,109,111,117,115,101,95,109,117,108,95,120,0,0,0,0,0,34,10,0,0,0,0,0,0])
.concat([97,100,100,114,61,48,120,37,48,56,108,120,32,115,105,122,101,61,37,108,117,32,102,105,108,101,61,37,115,10,0,0,104,0,0,0,0,0,0,0,45,45,37,115,0,0,0,0,67,77,80,65,46,76,0,0,101,120,112,101,99,116,105,110,103,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,116,100,48,58,32,100,114,111,112,112,105,110,103,32,112,104,97,110,116,111,109,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,10,0,0,82,101,108,101,97,115,101,32,51,46,48,55,36,48,0,0,83,119,97,112,77,77,85,77,111,100,101,0,0,0,0,0,46,114,97,119,0,0,0,0,79,0,0,0,0,0,0,0,87,105,110,100,111,119,115,76,101,102,116,0,0,0,0,0,97,108,116,101,114,110,97,116,101,32,118,105,100,101,111,32,98,117,102,102,101,114,10,0,118,105,100,101,111,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,77,85,76,85,46,87,0,0,77,101,109,111,114,121,68,105,115,112,97,116,99,104,0,0,83,116,97,114,116,76,101,102,116,0,0,0,0,0,0,0,109,97,105,110,32,118,105,100,101,111,32,98,117,102,102,101,114,10,0,0,0,0,0,0,103,0,0,0,0,0,0,0,82,83,69,84,0,0,0,0,115,112,101,101,100,58,32,37,117,10,0,0,0,0,0,0,65,78,68,46,66,0,0,0,80,111,119,101,114,79,102,102,0,0,0,0,0,0,0,0,83,117,112,101,114,76,101,102,116,0,0,0,0,0,0,0,86,73,65,58,0,0,0,0,65,66,67,68,46,66,0,0,80,114,105,109,101,84,105,109,101,0,0,0,0,0,0,0,77,101,116,97,0,0,0,0,118,105,97,0,0,0,0,0,65,78,68,46,87,0,0,0,82,109,118,84,105,109,101,0,40,65,37,117,41,43,0,0,77,101,116,97,76,101,102,116,0,0,0,0,0,0,0,0,83,67,67,58,0,0,0,0,65,78,68,46,76,0,0,0,73,110,115,84,105,109,101,0,67,116,114,108,0,0,0,0,115,99,99,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,99,101,32,107,101,121,58,32,37,48,52,120,32,40,37,115,41,10,0,0,0,0,83,101,116,65,112,112,66,97,115,101,0,0,0,0,0,0,67,116,114,108,76,101,102,116,0,0,0,0,0,0,0,0,42,42,42,32,99,97,110,39,116,32,111,112,101,110,32,100,114,105,118,101,114,32,40,37,115,41,10,0,0,0,0,0,77,85,76,83,46,87,0,0,76,111,119,101,114,84,101,120,116,0,0,0,0,0,0,0,67,114,101,97,116,101,0,0,47,0,0,0,0,0,0,0,42,42,42,32,98,97,100,32,112,111,114,116,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,0,105,119,109,58,32,100,114,105,118,101,32,37,117,32,101,106,101,99,116,10,0,0,0,0,115,111,110,121,58,32,119,114,105,116,101,32,101,114,114,111,114,32,97,116,32,37,117,47,37,117,47,37,117,10,0,0,65,68,68,65,46,87,0,0,83,116,114,105,112,65,100,100,114,101,115,115,0,0,0,0,115,99,115,105,58,32,116,111,111,32,109,97,110,121,32,98,108,111,99,107,115,32,40,37,117,41,10,0,0,0,0,0,83,108,97,115,104,0,0,0,112,111,114,116,61,37,117,32,109,117,108,116,105,99,104,97,114,61,37,117,32,100,114,105,118,101,114,61,37,115,10,0,65,68,68,46,66,0,0,0,101,109,117,46,100,105,115,107,46,114,119,0,0,0,0,0,115,100,108,58,32,98,108,105,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,85,112,114,83,116,114,105,110,103,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,70,56,0,0,0,0,0,0,61,61,0,0,0,0,0,0,46,0,0,0,0,0,0,0,115,101,99,116,105,111,110,0,102,0,0,0,0,0,0,0,83,69,82,73,65,76,58,0,115,114,101,99,0,0,0,0,115,99,97,108,101,0,0,0,99,112,117,46,109,111,100,101,108,32,61,32,34,0,0,0,82,65,77,58,0,0,0,0,99,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,65,68,68,88,46,66,0,0,101,120,112,101,99,116,105,110,103,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,37,48,50,88,32,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,0,82,101,108,101,97,115,101,32,51,46,48,50,36,48,0,0,46,112,115,105,0,0,0,0,87,114,105,116,101,88,80,114,97,109,0,0,0,0,0,0,78,0,0,0,0,0,0,0,80,101,114,105,111,100,0,0,109,117,108,116,105,99,104,97,114,0,0,0,0,0,0,0,65,68,68,46,87,0,0,0,82,101,97,100,88,80,114,97,109,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,112,111,114,116,0,0,0,0,114,117,110,32,117,110,116,105,108,32,101,120,99,101,112,116,105,111,110,0,0,0,0,0,115,115,112,0,0,0,0,0,65,68,68,88,46,87,0,0,115,121,115,116,101,109,32,116,111,111,32,115,108,111,119,44,32,115,107,105,112,112,105,110,103,32,49,32,115,101,99,111,110,100,10,0,0,0,0,0,82,101,108,83,116,114,105,110,103,0,0,0,0,0,0,0,67,111,109,109,97,0,0,0,99,111,112,121,32,109,101,109,111,114,121,0,0,0,0,0,115,101,114,105,97,108,0,0,65,68,68,46,76,0,0,0,82,68,114,118,114,73,110,115,116,97,108,108,0,0,0,0,109,0,0,0,0,0,0,0,115,114,99,32,100,115,116,32,99,110,116,0,0,0,0,0,42,42,42,32,114,101,97,100,105,110,103,32,114,116,99,32,102,105,108,101,32,102,97,105,108,101,100,10,0,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,40,112,114,105,41,10,0,0,0,0,65,68,68,88,46,76,0,0,65,100,100,68,114,105,118,101,0,0,0,0,0,0,0,0,68,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,60,110,111,119,62,0,0,0,32,68,51,61,37,48,56,108,88,32,32,68,55,61,37,48,56,108,88,32,32,65,51,61,37,48,56,108,88,32,32,65,55,61,37,48,56,108,88,32,32,83,83,80,61,37,48,56,108,88,10,0,0,0,0,0,65,68,68,65,46,76,0,0,80,117,114,103,101,77,101,109,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,91,101,120,112,114,46,46,46,93,0,0,0,0,0,0,0,102,105,108,101,61,37,115,32,114,101,97,108,116,105,109,101,61,37,100,32,115,116,97,114,116,61,37,115,32,114,111,109,100,105,115,107,61,37,100,10,0,0,0,0,0,0,0,0,117,110,104,97,110,100,108,101,100,32,109,97,103,105,99,32,107,101,121,32,40,37,117,41,10,0,0,0,0,0,0,0,32,68,50,61,37,48,56,108,88,32,32,68,54,61,37,48,56,108,88,32,32,65,50,61,37,48,56,108,88,32,32,65,54,61,37,48,56,108,88,32,32,85,83,80,61,37,48,56,108,88,10,0,0,0,0,0,82,79,82,46,66,0,0,0,67,111,109,112,97,99,116,77,101,109,0,0,0,0,0,0,118,0,0,0,0,0,0,0,119,114,105,116,101,32,109,101,109,111,114,121,32,116,111,32,97,32,102,105,108,101,0,0,82,84,67,58,0,0,0,0,32,68,49,61,37,48,56,108,88,32,32,68,53,61,37,48,56,108,88,32,32,65,49,61,37,48,56,108,88,32,32,65,53,61,37,48,56,108,88,32,32,76,80,67,61,37,48,56,108,88,10,0,0,0,0,0,82,79,88,82,46,66,0,0,83,101,116,71,114,111,119,90,111,110,101,0,0,0,0,0,71,101,116,86,111,108,73,110,102,111,0,0,0,0,0,0,99,0,0,0,0,0,0,0,110,97,109,101,32,91,102,109,116,93,32,91,97,32,110,46,46,46,93,0,0,0,0,0,115,116,97,114,116,0,0,0,37,48,52,88,0,0,0,0,32,68,48,61,37,48,56,108,88,32,32,68,52,61,37,48,56,108,88,32,32,65,48,61,37,48,56,108,88,32,32,65,52,61,37,48,56,108,88,32,32,32,80,67,61,37,48,56,108,88,10,0,0,0,0,0,68,105,97,108,111,103,68,105,115,112,97,116,99,104,0,0,115,111,110,121,58,32,99,111,110,116,114,111,108,58,32,117,110,107,110,111,119,110,32,40,111,112,99,111,100,101,61,48,120,37,48,52,120,41,10,0,76,83,82,46,66,0,0,0,77,111,100,97,108,68,105,97,108,111,103,77,101,110,117,83,101,116,117,112,0,0,0,0,77,101,110,117,67,104,111,105,99,101,0,0,0,0,0,0,83,101,116,77,67,69,110,116,114,105,101,115,0,0,0,0,72,78,111,80,117,114,103,101,0,0,0,0,0,0,0,0,71,101,116,77,67,69,110,116,114,121,0,0,0,0,0,0,68,105,115,112,77,67,69,110,116,114,105,101,115,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,101,114,114,111,114,10,0,0,0,0,0,0,83,101,116,77,67,73,110,102,111,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,113,117,105,116,0,0,0,0,71,101,116,77,67,73,110,102,111,0,0,0,0,0,0,0,114,111,109,100,105,115,107,0,68,101,108,77,67,69,110,116,114,105,101,115,0,0,0,0,72,105,103,104,76,101,118,101,108,70,83,68,105,115,112,97,116,99,104,0,0,0,0,0,32,83,82,61,37,48,52,88,91,37,99,37,99,93,32,32,67,67,61,37,48,50,88,91,37,99,37,99,37,99,37,99,37,99,93,32,69,88,61,37,48,50,88,40,37,45,52,115,41,32,84,82,80,61,37,48,52,88,32,73,77,76,61,37,88,32,73,80,76,61,37,88,10,0,0,0,0,0,0,0,67,111,112,121,68,101,101,112,77,97,115,107,0,0,0,0,65,83,82,46,66,0,0,0,83,101,101,100,67,70,105,108,108,0,0,0,0,0,0,0,67,97,108,99,67,77,97,115,107,0,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,114,111,0,0,0,0,0,83,101,116,83,116,100,67,80,114,111,99,115,0,0,0,0,115,100,108,58,32,107,101,121,32,61,32,48,120,37,48,52,120,10,0,0,0,0,0,0,72,80,117,114,103,101,0,0,68,101,108,67,111,109,112,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,68,101,108,83,101,97,114,99,104,0,0,0,0,0,0,0,70,55,0,0,0,0,0,0,78,101,119,67,68,105,97,108,111,103,0,0,0,0,0,0,38,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,115,101,110,100,32,97,32,109,101,115,115,97,103,101,32,116,111,32,116,104,101,32,101,109,117,108,97,116,111,114,32,99,111,114,101,0,0,0,0,0,82,101,115,116,111,114,101,69,110,116,114,105,101,115,0,0,114,101,97,108,116,105,109,101,0,0,0,0,0,0,0,0,83,97,118,101,69,110,116,114,105,101,115,0,0,0,0,0,101,0,0,0,0,0,0,0,71,101,116,67,87,77,103,114,80,111,114,116,0,0,0,0,67,76,75,61,37,108,120,32,32,79,80,61,37,108,120,32,32,68,76,89,61,37,108,117,32,32,67,80,73,61,37,46,52,102,10,0,0,0,0,0,105,104,120,0,0,0,0,0,109,105,110,95,104,0,0,0,100,101,102,97,117,108,116,0,10,0,0,0,0,0,0,0,83,101,116,68,101,115,107,67,80,97,116,0,0,0,0,0,111,102,102,115,101,116,0,0,44,32,0,0,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,82,79,82,46,76,0,0,0,58,0,0,0,0,0,0,0,71,101,116,78,101,119,67,87,105,110,100,111,119,0,0,0,116,100,48,58,32,115,101,99,116,111,114,32,99,114,99,32,111,118,101,114,32,104,101,97,100,101,114,43,100,97,116,97,10,0,0,0,0,0,0,0,78,101,119,67,87,105,110,100,111,119,0,0,0,0,0,0,71,101,116,65,117,120,67,116,108,0,0,0,0,0,0,0,99,112,50,58,32,119,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,67,80,50,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,46,112,102,100,99,0,0,0,80,116,114,90,111,110,101,0,83,101,116,67,116,108,67,111,108,111,114,0,0,0,0,0,71,101,116,65,117,120,87,105,110,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,83,101,116,87,105,110,67,111,108,111,114,0,0,0,0,0,60,0,0,0,0,0,0,0,109,115,103,32,91,118,97,108,93,0,0,0,0,0,0,0,81,68,69,114,114,111,114,0,112,114,97,109,46,100,97,116,0,0,0,0,0,0,0,0,83,101,116,69,110,116,114,105,101,115,0,0,0,0,0,0,82,101,115,101,114,118,101,69,110,116,114,121,0,0,0,0,54,56,48,48,48,0,0,0,80,114,111,116,101,99,116,69,110,116,114,121,0,0,0,0,82,79,88,82,46,76,0,0,83,101,116,67,108,105,101,110,116,73,68,0,0,0,0,0,65,100,100,67,111,109,112,0,65,100,100,83,101,97,114,99,104,0,0,0,0,0,0,0,83,101,116,84,114,97,112,65,100,100,114,101,115,115,0,0,77,97,107,101,73,84,97,98,108,101,0,0,0,0,0,0,85,112,100,97,116,101,80,105,120,77,97,112,0,0,0,0,71,101,116,83,117,98,84,97,98,108,101,0,0,0,0,0,76,101,115,115,0,0,0,0,114,101,97,100,32,97,32,102,105,108,101,32,105,110,116,111,32,109,101,109,111,114,121,0,82,101,97,108,67,111,108,111,114,0,0,0,0,0,0,0,114,116,99,0,0,0,0,0,73,110,118,101,114,116,67,111,108,111,114,0,0,0,0,0,73,110,100,101,120,50,67,111,108,111,114,0,0,0,0,0,77,69,77,0,0,0,0,0,91,101,120,99,101,112,116,105,111,110,93,0,0,0,0,0,117,115,112,0,0,0,0,0,67,111,108,111,114,50,73,110,100,101,120,0,0,0,0,0,76,83,82,46,76,0,0,0,71,101,116,71,68,101,118,105,99,101,0,0,0,0,0,0,83,101,116,71,68,101,118,105,99,101,0,0,0,0,0,0,109,97,99,58,32,114,101,115,101,116,10,0,0,0,0,0,68,105,115,112,111,115,71,68,101,118,105,99,101,0,0,0,71,101,116,84,114,97,112,65,100,100,114,101,115,115,0,0,78,101,119,71,68,101,118,105,99,101,0,0,0,0,0,0,73,110,105,116,71,68,101,118,105,99,101,0,0,0,0,0,83,101,116,68,101,118,105,99,101,65,116,116,114,105,98,117,116,101,0,0,0,0,0,0,83,104,105,102,116,0,0,0,110,97,109,101,32,91,102,109,116,93,32,91,97,32,91,110,93,93,0,0,0,0,0,0,84,101,115,116,68,101,118,105,99,101,65,116,116,114,105,98,117,116,101,0,0,0,0,0,109,111,100,101,108,61,37,117,32,105,110,116,101,114,110,97,116,105,111,110,97,108,61,37,100,32,107,101,121,112,97,100,61,37,115,10,0,0,0,0,71,101,116,78,101,120,116,68,101,118,105,99,101,0,0,0,71,101,116,77,97,105,110,68,101,118,105,99,101,0,0,0,87,82,37,48,50,117,65,61,37,48,50,88,32,32,82,82,37,48,50,117,65,61,37,48,50,88,32,32,87,82,37,48,50,117,66,61,37,48,50,88,32,32,82,82,37,48,50,117,66,61,37,48,50,88,10,0,71,101,116,68,101,118,105,99,101,76,105,115,116,0,0,0,65,83,82,46,76,0,0,0,71,101,116,67,84,83,101,101,100,0,0,0,0,0,0,0,71,101,116,77,97,120,68,101,118,105,99,101,0,0,0,0,68,105,115,112,111,115,67,67,117,114,115,111,114,0,0,0,70,108,117,115,104,70,105,108,101,0,0,0,0,0,0,0,68,105,115,112,111,115,67,73,99,111,110,0,0,0,0,0,68,105,115,112,111,115,67,84,97,98,108,101,0,0,0,0,67,104,97,114,69,120,116,114,97,0,0,0,0,0,0,0,83,104,105,102,116,76,101,102,116,0,0,0,0,0,0,0,112,114,105,110,116,32,104,101,108,112,0,0,0,0,0,0,72,105,108,105,116,101,67,111,108,111,114,0,0,0,0,0,75,69,89,66,79,65,82,68,58,0,0,0,0,0,0,0,79,112,67,111,108,111,114,0,80,108,111,116,67,73,99,111,110,0,0,0,0,0,0,0,32,32,73,82,81,61,37,117,10,0,0,0,0,0,0,0,71,101,116,67,73,99,111,110,0,0,0,0,0,0,0,0,65,83,82,46,87,0,0,0,65,108,108,111,99,67,117,114,115,111,114,0,0,0,0,0,83,101,116,67,67,117,114,115,111,114,0,0,0,0,0,0,71,101,116,67,67,117,114,115,111,114,0,0,0,0,0,0,83,101,116,70,80,111,115,0,71,101,116,66,97,99,107,67,111,108,111,114,0,0,0,0,65,0,0,0,0,0,0,0,71,101,116,70,111,114,101,67,111,108,111,114,0,0,0,0,71,101,116,67,84,97,98,108,101,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,102,105,110,100,32,98,121,116,101,115,32,105,110,32,109,101,109,111,114,121,0,0,0,0,71,101,116,67,80,105,120,101,108,0,0,0,0,0,0,0,105,110,116,108,0,0,0,0,83,101,116,67,80,105,120,101,108,0,0,0,0,0,0,0,82,71,66,66,97,99,107,67,111,108,111,114,0,0,0,0,56,53,51,48,45,83,67,67,0,0,0,0,0,0,0,0,82,71,66,70,111,114,101,67,111,108,111,114,0,0,0,0,82,79,76,46,66,0,0,0,70,105,108,108,67,80,111,108,121,0,0,0,0,0,0,0,70,105,108,108,67,82,103,110,0,0,0,0,0,0,0,0,70,105,108,108,67,65,114,99,0,0,0,0,0,0,0,0,83,101,116,70,105,108,84,121,112,101,0,0,0,0,0,0,70,105,108,108,67,82,111,117,110,100,82,101,99,116,0,0,70,105,108,108,67,79,118,97,108,0,0,0,0,0,0,0,70,105,108,108,67,82,101,99,116,0,0,0,0,0,0,0,66,97,99,107,115,108,97,115,104,0,0,0,0,0,0,0,97,100,100,114,32,99,110,116,32,91,118,97,108,46,46,46,93,0,0,0,0,0,0,0,77,97,107,101,82,71,66,80,97,116,0,0,0,0,0,0,109,111,100,101,108,0,0,0,71,101,116,80,105,120,80,97,116,0,0,0,0,0,0,0,66,97,99,107,80,105,120,80,97,116,0,0,0,0,0,0,32,32,80,65,61,37,48,50,88,32,32,32,80,66,61,37,48,50,88,32,32,67,66,50,61,37,88,32,32,37,99,84,50,86,61,37,48,52,88,10,0,0,0,0,0,0,0,0,80,101,110,80,105,120,80,97,116,0,0,0,0,0,0,0,107,101,121,112,97,100,32,109,111,100,101,58,32,107,101,121,112,97,100,10,0,0,0,0,82,79,88,76,46,66,0,0,67,111,112,121,80,105,120,80,97,116,0,0,0,0,0,0,68,105,115,112,111,115,80,105,120,80,97,116,0,0,0,0,78,101,119,80,105,120,80,97,116,0,0,0,0,0,0,0,83,101,116,67,80,111,114,116,80,105,120,0,0,0,0,0,82,115,116,70,105,108,76,111,99,107,0,0,0,0,0,0,67,111,112,121,80,105,120,77,97,112,0,0,0,0,0,0,68,105,115,112,111,115,80,105,120,77,97,112,0,0,0,0,39,0,0,0,0,0,0,0,101,110,116,101,114,32,98,121,116,101,115,32,105,110,116,111,32,109,101,109,111,114,121,0,78,101,119,80,105,120,77,97,112,0,0,0,0,0,0,0,107,101,121,112,97,100,0,0,73,110,105,116,67,112,111,114,116,0,0,0,0,0,0,0,79,112,101,110,67,112,111,114,116,0,0,0,0,0,0,0,32,79,82,65,61,37,48,50,88,32,32,79,82,66,61,37,48,50,88,32,32,67,66,49,61,37,88,32,32,32,84,50,76,61,37,48,52,88,10,0,68,101,98,117,103,103,101,114,0,0,0,0,0,0,0,0,76,83,76,46,66,0,0,0,80,117,116,83,99,114,97,112,0,0,0,0,0,0,0,0,71,101,116,83,99,114,97,112,0,0,0,0,0,0,0,0,90,101,114,111,83,99,114,97,112,0,0,0,0,0,0,0,76,111,100,101,83,99,114,97,112,0,0,0,0,0,0,0,83,101,116,70,105,108,76,111,99,107,0,0,0,0,0,0,75,105,108,108,73,79,0,0,85,110,108,111,100,101,83,99,114,97,112,0,0,0,0,0,73,110,102,111,83,99,114,97,112,0,0,0,0,0,0,0,65,112,111,115,116,114,111,112,104,101,0,0,0,0,0,0,97,100,100,114,32,91,118,97,108,124,115,116,114,105,110,103,46,46,46,93,0,0,0,0,77,101,116,104,111,100,68,105,115,112,97,116,99,104,0,0,109,111,116,105,111,110,0,0,83,101,116,82,101,115,70,105,108,101,65,116,116,114,115,0,71,101,116,82,101,115,70,105,108,101,65,116,116,114,115,0,32,73,82,65,61,37,48,50,88,32,32,73,82,66,61,37,48,50,88,32,32,67,65,50,61,37,88,32,32,37,99,84,49,86,61,37,48,52,88,10,0,0,0,0,0,0,0,0,71,101,116,65,112,112,80,97,114,109,115,0,0,0,0,0,115,111,110,121,58,32,115,116,97,116,117,115,58,32,117,110,107,110,111,119,110,32,40,99,115,61,48,120,37,48,52,120,41,10,0,0,0,0,0,0,65,83,76,46,66,0,0,0,69,120,105,116,84,111,83,104,101,108,108,0,0,0,0,0,67,104,97,105,110,0,0,0,76,97,117,110,99,104,0,0,85,110,108,111,97,100,83,101,103,0,0,0,0,0,0,0,82,101,115,114,118,77,101,109,0,0,0,0,0,0,0,0,76,111,97,100,83,101,103,0,115,99,115,105,58,32,119,114,105,116,101,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,117,32,47,32,37,117,41,10,0,0,0,0,80,116,114,65,110,100,72,97,110,100,0,0,0,0,0,0,81,117,111,116,101,0,0,0,100,117,109,112,32,109,101,109,111,114,121,0,0,0,0,0,80,97,99,107,55,0,0,0,107,101,121,98,111,97,114,100,32,107,101,121,112,97,100,95,109,111,100,101,61,37,115,10,0,0,0,0,0,0,0,0,80,97,99,107,54,0,0,0,80,97,99,107,53,0,0,0,68,68,82,65,61,37,48,50,88,32,68,68,82,66,61,37,48,50,88,32,32,67,65,49,61,37,88,32,32,32,84,49,76,61,37,48,52,88,32,83,72,70,84,61,37,48,50,88,47,37,117,10,0,0,0,0,69,108,101,109,115,54,56,75,0,0,0,0,0,0,0,0,80,97,99,107,52,0,0,0,68,87,0,0,0,0,0,0,70,80,54,56,75,0,0,0,101,109,117,46,100,105,115,107,46,105,110,115,101,114,116,0,80,97,99,107,51,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,80,97,99,107,50,0,0,0,73,110,105,116,85,116,105,108,0,0,0,0,0,0,0,0,80,97,99,107,49,0,0,0,70,54,0,0,0,0,0,0,80,97,99,107,48,0,0,0,94,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,91,97,100,100,114,32,91,99,110,116,93,93,0,0,0,0,73,110,105,116,65,108,108,80,97,99,107,115,0,0,0,0,60,110,108,62,0,0,0,0,109,111,117,115,101,10,0,0,73,110,105,116,80,97,99,107,0,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,72,97,110,100,65,110,100,72,97,110,100,0,0,0,0,0,32,80,67,82,61,37,48,50,88,32,32,65,67,82,61,37,48,50,88,32,32,73,70,82,61,37,48,50,88,32,32,73,69,82,61,37,48,50,88,32,32,73,82,81,61,37,117,10,0,0,0,0,0,0,0,0,105,104,101,120,0,0,0,0,109,105,110,95,119,0,0,0,115,105,122,101,0,0,0,0,37,115,58,32,101,114,114,111,114,32,112,97,114,115,105,110,103,32,105,110,105,32,115,116,114,105,110,103,32,40,37,115,41,10,0,0,0,0,0,0,80,116,114,84,111,72,97,110,100,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,32,32,45,37,99,0,0,0,115,116,114,105,110,103,32,116,111,111,32,108,111,110,103,0,101,120,112,101,99,116,105,110,103,32,97,100,100,114,101,115,115,0,0,0,0,0,0,0,80,116,114,84,111,88,72,97,110,100,0,0,0,0,0,0,82,79,76,46,76,0,0,0,116,100,48,58,32,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,40,37,117,47,37,117,47,37,117,32,37,117,41,10,0,72,97,110,100,84,111,72,97,110,100,0,0,0,0,0,0,115,116,120,58,32,114,101,97,100,32,101,114,114,111,114,32,40,115,101,99,116,111,114,32,100,97,116,97,41,10,0,0,77,117,110,103,101,114,0,0,99,112,50,58,32,110,111,116,32,97,32,67,80,50,32,102,105,108,101,10,0,0,0,0,46,109,115,97,0,0,0,0,84,69,83,101,116,74,117,115,116,0,0,0,0,0,0,0,68,114,118,114,82,101,109,111,118,101,0,0,0,0,0,0,121,100,105,118,0,0,0,0,84,69,73,110,115,101,114,116,0,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,84,69,83,99,114,111,108,108,0,0,0,0,0,0,0,0,83,101,109,105,99,111,108,111,110,0,0,0,0,0,0,0,115,101,116,32,97,110,32,101,120,112,114,101,115,115,105,111,110,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,84,69,75,101,121,0,0,0,42,42,42,32,99,97,110,39,116,32,99,114,101,97,116,101,32,97,100,98,10,0,0,0,84,69,80,97,115,116,101,0,84,69,73,100,108,101,0,0,54,53,50,50,45,86,73,65,0,0,0,0,0,0,0,0,84,69,68,101,97,99,116,105,118,97,116,101,0,0,0,0,84,69,65,99,116,105,118,97,116,101,0,0,0,0,0,0,82,79,88,76,46,76,0,0,84,69,68,101,108,101,116,101,0,0,0,0,0,0,0,0,84,69,67,117,116,0,0,0,84,69,67,111,112,121,0,0,68,114,118,114,73,110,115,116,97,108,108,0,0,0,0,0,84,69,67,108,105,99,107,0,84,69,85,112,100,97,116,101,0,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,101,120,112,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,84,69,78,101,119,0,0,0,101,110,97,98,108,101,100,10,0,0,0,0,0,0,0,0,84,69,83,101,116,83,101,108,101,99,116,0,0,0,0,0,84,69,67,97,108,84,101,120,116,0,0,0,0,0,0,0,101,120,99,101,112,116,105,111,110,32,37,48,50,88,32,40,37,115,41,10,0,0,0,0,103,101,0,0,0,0,0,0,99,99,114,0,0,0,0,0,84,69,83,101,116,84,101,120,116,0,0,0,0,0,0,0,84,101,120,116,66,111,120,0,76,83,76,46,76,0,0,0,84,69,68,105,115,112,111,115,101,0,0,0,0,0,0,0,84,69,73,110,105,116,0,0,54,56,48,50,48,0,0,0,84,69,71,101,116,84,101,120,116,0,0,0,0,0,0,0,67,109,112,83,116,114,105,110,103,0,0,0,0,0,0,0,80,117,116,73,99,111,110,0,83,121,115,69,114,114,111,114,0,0,0,0,0,0,0,0,107,0,0,0,0,0,0,0,98,115,120,0,0,0,0,0,83,121,115,66,101,101,112,0,65,68,66,58,0,0,0,0,68,97,116,101,50,83,101,99,0,0,0,0,0,0,0,0,83,101,99,115,50,68,97,116,101,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,82,115,114,99,77,97,112,69,110,116,114,121,0,0,0,0,79,112,101,110,82,70,80,101,114,109,0,0,0,0,0,0,65,83,76,46,76,0,0,0,75,101,121,84,114,97,110,115,0,0,0,0,0,0,0,0,83,121,115,69,100,105,116,0,85,110,105,113,117,101,73,68,0,0,0,0,0,0,0,0,68,101,108,97,121,0,0,0,71,101,116,78,101,119,77,66,97,114,0,0,0,0,0,0,71,101,116,82,77,101,110,117,0,0,0,0,0,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,32,40,100,105,115,107,41,10,0,0,0,0,0,106,0,0,0,0,0,0,0,115,101,116,32,97,110,32,97,100,100,114,101,115,115,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,0,0,0,71,101,116,78,101,119,67,111,110,116,114,111,108,0,0,0,107,101,121,112,97,100,95,109,111,116,105,111,110,0,0,0,71,101,116,78,101,119,87,105,110,100,111,119,0,0,0,0,71,101,116,80,105,99,116,117,114,101,0,0,0,0,0,0,109,105,115,115,105,110,103,32,118,97,108,117,101,10,0,0,71,101,116,73,99,111,110,0,71,101,116,83,116,114,105,110,103,0,0,0,0,0,0,0,65,83,76,46,87,0,0,0,71,101,116,67,117,114,115,111,114,0,0,0,0,0,0,0,71,101,116,80,97,116,116,101,114,110,0,0,0,0,0,0,67,108,111,115,101,68,101,115,107,65,99,99,0,0,0,0,83,101,116,68,97,116,101,84,105,109,101,0,0,0,0,0,37,115,37,117,0,0,0,0,79,112,101,110,68,101,115,107,65,99,99,0,0,0,0,0,83,121,115,116,101,109,77,101,110,117,0,0,0,0,0,0,104,0,0,0,0,0,0,0,97,100,100,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,83,121,115,116,101,109,84,97,115,107,0,0,0,0,0,0,107,101,121,98,111,97,114,100,0,0,0,0,0,0,0,0,83,121,115,116,101,109,67,108,105,99,107,0,0,0,0,0,83,121,115,116,101,109,69,118,101,110,116,0,0,0,0,0,37,48,56,108,88,10,0,0,67,114,101,97,116,101,82,101,115,70,105,108,101,0,0,0,87,114,105,116,101,82,101,115,111,117,114,99,101,0,0,0,76,83,82,46,87,0,0,0,82,101,115,69,114,114,111,114,0,0,0,0,0,0,0,0,82,109,118,101,82,101,102,101,114,101,110,99,101,0,0,0,82,109,118,101,82,101,115,111,117,114,99,101,0,0,0,0,82,101,97,100,68,97,116,101,84,105,109,101,0,0,0,0,65,100,100,82,101,102,101,114,101,110,99,101,0,0,0,0,65,100,100,82,101,115,111,117,114,99,101,0,0,0,0,0,103,0,0,0,0,0,0,0,98,115,0,0,0,0,0,0,67,104,97,110,103,101,100,82,101,115,111,117,114,99,101,0,109,111,117,115,101,0,0,0,83,101,116,82,101,115,73,110,102,111,0,0,0,0,0,0,71,101,116,82,101,115,73,110,102,111,0,0,0,0,0,0,98,97,100,32,114,101,103,105,115,116,101,114,32,40,37,115,41,10,0,0,0,0,0,0,83,101,116,82,101,115,65,116,116,114,115,0,0,0,0,0,71,101,116,82,101,115,65,116,116,114,115,0,0,0,0,0,107,101,121,112,97,100,32,109,111,100,101,58,32,109,111,116,105,111,110,10,0,0,0,0,76,83,76,46,87,0,0,0,83,105,122,101,82,115,114,99,0,0,0,0,0,0,0,0,72,111,109,101,82,101,115,70,105,108,101,0,0,0,0,0,82,101,108,101,97,115,101,82,101,115,111,117,114,99,101,0,87,114,105,116,101,80,97,114,97,109,0,0,0,0,0,0,76,111,97,100,82,101,115,111,117,114,99,101,0,0,0,0,71,101,116,78,97,109,101,100,82,101,115,111,117,114,99,101,0,0,0,0,0,0,0,0,80,114,105,110,116,32,118,101,114,115,105,111,110,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,108,105,115,116,32,98,114,101,97,107,112,111,105,110,116,115,0,0,0,0,0,0,0,0,71,101,116,82,101,115,111,117,114,99,101,0,0,0,0,0,97,100,98,0,0,0,0,0,71,101,116,73,110,100,84,121,112,101,0,0,0,0,0,0,67,111,117,110,116,84,121,112,101,115,0,0,0,0,0,0,109,105,115,115,105,110,103,32,114,101,103,105,115,116,101,114,10,0,0,0,0,0,0,0,71,101,116,73,110,100,82,101,115,111,117,114,99,101,0,0,67,111,117,110,116,82,101,115,111,117,114,99,101,115,0,0,82,79,88,82,46,87,0,0,83,101,116,82,101,115,76,111,97,100,0,0,0,0,0,0,67,108,111,115,101,82,101,115,70,105,108,101,0,0,0,0,85,112,100,97,116,101,82,101,115,70,105,108,101,0,0,0,77,111,114,101,77,97,115,116,101,114,115,0,0,0,0,0,85,115,101,82,101,115,70,105,108,101,0,0,0,0,0,0,83,116,97,116,117,115,0,0,79,112,101,110,82,101,115,70,105,108,101,0,0,0,0,0,118,101,114,115,105,111,110,0,100,0,0,0,0,0,0,0,98,108,0,0,0,0,0,0,82,115,114,99,90,111,110,101,73,110,105,116,0,0,0,0,100,114,105,118,101,61,37,117,32,115,105,122,101,61,37,117,75,32,108,111,99,107,101,100,61,37,100,32,114,111,116,97,116,101,61,37,100,32,100,105,115,107,61,37,117,32,102,105,108,101,61,37,115,10,0,0,73,110,105,116,82,101,115,111,117,114,99,101,115,0,0,0,67,117,114,82,101,115,70,105,108,101,0,0,0,0,0,0,59,32,0,0,0,0,0,0,83,101,116,82,101,115,80,117,114,103,101,0,0,0,0,0,105,110,115,101,114,116,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,0,0,0,68,101,116,97,99,104,82,101,115,111,117,114,99,101,0,0,82,79,88,76,46,87,0,0,77,111,100,97,108,68,105,97,108,111,103,0,0,0,0,0,71,101,116,73,84,101,120,116,0,0,0,0,0,0,0,0,83,101,116,73,84,101,120,116,0,0,0,0,0,0,0,0,79,102,102,108,105,110,101,0,83,101,116,68,73,116,101,109,0,0,0,0,0,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,98,108,111,99,107,32,99,111,117,110,116,32,37,117,10,0,0,0,0,0,71,101,116,68,73,116,101,109,0,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,100,101,98,117,103,32,91,110,111,93,0,115,0,0,0,0,0,0,0,99,108,101,97,114,32,97,32,98,114,101,97,107,112,111,105,110,116,32,111,114,32,97,108,108,0,0,0,0,0,0,0,69,114,114,111,114,83,111,117,110,100,0,0,0,0,0,0,97,117,116,111,95,114,111,116,97,116,101,0,0,0,0,0,80,97,114,97,109,84,101,120,116,0,0,0,0,0,0,0,70,114,101,101,65,108,101,114,116,0,0,0,0,0,0,0,109,97,99,46,105,110,115,101,114,116,0,0,0,0,0,0,67,111,117,108,100,65,108,101,114,116,0,0,0,0,0,0,67,97,117,116,105,111,110,65,108,101,114,116,0,0,0,0,82,79,82,46,87,0,0,0,78,111,116,101,65,108,101,114,116,0,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,101,106,101,99,116,0,0,83,116,111,112,65,108,101,114,116,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,65,108,101,114,116,0,0,0,86,82,101,109,111,118,101,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,70,105,110,100,68,73,116,101,109,0,0,0,0,0,0,0,70,53,0,0,0,0,0,0,68,105,115,112,111,115,68,105,97,108,111,103,0,0,0,0,94,94,0,0,0,0,0,0,118,101,114,98,111,115,101,0,97,0,0,0,0,0,0,0,91,105,110,100,101,120,93,0,67,108,111,115,101,68,105,97,108,111,103,0,0,0,0,0,60,101,111,102,62,0,0,0,105,110,115,101,114,116,101,100,0,0,0,0,0,0,0,0,68,114,97,119,68,105,97,108,111,103,0,0,0,0,0,0,115,97,118,101,0,0,0,0,68,105,97,108,111,103,83,101,108,101,99,116,0,0,0,0,37,45,56,115,32,37,115,44,32,37,115,44,32,37,115,0,97,117,116,111,0,0,0,0,97,115,112,101,99,116,95,121,0,0,0,0,0,0,0,0,115,105,122,101,107,0,0,0,37,115,58,32,98,97,100,32,100,114,105,118,101,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,73,115,68,105,97,108,111,103,69,118,101,110,116,0,0,0,116,121,112,101,0,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,45,37,99,41,10,0,0,0,0,0,0,105,100,101,110,116,105,102,105,101,114,32,116,111,111,32,108,111,110,103,0,0,0,0,0,120,0,0,0,0,0,0,0,83,101,108,73,84,101,120,116,0,0,0,0,0,0,0,0,82,79,76,46,87,0,0,0,110,111,0,0,0,0,0,0,116,100,48,58,32,122,101,114,111,32,100,97,116,97,32,108,101,110,103,116,104,32,40,37,117,47,37,117,47,37,117,41,10,0,0,0,0,0,0,0,78,101,119,68,105,97,108,111,103,0,0,0,0,0,0,0,37,117,47,37,117,47,37,117,10,0,0,0,0,0,0,0,71,101,116,78,101,119,68,105,97,108,111,103,0,0,0,0,46,105,109,103,0,0,0,0,73,110,105,116,68,105,97,108,111,103,115,0,0,0,0,0,86,73,110,115,116,97,108,108,0,0,0,0,0,0,0,0,46,116,99,0,0,0,0,0,115,101,114,99,111,110,0,0,121,109,117,108,0,0,0,0,70,114,101,101,68,105,97,108,111,103,0,0,0,0,0,0,115,116,100,105,111,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,97,105,108,101,100,10,0,0,0,67,111,117,108,100,68,105,97,108,111,103,0,0,0,0,0,83,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,100,101,118,105,99,101,0,67,97,112,115,76,111,99,107,0,0,0,0,0,0,0,0,98,99,0,0,0,0,0,0,85,112,100,116,68,105,97,108,111,103,0,0,0,0,0,0,108,111,99,107,101,100,0,0,87,97,105,116,77,111,117,115,101,85,112,0,0,0,0,0,71,101,116,75,101,121,115,0,114,117,110,32,119,105,116,104,32,98,114,101,97,107,112,111,105,110,116,115,32,97,116,32,97,100,100,114,0,0,0,0,37,45,56,115,32,37,115,44,32,37,115,0,0,0,0,0,84,105,99,107,67,111,117,110,116,0,0,0,0,0,0,0,66,117,116,116,111,110,0,0,66,70,84,83,84,0,0,0,83,116,105,108,108,68,111,119,110,0,0,0,0,0,0,0,71,101,116,77,111,117,115,101,0,0,0,0,0,0,0,0,69,118,101,110,116,65,118,97,105,108,0,0,0,0,0,0,70,108,117,115,104,69,118,101,110,116,115,0,0,0,0,0,71,101,116,78,101,120,116,69,118,101,110,116,0,0,0,0,69,110,113,117,101,117,101,0,82,101,116,117,114,110,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,68,101,113,117,101,117,101,0,115,105,110,103,108,101,95,115,105,100,101,100,0,0,0,0,68,114,97,119,49,67,111,110,116,114,111,108,0,0,0,0,70,105,110,100,67,111,110,116,114,111,108,0,0,0,0,0,37,45,56,115,32,37,115,0,99,0,0,0,0,0,0,0,115,112,0,0,0,0,0,0,83,101,116,67,116,108,65,99,116,105,111,110,0,0,0,0,71,101,116,67,116,108,65,99,116,105,111,110,0,0,0,0,66,70,69,88,84,85,0,0,68,114,97,119,67,111,110,116,114,111,108,115,0,0,0,0,84,114,97,99,107,67,111,110,116,114,111,108,0,0,0,0,68,114,97,103,67,111,110,116,114,111,108,0,0,0,0,0,54,56,48,49,48,0,0,0,71,101,116,79,83,69,118,101,110,116,0,0,0,0,0,0,84,101,115,116,67,111,110,116,114,111,108,0,0,0,0,0,83,101,116,77,97,120,67,116,108,0,0,0,0,0,0,0,93,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,115,112,101,101,100,0,0,0,0,0,0,0,83,101,116,77,105,110,67,116,108,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,83,101,116,67,116,108,86,97,108,117,101,0,0,0,0,0,71,101,116,77,97,120,67,116,108,0,0,0,0,0,0,0,91,97,100,100,114,46,46,93,0,0,0,0,0,0,0,0,71,101,116,77,105,110,67,116,108,0,0,0,0,0,0,0,71,101,116,67,116,108,86,97,108,117,101,0,0,0,0,0,66,70,67,72,71,0,0,0,83,101,116,67,84,105,116,108,101,0,0,0,0,0,0,0,71,101,116,67,84,105,116,108,101,0,0,0,0,0,0,0,72,105,108,105,116,101,67,111,110,116,114,111,108,0,0,0,79,83,69,118,101,110,116,65,118,97,105,108,0,0,0,0,83,105,122,101,67,111,110,116,114,111,108,0,0,0,0,0,83,101,116,67,82,101,102,67,111,110,0,0,0,0,0,0,71,101,116,67,82,101,102,67,111,110,0,0,0,0,0,0,82,105,103,104,116,66,114,97,99,107,101,116,0,0,0,0,105,110,116,0,0,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,32,40,112,114,105,41,10,0,0,0,0,0,0,77,111,118,101,67,111,110,116,114,111,108,0,0,0,0,0,72,105,100,101,67,111,110,116,114,111,108,0,0,0,0,0,100,105,115,107,0,0,0,0,83,104,111,119,67,111,110,116,114,111,108,0,0,0,0,0,75,105,108,108,67,111,110,116,114,111,108,115,0,0,0,0,66,70,69,88,84,83,0,0,68,105,115,112,111,115,67,111,110,116,114,111,108,0,0,0,78,101,119,67,111,110,116,114,111,108,0,0,0,0,0,0,85,112,100,116,67,111,110,116,114,111,108,0,0,0,0,0,80,111,115,116,69,118,101,110,116,0,0,0,0,0,0,0,65,37,117,0,0,0,0,0,68,101,108,77,101,110,117,73,116,101,109,0,0,0,0,0,73,110,115,101,114,116,82,101,115,77,101,110,117,0,0,0,91,0,0,0,0,0,0,0,115,112,101,101,100,0,0,0,67,111,117,110,116,77,73,116,101,109,115,0,0,0,0,0,98,108,111,99,107,95,99,111,117,110,116,0,0,0,0,0,68,101,108,116,97,80,111,105,110,116,0,0,0,0,0,0,80,105,110,82,101,99,116,0,97,100,100,114,61,48,120,37,48,54,108,120,10,0,0,0,65,100,100,82,101,115,77,101,110,117,0,0,0,0,0,0,70,108,97,115,104,77,101,110,117,66,97,114,0,0,0,0,66,70,67,76,82,0,0,0,80,108,111,116,73,99,111,110,0,0,0,0,0,0,0,0,83,101,116,77,70,108,97,115,104,0,0,0,0,0,0,0,71,101,116,77,72,97,110,100,108,101,0,0,0,0,0,0,66,108,111,99,107,77,111,118,101,0,0,0,0,0,0,0,67,97,108,99,77,101,110,117,83,105,122,101,0,0,0,0,83,101,116,73,116,101,109,0,76,101,102,116,66,114,97,99,107,101,116,0,0,0,0,0])
.concat([78,101,118,101,114,32,115,116,111,112,32,114,117,110,110,105,110,103,32,91,110,111,93,0,71,101,116,73,116,101,109,0,98,108,111,99,107,95,115,116,97,114,116,0,0,0,0,0,67,104,101,99,107,73,116,101,109,0,0,0,0,0,0,0,83,101,116,73,116,109,77,97,114,107,0,0,0,0,0,0,73,87,77,58,0,0,0,0,71,101,116,73,116,109,77,97,114,107,0,0,0,0,0,0,83,101,116,73,116,109,83,116,121,108,101,0,0,0,0,0,66,70,83,69,84,0,0,0,71,101,116,73,116,109,83,116,121,108,101,0,0,0,0,0,52,0,0,0,0,0,0,0,83,101,116,73,116,109,73,99,111,110,0,0,0,0,0,0,71,101,116,73,116,109,73,99,111,110,0,0,0,0,0,0,83,101,116,65,112,112,108,76,105,109,105,116,0,0,0,0,77,101,110,117,75,101,121,0,77,101,110,117,83,101,108,101,99,116,0,0,0,0,0,0,112,0,0,0,0,0,0,0,110,111,45,109,111,110,105,116,111,114,0,0,0,0,0,0,83,101,116,77,101,110,117,66,97,114,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,118,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,10,0,0,0,0,0,0,105,119,109,0,0,0,0,0,71,101,116,77,101,110,117,66,97,114,0,0,0,0,0,0,68,105,115,97,98,108,101,73,116,101,109,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,69,110,97,98,108,101,73,116,101,109,0,0,0,0,0,0,117,110,104,97,110,100,108,101,100,32,104,111,111,107,32,40,37,48,52,88,41,10,0,0,72,105,108,105,116,101,77,101,110,117,0,0,0,0,0,0,36,0,0,0,0,0,0,0,68,114,97,119,77,101,110,117,66,97,114,0,0,0,0,0,68,101,108,101,116,101,77,101,110,117,0,0,0,0,0,0,73,110,115,101,114,116,77,101,110,117,0,0,0,0,0,0,73,110,105,116,65,112,112,108,90,111,110,101,0,0,0,0,67,108,101,97,114,77,101,110,117,66,97,114,0,0,0,0,67,111,110,116,114,111,108,0,117,110,107,110,111,119,110,32,67,80,85,32,109,111,100,101,108,32,40,37,115,41,10,0,65,112,112,101,110,100,77,101,110,117,0,0,0,0,0,0,111,0,0,0,0,0,0,0,83,116,97,114,116,32,114,117,110,110,105,110,103,32,105,109,109,101,100,105,97,116,101,108,121,32,91,110,111,93,0,0,68,105,115,112,111,115,77,101,110,117,0,0,0,0,0,0,118,105,115,105,98,108,101,95,115,0,0,0,0,0,0,0,105,100,61,37,117,32,100,114,105,118,101,61,37,117,32,118,101,110,100,111,114,61,34,37,115,34,32,112,114,111,100,117,99,116,61,34,37,115,34,10,0,0,0,0,0,0,0,0,78,101,119,77,101,110,117,0,73,110,105,116,77,101,110,117,115,0,0,0,0,0,0,0,32,32,32,32,32,0,0,0,71,101,116,87,105,110,100,111,119,80,105,99,0,0,0,0,115,111,110,121,32,100,114,105,118,101,114,32,97,116,32,48,120,37,48,54,108,120,10,0,83,101,116,87,105,110,100,111,119,80,105,99,0,0,0,0,40,91,37,115,44,32,37,115,44,32,37,115,37,115,93,44,32,37,115,41,0,0,0,0,67,108,111,115,101,87,105,110,100,111,119,0,0,0,0,0,70,105,110,100,87,105,110,100,111,119,0,0,0,0,0,0,71,114,111,119,87,105,110,100,111,119,0,0,0,0,0,0,69,109,112,116,121,72,97,110,100,108,101,0,0,0,0,0,86,97,108,105,100,82,101,99,116,0,0,0,0,0,0,0,79,112,101,110,0,0,0,0,115,99,115,105,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,48,50,88,41,10,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,32,102,111,114,32,100,114,105,118,101,32,37,117,10,0,0,86,97,108,105,100,82,103,110,0,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,114,117,110,0,0,0,0,0,73,110,118,97,108,82,101,99,116,0,0,0,0,0,0,0,118,105,115,105,98,108,101,95,104,0,0,0,0,0,0,0,80,67,69,68,73,83,75,0,73,110,118,97,108,82,103,110,0,0,0,0,0,0,0,0,68,114,97,103,84,104,101,82,103,110,0,0,0,0,0,0,37,48,52,88,32,0,0,0,68,114,97,103,87,105,110,100,111,119,0,0,0,0,0,0,70,114,111,110,116,87,105,110,100,111,119,0,0,0,0,0,40,91,37,115,44,32,37,115,93,44,32,37,115,37,115,44,32,37,115,41,0,0,0,0,69,110,100,85,112,100,97,116,101,0,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,99,111,109,109,105,116,0,66,101,103,105,110,85,112,100,97,116,101,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,83,101,110,100,66,101,104,105,110,100,0,0,0,0,0,0,72,85,110,108,111,99,107,0,116,101,114,109,46,115,99,114,101,101,110,115,104,111,116,0,66,114,105,110,103,84,111,70,114,111,110,116,0,0,0,0,70,52,0,0,0,0,0,0,83,101,108,101,99,116,87,105,110,100,111,119,0,0,0,0,99,111,109,109,105,116,0,0,124,0,0,0,0,0,0,0,117,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,101,114,114,111,114,32,91,110,111,93,0,84,114,97,99,107,71,111,65,119,97,121,0,0,0,0,0,118,105,115,105,98,108,101,95,99,0,0,0,0,0,0,0,58,32,0,0,0,0,0,0,112,114,111,100,117,99,116,0,83,105,122,101,87,105,110,100,111,119,0,0,0,0,0,0,108,111,97,100,0,0,0,0,72,105,108,105,116,101,87,105,110,100,111,119,0,0,0,0,37,48,56,108,88,32,32,37,115,10,0,0,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,98,105,110,97,114,121,32,97,100,100,114,61,48,120,37,48,56,108,120,10,0,0,0,0,0,97,115,112,101,99,116,95,120,0,0,0,0,0,0,0,0,115,105,122,101,109,0,0,0,77,111,118,101,87,105,110,100,111,119,0,0,0,0,0,0,100,114,105,118,101,0,0,0,114,111,109,115,47,112,99,101,45,99,111,110,102,105,103,46,99,102,103,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,45,37,99,41,10,0,0,0,0,0,0,0,42,42,42,32,37,115,32,91,37,115,93,10,0,0,0,0,83,101,116,87,84,105,116,108,101,0,0,0,0,0,0,0,98,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,0,0,0,0,0,0,102,97,108,115,101,0,0,0,37,115,37,115,37,48,56,88,0,0,0,0,0,0,0,0,115,100,108,0,0,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,110,111,32,100,97,116,97,41,10,0,0,0,0,71,101,116,87,84,105,116,108,101,0,0,0,0,0,0,0,83,101,116,87,82,101,102,67,111,110,0,0,0,0,0,0,32,37,48,50,88,0,0,0,46,105,109,100,0,0,0,0,71,101,116,87,82,101,102,67,111,110,0,0,0,0,0,0,72,76,111,99,107,0,0,0,46,112,114,105,0,0,0,0,45,45,0,0,0,0,0,0,120,100,105,118,0,0,0,0,72,105,100,101,87,105,110,100,111,119,0,0,0,0,0,0,112,116,121,0,0,0,0,0,113,101,100,58,32,117,110,107,110,111,119,110,32,102,101,97,116,117,114,101,115,32,40,48,120,37,48,56,108,108,120,41,10,0,0,0,0,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,100,99,32,105,109,97,103,101,10,0,0,0,0,0,0,0,0,83,104,111,119,87,105,110,100,111,119,0,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,121,0,0,0,0,0,0,0,113,117,105,101,116,0,0,0,68,105,115,112,111,115,87,105,110,100,111,119,0,0,0,0,100,105,115,107,0,0,0,0,80,67,69,0,0,0,0,0,78,101,119,87,105,110,100,111,119,0,0,0,0,0,0,0,73,110,105,116,87,105,110,100,111,119,115,0,0,0,0,0,45,0,0,0,0,0,0,0,67,104,101,99,107,85,112,100,97,116,101,0,0,0,0,0,71,101,116,87,77,103,114,80,111,114,116,0,0,0,0,0,42,37,117,0,0,0,0,0,68,114,97,119,78,101,119,0,83,97,118,101,79,108,100,0,80,97,105,110,116,66,101,104,105,110,100,0,0,0,0,0,82,101,99,111,118,101,114,72,97,110,100,108,101,0,0,0,80,97,105,110,116,79,110,101,0,0,0,0,0,0,0,0,67,108,105,112,65,98,111,118,101,0,0,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,109,111,100,101,108,0,0,0,0,0,0,0,67,97,108,99,86,66,101,104,105,110,100,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,32,40,99,111,119,41,10,0,0,118,101,110,100,111,114,0,0,67,97,108,99,86,105,115,0,83,104,111,119,72,105,100,101,0,0,0,0,0,0,0,0,37,48,56,108,88,58,32,117,110,100,101,102,105,110,101,100,32,111,112,101,114,97,116,105,111,110,58,32,37,48,52,108,88,32,91,37,48,52,88,32,37,48,52,88,32,37,48,52,88,32,37,48,52,88,32,37,48,52,88,93,10,0,0,0,97,100,98,45,107,98,100,58,32,116,97,108,107,32,50,10,0,0,0,0,0,0,0,0,115,114,0,0,0,0,0,0,83,101,116,83,116,114,105,110,103,0,0,0,0,0,0,0,78,101,119,83,116,114,105,110,103,0,0,0,0,0,0,0,37,115,37,117,37,115,0,0,68,114,97,103,71,114,97,121,82,103,110,0,0,0,0,0,68,114,97,119,71,114,111,119,73,99,111,110,0,0,0,0,83,101,116,70,111,110,116,76,111,99,107,0,0,0,0,0,82,101,97,108,108,111,99,72,97,110,100,108,101,0,0,0,82,101,97,108,70,111,110,116,0,0,0,0,0,0,0,0,54,56,48,48,48,0,0,0,70,77,83,119,97,112,70,111,110,116,0,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,102,97,105,108,101,100,32,102,111,114,32,97,116,32,108,101,97,115,116,32,111,110,101,32,100,105,115,107,10,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,0,0,0,71,101,116,70,78,117,109,0,100,114,105,118,101,0,0,0,71,101,116,70,78,97,109,101,0,0,0,0,0,0,0,0,73,110,105,116,70,111,110,116,115,0,0,0,0,0,0,0,37,48,56,108,88,58,32,101,120,99,101,112,116,105,111,110,32,37,48,50,88,32,40,37,115,41,32,73,87,61,37,48,52,88,10,0,0,0,0,0,80,114,71,108,117,101,0,0,77,97,112,80,111,108,121,0,80,67,0,0,0,0,0,0,77,97,112,82,103,110,0,0,77,97,112,82,101,99,116,0,77,97,112,80,116,0,0,0,72,97,110,100,108,101,90,111,110,101,0,0,0,0,0,0,83,99,97,108,101,80,116,0,76,97,121,111,117,116,0,0,99,111,109,109,105,116,105,110,103,32,97,108,108,32,100,114,105,118,101,115,10,0,0,0,101,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,68,114,97,119,80,105,99,116,117,114,101,0,0,0,0,0,114,119,0,0,0,0,0,0,75,105,108,108,80,105,99,116,117,114,101,0,0,0,0,0,49,0,0,0,0,0,0,0,105,100,0,0,0,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,67,108,111,115,101,80,105,99,116,117,114,101,0,0,0,0,103,98,0,0,0,0,0,0,79,112,101,110,80,105,99,116,117,114,101,0,0,0,0,0,83,79,78,89,58,0,0,0,80,105,99,67,111,109,109,101,110,116,0,0,0,0,0,0,60,69,65,62,40,37,48,50,88,41,0,0,0,0,0,0,83,116,100,67,111,109,109,101,110,116,0,0,0,0,0,0,83,116,100,80,117,116,80,105,99,0,0,0,0,0,0,0,83,99,114,111,108,108,82,101,99,116,0,0,0,0,0,0,71,101,116,72,97,110,100,108,101,83,105,122,101,0,0,0,68,37,117,0,0,0,0,0,83,116,100,71,101,116,80,105,99,0,0,0,0,0,0,0,83,116,100,84,120,77,101,97,115,0,0,0,0,0,0,0,97,108,108,0,0,0,0,0,119,0,0,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,97,102,116,101,114,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,67,111,112,121,66,105,116,115,0,0,0,0,0,0,0,0,114,111,0,0,0,0,0,0,100,101,118,105,99,101,0,0,83,116,100,66,105,116,115,0,83,101,116,83,116,100,80,114,111,99,115,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,82,101,99,116,73,110,82,103,110,0,0,0,0,0,0,0,80,116,73,110,82,103,110,0,37,115,37,115,37,48,50,88,40,80,67,44,32,37,115,37,117,37,115,42,37,117,41,0,88,111,114,82,103,110,0,0,68,105,102,102,82,103,110,0,115,116,100,105,111,58,102,105,108,101,61,0,0,0,0,0,85,110,105,111,110,82,103,110,0,0,0,0,0,0,0,0,83,101,116,72,97,110,100,108,101,83,105,122,101,0,0,0,83,101,99,116,82,103,110,0,69,113,117,97,108,82,103,110,0,0,0,0,0,0,0,0,101,106,101,99,116,105,110,103,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,113,0,0,0,0,0,0,0,105,110,105,45,97,112,112,101,110,100,0,0,0,0,0,0,69,109,112,116,121,82,103,110,0,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,37,115,32,98,108,111,99,107,115,61,37,108,117,32,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,32,37,115,32,102,105,108,101,61,37,115,10,0,97,100,100,114,61,48,120,37,48,54,108,120,32,115,105,122,101,61,48,120,37,108,120,10,0,0,0,0,0,0,0,0,73,110,115,101,116,82,103,110,0,0,0,0,0,0,0,0,79,102,115,101,116,82,103,110,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,82,101,99,116,82,103,110,0,83,101,116,82,101,99,82,103,110,0,0,0,0,0,0,0,37,115,37,48,56,108,88,40,80,67,41,0,0,0,0,0,83,101,116,69,109,112,116,121,82,103,110,0,0,0,0,0,67,111,112,121,82,103,110,0,51,0,0,0,0,0,0,0,67,108,111,115,101,82,103,110,0,0,0,0,0,0,0,0,68,105,115,112,111,115,72,97,110,100,108,101,0,0,0,0,79,112,101,110,82,103,110,0,68,105,115,112,111,115,82,103,110,0,0,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,110,111,32,115,117,99,104,32,100,105,115,107,32,40,37,108,117,41,10,0,0,0,0,0,0,0,84,97,98,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,98,101,102,111,114,101,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,0,0,0,0,0,0,0,78,101,119,82,103,110,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,83,67,83,73,58,0,0,0,66,105,116,77,97,112,84,111,82,101,103,105,111,110,0,0,70,105,108,108,82,103,110,0,117,110,107,110,111,119,110,32,99,111,109,112,111,110,101,110,116,32,40,37,115,41,10,0,73,110,118,101,114,82,103,110,0,0,0,0,0,0,0,0,69,114,97,115,101,82,103,110,0,0,0,0,0,0,0,0,109,97,114,107,58,32,80,67,61,37,48,54,108,88,10,0,37,115,37,115,37,48,52,88,0,0,0,0,0,0,0,0,80,97,105,110,116,82,103,110,0,0,0,0,0,0,0,0,70,114,97,109,101,82,103,110,0,0,0,0,0,0,0,0,83,116,100,82,103,110,0,0,78,101,119,72,97,110,100,108,101,0,0,0,0,0,0,0,85,110,112,97,99,107,66,105,116,115,0,0,0,0,0,0,87,114,105,116,101,0,0,0,80,97,99,107,66,105,116,115,0,0,0,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,66,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,105,110,105,45,112,114,101,102,105,120,0,0,0,0,0,0,79,102,102,115,101,116,80,111,108,121,0,0,0,0,0,0,116,101,108,101,100,105,115,107,0,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,75,105,108,108,80,111,108,121,0,0,0,0,0,0,0,0,67,108,111,115,101,80,103,111,110,0,0,0,0,0,0,0,118,105,97,0,0,0,0,0,79,112,101,110,80,111,108,121,0,0,0,0,0,0,0,0,115,111,110,121,32,100,114,105,118,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,70,105,108,108,80,111,108,121,0,0,0,0,0,0,0,0,46,87,0,0,0,0,0,0,73,110,118,101,114,116,80,111,108,121,0,0,0,0,0,0,69,114,97,115,101,80,111,108,121,0,0,0,0,0,0,0,80,97,105,110,116,80,111,108,121,0,0,0,0,0,0,0,71,101,116,80,116,114,83,105,122,101,0,0,0,0,0,0,70,114,97,109,101,80,111,108,121,0,0,0,0,0,0,0,115,99,115,105,58,32,115,101,116,32,32,56,58,32,37,48,52,108,88,32,60,45,32,37,48,50,88,10,0,0,0,0,83,116,100,80,111,108,121,0,115,101,116,116,105,110,103,32,114,101,97,100,111,110,108,121,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,61,0,0,0,0,0,0,0,65,100,100,32,97,32,100,105,114,101,99,116,111,114,121,32,116,111,32,116,104,101,32,115,101,97,114,99,104,32,112,97,116,104,0,0,0,0,0,0,65,110,103,108,101,70,114,111,109,83,108,111,112,101,0,0,112,115,105,0,0,0,0,0,115,99,115,105,0,0,0,0,80,116,84,111,65,110,103,108,101,0,0,0,0,0,0,0,70,105,108,108,65,114,99,0,115,99,99,0,0,0,0,0,73,110,118,101,114,116,65,114,99,0,0,0,0,0,0,0,69,114,97,115,101,65,114,99,0,0,0,0,0,0,0,0,46,76,0,0,0,0,0,0,80,97,105,110,116,65,114,99,0,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,70,114,97,109,101,65,114,99,0,0,0,0,0,0,0,0,107,101,121,109,97,112,0,0,83,116,100,65,114,99,0,0,83,101,116,80,116,114,83,105,122,101,0,0,0,0,0,0,116,101,114,109,46,101,115,99,97,112,101,0,0,0,0,0,83,108,111,112,101,70,114,111,109,65,110,103,108,101,0,0,70,51,0,0,0,0,0,0,70,105,108,108,79,118,97,108,0,0,0,0,0,0,0,0,115,101,116,116,105,110,103,32,114,101,97,100,47,119,114,105,116,101,32,100,114,105,118,101,32,37,108,117,10,0,0,0,38,38,0,0,0,0,0,0,69,113,117,97,108,0,0,0,112,97,116,104,0,0,0,0,73,110,118,101,114,116,79,118,97,108,0,0,0,0,0,0,112,102,100,99,45,97,117,116,111,0,0,0,0,0,0,0,37,115,58,37,108,117,58,32,37,115,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,100,101,108,97,121,61,37,108,117,10,0,0,0,0,0,69,114,97,115,101,79,118,97,108,0,0,0,0,0,0,0,80,97,105,110,116,79,118,97,108,0,0,0,0,0,0,0,109,101,109,0,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,115,114,101,99,10,0,0,0,0,101,115,99,97,112,101,0,0,98,97,115,101,0,0,0,0,70,114,97,109,101,79,118,97,108,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,99,111,119,32,102,105,108,101,61,37,115,10,0,0,0,0,0,0,91,37,48,54,108,88,93,32,0,0,0,0,0,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,37,115,41,10,0,0,0,0,0,0,0,83,116,100,79,118,97,108,0,99,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,37,115,37,115,37,48,50,88,40,65,37,117,44,32,37,115,37,117,37,115,42,37,117,41,0,0,0,0,0,0,0,0,119,97,118,0,0,0,0,0,116,100,48,58,32,116,114,97,99,107,32,99,114,99,32,40,37,48,50,88,32,37,48,52,88,41,10,0,0,0,0,0,83,99,114,105,112,116,85,116,105,108,0,0,0,0,0,0,115,116,120,58,32,114,101,97,100,32,101,114,114,111,114,32,40,115,101,99,116,111,114,32,104,101,97,100,101,114,41,10,0,0,0,0,0,0,0,0,112,115,105,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,40,37,108,117,41,10,0,0,0,0,0,100,99,52,50,58,32,116,97,103,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,0,70,105,108,108,82,111,117,110,100,82,101,99,116,0,0,0,46,105,109,97,0,0,0,0,73,110,118,101,114,82,111,117,110,100,82,101,99,116,0,0,46,112,98,105,116,0,0,0,68,105,115,112,111,115,80,116,114,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,45,0,0,0,0,0,0,0,120,109,117,108,0,0,0,0,69,114,97,115,101,82,111,117,110,100,82,101,99,116,0,0,115,101,114,99,111,110,0,0,99,111,109,109,105,116,0,0,99,111,109,109,105,116,0,0,99,111,109,109,105,116,0,0,80,97,105,110,116,82,111,117,110,100,82,101,99,116,0,0,115,101,116,116,105,110,103,32,105,119,109,32,100,114,105,118,101,32,37,108,117,32,116,111,32,114,101,97,100,45,111,110,108,121,10,0,0,0,0,0,45,0,0,0,0,0,0,0,48,98,0,0,0,0,0,0,83,101,116,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,70,114,97,109,101,82,111,117,110,100,82,101,99,116,0,0,112,102,100,99,0,0,0,0,83,79,78,89,58,0,0,0,83,116,100,82,82,101,99,116,0,0,0,0,0,0,0,0,69,109,112,116,121,82,101,99,116,0,0,0,0,0,0,0,99,112,117,0,0,0,0,0,80,116,73,110,82,101,99,116,0,0,0,0,0,0,0,0,80,116,50,82,101,99,116,0,40,65,37,117,41,0,0,0,85,110,105,111,110,82,101,99,116,0,0,0,0,0,0,0,83,101,99,116,82,101,99,116,0,0,0,0,0,0,0,0,73,110,115,101,116,82,101,99,116,0,0,0,0,0,0,0,78,101,119,80,116,114,0,0,79,102,102,115,101,116,82,101,99,116,0,0,0,0,0,0,114,98,0,0,0,0,0,0,83,101,116,82,101,99,116,0,115,101,116,116,105,110,103,32,97,108,108,32,105,119,109,32,100,114,105,118,101,115,32,116,111,32,114,101,97,100,45,111,110,108,121,10,0,0,0,0,77,105,110,117,115,0,0,0,48,120,0,0,0,0,0,0,115,116,114,105,110,103,0,0,69,113,117,97,108,82,101,99,116,0,0,0,0,0,0,0,105,109,100,0,0,0,0,0,105,110,115,101,114,116,95,100,101,108,97,121,95,37,117,0,70,105,108,108,82,101,99,116,0,0,0,0,0,0,0,0,73,110,118,101,114,82,101,99,116,0,0,0,0,0,0,0,100,105,115,97,115,115,101,109,98,108,101,0,0,0,0,0,97,100,98,45,107,98,100,58,32,116,97,108,107,32,37,117,10,0,0,0,0,0,0,0,108,112,99,0,0,0,0,0,69,114,97,115,101,82,101,99,116,0,0,0,0,0,0,0,80,97,105,110,116,82,101,99,116,0,0,0,0,0,0,0,37,115,37,117,47,37,115,37,117,0,0,0,0,0,0,0,70,114,97,109,101,82,101,99,116,0,0,0,0,0,0,0,83,116,100,82,101,99,116,0,85,110,105,109,112,108,101,109,101,110,116,101,100,0,0,0,77,97,120,77,101,109,0,0,80,101,110,78,111,114,109,97,108,0,0,0,0,0,0,0,80,101,110,80,97,116,0,0,115,101,116,116,105,110,103,32,105,119,109,32,100,114,105,118,101,32,37,108,117,32,116,111,32,114,101,97,100,47,119,114,105,116,101,10,0,0,0,0,48,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,99,111,110,102,105,103,0,0,80,101,110,77,111,100,101,0,105,109,97,103,101,100,105,115,107,0,0,0,0,0,0,0,102,111,114,109,97,116,95,104,100,95,97,115,95,100,100,0,80,101,110,83,105,122,101,0,71,101,116,80,101,110,0,0,91,91,45,93,97,100,100,114,32,91,99,110,116,93,93,0,83,101,116,80,101,110,83,116,97,116,101,0,0,0,0,0,71,101,116,80,101,110,83,116,97,116,101,0,0,0,0,0,107,98,100,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,48,50,88,41,10,0,0,0,0,37,115,37,117,45,37,115,37,117,0,0,0,0,0,0,0,83,104,111,119,80,101,110,0,72,105,100,101,80,101,110,0,83,104,117,116,100,111,119,110,0,0,0,0,0,0,0,0,70,114,101,101,77,101,109,0,77,111,118,101,0,0,0,0,77,111,118,101,84,111,0,0,115,101,116,116,105,110,103,32,97,108,108,32,105,119,109,32,100,114,105,118,101,115,32,116,111,32,114,101,97,100,47,119,114,105,116,101,10,0,0,0,57,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,83,101,116,32,116,104,101,32,100,105,115,107,32,100,101,108,97,121,32,91,51,48,93,0,76,105,110,101,0,0,0,0,100,99,52,50,0,0,0,0,105,110,115,101,114,116,95,100,101,108,97,121,0,0,0,0,76,105,110,101,84,111,0,0,83,116,100,76,105,110,101,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,10,0,0,0,117,0,0,0,0,0,0,0,79,83,68,105,115,112,97,116,99,104,0,0,0,0,0,0,83,112,97,99,101,69,120,116,114,97,0,0,0,0,0,0,67,104,97,114,87,105,100,116,104,0,0,0,0,0,0,0,83,116,114,105,110,103,87,105,100,116,104,0,0,0,0,0,71,101,116,70,111,110,116,73,110,102,111,0,0,0,0,0,83,101,116,90,111,110,101,0,35,37,115,37,48,52,88,0,84,101,120,116,83,105,122,101,0,0,0,0,0,0,0,0,84,101,120,116,77,111,100,101,0,0,0,0,0,0,0,0,73,87,77,32,100,114,105,118,101,32,37,117,58,32,108,111,99,107,101,100,61,37,100,10,0,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,100,101,102,105,110,101,100,0,100,114,105,118,101,32,100,101,108,97,121,0,0,0,0,0,84,101,120,116,70,97,99,101,0,0,0,0,0,0,0,0,99,112,50,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,32,91,49,93,0,0,0,0,115,111,110,121,0,0,0,0,84,101,120,116,70,111,110,116,0,0,0,0,0,0,0,0,79,82,73,46,66,0,0,0,84,101,120,116,87,105,100,116,104,0,0,0,0,0,0,0,99,108,111,99,107,0,0,0,79,82,73,46,87,0,0,0,68,114,97,119,84,101,120,116,0,0,0,0,0,0,0,0,79,82,73,46,76,0,0,0,68,114,97,119,83,116,114,105,110,103,0,0,0,0,0,0,67,77,80,50,46,66,0,0,67,82,40,37,117,41,0,0,68,114,97,119,67,104,97,114,0,0,0,0,0,0,0,0,67,72,75,50,46,66,0,0,83,116,100,84,101,120,116,0,69,113,117,97,108,80,116,0,71,101,116,90,111,110,101,0,83,101,116,80,116,0,0,0,65,78,68,73,46,66,0,0,83,117,98,80,116,0,0,0,65,78,68,73,46,87,0,0,32,9,0,0,0,0,0,0,43,49,0,0,0,0,0,0,55,0,0,0,0,0,0,0,41,0,0,0,0,0,0,0,100,105,115,107,45,100,101,108,97,121,0,0,0,0,0,0,65,100,100,80,116,0,0,0,65,78,68,73,46,76,0,0,97,110,97,100,105,115,107,0,42,42,42,32,115,101,116,116,105,110,103,32,115,111,117,110,100,32,100,114,105,118,101,114,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,67,108,111,115,101,67,80,111,114,116,0,0,0,0,0,0,67,77,80,50,46,87,0,0,67,108,111,115,101,80,111,114,116,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,67,72,75,50,46,87,0,0,66,97,99,107,80,97,116,0,83,85,66,73,46,66,0,0,67,108,105,112,82,101,99,116,0,0,0,0,0,0,0,0,83,85,66,73,46,87,0,0,86,66,82,0,0,0,0,0,71,101,116,67,108,105,112,0,83,85,66,73,46,76,0,0,83,101,116,67,108,105,112,0,67,77,80,50,46,76,0,0,83,101,116,79,114,105,103,105,110,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,67,72,75,50,46,76,0,0,73,110,105,116,90,111,110,101,0,0,0,0,0,0,0,0,77,111,118,101,80,111,114,116,84,111,0,0,0,0,0,0,65,68,68,73,46,66,0,0,80,111,114,116,83,105,122,101,0,0,0,0,0,0,0,0,65,68,68,73,46,87,0,0,58,0,0,0,0,0,0,0,45,49,0,0,0,0,0,0,54,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,100,105,115,107,32,100,101,108,97,121,32,102,111,114,32,100,114,105,118,101,32,49,32,91,51,48,93,0,0,0,0,0,83,101,116,80,66,105,116,115,0,0,0,0,0,0,0,0,65,68,68,73,46,76,0,0,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,60,110,111,110,101,62,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,71,101,116,80,111,114,116,0,66,84,83,84,0,0,0,0,83,101,116,80,111,114,116,0,112,114,105,110,116,32,115,116,97,116,117,115,32,40,99,112,117,124,109,101,109,124,115,99,99,124,118,105,97,41,0,0,66,67,72,71,0,0,0,0,71,114,97,102,68,101,118,105,99,101,0,0,0,0,0,0,66,67,76,82,0,0,0,0,71,108,111,98,97,108,84,111,76,111,99,97,108,0,0,0,66,83,69,84,0,0,0,0,68,70,67,0,0,0,0,0,76,111,99,97,108,84,111,71,108,111,98,97,108,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,69,79,82,73,46,66,0,0,79,112,101,110,80,111,114,116,0,0,0,0,0,0,0,0,69,79,82,73,46,87,0,0,112,99,101,37,48,52,117,46,112,112,109,0,0,0,0,0,73,110,105,116,71,114,97,102,0,0,0,0,0,0,0,0,69,79,82,73,46,76,0,0,71,101,116,70,80,111,115,0,73,110,105,116,80,111,114,116,0,0,0,0,0,0,0,0,67,77,80,73,46,66,0,0,82,101,97,100,0,0,0,0,70,105,120,82,111,117,110,100,0,0,0,0,0,0,0,0,67,77,80,73,46,87,0,0,49,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,53,0,0,0,0,0,0,0,100,101,108,97,121,0,0,0,76,111,87,111,114,100,0,0,67,77,80,73,46,76,0,0,113,101,100,0,0,0,0,0,32,32,32,0,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,88,32,108,111,119,112,97,115,115,61,37,108,117,32,100,114,105,118,101,114,61,37,115,10,0,0,0,0,0,72,105,87,111,114,100,0,0,77,79,86,83,46,66,0,0,70,105,120,82,97,116,105,111,0,0,0,0,0,0,0,0,91,119,104,97,116,93,0,0,77,79,86,83,46,87,0,0,70,105,120,77,117,108,0,0,77,79,86,83,46,76,0,0,80,67,69,32,82,79,77,32,101,120,116,101,110,115,105,111,110,32,97,116,32,48,120,37,48,54,108,120,10,0,0,0,76,111,110,103,77,117,108,0,83,70,67,0,0,0,0,0,83,116,117,102,102,72,101,120,0,0,0,0,0,0,0,0,77,79,86,69,46,66,0,0,71,101,116,80,105,120,101,108,0,0,0,0,0,0,0,0,77,79,86,69,46,76,0,0,67,111,108,111,114,66,105,116,0,0,0,0,0,0,0,0,69,106,101,99,116,0,0,0,66,97,99,107,67,111,108,111,114,0,0,0,0,0,0,0,70,111,114,101,67,111,108,111,114,0,0,0,0,0,0,0,78,69,71,88,46,66,0,0,115,99,115,105,58,32,103,101,116,32,32,56,58,32,37,48,52,108,88,32,45,62,32,37,48,50,88,10,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,100,105,115,107,45,100,101,108,97,121,45,49,0,0,0,0,82,97,110,100,111,109,0,0,78,69,71,88,46,87,0,0,112,99,101,0,0,0,0,0,32,37,48,50,88,0,0,0,83,79,85,78,68,58,0,0,119,97,114,110,105,110,103,58,32,100,101,108,97,121,32,61,61,32,48,32,97,116,32,37,48,56,108,120,10,0,0,0,87,97,105,116,78,101,120,116,69,118,101,110,116,0,0,0,78,69,71,88,46,76,0,0,69,83,67,0,0,0,0,0,66,105,116,67,108,114,0,0,115,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,114,98,0,0,0,0,0,0,66,105,116,83,101,116,0,0,114,43,98,0,0,0,0,0,66,105,116,84,115,116,0,0,67,76,82,46,66,0,0,0,66,105,116,83,104,105,102,116,0,0,0,0,0,0,0,0,67,76,82,46,87,0,0,0,66,105,116,79,114,0,0,0,67,76,82,46,76,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,63,0,0,0,0,0,0,0,114,101,112,111,114,116,95,107,101,121,115,0,0,0,0,0,66,105,116,78,111,116,0,0,78,69,71,46,66,0,0,0,73,110,105,116,81,117,101,117,101,0,0,0,0,0,0,0,80,54,10,37,117,32,37,117,10,37,117,10,0,0,0,0,66,105,116,88,111,114,0,0,78,69,71,46,87,0,0,0,70,50,0,0,0,0,0,0,66,105,116,65,110,100,0,0,78,69,71,46,76,0,0,0,99,111,109,109,105,116,0,0,109,97,99,46,105,110,115,101,114,116,0,0,0,0,0,0,124,124,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,80,114,105,110,116,32,117,115,97,103,101,32,105,110,102,111,114,109,97,116,105,111,110,0,79,98,115,99,117,114,101,67,117,114,115,111,114,0,0,0,42,42,42,32,110,111,32,116,101,114,109,105,110,97,108,32,102,111,117,110,100,10,0,0,78,79,84,46,66,0,0,0,100,111,115,101,109,117,0,0,60,110,111,110,101,62,0,0,60,45,0,0,0,0,0,0,32,9,0,0,0,0,0,0,100,114,105,118,101,114,0,0,73,78,84,82,0,0,0,0,83,104,105,101,108,100,67,117,114,115,111,114,0,0,0,0,78,79,84,46,87,0,0,0,37,45,57,115,32,0,0,0,70,111,110,116,68,105,115,112,97,116,99,104,0,0,0,0,103,101,116,32,111,114,32,115,101,116,32,97,32,114,101,103,105,115,116,101,114,0,0,0,78,79,84,46,76,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,105,104,101,120,10,0,0,0,0,110,117,108,108,0,0,0,0,97,100,100,114,101,115,115,0,83,104,111,119,67,117,114,115,111,114,0,0,0,0,0,0,77,79,86,69,46,87,0,0,42,42,42,32,99,111,119,32,102,97,105,108,101,100,32,40,100,114,105,118,101,61,37,117,32,102,105,108,101,61,37,115,41,10,0,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,115,105,103,110,97,108,32,37,100,10,0,72,105,100,101,67,117,114,115,111,114,0,0,0,0,0,0,115,0,0,0,0,0,0,0,78,66,67,68,46,66,0,0,121,101,115,0,0,0,0,0,37,117,0,0,0,0,0,0,114,0,0,0,0,0,0,0,110,117,108,108,0,0,0,0,116,100,48,58,32,104,101,97,100,101,114,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,83,101,116,67,117,114,115,111,114,0,0,0,0,0,0,0,109,102,109,0,0,0,0,0,115,116,120,58,32,114,101,97,100,32,101,114,114,111,114,32,40,116,114,97,99,107,32,104,101,97,100,101,114,41,10,0,112,115,105,58,32,111,114,112,104,97,110,101,100,32,97,108,116,101,114,110,97,116,101,32,115,101,99,116,111,114,10,0,112,102,100,99,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,40,37,108,117,41,10,0,0,0,0,100,99,52,50,58,32,100,97,116,97,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,73,110,105,116,67,117,114,115,111,114,0,0,0,0,0,0,83,87,65,80,0,0,0,0,32,45,0,0,0,0,0,0,112,97,114,115,101,32,101,114,114,111,114,32,98,101,102,111,114,101,0,0,0,0,0,0,46,105,109,97,103,101,0,0,112,114,105,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,0,83,101,116,73,116,101,109,67,109,100,0,0,0,0,0,0,112,114,105,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,108,117,41,10,0,0,0,0,0,0,69,88,84,46,87,0,0,0,45,0,0,0,0,0,0,0,83,101,116,86,111,108,0,0,99,104,97,114,45,112,116,121,58,32,37,115,10,0,0,0,119,114,105,116,101,0,0,0,109,115,121,115,0,0,0,0,71,101,116,73,116,101,109,67,109,100,0,0,0,0,0,0,112,111,115,105,120,0,0,0,69,88,84,46,76,0,0,0,119,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,70,105,120,68,105,118,0,0,69,88,84,66,46,76,0,0,114,0,0,0,0,0,0,0,101,109,117,46,118,105,100,101,111,46,98,114,105,103,104,116,110,101,115,115,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,37,0,0,0,0,0,0,0,104,101,108,112,0,0,0,0,85,115,101,114,68,101,108,97,121,0,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,58,32,37,115,10,0,0,0,0,0,0,0,0,84,83,84,46,66,0,0,0,105,109,97,103,101,0,0,0,116,114,117,101,0,0,0,0,45,62,0,0,0,0,0,0,108,111,119,112,97,115,115,0,84,82,65,80,0,0,0,0,70,114,97,99,68,105,118,0,84,83,84,46,87,0,0,0,70,114,97,99,77,117,108,0,114,101,103,32,91,118,97,108,93,0,0,0,0,0,0,0,84,83,84,46,76,0,0,0,70,114,97,99,83,113,114,116,0,0,0,0,0,0,0,0,70,114,97,99,83,105,110,0,68,37,117,58,68,37,117,0,70,114,97,99,67,111,115,0,77,85,76,85,46,76,0,0,88,50,70,114,97,99,0,0,68,73,86,85,46,76,0,0,70,114,97,99,50,88,0,0,71,101,116,86,111,108,0,0,88,50,70,105,120,0,0,0,70,105,120,50,88,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,117,115,97,103,101,58,32,112,99,101,45,109,97,99,112,108,117,115,32,91,111,112,116,105,111,110,115,93,0,0,0,0,70,114,97,99,50,70,105,120,0,0,0,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,110,117,108,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,77,79,86,69,0,0,0,0,114,97,109,0,0,0,0,0,37,115,32,37,48,50,88,0,115,111,117,110,100,0,0,0,65,86,69,67,0,0,0,0,70,105,120,50,70,114,97,99,0,0,0,0,0,0,0,0,85,78,76,75,0,0,0,0,70,105,120,50,76,111,110,103,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,97,100,98,45,107,98,100,58,32,108,105,115,116,101,110,32,37,117,10,0,0,0,0,0,76,73,78,75,0,0,0,0,97,0,0,0,0,0,0,0,112,99,0,0,0,0,0,0,76,111,110,103,50,70,105,120,0,0,0,0,0,0,0,0,84,82,65,80,0,0,0,0,84,69,83,116,121,108,101,78,101,119,0,0,0,0,0,0,77,79,86,69,67,0,0,0,114,98,0,0,0,0,0,0,85,83,80,0,0,0,0,0,84,69,68,105,115,112,97,116,99,104,0,0,0,0,0,0,84,69,71,101,116,79,102,102,115,101,116,0,0,0,0,0,84,82,65,80,86,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,84,114,97,99,107,66,111,120,0,0,0,0,0,0,0,0,70,108,117,115,104,86,111,108,0,0,0,0,0,0,0,0,90,111,111,109,87,105,110,100,111,119,0,0,0,0,0,0,114,97,109,0,0,0,0,0,83,101,101,100,70,105,108,108,0,0,0,0,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,102,105,108,101,0,0,0,0,0,0,0,0,67,97,108,99,77,97,115,107,0,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,96,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,112,99,101,45,109,97,99,112])
.concat([108,117,115,58,32,77,97,99,105,110,116,111,115,104,32,80,108,117,115,32,101,109,117,108,97,116,111,114,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,115,100,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,0,83,84,79,80,0,0,0,0,114,98,0,0,0,0,0,0,45,45,32,37,115,61,37,100,10,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,70,82,77,84,0,0,0,0,77,101,97,115,117,114,101,84,101,120,116,0,0,0,0,0,71,101,116,77,97,115,107,84,97,98,108,101,0,0,0,0,101,120,101,99,117,116,101,32,116,111,32,110,101,120,116,32,114,116,101,0,0,0,0,0,82,69,83,69,84,0,0,0,70,111,110,116,77,101,116,114,105,99,115,0,0,0,0,0,83,101,116,70,83,99,97,108,101,68,105,115,97,98,108,101,0,0,0,0,0,0,0,0,65,68,68,81,46,66,0,0,99,111,119,0,0,0,0,0,83,82,0,0,0,0,0,0,83,99,114,110,66,105,116,77,97,112,0,0,0,0,0,0,60,110,111,110,101,62,0,0,65,68,68,81,46,87,0,0,37,115,10,10,0,0,0,0,80,97,99,107,49,53,0,0,65,68,68,81,46,76,0,0,80,97,99,107,49,52,0,0,73,87,77,58,32,68,37,117,32,84,114,97,99,107,32,37,117,32,32,32,32,13,0,0,84,82,65,80,76,69,0,0,80,97,99,107,49,51,0,0,83,101,116,69,79,70,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,115,101,103,109,101,110,116,97,116,105,111,110,32,102,97,117,108,116,10,0,0,0,0,0,0,0,0,84,82,65,80,71,84,0,0,80,97,99,107,49,50,0,0,84,82,65,80,76,84,0,0,101,109,117,46,115,101,114,112,111,114,116,46,100,114,105,118,101,114,0,0,0,0,0,0,56,0,0,0,0,0,0,0,66,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,37,108,117,0,0,0,0,0,101,108,115,101,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,32,118,101,114,115,105,111,110,32,50,48,49,52,48,49,49,53,45,54,51,97,99,102,98,54,45,109,111,100,10,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,50,48,48,55,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,0,80,97,99,107,49,49,0,0,115,100,108,0,0,0,0,0,84,82,65,80,71,69,0,0,102,105,108,101,0,0,0,0,82,73,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,70,88,88,88,0,0,0,0,80,97,99,107,49,48,0,0,84,82,65,80,77,73,0,0,80,97,99,107,57,0,0,0,114,116,101,0,0,0,0,0,84,82,65,80,80,76,0,0,67,111,109,112,111,110,101,110,116,68,105,115,112,97,116,99,104,0,0,0,0,0,0,0,37,52,117,32,32,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,40,100,105,115,107,41,10,0,0,0,84,82,65,80,86,83,0,0,49,0,0,0,0,0,0,0,76,97,121,101,114,68,105,115,112,97,116,99,104,0,0,0,84,82,65,80,86,67,0,0,119,97,118,0,0,0,0,0,83,104,111,119,68,73,116,101,109,0,0,0,0,0,0,0,84,82,65,80,69,81,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,97,117,100,105,111,32,115,117,98,115,121,115,116,101,109,32,40,37,115,41,10,0,0,0,0,0,0,0,72,105,100,101,68,73,116,101,109,0,0,0,0,0,0,0,84,82,65,80,78,69,0,0,119,97,118,102,105,108,116,101,114,0,0,0,0,0,0,0,73,110,115,77,101,110,117,73,116,101,109,0,0,0,0,0,84,82,65,80,67,83,0,0,71,101,116,69,79,70,0,0,66,70,73,78,83,0,0,0,65,108,105,97,115,68,105,115,112,97,116,99,104,0,0,0,84,82,65,80,67,67,0,0,82,101,115,111,117,114,99,101,68,105,115,112,97,116,99,104,0,0,0,0,0,0,0,0,84,82,65,80,76,83,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,112,99,101,0,0,0,0,0,55,0,0,0,0,0,0,0,80,97,117,115,101,0,0,0,45,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,32,118,101,114,115,105,111,110,32,50,48,49,52,48,49,49,53,45,54,51,97,99,102,98,54,45,109,111,100,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,50,48,48,55,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,0,0,77,97,120,83,105,122,101,82,115,114,99,0,0,0,0,0,42,42,42,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,32,39,120,49,49,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,84,82,65,80,72,73,0,0,111,112,116,105,111,110,97,108,0,0,0,0,0,0,0,0,67,68,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,88,32,119,61,37,117,32,104,61,37,117,32,98,114,105,103,104,116,61,37,117,37,37,10,0,0,0,0,0,65,88,88,88,0,0,0,0,71,101,116,49,78,97,109,101,100,82,101,115,111,117,114,99,101,0,0,0,0,0,0,0,84,82,65,80,70,0,0,0,71,101,116,49,82,101,115,111,117,114,99,101,0,0,0,0,114,101,115,101,116,0,0,0,84,82,65,80,84,0,0,0,116,99,58,32,117,110,107,110,111,119,110,32,109,97,114,107,32,48,120,37,48,50,120,32,40,37,115,44,32,99,61,37,117,44,32,104,61,37,117,44,32,98,105,116,61,37,108,117,47,37,108,117,41,10,0,0,73,110,118,97,108,77,101,110,117,66,97,114,0,0,0,0,68,66,76,69,0,0,0,0,67,111,117,110,116,49,84,121,112,101,115,0,0,0,0,0,68,66,71,84,0,0,0,0,37,115,37,48,56,108,88,0,72,67,114,101,97,116,101,82,101,115,70,105,108,101,0,0,68,66,76,84,0,0,0,0,72,79,112,101,110,82,101,115,70,105,108,101,0,0,0,0,68,66,71,69,0,0,0,0,112,102,100,99,58,32,99,114,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,88,77,117,110,103,101,114,0,68,66,77,73,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,50,32,102,105,108,101,10,0,0,0,0,0,0,0,65,108,108,111,99,97,116,101,0,0,0,0,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,49,32,102,105,108,101,10,0,0,0,0,0,0,0,70,105,120,65,116,97,110,50,0,0,0,0,0,0,0,0,115,111,110,121,58,32,114,101,97,100,32,101,114,114,111,114,32,97,116,32,37,117,47,37,117,47,37,117,10,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,48,32,102,105,108,101,10,0,0,0,0,0,0,0,68,66,80,76,0,0,0,0,115,99,115,105,58,32,109,111,100,101,32,115,101,110,115,101,58,32,117,110,107,110,111,119,110,32,109,111,100,101,32,112,97,103,101,32,40,37,48,50,88,41,10,0,0,0,0,0,67,111,112,121,77,97,115,107,0,0,0,0,0,0,0,0,68,66,86,83,0,0,0,0,101,109,117,46,114,101,97,108,116,105,109,101,46,116,111,103,103,108,101,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,54,0,0,0,0,0,0,0,83,99,114,76,107,0,0,0,43,0,0,0,0,0,0,0,99,97,110,39,116,32,111,112,101,110,32,105,110,99,108,117,100,101,32,102,105,108,101,58,0,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,102,97,105,108,101,100,10,0,80,97,99,107,56,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,0,0,0,0,120,49,49,0,0,0,0,0,68,66,86,67,0,0,0,0,114,101,97,100,111,110,108,121,0,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,68,83,82,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,44,32,115,107,105,112,32,99,97,108,108,115,32,91,49,93,0,0,0,0,0,0,0,0,86,73,68,69,79,58,0,0,84,82,65,67,69,0,0,0,83,67,83,73,68,105,115,112,97,116,99,104,0,0,0,0,68,66,69,81,0,0,0,0,83,101,116,70,114,97,99,116,69,110,97,98,108,101,0,0,91,99,110,116,93,0,0,0,68,66,78,69,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,32,115,101,99,116,111,114,32,100,97,116,97,32,116,111,111,32,98,105,103,32,40,37,117,41,10,0,0,0,0,0,0,0,0,84,69,65,117,116,111,86,105,101,119,0,0,0,0,0,0,68,66,67,83,0,0,0,0,84,69,80,105,110,83,99,114,111,108,108,0,0,0,0,0,68,66,67,67,0,0,0,0,35,37,115,37,88,0,0,0,84,69,83,101,108,86,105,101,119,0,0,0,0,0,0,0,68,66,76,83,0,0,0,0,85,110,105,113,117,101,49,73,68,0,0,0,0,0,0,0,68,66,72,73,0,0,0,0,71,101,116,49,73,120,84,121,112,101,0,0,0,0,0,0,68,66,70,0,0,0,0,0,71,101,116,49,73,120,82,101,115,111,117,114,99,101,0,0,77,111,117,110,116,86,111,108,0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,115,111,110,121,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,68,66,84,0,0,0,0,0,65,80,80,76,69,32,67,79,77,80,85,84,69,82,44,32,73,78,67,0,0,0,0,0,67,111,117,110,116,49,82,101,115,111,117,114,99,101,115,0,83,76,69,0,0,0,0,0,101,109,117,46,114,101,97,108,116,105,109,101,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,53,0,0,0,0,0,0,0,83,99,114,111,108,108,76,111,99,107,0,0,0,0,0,0,62,62,0,0,0,0,0,0,63,0,0,0,0,0,0,0,102,105,108,101,61,34,37,115,34,10,0,0,0,0,0,0,82,71,101,116,82,101,115,111,117,114,99,101,0,0,0,0,98,97,115,101,0,0,0,0,69,83,67,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,111,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,115,105,122,101,103,0,0,0,83,71,84,0,0,0,0,0,114,98,0,0,0,0,0,0,82,84,83,0,0,0,0,0,46,97,110,97,0,0,0,0,98,114,105,103,104,116,110,101,115,115,0,0,0,0,0,0,80,82,73,86,0,0,0,0,80,111,112,85,112,77,101,110,117,83,101,108,101,99,116,0,83,76,84,0,0,0,0,0,71,101,116,87,86,97,114,105,97,110,116,0,0,0,0,0,112,0,0,0,0,0,0,0,83,71,69,0,0,0,0,0,71,101,116,67,86,97,114,105,97,110,116,0,0,0,0,0,83,77,73,0,0,0,0,0,73,110,105,116,80,114,111,99,77,101,110,117,0,0,0,0,83,80,76,0,0,0,0,0,35,37,115,37,48,56,108,88,0,0,0,0,0,0,0,0,83,110,100,78,101,119,67,104,97,110,110,101,108,0,0,0,83,86,83,0,0,0,0,0,83,110,100,67,111,110,116,114,111,108,0,0,0,0,0,0,114,98,0,0,0,0,0,0,103,99,114,58,32,100,97,116,97,32,99,114,99,32,101,114,114,111,114,32,40,37,117,47,37,117,47,37,117,41,10,0,49,0,0,0,0,0,0,0,83,86,67,0,0,0,0,0,102,105,108,101,0,0,0,0,69,120,116,114,97,49,54,0,83,110,100,80,108,97,121,0,115,121,109,108,105,110,107,0,83,69,81,0,0,0,0,0,85,110,109,111,117,110,116,86,111,108,0,0,0,0,0,0,69,120,116,114,97,49,53,0,102,105,108,101,0,0,0,0,83,110,100,68,111,73,109,109,101,100,105,97,116,101,0,0,115,111,110,121,58,32,110,111,110,45,97,108,105,103,110,101,100,32,114,101,97,100,10,0,83,78,69,0,0,0,0,0,67,108,111,115,101,0,0,0,115,99,115,105,58,32,115,116,97,114,116,47,115,116,111,112,32,117,110,105,116,32,37,117,32,40,37,115,41,10,0,0,69,120,116,114,97,49,52,0,112,114,111,116,111,99,111,108,0,0,0,0,0,0,0,0,83,110,100,68,111,67,111,109,109,97,110,100,0,0,0,0,83,67,83,0,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,121,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,80,114,116,83,99,110,0,0,60,60,0,0,0,0,0,0,69,120,116,114,97,49,51,0,105,110,99,108,117,100,101,0,83,110,100,65,100,100,77,111,100,105,102,105,101,114,0,0,97,100,100,114,101,115,115,0,67,79,78,70,73,71,58,0,100,114,105,118,101,114,61,37,115,32,69,83,67,61,37,115,32,97,115,112,101,99,116,61,37,117,47,37,117,32,109,105,110,95,115,105,122,101,61,37,117,42,37,117,32,115,99,97,108,101,61,37,117,32,109,111,117,115,101,61,91,37,117,47,37,117,32,37,117,47,37,117,93,10,0,0,0,0,0,0,82,79,77,58,0,0,0,0,115,105,122,101,109,0,0,0,83,67,67,0,0,0,0,0,46,120,100,102,0,0,0,0,68,84,82,0,0,0,0,0,69,120,116,114,97,49,50,0,99,111,108,111,114,49,0,0,79,70,76,87,0,0,0,0,83,110,100,68,105,115,112,111,115,101,67,104,97,110,110,101,108,0,0,0,0,0,0,0,83,76,83,0,0,0,0,0,69,120,116,114,97,49,49,0,83,111,117,110,100,68,105,115,112,97,116,99,104,0,0,0,115,101,116,32,104,97,108,116,32,115,116,97,116,101,32,91,50,93,0,0,0,0,0,0,83,72,73,0,0,0,0,0,69,120,116,114,97,49,48,0,109,111,117,115,101,0,0,0,72,87,80,114,105,118,0,0,83,70,0,0,0,0,0,0,114,98,0,0,0,0,0,0,69,120,116,114,97,57,0,0,80,67,69,32,82,79,77,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,69,103,114,101,116,68,105,115,112,97,116,99,104,0,0,0,83,84,0,0,0,0,0,0,114,98,0,0,0,0,0,0,35,37,115,37,48,50,88,0,69,120,116,114,97,56,0,0,114,98,0,0,0,0,0,0,84,114,97,110,115,108,97,116,101,50,52,116,111,51,50,0,83,85,66,81,46,66,0,0,69,120,116,114,97,55,0,0,68,79,83,69,77,85,0,0,83,121,115,69,110,118,105,114,111,110,115,0,0,0,0,0,83,85,66,81,46,87,0,0,69,120,116,114,97,54,0,0,68,101,102,101,114,85,115,101,114,70,110,0,0,0,0,0,83,85,66,81,46,76,0,0,83,101,116,70,105,108,101,73,110,102,111,0,0,0,0,0,69,120,116,114,97,53,0,0,68,101,98,117,103,85,116,105,108,0,0,0,0,0,0,0,115,111,110,121,58,32,119,114,105,116,101,32,101,114,114,111,114,10,0,0,0,0,0,0,66,76,69,0,0,0,0,0,108,111,97,100,32,109,101,100,105,97,0,0,0,0,0,0,69,120,116,114,97,52,0,0,67,111,109,109,84,111,111,108,98,111,120,68,105,115,112,97,116,99,104,0,0,0,0,0,66,71,84,0,0,0,0,0,80,67,69,68,73,83,75,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,0,0,0,0,0,0,0,99,111,109,109,105,116,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,120,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,80,114,105,110,116,83,99,114,101,101,110,0,0,0,0,0,62,0,0,0,0,0,0,0,69,120,116,114,97,51,0,0,105,102,0,0,0,0,0,0,121,0,0,0,0,0,0,0,83,108,101,101,112,0,0,0,102,105,108,101,0,0,0,0,84,69,82,77,58,0,0,0,114,111,109,0,0,0,0,0,115,105,122,101,107,0,0,0,66,76,84,0,0,0,0,0,46,116,100,48,0,0,0,0,67,84,83,0,0,0,0,0,69,120,116,114,97,50,0,0,99,111,108,111,114,48,0,0,67,72,75,0,0,0,0,0,73,79,80,77,111,118,101,68,97,116,97,0,0,0,0,0,66,71,69,0,0,0,0,0,114,98,0,0,0,0,0,0,69,120,116,114,97,49,0,0,73,79,80,77,115,103,82,101,113,117,101,115,116,0,0,0,91,118,97,108,93,0,0,0,66,77,73,0,0,0,0,0,82,105,103,104,116,0,0,0,73,79,80,73,110,102,111,65,99,99,101,115,115,0,0,0,66,80,76,0,0,0,0,0,68,111,119,110,0,0,0,0,80,77,103,114,79,112,0,0,66,86,83,0,0,0,0,0,76,101,102,116,0,0,0,0,71,101,116,79,83,68,101,102,97,117,108,116,0,0,0,0,66,86,67,0,0,0,0,0,85,112,0,0,0,0,0,0,83,101,116,79,83,68,101,102,97,117,108,116,0,0,0,0,66,69,81,0,0,0,0,0,101,109,117,46,99,112,117,46,109,111,100,101,108,0,0,0,80,97,103,101,68,111,119,110,0,0,0,0,0,0,0,0,66,76,75,32,37,48,52,88,58,32,65,49,61,37,48,56,108,88,32,65,50,61,37,48,56,108,88,32,83,61,37,48,56,108,88,32,82,79,61,37,100,10,0,0,0,0,0,0,98,111,114,100,101,114,0,0,68,84,73,110,115,116,97,108,108,0,0,0,0,0,0,0,66,78,69,0,0,0,0,0,119,98,0,0,0,0,0,0,71,101,116,70,105,108,101,73,110,102,111,0,0,0,0,0,69,110,100,0,0,0,0,0,83,101,116,86,105,100,101,111,68,101,102,97,117,108,116,0,115,111,110,121,58,32,110,111,110,45,97,108,105,103,110,101,100,32,119,114,105,116,101,10,0,0,0,0,0,0,0,0,66,67,83,0,0,0,0,0,101,106,101,99,116,32,109,101,100,105,97,0,0,0,0,0,68,101,108,101,116,101,0,0,70,49,0,0,0,0,0,0,71,101,116,86,105,100,101,111,68,101,102,97,117,108,116,0,114,43,98,0,0,0,0,0,119,43,98,0,0,0,0,0,66,67,67,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,50,0,0,0,0,0,0,0,70,49,50,0,0,0,0,0,60,0,0,0,0,0,0,0,80,97,103,101,85,112,0,0,61,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,87,97,105,116,0,0,0,0,102,111,114,109,97,116,0,0,109,97,99,112,108,117,115,0,109,111,117,115,101,95,100,105,118,95,121,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,97,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,115,105,122,101,0,0,0,0,66,76,83,0,0,0,0,0,65,32,32,37,48,56,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,82,101,108,101,97,115,101,32,54,46,48,10,36,48,0,0,114,98,0,0,0,0,0,0,46,116,99,0,0,0,0,0,45,45,32,37,108,117,32,37,117,37,115,37,117,10,0,0,112,97,116,104,0,0,0,0,72,111,109,101,0,0,0,0,102,97,108,115,101,0,0,0,104,97,108,116,0,0,0,0,104,101,105,103,104,116,0,0,68,73,86,90,0,0,0,0,83,101,116,68,101,102,97,117,108,116,83,116,97,114,116,117,112,0,0,0,0,0,0,0,66,72,73,0,0,0,0,0,73,110,115,101,114,116,0,0,71,101,116,68,101,102,97,117,108,116,83,116,97,114,116,117,112,0,0,0,0,0,0,0,60,110,111,110,101,62,0,0,66,83,82,0,0,0,0,0,76,111,97,100,58,0,0,0,100,114,105,118,101,114,0,0,102,105,108,101,0,0,0,0,75,80,95,80,101,114,105,111,100,0,0,0,0,0,0,0,65,68,66,79,112,0,0,0,66,82,65,0,0,0,0,0,68,73,83,75,58,0,0,0,99,112,117,0,0,0,0,0,75,80,95,48,0,0,0,0,65,68,66,82,101,73,110,105,116,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,46,83,0,0,0,0,0,0,116,114,117,101,0,0,0,0,119,98,0,0,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,111,112,101,110,105,110,103,32,111,117,116,112,117,116,32,40,37,115,41,10,0,0,0,0,0,108,111,119,112,97,115,115,0,45,0,0,0,0,0,0,0,75,80,95,69,110,116,101,114,0,0,0,0,0,0,0,0,116,100,48,58,32,97,100,118,97,110,99,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,83,101,116,65,68,66,73,110,102,111,0,0,0,0,0,0,102,109,0,0,0,0,0,0,77,79,86,69,81,0,0,0,115,116,120,58,32,98,97,100,32,109,97,103,105,99,10,0,112,115,105,58,32,99,114,99,32,101,114,114,111,114,10,0,112,102,100,99,58,32,111,114,112,104,97,110,101,100,32,97,108,116,101,114,110,97,116,101,32,115,101,99,116,111,114,10,0,0,0,0,0,0,0,0,75,80,95,51,0,0,0,0,73,77,68,32,49,46,49,55,58,32,37,50,100,47,37,50,100,47,37,52,100,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,0,0,6,78,111,110,97,109,101,0,71,101,116,65,68,66,73,110,102,111,0,0,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,0,0,68,73,86,85,46,87,0,0,75,80,95,50,0,0,0,0,46,99,112,50,0,0,0,0,112,114,105,58,32,99,114,99,32,101,114,114,111,114,10,0,71,101,116,73,110,100,65,68,66,0,0,0,0,0,0,0,112,114,105,58,32,99,114,99,32,101,114,114,111,114,10,0,79,82,46,66,0,0,0,0,119,98,0,0,0,0,0,0,102,108,117,115,104,0,0,0,42,42,42,32,101,114,114,111,114,32,99,114,101,97,116,105,110,103,32,115,121,109,108,105,110,107,32,37,115,32,45,62,32,37,115,10,0,0,0,0,82,101,110,97,109,101,0,0,114,101,97,100,0,0,0,0,109,105,99,114,111,115,111,102,116,0,0,0,0,0,0,0,75,80,95,49,0,0,0,0,67,111,117,110,116,65,68,66,115,0,0,0,0,0,0,0,110,117,108,108,0,0,0,0,115,111,110,121,58,32,112,114,105,109,101,58,32,117,110,107,110,111,119,110,32,40,116,114,97,112,61,48,120,37,48,52,120,41,10,0,0,0,0,0,114,43,98,0,0,0,0,0,83,66,67,68,46,66,0,0,114,43,98,0,0,0,0,0,114,43,98,0,0,0,0,0,114,98,0,0,0,0,0,0,115,116,97,114,116,32,109,111,116,111,114,0,0,0,0,0,75,80,95,54,0,0,0,0,114,43,98,0,0,0,0,0,83,73,110,116,82,101,109,111,118,101,0,0,0,0,0,0,79,82,46,87,0,0,0,0,101,109,117,46,105,119,109,46,115,116,97,116,117,115,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,70,49,49,0,0,0,0,0,62,61,0,0,0,0,0,0,75,80,95,53,0,0,0,0,63,61,0,0,0,0,0,0,113,0,0,0,0,0,0,0,83,73,110,116,73,110,115,116,97,108,108,0,0,0,0,0,108,111,97,100,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,109,111,117,115,101,95,109,117,108,95,121,0,0,0,0,0,42,42,42,32,109,101,109,111,114,121,32,98,108,111,99,107,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,98,108,111,99,107,115,0,0,79,82,46,76,0,0,0,0,83,32,32,37,48,52,88,58,37,48,52,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,0,0,0,116,100,48,58,32,99,111,109,109,101,110,116,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,82,101,108,101,97,115,101,32,53,46,48,49,36,48,0,0,46,115,116,120,0,0,0,0,63,0,0,0,0,0,0,0,75,80,95,52,0,0,0,0,119,105,100,116,104,0,0,0,73,76,76,71,0,0,0,0,68,111,86,66,76,84,97,115,107,0,0,0,0,0,0,0,68,73,86,83,46,87,0,0,65,116,116,97,99,104,86,66,76,0,0,0,0,0,0,0,75,80,95,80,108,117,115,0,42,42,42,32,117,110,107,110,111,119,110,32,109,111,100,101,108,32,40,37,115,41,10,0,114,117,110,0,0,0,0,0,83,85,66,65,46,87,0,0,83,108,111,116,86,82,101,109,111,118,101,0,0,0,0,0,75,80,95,57,0,0,0,0,109,97,99,45,99,108,97,115,115,105,99,0,0,0,0,0,83,85,66,46,66,0,0,0,83,108,111,116,86,73,110,115,116,97,108,108,0,0,0,0,75,80,95,56,0,0,0,0,109,97,99,45,115,101,0,0,83,85,66,88,46,66,0,0,83,108,111,116,77,97,110,97,103,101,114,0,0,0,0,0,37,115,37,115,37,48,52,88,40,65,37,117,41,0,0,0,75,80,95,55,0,0,0,0,109,111,100,101,108,61,37,115,10,0,0,0,0,0,0,0,83,85,66,46,87,0,0,0,73,110,105,116,69,118,101,110,116,115,0,0,0,0,0,0,75,80,95,77,105,110,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,58,0,83,85,66,88,46,87,0,0,73,110,105,116,70,83,0,0,75,80,95,83,116,97,114,0,109,97,99,45,112,108,117,115,0,0,0,0,0,0,0,0,83,85,66,46,76,0,0,0,72,83,101,116,83,116,97,116,101,0,0,0,0,0,0,0,79,112,101,110,82,70,0,0,75,80,95,83,108,97,115,104,0,0,0,0,0,0,0,0,115,121,115,116,101,109,0,0,115,111,110,121,58,32,102,111,114,109,97,116,116,101,100,32,100,105,115,107,32,40,37,108,117,32,98,108,111,99,107,115,41,10,0,0,0,0,0,0,83,85,66,88,46,76,0,0,72,71,101,116,83,116,97,116,101,0,0,0,0,0,0,0,115,116,111,112,32,109,111,116,111,114,0,0,0,0,0,0,78,117,109,76,111,99,107,0,100,105,115,97,98,108,105,110,103,32,109,101,109,111,114,121,32,116,101,115,116,10,0,0,83,85,66,65,46,76,0,0,101,109,117,46,105,119,109,46,114,119,0,0,0,0,0,0,72,67,108,114,82,66,105,116,0,0,0,0,0,0,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,70,49,48,0,0,0,0,0,60,61,0,0,0,0,0,0,67,116,114,108,82,105,103,104,116,0,0,0,0,0,0,0,125,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,82,65,77,58,0,0,0,0,98,105,110,97,114,121,0,0,109,111,117,115,101,95,100,105,118,95,120,0,0,0,0,0,99,112,117,46,115,112,101,101,100,32,61,32,0,0,0,0,60,110,111,110,101,62,0,0,115,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,67,77,80,46,66,0,0,0,69,32,32,34,37,115,34,10,0,0,0,0,0,0,0,0,116,100,48,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,82,101,108,101,97,115,101,32,52,46,48,48,36,48,0,0,72,83,101,116,82,66,105,116,0,0,0,0,0,0,0,0,46,115,116,0,0,0,0,0,69,0,0,0,0,0,0,0,77,101,110,117,0,0,0,0,97,100,100,114,101,115,115,0,65,68,68,82,0,0,0,0,109,101,109,116,101,115,116,0,67,77,80,46,87,0,0,0,78,101,119,69,109,112,116,121,72,97,110,100,108,101,0,0,87,105,110,100,111,119,115,82,105,103,104,116,0,0,0,0,42,42,42,32,82,79,77,32,110,111,116,32,102,111,117,110,100,32,97,116,32,52,48,48,48,48,48,10,0,0,0,0,105,103,110,111,114,105,110,103,32,112,99,101,32,107,101,121,58,32,48,120,37,48,52,120,32,40,37,115,41,10,0,0,97,100,98,58,32,117,110,107,110,111,119,110,32,99,109,100,32,40,37,48,50,88,41,10,0,0,0,0,0,0,0,0])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _llvm_dbg_value() {
  Module['printErr']('missing function: llvm_dbg_value'); abort(-1);
  }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i64=_memset;
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  var _llvm_dbg_declare=undefined;
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      var steps = 0;
      var stepStart;
      var stepEnd;
      var sampleStep = false;
      function step_run(){
        // if (sampleStep) {
        //   console.log('yield time', new Date() - stepEnd);
        // }
        // steps++;
        // sampleStep = steps % 10 == 0
        // if (sampleStep) {
        //   console.log('step',steps)
        //   stepStart = new Date();
        // }
        Runtime.dynCall('v', func);
        // if (sampleStep) {
        //   stepEnd = new Date();
        //   console.log('step time',stepEnd - stepStart);
        // }
        // step_req();
        setTimeout(step_run);
      }
      Browser.step_func = step_run;
      step_run();
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,ELBIN:75,EDOTDOT:76,EBADMSG:77,EFTYPE:79,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENMFILE:89,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EPROCLIM:130,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,ENOSHARE:136,ECASECLASH:137,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  var __impure_ptr=allocate(1, "i32*", ALLOC_STATIC);var FS={currentPath:"/",nextInode:2,streams:[null],ignorePermissions:true,createFileHandle:function (stream, fd) {
        if (typeof stream === 'undefined') {
          stream = null;
        }
        if (!fd) {
          if (stream && stream.socket) {
            for (var i = 1; i < 64; i++) {
              if (!FS.streams[i]) {
                fd = i;
                break;
              }
            }
            assert(fd, 'ran out of low fds for sockets');
          } else {
            fd = Math.max(FS.streams.length, 64);
            for (var i = FS.streams.length; i < fd; i++) {
              FS.streams[i] = null; // Keep dense
            }
          }
        }
        // Close WebSocket first if we are about to replace the fd (i.e. dup2)
        if (FS.streams[fd] && FS.streams[fd].socket && FS.streams[fd].socket.close) {
          FS.streams[fd].socket.close();
        }
        FS.streams[fd] = stream;
        return fd;
      },removeFileHandle:function (fd) {
        FS.streams[fd] = null;
      },joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile) {
        Browser.init();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        FS.ensureRoot();
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === 10) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        stdin.isTerminal = !stdinOverridden;
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        stdout.isTerminal = !stdoutOverridden;
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        stderr.isTerminal = !stderrOverridden;
        FS.createDevice(devFolder, 'tty', input, output);
        FS.createDevice(devFolder, 'null', function(){}, function(){});
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        // TODO: put these low in memory like we used to assert on: assert(Math.max(_stdin, _stdout, _stderr) < 15000); // make sure these are low, we flatten arrays with these
        HEAP32[((_stdin)>>2)]=1;
        HEAP32[((_stdout)>>2)]=2;
        HEAP32[((_stderr)>>2)]=3;
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_NORMAL) ], 'void*', ALLOC_NONE, __impure_ptr);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output(10);
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output(10);
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'jpeg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(name.lastIndexOf('.')+1)];
        }
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          if (Module["canvasFront"]) {
            var rect = Module["canvasFront"].getBoundingClientRect();
          } else {
            var rect = Module["canvas"].getBoundingClientRect();
          }
          var x = event.pageX - (window.scrollX + rect.left);
          var y = event.pageY - (window.scrollY + rect.top);
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var SDL={defaults:{width:320,height:200,copyOnLock:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,keyboardState:null,keyboardMap:{},textInput:false,startTime:null,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},keyCodes:{16:1249,17:1248,18:1250,33:1099,34:1102,37:1104,38:1106,39:1103,40:1105,46:127,96:1112,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,173:45,188:44,190:46,191:47,192:96},scanCodes:{9:43,13:40,27:41,32:44,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,92:49,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,305:224,308:226},structs:{Rect:{__size__:16,x:0,y:4,w:8,h:12},PixelFormat:{__size__:36,format:0,palette:4,BitsPerPixel:8,BytesPerPixel:9,padding1:10,padding2:11,Rmask:12,Gmask:16,Bmask:20,Amask:24,Rloss:28,Gloss:29,Bloss:30,Aloss:31,Rshift:32,Gshift:33,Bshift:34,Ashift:35},KeyboardEvent:{__size__:16,type:0,windowID:4,state:8,repeat:9,padding2:10,padding3:11,keysym:12},keysym:{__size__:16,scancode:0,sym:4,mod:8,unicode:12},TextInputEvent:{__size__:264,type:0,windowID:4,text:8},MouseMotionEvent:{__size__:28,type:0,windowID:4,state:8,padding1:9,padding2:10,padding3:11,x:12,y:16,xrel:20,yrel:24},MouseButtonEvent:{__size__:20,type:0,windowID:4,button:8,state:9,padding1:10,padding2:11,x:12,y:16},ResizeEvent:{__size__:12,type:0,w:4,h:8},AudioSpec:{__size__:24,freq:0,format:4,channels:6,silence:7,samples:8,size:12,callback:16,userdata:20},version:{__size__:3,major:0,minor:1,patch:2}},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + SDL.structs.Rect.x)>>2)],
          y: HEAP32[((rect + SDL.structs.Rect.y)>>2)],
          w: HEAP32[((rect + SDL.structs.Rect.w)>>2)],
          h: HEAP32[((rect + SDL.structs.Rect.h)>>2)]
        };
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var surf = _malloc(14*Runtime.QUANTUM_SIZE);  // SDL_Surface has 14 fields of quantum size
        var buffer = _malloc(width*height*4); // TODO: only allocate when locked the first time
        var pixelFormat = _malloc(18*Runtime.QUANTUM_SIZE);
        flags |= 1; // SDL_HWSURFACE - this tells SDL_MUSTLOCK that this needs to be locked
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var is_SDL_HWPALETTE = flags & 0x00200000;  
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        HEAP32[((surf+Runtime.QUANTUM_SIZE*0)>>2)]=flags         // SDL_Surface.flags
        HEAP32[((surf+Runtime.QUANTUM_SIZE*1)>>2)]=pixelFormat // SDL_Surface.format TODO
        HEAP32[((surf+Runtime.QUANTUM_SIZE*2)>>2)]=width         // SDL_Surface.w
        HEAP32[((surf+Runtime.QUANTUM_SIZE*3)>>2)]=height        // SDL_Surface.h
        HEAP32[((surf+Runtime.QUANTUM_SIZE*4)>>2)]=width * bpp       // SDL_Surface.pitch, assuming RGBA or indexed for now,
                                                                                 // since that is what ImageData gives us in browsers
        HEAP32[((surf+Runtime.QUANTUM_SIZE*5)>>2)]=buffer      // SDL_Surface.pixels
        HEAP32[((surf+Runtime.QUANTUM_SIZE*6)>>2)]=0      // SDL_Surface.offset
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.format)>>2)]=-2042224636 // SDL_PIXELFORMAT_RGBA8888
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.palette)>>2)]=0 // TODO
        HEAP8[((pixelFormat + SDL.structs.PixelFormat.BitsPerPixel)|0)]=bpp * 8
        HEAP8[((pixelFormat + SDL.structs.PixelFormat.BytesPerPixel)|0)]=bpp
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Rmask)>>2)]=rmask || 0x000000ff
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Gmask)>>2)]=gmask || 0x0000ff00
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Bmask)>>2)]=bmask || 0x00ff0000
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Amask)>>2)]=amask || 0xff000000
        // Decide if we want to use WebGL or not
        var useWebGL = (flags & 0x04000000) != 0; // SDL_OPENGL
        SDL.GL = SDL.GL || useWebGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }
        var ctx = Browser.createContext(canvas, useWebGL, usePageCanvas);
        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,
          isFlagSet: function (flag) {
            return flags & flag;
          }
        };
        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }
        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;
        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;
        var buffer  = surfData.buffer;
        var data    = surfData.image.data;
        var colors  = surfData.colors;
        for (var y = startY; y < endY; ++y) {
          var indexBase = y * fullWidth;
          var colorBase = indexBase * 4;
          for (var x = startX; x < endX; ++x) {
            // HWPALETTE have only 256 colors (not rgba)
            var index = HEAPU8[((buffer + indexBase + x)|0)] * 3;
            var colorOffset = colorBase + x * 4;
            data[colorOffset   ] = colors[index   ];
            data[colorOffset +1] = colors[index +1];
            data[colorOffset +2] = colors[index +2];
            //unused: data[colorOffset +3] = color[index +3];
          }
        }
      },freeSurface:function (surf) {
        var info = SDL.surfaces[surf];
        if (!info) return; // surface has already been freed
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;
      },touchX:0,touchY:0,receiveEvent:function (event) {
        switch(event.type) {
          case 'touchstart':
            event.preventDefault();
            var touch = event.touches[0];
            touchX = touch.pageX;
            touchY = touch.pageY;
            var event = {
              type: 'mousedown',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.DOMButtons[0] = 1;
            SDL.events.push(event);
            break;
          case 'touchmove':
            event.preventDefault();
            var touch = event.touches[0];
            touchX = touch.pageX;
            touchY = touch.pageY;
            event = {
              type: 'mousemove',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.events.push(event);
            break;
          case 'touchend':
            event.preventDefault();
            event = {
              type: 'mouseup',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(event);
            break;
          case 'mousemove':
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup': case 'DOMMouseScroll': case 'mousewheel':
            if (event.type == 'DOMMouseScroll' || event.type == 'mousewheel') {
              var button = (event.type == 'DOMMouseScroll' ? event.detail : -event.wheelDelta) > 0 ? 4 : 3;
              var event2 = {
                type: 'mousedown',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
              SDL.events.push(event2);
              event = {
                type: 'mouseup',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
            } else if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                event.preventDefault();
                return;
              }
              SDL.DOMButtons[event.button] = 0;
            }
            if (event.type == 'keypress' && !SDL.textInput) {
              break;
            }
            SDL.events.push(event);
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            break;
          case 'blur':
          case 'visibilitychange': {
            // Un-press all pressed keys: TODO
            for (var code in SDL.keyboardMap) {
              SDL.events.push({
                type: 'keyup',
                keyCode: SDL.keyboardMap[code]
              });
            }
            break;
          }
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            break;
        }
        if (SDL.events.length >= 10000) {
          Module.printErr('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        // manually triggered resize event doesn't have a preventDefault member
        if (event.preventDefault) {
          event.preventDefault();
        }
        return;
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, SDL.structs.KeyboardEvent.__size__); // XXX
          return;
        }
        switch(event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //Module.print('Received key event: ' + event.keyCode);
            var key = event.keyCode;
            if (key >= 65 && key <= 90) {
              key += 32; // make lowercase for SDL
            } else {
              key = SDL.keyCodes[event.keyCode] || event.keyCode;
            }
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }
            var code = SDL.keyCodes[event.keyCode] || event.keyCode;
            HEAP8[(((SDL.keyboardState)+(code))|0)]=down;
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))|0)] ? 0x0040 | 0x0080 : 0) | // KMOD_LCTRL & KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))|0)] ? 0x0001 | 0x0002 : 0) | // KMOD_LSHIFT & KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))|0)] ? 0x0100 | 0x0200 : 0); // KMOD_LALT & KMOD_RALT
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type]
            HEAP8[(((ptr)+(SDL.structs.KeyboardEvent.state))|0)]=down ? 1 : 0
            HEAP8[(((ptr)+(SDL.structs.KeyboardEvent.repeat))|0)]=0 // TODO
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.scancode))>>2)]=scan
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.sym))>>2)]=key
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.mod))>>2)]=SDL.modState
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.unicode))>>2)]=key
            break;
          }
          case 'keypress': {
            HEAP32[(((ptr)+(SDL.structs.TextInputEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type]
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(SDL.structs.TextInputEvent.text + i))|0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP8[(((ptr)+(SDL.structs.MouseButtonEvent.button))|0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(SDL.structs.MouseButtonEvent.state))|0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.x))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.y))>>2)]=Browser.mouseY;
            } else {
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP8[(((ptr)+(SDL.structs.MouseMotionEvent.state))|0)]=SDL.buttonState;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.x))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.y))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.xrel))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.yrel))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'unload': {
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(SDL.structs.ResizeEvent.w))>>2)]=event.w;
            HEAP32[(((ptr)+(SDL.structs.ResizeEvent.h))>>2)]=event.h;
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = h + 'px ' + fontData.name;
        var tempCtx = SDL.ttfContext;
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = volume / 128;
          if (info.audio) info.audio.volume = info.volume;
        }
        return ret;
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      }};function _SDL_GetVideoInfo() {
      // %struct.SDL_VideoInfo = type { i32, i32, %struct.SDL_PixelFormat*, i32, i32 } - 5 fields of quantum size
      var ret = _malloc(5*Runtime.QUANTUM_SIZE);
      HEAP32[((ret+Runtime.QUANTUM_SIZE*0)>>2)]=0 // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*1)>>2)]=0 // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*2)>>2)]=0
      HEAP32[((ret+Runtime.QUANTUM_SIZE*3)>>2)]=Module["canvas"].width
      HEAP32[((ret+Runtime.QUANTUM_SIZE*4)>>2)]=Module["canvas"].height
      return ret;
    }
  function _SDL_GetMouseState(x, y) {
      if (x) HEAP32[((x)>>2)]=Browser.mouseX;
      if (y) HEAP32[((y)>>2)]=Browser.mouseY;
      return SDL.buttonState;
    }
  function _emscripten_cancel_main_loop() {
      Browser.mainLoop.scheduler = null;
      Browser.mainLoop.shouldPause = true;
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  Module["_strcat"] = _strcat;
  var _llvm_memset_p0i8_i32=_memset;
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  function _send(fd, buf, len, flags) {
      var info = FS.streams[fd];
      if (!info) return -1;
      info.sender(HEAPU8.subarray(buf, buf+len));
      return len;
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[(((buf)+(i))|0)];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (stream && ('socket' in stream)) {
          return _send(fildes, buf, nbyte, 0);
      } else if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[(((buf)+(i))|0)]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      var flush = function(filedes) {
        // Right now we write all data directly, except for output devices.
        if (FS.streams[filedes] && FS.streams[filedes].object.output) {
          if (!FS.streams[filedes].object.isTerminal) { // don't flush terminals, it would cause a \n to also appear
            FS.streams[filedes].object.output(null);
          }
        }
      };
      try {
        if (stream === 0) {
          for (var i = 0; i < FS.streams.length; i++) if (FS.streams[i]) flush(i);
        } else {
          flush(stream);
        }
        return 0;
      } catch (e) {
        ___setErrNo(ERRNO_CODES.EIO);
        return -1;
      }
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      function ExitStatus() {
        this.name = "ExitStatus";
        this.message = "Program terminated with exit(" + status + ")";
        this.status = status;
        Module.print('Exit Status: ' + status);
      };
      ExitStatus.prototype = new Error();
      ExitStatus.prototype.constructor = ExitStatus;
      exitRuntime();
      ABORT = true;
      throw new ExitStatus();
    }function _exit(status) {
      __exit(status);
    }
  var _llvm_va_start=undefined;
  function _llvm_va_end() {}
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"](((Math.min((+(Math.floor((ret)/(+(4294967296))))), (+(4294967295))))|0)>>>0),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }
  function _SDL_Init(what) {
      SDL.startTime = Date.now();
      // capture all key events. we just keep down and up, but also capture press to prevent default actions
      if (!Module['doNotCaptureKeyboard']) {
        document.addEventListener("keydown", SDL.receiveEvent);
        document.addEventListener("keyup", SDL.receiveEvent);
        document.addEventListener("keypress", SDL.receiveEvent);
        document.addEventListener("blur", SDL.receiveEvent);
        document.addEventListener("visibilitychange", SDL.receiveEvent);
      }
      window.addEventListener("unload", SDL.receiveEvent);
      SDL.keyboardState = _malloc(0x10000); // Our SDL needs 512, but 64K is safe for older SDLs
      _memset(SDL.keyboardState, 0, 0x10000);
      // Initialize this structure carefully for closure
      SDL.DOMEventToSDLEvent['keydown'] = 0x300 /* SDL_KEYDOWN */;
      SDL.DOMEventToSDLEvent['keyup'] = 0x301 /* SDL_KEYUP */;
      SDL.DOMEventToSDLEvent['keypress'] = 0x303 /* SDL_TEXTINPUT */;
      SDL.DOMEventToSDLEvent['mousedown'] = 0x401 /* SDL_MOUSEBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['mouseup'] = 0x402 /* SDL_MOUSEBUTTONUP */;
      SDL.DOMEventToSDLEvent['mousemove'] = 0x400 /* SDL_MOUSEMOTION */;
      SDL.DOMEventToSDLEvent['unload'] = 0x100 /* SDL_QUIT */;
      SDL.DOMEventToSDLEvent['resize'] = 0x7001 /* SDL_VIDEORESIZE/SDL_EVENT_COMPAT2 */;
      return 0; // success
    }
  function _signal(sig, func) {
      // TODO
      return 0;
    }
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      // NOTE: This implementation tries to mimic glibc rather than strictly
      // following the POSIX standard.
      var mode = HEAP32[((varargs)>>2)];
      // Simplify flags.
      var accessMode = oflag & 3;
      var isWrite = accessMode != 0;
      var isRead = accessMode != 1;
      var isCreate = Boolean(oflag & 512);
      var isExistCheck = Boolean(oflag & 2048);
      var isTruncate = Boolean(oflag & 1024);
      var isAppend = Boolean(oflag & 8);
      // Verify path.
      var origPath = path;
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      }
      var target = path.object || null;
      var finalPath;
      // Verify the file exists, create if needed and allowed.
      if (target) {
        if (isCreate && isExistCheck) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          return -1;
        }
        if ((isWrite || isTruncate) && target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        }
        if (isRead && !target.read || isWrite && !target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        if (isTruncate && !target.isDevice) {
          target.contents = [];
        } else {
          if (!FS.forceLoadFile(target)) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        finalPath = path.path;
      } else {
        if (!isCreate) {
          ___setErrNo(ERRNO_CODES.ENOENT);
          return -1;
        }
        if (!path.parentObject.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        target = FS.createDataFile(path.parentObject, path.name, [],
                                   mode & 0x100, mode & 0x80);  // S_IRUSR, S_IWUSR.
        finalPath = path.parentPath + '/' + path.name;
      }
      // Actually create an open stream.
      var id;
      if (target.isFolder) {
        var entryBuffer = 0;
        if (___dirent_struct_layout) {
          entryBuffer = _malloc(___dirent_struct_layout.__size__);
        }
        var contents = [];
        for (var key in target.contents) contents.push(key);
        id = FS.createFileHandle({
          path: finalPath,
          object: target,
          // An index into contents. Special values: -2 is ".", -1 is "..".
          position: -2,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: [],
          // Folder-specific properties:
          // Remember the contents at the time of opening in an array, so we can
          // seek between them relying on a single order.
          contents: contents,
          // Each stream has its own area for readdir() returns.
          currentEntry: entryBuffer
        });
      } else {
        id = FS.createFileHandle({
          path: finalPath,
          object: target,
          position: 0,
          isRead: isRead,
          isWrite: isWrite,
          isAppend: isAppend,
          error: false,
          eof: false,
          ungotten: []
        });
      }
      return id;
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _recv(fd, buf, len, flags) {
      var info = FS.streams[fd];
      if (!info) return -1;
      if (!info.hasData()) {
        ___setErrNo(ERRNO_CODES.EAGAIN); // no data, and all sockets are nonblocking, so this is the right behavior
        return -1;
      }
      var buffer = info.inQueue.shift();
      if (len < buffer.length) {
        if (info.stream) {
          // This is tcp (reliable), so if not all was read, keep it
          info.inQueue.unshift(buffer.subarray(len));
        }
        buffer = buffer.subarray(0, len);
      }
      HEAPU8.set(buffer, buf);
      return buffer.length;
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[((buf++)|0)]=stream.ungotten.pop()
          nbyte--;
          bytesRead++;
        }
        var contents = stream.object.contents;
        var size = Math.min(contents.length - offset, nbyte);
        if (contents.subarray) { // typed array
          HEAPU8.set(contents.subarray(offset, offset+size), buf);
        } else
        if (contents.slice) { // normal array
          for (var i = 0; i < size; i++) {
            HEAP8[(((buf)+(i))|0)]=contents[offset + i]
          }
        } else {
          for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
            HEAP8[(((buf)+(i))|0)]=contents.get(offset + i)
          }
        }
        bytesRead += size;
        return bytesRead;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (stream && ('socket' in stream)) {
        return _recv(fildes, buf, nbyte, 0);
      } else if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead;
        if (stream.object.isDevice) {
          if (stream.object.input) {
            bytesRead = 0;
            while (stream.ungotten.length && nbyte > 0) {
              HEAP8[((buf++)|0)]=stream.ungotten.pop()
              nbyte--;
              bytesRead++;
            }
            for (var i = 0; i < nbyte; i++) {
              try {
                var result = stream.object.input();
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
              if (result === undefined && bytesRead === 0) {
                ___setErrNo(ERRNO_CODES.EAGAIN);
                return -1;
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              HEAP8[(((buf)+(i))|0)]=result
            }
            return bytesRead;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var ungotSize = stream.ungotten.length;
          bytesRead = _pread(fildes, buf, nbyte, stream.position);
          if (bytesRead != -1) {
            stream.position += (stream.ungotten.length - ungotSize) + bytesRead;
          }
          return bytesRead;
        }
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) return 0;
      var bytesRead = _read(stream, ptr, bytesToRead);
      var streamObj = FS.streams[stream];
      if (bytesRead == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        if (bytesRead < bytesToRead) streamObj.eof = true;
        return Math.floor(bytesRead / size);
      }
    }
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      if (FS.streams[fildes]) {
        if (FS.streams[fildes].currentEntry) {
          _free(FS.streams[fildes].currentEntry);
        }
        FS.streams[fildes] = null;
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      if (FS.streams[fildes]) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  Module["_memcmp"] = _memcmp;
  Module["_strcpy"] = _strcpy;
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      if (FS.streams[fildes] && !FS.streams[fildes].object.isDevice) {
        var stream = FS.streams[fildes];
        var position = offset;
        if (whence === 1) {  // SEEK_CUR.
          position += stream.position;
        } else if (whence === 2) {  // SEEK_END.
          position += stream.object.contents.length;
        }
        if (position < 0) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else {
          stream.ungotten = [];
          stream.position = position;
          return position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      } else {
        FS.streams[stream].eof = false;
        return 0;
      }
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      if (FS.streams[stream]) {
        stream = FS.streams[stream];
        if (stream.object.isDevice) {
          ___setErrNo(ERRNO_CODES.ESPIPE);
          return -1;
        } else {
          return stream.position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _truncate(path, length) {
      // int truncate(const char *path, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/truncate.html
      // NOTE: The path argument may be a string, to simplify ftruncate().
      if (length < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (typeof path !== 'string') path = Pointer_stringify(path);
        var target = FS.findObject(path);
        if (target === null) return -1;
        if (target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        } else if (target.isDevice) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else if (!target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        } else {
          var contents = target.contents;
          if (length < contents.length) contents.length = length;
          else while (length > contents.length) contents.push(0);
          target.timestamp = Date.now();
          return 0;
        }
      }
    }function _ftruncate(fildes, length) {
      // int ftruncate(int fildes, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftruncate.html
      if (FS.streams[fildes] && FS.streams[fildes].isWrite) {
        return _truncate(FS.streams[fildes].path, length);
      } else if (FS.streams[fildes]) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      // We use file descriptor numbers and FILE* streams interchangeably.
      return stream;
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return -1;
      } else {
        return chr;
      }
    }
  var ___pollfd_struct_layout={__size__:8,fd:0,events:4,revents:6};function _poll(fds, nfds, timeout) {
      // int poll(struct pollfd fds[], nfds_t nfds, int timeout);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/poll.html
      // NOTE: This is pretty much a no-op mimicking glibc.
      var offsets = ___pollfd_struct_layout;
      var nonzero = 0;
      for (var i = 0; i < nfds; i++) {
        var pollfd = fds + ___pollfd_struct_layout.__size__ * i;
        var fd = HEAP32[(((pollfd)+(offsets.fd))>>2)];
        var events = HEAP16[(((pollfd)+(offsets.events))>>1)];
        var revents = 0;
        if (FS.streams[fd]) {
          var stream = FS.streams[fd];
          if (events & 1) revents |= 1;
          if (events & 2) revents |= 2;
        } else {
          if (events & 4) revents |= 4;
        }
        if (revents) nonzero++;
        HEAP16[(((pollfd)+(offsets.revents))>>1)]=revents
      }
      return nonzero;
    }
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists || !path.exists) {
        ___setErrNo(path.error);
        return -1;
      } else if (path.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (!path.object.write) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else {
        delete path.parentObject.contents[path.name];
        return 0;
      }
    }
  function _posix_openpt() {
  Module['printErr']('missing function: posix_openpt'); abort(-1);
  }
  function _symlink(path1, path2) {
      // int symlink(const char *path1, const char *path2);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/symlink.html
      var path = FS.analyzePath(Pointer_stringify(path2), true);
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      } else if (path.exists) {
        ___setErrNo(ERRNO_CODES.EEXIST);
        return -1;
      } else {
        FS.createLink(path.parentPath, path.name,
                      Pointer_stringify(path1), true, true);
        return 0;
      }
    }
  function _tcgetattr() {
  Module['printErr']('missing function: tcgetattr'); abort(-1);
  }
  function _tcsetattr() {
  Module['printErr']('missing function: tcsetattr'); abort(-1);
  }
  function _tcflush() {
  Module['printErr']('missing function: tcflush'); abort(-1);
  }
  var ___flock_struct_layout={__size__:16,l_type:0,l_whence:2,l_start:4,l_len:8,l_pid:12,l_xxx:14};function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      if (!FS.streams[fildes]) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      var stream = FS.streams[fildes];
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream = {};
          for (var member in stream) {
            newStream[member] = stream[member];
          }
          arg = dup2 ? arg : Math.max(arg, FS.streams.length); // dup2 wants exactly arg; fcntl wants a free descriptor >= arg
          FS.createFileHandle(newStream, arg);
          return arg;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          var flags = 0;
          if (stream.isRead && stream.isWrite) flags = 2;
          else if (!stream.isRead && stream.isWrite) flags = 1;
          else if (stream.isRead && !stream.isWrite) flags = 0;
          if (stream.isAppend) flags |= 8;
          // Synchronization and blocking flags are irrelevant to us.
          return flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.isAppend = Boolean(arg | 8);
          // Synchronization and blocking flags are irrelevant to us.
          return 0;
        case 7:
        case 20:
          var arg = HEAP32[((varargs)>>2)];
          var offset = ___flock_struct_layout.l_type;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=3
          return 0;
        case 8:
        case 9:
        case 21:
        case 22:
          // Pretend that the locking is successful.
          return 0;
        case 6:
        case 5:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }
  function _grantpt() {
  Module['printErr']('missing function: grantpt'); abort(-1);
  }
  function _unlockpt() {
  Module['printErr']('missing function: unlockpt'); abort(-1);
  }
  function _ptsname() {
  Module['printErr']('missing function: ptsname'); abort(-1);
  }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezones={};
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      var timezone = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | date.toString().match(/\(([A-Z]+)\)/)[1];
      if (!(timezone in ___tm_timezones)) {
        ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), 'i8', ALLOC_NORMAL);
      }
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezones[timezone]
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      if (!FS.streams[stream]) return -1;
      var streamObj = FS.streams[stream];
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _read(stream, _fgetc.ret, 1);
      if (ret == 0) {
        streamObj.eof = true;
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      var offsets = ___tm_struct_layout;
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getUTCSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getUTCMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getUTCHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getUTCDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getUTCMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getUTCFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getUTCDay()
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=0
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=0
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.round((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      var timezone = "GMT";
      if (!(timezone in ___tm_timezones)) {
        ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), 'i8', ALLOC_NORMAL);
      }
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezones[timezone]
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }
  var _tan=Math.tan;
  function _SDL_PauseAudio(pauseOn) {
      if (SDL.audio.paused !== pauseOn) {
        SDL.audio.timer = pauseOn ? SDL.audio.timer && clearInterval(SDL.audio.timer) : Browser.safeSetInterval(SDL.audio.caller, 1/35);
      }
      SDL.audio.paused = pauseOn;
    }function _SDL_CloseAudio() {
      if (SDL.audio) {
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
      }
    }
  function _SDL_WasInit() {
      if (SDL.startTime === null) {
        _SDL_Init();
      }
      return 1;
    }
  function _SDL_InitSubSystem(flags) { return 0 }
  function _SDL_GetError() {
      if (!SDL.errorMessage) {
        SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), 'i8', ALLOC_NORMAL);
      }
      return SDL.errorMessage;
    }
  function _SDL_OpenAudio(desired, obtained) {
      SDL.allocateChannels(32);
      SDL.audio = {
        freq: HEAPU32[(((desired)+(SDL.structs.AudioSpec.freq))>>2)],
        format: HEAPU16[(((desired)+(SDL.structs.AudioSpec.format))>>1)],
        channels: HEAPU8[(((desired)+(SDL.structs.AudioSpec.channels))|0)],
        samples: HEAPU16[(((desired)+(SDL.structs.AudioSpec.samples))>>1)],
        callback: HEAPU32[(((desired)+(SDL.structs.AudioSpec.callback))>>2)],
        userdata: HEAPU32[(((desired)+(SDL.structs.AudioSpec.userdata))>>2)],
        paused: true,
        timer: null
      };
      if (obtained) {
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.freq))>>2)]=SDL.audio.freq; // no good way for us to know if the browser can really handle this
        HEAP16[(((obtained)+(SDL.structs.AudioSpec.format))>>1)]=33040; // float, signed, 16-bit
        HEAP8[(((obtained)+(SDL.structs.AudioSpec.channels))|0)]=SDL.audio.channels;
        HEAP8[(((obtained)+(SDL.structs.AudioSpec.silence))|0)]=HEAPU8[(((desired)+(SDL.structs.AudioSpec.silence))|0)]; // unclear if browsers can provide this
        HEAP16[(((obtained)+(SDL.structs.AudioSpec.samples))>>1)]=SDL.audio.samples;
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.callback))>>2)]=SDL.audio.callback;
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.userdata))>>2)]=SDL.audio.userdata;
      }
      var totalSamples = SDL.audio.samples*SDL.audio.channels;
      SDL.audio.bufferSize = totalSamples*2; // hardcoded 16-bit audio
      SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
      SDL.audio.caller = function() {
        Runtime.dynCall('viii', SDL.audio.callback, [SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize]);
        SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize);
      };
      // Mozilla Audio API. TODO: Other audio APIs
      try {
        SDL.audio.mozOutput = new Audio();
        SDL.audio.mozOutput['mozSetup'](SDL.audio.channels, SDL.audio.freq); // use string attributes on mozOutput for closure compiler
        SDL.audio.mozBuffer = new Float32Array(totalSamples);
        SDL.audio.pushAudio = function(ptr, size) {
          var mozBuffer = SDL.audio.mozBuffer;
          for (var i = 0; i < totalSamples; i++) {
            mozBuffer[i] = (HEAP16[(((ptr)+(i*2))>>1)]) / 0x8000; // hardcoded 16-bit audio, signed (TODO: reSign if not ta2?)
          }
          SDL.audio.mozOutput['mozWriteAudio'](mozBuffer);
        }
      } catch(e) {
        SDL.audio = null;
      }
      if (!SDL.audio) return -1;
      return 0;
    }
  function _SDL_LockAudio() {}
  function _SDL_UnlockAudio() {}
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }
  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }
  function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      var start = Date.now();
      while (Date.now() - start < msec) {
        // Do nothing.
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _gettimeofday(ptr) {
      // %struct.timeval = type { i32, i32 }
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }
  function _SDL_PollEvent(ptr) {
      if (SDL.events.length === 0) return 0;
      if (ptr) {
        SDL.makeCEvent(SDL.events.shift(), ptr);
      }
      return 1;
    }
  function _SDL_ShowCursor(toggle) {
      switch (toggle) {
        case 0: // SDL_DISABLE
          if (Browser.isFullScreen) { // only try to lock the pointer when in full screen mode
            Module['canvas'].requestPointerLock();
            return 0;
          } else { // else return SDL_ENABLE to indicate the failure
            return 1;
          }
          break;
        case 1: // SDL_ENABLE
          Module['canvas'].exitPointerLock();
          return 1;
          break;
        case -1: // SDL_QUERY
          return !Browser.pointerLock;
          break;
        default:
          console.log( "SDL_ShowCursor called with unknown toggle parameter value: " + toggle + "." );
          break;
      }
    }
  function _SDL_WM_GrabInput() {}
  function _SDL_WM_ToggleFullScreen(surf) {
      if (Browser.isFullScreen) {
        Module['canvas'].cancelFullScreen();
        return 1;
      } else {
        return 0;
      }
    }
  function _SDL_CreateRGBSurfaceFrom(pixels, width, height, depth, pitch, rmask, gmask, bmask, amask) {
      // TODO: Take into account depth and pitch parameters.
      var surface = SDL.makeSurface(width, height, 0, false, 'CreateRGBSurfaceFrom', rmask, gmask, bmask, amask);
      var surfaceData = SDL.surfaces[surface];
      var surfaceImageData = surfaceData.ctx.getImageData(0, 0, width, height);
      var surfacePixelData = surfaceImageData.data;
      // Fill pixel data to created surface.
      // Supports SDL_PIXELFORMAT_RGBA8888 and SDL_PIXELFORMAT_RGB888
      var channels = amask ? 4 : 3; // RGBA8888 or RGB888
      for (var pixelOffset = 0; pixelOffset < width*height; pixelOffset++) {
        surfacePixelData[pixelOffset*4+0] = HEAPU8[pixels + (pixelOffset*channels+0)]; // R
        surfacePixelData[pixelOffset*4+1] = HEAPU8[pixels + (pixelOffset*channels+1)]; // G
        surfacePixelData[pixelOffset*4+2] = HEAPU8[pixels + (pixelOffset*channels+2)]; // B
        surfacePixelData[pixelOffset*4+3] = amask ? HEAPU8[pixels + (pixelOffset*channels+3)] : 0xff; // A
      };
      surfaceData.ctx.putImageData(surfaceImageData, 0, 0);
      return surface;
    }
  function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      var srcData = SDL.surfaces[src];
      var dstData = SDL.surfaces[dst];
      var sr, dr;
      if (srcrect) {
        sr = SDL.loadRect(srcrect);
      } else {
        sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
      }
      if (dstrect) {
        dr = SDL.loadRect(dstrect);
      } else {
        dr = { x: 0, y: 0, w: -1, h: -1 };
      }
      dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, sr.w, sr.h);
      if (dst != SDL.screen) {
        // XXX As in IMG_Load, for compatibility we write out |pixels|
        console.log('WARNING: copying canvas data to memory for compatibility');
        _SDL_LockSurface(dst);
        dstData.locked--; // The surface is not actually locked in this hack
      }
      return 0;
    }
  function _SDL_FreeSurface(surf) {
      if (surf) SDL.freeSurface(surf);
    }
  function _SDL_Flip(surf) {
      // We actually do this in Unlock, since the screen surface has as its canvas
      // backing the page canvas element
    }
  function _SDL_SetVideoMode(width, height, depth, flags) {
      ['mousedown', 'mouseup', 'mousemove', 'DOMMouseScroll', 'mousewheel', 'mouseout'].forEach(function(event) {
        if (Module["canvasFront"]) {
          Module['canvasFront'].addEventListener(event, SDL.receiveEvent, true);
        } else {
          Module['canvas'].addEventListener(event, SDL.receiveEvent, true);
        }
      });
      Browser.setCanvasSize(width, height, true);
      // Free the old surface first.
      if (SDL.screen) {
        SDL.freeSurface(SDL.screen);
        SDL.screen = null;
      }
      SDL.screen = SDL.makeSurface(width, height, flags, true, 'screen');
      if (!SDL.addedResizeListener) {
        SDL.addedResizeListener = true;
        Browser.resizeListeners.push(function(w, h) {
          SDL.receiveEvent({
            type: 'resize',
            w: w,
            h: h
          });
        });
      }
      return SDL.screen;
    }
  function _SDL_WM_SetCaption(title, icon) {
      title = title && Pointer_stringify(title);
      icon = icon && Pointer_stringify(icon);
    }
  function _SDL_EnableKeyRepeat(delay, interval) {
      // TODO
    }
  function _SDL_EventState() {}
  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
  'use asm';
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);
  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var ctlz_i8=env.ctlz_i8|0;
  var _stdout=env._stdout|0;
  var _stdin=env._stdin|0;
  var _stderr=env._stderr|0;
  var NaN=+env.NaN;
  var Infinity=+env.Infinity;
  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;
  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var abort=env.abort;
  var assert=env.assert;
  var asmPrintInt=env.asmPrintInt;
  var asmPrintFloat=env.asmPrintFloat;
  var Math_min=env.min;
  var invoke_ii=env.invoke_ii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_vi=env.invoke_vi;
  var invoke_vii=env.invoke_vii;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viii=env.invoke_viii;
  var invoke_v=env.invoke_v;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_viiii=env.invoke_viiii;
  var _llvm_lifetime_end=env._llvm_lifetime_end;
  var _lseek=env._lseek;
  var _llvm_dbg_value=env._llvm_dbg_value;
  var _fclose=env._fclose;
  var _SDL_EventState=env._SDL_EventState;
  var _strtoul=env._strtoul;
  var _fflush=env._fflush;
  var _SDL_GetMouseState=env._SDL_GetMouseState;
  var _strtol=env._strtol;
  var _fputc=env._fputc;
  var _fwrite=env._fwrite;
  var _ptsname=env._ptsname;
  var _send=env._send;
  var _tcflush=env._tcflush;
  var _fputs=env._fputs;
  var _emscripten_cancel_main_loop=env._emscripten_cancel_main_loop;
  var _SDL_UnlockAudio=env._SDL_UnlockAudio;
  var _SDL_WasInit=env._SDL_WasInit;
  var _read=env._read;
  var _fileno=env._fileno;
  var _fsync=env._fsync;
  var _signal=env._signal;
  var _SDL_PauseAudio=env._SDL_PauseAudio;
  var _SDL_LockAudio=env._SDL_LockAudio;
  var _strcmp=env._strcmp;
  var _strncmp=env._strncmp;
  var _snprintf=env._snprintf;
  var _fgetc=env._fgetc;
  var _atexit=env._atexit;
  var _close=env._close;
  var _tcsetattr=env._tcsetattr;
  var _strchr=env._strchr;
  var _tcgetattr=env._tcgetattr;
  var _poll=env._poll;
  var ___setErrNo=env.___setErrNo;
  var _grantpt=env._grantpt;
  var _ftell=env._ftell;
  var _exit=env._exit;
  var _sprintf=env._sprintf;
  var _fcntl=env._fcntl;
  var _SDL_ShowCursor=env._SDL_ShowCursor;
  var _gmtime=env._gmtime;
  var _symlink=env._symlink;
  var _localtime_r=env._localtime_r;
  var _ftruncate=env._ftruncate;
  var _recv=env._recv;
  var _SDL_PollEvent=env._SDL_PollEvent;
  var _SDL_Init=env._SDL_Init;
  var __exit=env.__exit;
  var _SDL_WM_GrabInput=env._SDL_WM_GrabInput;
  var _llvm_va_end=env._llvm_va_end;
  var _tzset=env._tzset;
  var _SDL_CreateRGBSurfaceFrom=env._SDL_CreateRGBSurfaceFrom;
  var _printf=env._printf;
  var _unlockpt=env._unlockpt;
  var _pread=env._pread;
  var _SDL_SetVideoMode=env._SDL_SetVideoMode;
  var _fopen=env._fopen;
  var _open=env._open;
  var _usleep=env._usleep;
  var _SDL_EnableKeyRepeat=env._SDL_EnableKeyRepeat;
  var _puts=env._puts;
  var _SDL_GetVideoInfo=env._SDL_GetVideoInfo;
  var _nanosleep=env._nanosleep;
  var _SDL_Flip=env._SDL_Flip;
  var _SDL_InitSubSystem=env._SDL_InitSubSystem;
  var _strdup=env._strdup;
  var _SDL_GetError=env._SDL_GetError;
  var __formatString=env.__formatString;
  var _gettimeofday=env._gettimeofday;
  var _vfprintf=env._vfprintf;
  var _SDL_WM_SetCaption=env._SDL_WM_SetCaption;
  var _sbrk=env._sbrk;
  var ___errno_location=env.___errno_location;
  var _SDL_CloseAudio=env._SDL_CloseAudio;
  var _isspace=env._isspace;
  var _llvm_lifetime_start=env._llvm_lifetime_start;
  var __parseInt=env.__parseInt;
  var _SDL_OpenAudio=env._SDL_OpenAudio;
  var _localtime=env._localtime;
  var _gmtime_r=env._gmtime_r;
  var _sysconf=env._sysconf;
  var _fread=env._fread;
  var _SDL_WM_ToggleFullScreen=env._SDL_WM_ToggleFullScreen;
  var _abort=env._abort;
  var _fprintf=env._fprintf;
  var _tan=env._tan;
  var __reallyNegative=env.__reallyNegative;
  var _posix_openpt=env._posix_openpt;
  var _fseek=env._fseek;
  var _write=env._write;
  var _SDL_UpperBlit=env._SDL_UpperBlit;
  var _truncate=env._truncate;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var _unlink=env._unlink;
  var _pwrite=env._pwrite;
  var _SDL_FreeSurface=env._SDL_FreeSurface;
  var _time=env._time;
// EMSCRIPTEN_START_FUNCS
function stackAlloc(size) {
 size = size | 0;
 var ret = 0;
 ret = STACKTOP; //@line 3
 STACKTOP = STACKTOP + size | 0; //@line 4
 STACKTOP = STACKTOP + 7 >> 3 << 3; //@line 5
 return ret | 0; //@line 6
}
function stackSave() {
 return STACKTOP | 0; //@line 9
}
function stackRestore(top) {
 top = top | 0;
 STACKTOP = top; //@line 13
}
function setThrew(threw, value) {
 threw = threw | 0;
 value = value | 0;
 if ((__THREW__ | 0) == 0) {
  __THREW__ = threw; //@line 19
  threwValue = value; //@line 20
 }
}
function copyTempFloat(ptr) {
 ptr = ptr | 0;
 HEAP8[tempDoublePtr] = HEAP8[ptr]; //@line 25
 HEAP8[tempDoublePtr + 1 | 0] = HEAP8[ptr + 1 | 0]; //@line 26
 HEAP8[tempDoublePtr + 2 | 0] = HEAP8[ptr + 2 | 0]; //@line 27
 HEAP8[tempDoublePtr + 3 | 0] = HEAP8[ptr + 3 | 0]; //@line 28
}
function copyTempDouble(ptr) {
 ptr = ptr | 0;
 HEAP8[tempDoublePtr] = HEAP8[ptr]; //@line 32
 HEAP8[tempDoublePtr + 1 | 0] = HEAP8[ptr + 1 | 0]; //@line 33
 HEAP8[tempDoublePtr + 2 | 0] = HEAP8[ptr + 2 | 0]; //@line 34
 HEAP8[tempDoublePtr + 3 | 0] = HEAP8[ptr + 3 | 0]; //@line 35
 HEAP8[tempDoublePtr + 4 | 0] = HEAP8[ptr + 4 | 0]; //@line 36
 HEAP8[tempDoublePtr + 5 | 0] = HEAP8[ptr + 5 | 0]; //@line 37
 HEAP8[tempDoublePtr + 6 | 0] = HEAP8[ptr + 6 | 0]; //@line 38
 HEAP8[tempDoublePtr + 7 | 0] = HEAP8[ptr + 7 | 0]; //@line 39
}
function setTempRet0(value) {
 value = value | 0;
 tempRet0 = value; //@line 44
}
function setTempRet1(value) {
 value = value | 0;
 tempRet1 = value; //@line 49
}
function setTempRet2(value) {
 value = value | 0;
 tempRet2 = value; //@line 54
}
function setTempRet3(value) {
 value = value | 0;
 tempRet3 = value; //@line 59
}
function setTempRet4(value) {
 value = value | 0;
 tempRet4 = value; //@line 64
}
function setTempRet5(value) {
 value = value | 0;
 tempRet5 = value; //@line 69
}
function setTempRet6(value) {
 value = value | 0;
 tempRet6 = value; //@line 74
}
function setTempRet7(value) {
 value = value | 0;
 tempRet7 = value; //@line 79
}
function setTempRet8(value) {
 value = value | 0;
 tempRet8 = value; //@line 84
}
function setTempRet9(value) {
 value = value | 0;
 tempRet9 = value; //@line 89
}
function runPostSets() {
}
function _adb_dev_talk_done($dev, $reg) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 return;
}
function _adb_dev_flush($dev) {
 $dev = $dev | 0;
 HEAP8[$dev + 7 | 0] = 0; //@line 112
 return;
}
function _adb_dev_talk($dev, $reg, $buf) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 $buf = $buf | 0;
 var $3 = 0, $_0 = 0;
 if (($reg | 0) != 3) {
  $_0 = 0; //@line 129
  return $_0 | 0; //@line 132
 }
 $3 = $dev + 20 | 0; //@line 134
 HEAP8[$buf + 1 | 0] = HEAP32[$3 >> 2] & 255; //@line 138
 HEAP8[$buf] = (HEAP32[$3 >> 2] | 0) >>> 8 & 255; //@line 142
 $_0 = 2; //@line 144
 return $_0 | 0; //@line 147
}
function _adb_dev_listen($dev, $reg, $buf, $cnt) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $10 = 0, $13 = 0;
 if (($reg | 0) != 3 | $cnt >>> 0 < 2) {
  return;
 }
 if ((HEAP8[$buf + 1 | 0] | 0) != -2) {
  return;
 }
 $10 = HEAP8[$buf] & 15; //@line 178
 HEAP8[$dev + 4 | 0] = $10 & 255; //@line 181
 $13 = $dev + 20 | 0; //@line 182
 HEAP32[$13 >> 2] = $10 << 8 | HEAP32[$13 >> 2] & 61695; //@line 187
 return;
}
function _adb_set_shift_in_fct($adb, $ext, $fct) {
 $adb = $adb | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$adb + 92 >> 2] = $ext; //@line 202
 HEAP32[$adb + 96 >> 2] = $fct; //@line 205
 return;
}
function _adb_set_shift_out_fct($adb, $ext, $fct) {
 $adb = $adb | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$adb + 100 >> 2] = $ext; //@line 219
 HEAP32[$adb + 104 >> 2] = $fct; //@line 222
 return;
}
function _adb_set_int_fct($adb, $ext, $fct) {
 $adb = $adb | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$adb + 112 >> 2] = $ext; //@line 236
 HEAP32[$adb + 116 >> 2] = $fct; //@line 239
 return;
}
function _adb_add_device($adb, $dev) {
 $adb = $adb | 0;
 $dev = $dev | 0;
 var $1 = 0, $2 = 0, $i_0 = 0, $_0 = 0, label = 0;
 $1 = $adb + 24 | 0; //@line 252
 $2 = HEAP32[$1 >> 2] | 0; //@line 253
 $i_0 = 0; //@line 255
 while (1) {
  if ($i_0 >>> 0 >= $2 >>> 0) {
   break;
  }
  if ((HEAP32[$adb + 28 + ($i_0 << 2) >> 2] | 0) == ($dev | 0)) {
   $_0 = 1; //@line 269
   label = 24; //@line 270
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 273
  }
 }
 if ((label | 0) == 24) {
  return $_0 | 0; //@line 279
 }
 if ($2 >>> 0 > 15) {
  $_0 = 1; //@line 284
  return $_0 | 0; //@line 287
 }
 HEAP32[$1 >> 2] = $2 + 1; //@line 290
 HEAP32[$adb + 28 + ($2 << 2) >> 2] = $dev; //@line 292
 $_0 = 0; //@line 294
 return $_0 | 0; //@line 297
}
function _adb_dev_reset($dev) {
 $dev = $dev | 0;
 var $2 = 0;
 $2 = HEAP8[$dev + 5 | 0] | 0; //@line 308
 HEAP8[$dev + 4 | 0] = $2; //@line 310
 _memset($dev + 7 | 0, 0, 13); //@line 313
 HEAP32[$dev + 20 >> 2] = ($2 & 255) << 8 & 3840 | (HEAPU8[$dev + 6 | 0] | 0) | 24576; //@line 322
 return;
}
function _adb_dev_init($dev, $addr, $handler) {
 $dev = $dev | 0;
 $addr = $addr | 0;
 $handler = $handler | 0;
 var $2 = 0;
 HEAP32[$dev >> 2] = 0; //@line 338
 $2 = $addr & 255; //@line 339
 HEAP8[$dev + 4 | 0] = $2; //@line 341
 HEAP8[$dev + 5 | 0] = $2; //@line 343
 HEAP8[$dev + 6 | 0] = $handler & 255; //@line 346
 _memset($dev + 7 | 0, 0, 13); //@line 349
 HEAP32[$dev + 20 >> 2] = $addr << 8 & 3840 | $handler & 255 | 24576; //@line 355
 HEAP32[$dev + 24 >> 2] = 0; //@line 357
 HEAP32[$dev + 28 >> 2] = 164; //@line 359
 HEAP32[$dev + 32 >> 2] = 58; //@line 361
 HEAP32[$dev + 36 >> 2] = 92; //@line 363
 HEAP32[$dev + 40 >> 2] = 132; //@line 365
 HEAP32[$dev + 44 >> 2] = 2; //@line 367
 return;
}
function _mac_adb_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(120) | 0; //@line 378
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 382
  return $_0 | 0; //@line 385
 }
 HEAP8[$1] = 3; //@line 388
 HEAP32[$1 + 112 >> 2] = 0; //@line 394
 HEAP32[$1 + 116 >> 2] = 0; //@line 397
 _memset($1 + 1 | 0, 0, 5); //@line 398
 _memset($1 + 14 | 0, 0, 14); //@line 399
 _memset($1 + 92 | 0, 0, 17); //@line 400
 $_0 = $1; //@line 402
 return $_0 | 0; //@line 405
}
function _adb_reset($adb) {
 $adb = $adb | 0;
 var $1 = 0, $i_017 = 0, $5 = 0, $16 = 0, $17 = 0, $22 = 0;
 $1 = $adb + 24 | 0; //@line 417
 if ((HEAP32[$1 >> 2] | 0) != 0) {
  $i_017 = 0; //@line 422
  do {
   $5 = HEAP32[$adb + 28 + ($i_017 << 2) >> 2] | 0; //@line 426
   FUNCTION_TABLE_vi[HEAP32[$5 + 28 >> 2] & 1023]($5); //@line 430
   $i_017 = $i_017 + 1 | 0; //@line 431
  } while ($i_017 >>> 0 < (HEAP32[$1 >> 2] | 0) >>> 0);
 }
 HEAP8[$adb | 0] = 3; //@line 443
 HEAP8[$adb + 1 | 0] = 1; //@line 445
 $16 = $adb + 108 | 0; //@line 448
 $17 = $adb + 2 | 0; //@line 449
 tempBigInt = 0; //@line 450
 HEAP8[$17] = tempBigInt & 255; //@line 450
 tempBigInt = tempBigInt >> 8; //@line 450
 HEAP8[$17 + 1 | 0] = tempBigInt & 255; //@line 450
 tempBigInt = tempBigInt >> 8; //@line 450
 HEAP8[$17 + 2 | 0] = tempBigInt & 255; //@line 450
 tempBigInt = tempBigInt >> 8; //@line 450
 HEAP8[$17 + 3 | 0] = tempBigInt & 255; //@line 450
 _memset($adb + 14 | 0, 0, 10); //@line 451
 if ((HEAP8[$16] | 0) == 0) {
  return;
 }
 HEAP8[$16] = 0; //@line 459
 $22 = HEAP32[$adb + 116 >> 2] | 0; //@line 461
 if (($22 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$22 & 511](HEAP32[$adb + 112 >> 2] | 0, 0); //@line 470
 return;
}
function _mac_adb_set_state($adb, $val) {
 $adb = $adb | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $6 = 0, $13 = 0, $17 = 0, $22 = 0, $23 = 0, $25 = 0, $i_0_i_i_i = 0, $30 = 0, $43 = 0, $48 = 0, $63 = 0, $64 = 0, $66 = 0, $70 = 0, $79 = 0, $80 = 0, $82 = 0, $i_0_i_i = 0, $87 = 0, $104 = 0, label = 0;
 $1 = $val & 3; //@line 495
 $2 = $adb | 0; //@line 496
 if ((HEAP8[$2] | 0) == $1 << 24 >> 24) {
  return;
 }
 $6 = $adb + 16 | 0; //@line 504
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 783; //@line 507
 L52 : do {
  if (($1 << 24 >> 24 | 0) == 3 | ($1 << 24 >> 24 | 0) == 0) {
   $13 = HEAP8[$adb + 5 | 0] | 0; //@line 513
   if ((HEAPU8[$adb + 4 | 0] | 0) >= ($13 & 255)) {
    break;
   }
   $17 = HEAP8[$adb + 2 | 0] | 0; //@line 520
   if (($17 & 12) != 8) {
    break;
   }
   HEAP8[$adb + 1 | 0] = 0; //@line 528
   $22 = $17 & 255; //@line 529
   $23 = $22 >>> 4; //@line 530
   $25 = HEAP32[$adb + 24 >> 2] | 0; //@line 532
   $i_0_i_i_i = 0; //@line 534
   while (1) {
    if ($i_0_i_i_i >>> 0 >= $25 >>> 0) {
     break L52;
    }
    $30 = HEAP32[$adb + 28 + ($i_0_i_i_i << 2) >> 2] | 0; //@line 543
    if ((HEAPU8[$30 + 4 | 0] | 0) == ($23 | 0)) {
     break;
    } else {
     $i_0_i_i_i = $i_0_i_i_i + 1 | 0; //@line 553
    }
   }
   if (($30 | 0) == 0) {
    break;
   }
   FUNCTION_TABLE_viiii[HEAP32[$30 + 44 >> 2] & 7]($30, $22 & 3, $adb + 6 | 0, $13 & 255); //@line 566
  }
 } while (0);
 HEAP8[$2] = $1; //@line 570
 $43 = $adb + 108 | 0; //@line 571
 do {
  if ((HEAP8[$43] | 0) != 0) {
   HEAP8[$43] = 0; //@line 577
   $48 = HEAP32[$adb + 116 >> 2] | 0; //@line 579
   if (($48 | 0) == 0) {
    break;
   }
   FUNCTION_TABLE_vii[$48 & 511](HEAP32[$adb + 112 >> 2] | 0, 0); //@line 587
  }
 } while (0);
 if (($1 << 24 >> 24 | 0) == 0) {
  HEAP8[$adb + 1 | 0] = 0; //@line 593
  HEAP8[$adb + 4 | 0] = 0; //@line 595
  HEAP8[$adb + 5 | 0] = 0; //@line 597
  HEAP8[$adb + 14 | 0] = 8; //@line 599
  HEAP8[$adb + 15 | 0] = 0; //@line 601
  return;
 } else if (($1 << 24 >> 24 | 0) == 1 | ($1 << 24 >> 24 | 0) == 2) {
  if ((HEAP8[$adb + 1 | 0] | 0) == 0) {
   HEAP8[$adb + 14 | 0] = 8; //@line 612
   HEAP8[$adb + 15 | 0] = 0; //@line 614
   return;
  }
  $63 = $adb + 4 | 0; //@line 618
  $64 = HEAP8[$63] | 0; //@line 619
  $66 = HEAP8[$adb + 5 | 0] | 0; //@line 621
  HEAP8[$adb + 14 | 0] = 8; //@line 624
  if (($64 & 255) >= ($66 & 255)) {
   HEAP8[$adb + 15 | 0] = -86; //@line 628
   if ((HEAP8[$43] | 0) == 1) {
    return;
   }
   HEAP8[$43] = 1; //@line 636
   $104 = HEAP32[$adb + 116 >> 2] | 0; //@line 638
   if (($104 | 0) == 0) {
    return;
   }
   FUNCTION_TABLE_vii[$104 & 511](HEAP32[$adb + 112 >> 2] | 0, 1); //@line 647
   return;
  }
  $70 = $64 + 1 & 255; //@line 652
  HEAP8[$63] = $70; //@line 653
  HEAP8[$adb + 15 | 0] = HEAP8[($64 & 255) + ($adb + 6) | 0] | 0; //@line 658
  if (($70 & 255) < ($66 & 255)) {
   return;
  }
  $79 = HEAPU8[$adb + 2 | 0] | 0; //@line 667
  $80 = $79 >>> 4; //@line 668
  $82 = HEAP32[$adb + 24 >> 2] | 0; //@line 670
  $i_0_i_i = 0; //@line 672
  while (1) {
   if ($i_0_i_i >>> 0 >= $82 >>> 0) {
    label = 75; //@line 678
    break;
   }
   $87 = HEAP32[$adb + 28 + ($i_0_i_i << 2) >> 2] | 0; //@line 682
   if ((HEAPU8[$87 + 4 | 0] | 0) == ($80 | 0)) {
    break;
   } else {
    $i_0_i_i = $i_0_i_i + 1 | 0; //@line 692
   }
  }
  if ((label | 0) == 75) {
   return;
  }
  if (($87 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[HEAP32[$87 + 40 >> 2] & 511]($87, $79 & 3); //@line 708
  return;
 } else if (($1 << 24 >> 24 | 0) == 3) {
  HEAP8[$adb + 1 | 0] = 1; //@line 714
  HEAP8[$adb + 4 | 0] = 0; //@line 716
  HEAP8[$adb + 5 | 0] = 0; //@line 718
  HEAP8[$adb + 14 | 0] = 0; //@line 720
  HEAP8[$adb + 15 | 0] = 0; //@line 722
  HEAP32[$adb + 20 >> 2] = 0; //@line 724
  return;
 } else {
  return;
 }
}
function _mac_adb_clock($adb, $cnt) {
 $adb = $adb | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $2 = 0, $9 = 0, $11 = 0, $15 = 0, $33 = 0, $34 = 0, $44 = 0, $49 = 0, $_pre_phi = 0, $53 = 0, $58 = 0, $61 = 0, $63 = 0, $74 = 0, $83 = 0, $84 = 0, $88 = 0;
 $1 = $adb + 14 | 0; //@line 750
 $2 = HEAP8[$1] | 0; //@line 751
 if ($2 << 24 >> 24 == 0) {
  if ((HEAP8[$adb | 0] | 0) != 3) {
   return;
  }
  $9 = $adb + 20 | 0; //@line 763
  $11 = (HEAP32[$9 >> 2] | 0) + $cnt | 0; //@line 765
  HEAP32[$9 >> 2] = $11; //@line 766
  if ($11 >>> 0 < 86170) {
   return;
  }
  HEAP32[$9 >> 2] = 0; //@line 773
  $15 = HEAP8[$adb + 3 | 0] | 0; //@line 775
  if ($15 << 24 >> 24 == 0) {
   return;
  }
  _adb_start_transaction($adb, $15, 1); //@line 782
  if ((HEAPU8[$adb + 4 | 0] | 0) < (HEAPU8[$adb + 5 | 0] | 0)) {
   HEAP8[$1] = 8; //@line 790
   HEAP8[$adb + 15 | 0] = -86; //@line 792
   return;
  }
  if ((HEAP8[$adb + 108 | 0] | 0) == 0) {
   return;
  }
  HEAP8[$1] = 8; //@line 805
  HEAP8[$adb + 15 | 0] = -86; //@line 807
  return;
 }
 HEAP32[$adb + 20 >> 2] = 0; //@line 813
 $33 = $adb + 16 | 0; //@line 814
 $34 = HEAP32[$33 >> 2] | 0; //@line 815
 if ($34 >>> 0 > $cnt >>> 0) {
  HEAP32[$33 >> 2] = $34 - $cnt; //@line 820
  return;
 }
 HEAP32[$33 >> 2] = 0; //@line 825
 do {
  if ((HEAP8[$adb + 1 | 0] | 0) == 0) {
   $58 = $adb + 15 | 0; //@line 832
   HEAP8[$58] = HEAP8[$58] << 1; //@line 835
   $61 = $2 - 1 & 255; //@line 836
   HEAP8[$1] = $61; //@line 837
   $63 = HEAP32[$adb + 104 >> 2] | 0; //@line 839
   if (($63 | 0) == 0) {
    $74 = $61; //@line 843
   } else {
    if ((FUNCTION_TABLE_ii[$63 & 31](HEAP32[$adb + 100 >> 2] | 0) | 0) << 24 >> 24 != 0) {
     HEAP8[$58] = HEAP8[$58] | 1; //@line 853
    }
    $74 = HEAP8[$1] | 0; //@line 857
   }
   if ($74 << 24 >> 24 != 0) {
    break;
   }
   if ((HEAP8[$adb | 0] | 0) == 0) {
    _adb_start_transaction($adb, HEAP8[$58] | 0, 0); //@line 871
    break;
   }
   $83 = $adb + 5 | 0; //@line 875
   $84 = HEAP8[$83] | 0; //@line 876
   if (($84 & 255) >= 8) {
    break;
   }
   $88 = HEAP8[$58] | 0; //@line 883
   HEAP8[$83] = $84 + 1 & 255; //@line 885
   HEAP8[($84 & 255) + ($adb + 6) | 0] = $88; //@line 887
  } else {
   $44 = HEAP32[$adb + 96 >> 2] | 0; //@line 891
   if (($44 | 0) == 0) {
    $53 = $2;
    $_pre_phi = $adb + 15 | 0;
   } else {
    $49 = $adb + 15 | 0; //@line 901
    FUNCTION_TABLE_vii[$44 & 511](HEAP32[$adb + 92 >> 2] | 0, (HEAPU8[$49] | 0) >>> 7); //@line 904
    $53 = HEAP8[$1] | 0;
    $_pre_phi = $49;
   }
   HEAP8[$_pre_phi] = HEAP8[$_pre_phi] << 1; //@line 913
   HEAP8[$1] = $53 - 1 & 255; //@line 915
  }
 } while (0);
 HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 783; //@line 921
 return;
}
function _adb_start_transaction($adb, $cmd, $poll) {
 $adb = $adb | 0;
 $cmd = $cmd | 0;
 $poll = $poll | 0;
 var $1 = 0, $6 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $18 = 0, $i_017_i_i = 0, $22 = 0, $30 = 0, $32 = 0, $37 = 0, $43 = 0, $46 = 0, $48 = 0, $i_0_i_i = 0, $53 = 0, $72 = 0, $74 = 0, $i_0_i_i19 = 0, $79 = 0, $93 = 0, $94 = 0, $95 = 0, $97 = 0, $98 = 0, $100 = 0, $i_010_i = 0, $102 = 0, $120 = 0, $124 = 0, $125 = 0, sp = 0;
 sp = STACKTOP; //@line 947
 $1 = $adb + 108 | 0; //@line 948
 do {
  if ((HEAP8[$1] | 0) != 0) {
   HEAP8[$1] = 0; //@line 954
   $6 = HEAP32[$adb + 116 >> 2] | 0; //@line 956
   if (($6 | 0) == 0) {
    break;
   }
   FUNCTION_TABLE_vii[$6 & 511](HEAP32[$adb + 112 >> 2] | 0, 0); //@line 964
  }
 } while (0);
 $11 = $adb + 2 | 0; //@line 968
 HEAP8[$11] = $cmd; //@line 969
 HEAP8[$adb + 4 | 0] = 0; //@line 971
 $13 = $adb + 5 | 0; //@line 972
 HEAP8[$13] = 0; //@line 973
 $14 = $cmd & 255; //@line 974
 $15 = $14 & 15; //@line 975
 L150 : do {
  if (($15 | 0) == 0) {
   $18 = $adb + 24 | 0; //@line 980
   if ((HEAP32[$18 >> 2] | 0) != 0) {
    $i_017_i_i = 0; //@line 985
    do {
     $22 = HEAP32[$adb + 28 + ($i_017_i_i << 2) >> 2] | 0; //@line 989
     FUNCTION_TABLE_vi[HEAP32[$22 + 28 >> 2] & 1023]($22); //@line 993
     $i_017_i_i = $i_017_i_i + 1 | 0; //@line 994
    } while ($i_017_i_i >>> 0 < (HEAP32[$18 >> 2] | 0) >>> 0);
   }
   HEAP8[$adb | 0] = 3; //@line 1006
   $30 = $adb + 1 | 0; //@line 1007
   HEAP8[$30] = 1; //@line 1008
   $32 = $11; //@line 1010
   tempBigInt = 0; //@line 1011
   HEAP8[$32] = tempBigInt & 255; //@line 1011
   tempBigInt = tempBigInt >> 8; //@line 1011
   HEAP8[$32 + 1 | 0] = tempBigInt & 255; //@line 1011
   tempBigInt = tempBigInt >> 8; //@line 1011
   HEAP8[$32 + 2 | 0] = tempBigInt & 255; //@line 1011
   tempBigInt = tempBigInt >> 8; //@line 1011
   HEAP8[$32 + 3 | 0] = tempBigInt & 255; //@line 1011
   _memset($adb + 14 | 0, 0, 10); //@line 1012
   do {
    if ((HEAP8[$1] | 0) != 0) {
     HEAP8[$1] = 0; //@line 1018
     $37 = HEAP32[$adb + 116 >> 2] | 0; //@line 1020
     if (($37 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$37 & 511](HEAP32[$adb + 112 >> 2] | 0, 0); //@line 1028
    }
   } while (0);
   HEAP8[$30] = 1; //@line 1032
  } else {
   $43 = $14 & 12; //@line 1035
   if (($43 | 0) == 8) {
    break;
   } else if (($43 | 0) == 12) {
    HEAP8[$adb + 1 | 0] = 1; //@line 1040
    $46 = $14 >>> 4; //@line 1041
    $48 = HEAP32[$adb + 24 >> 2] | 0; //@line 1043
    $i_0_i_i = 0; //@line 1045
    while (1) {
     if ($i_0_i_i >>> 0 >= $48 >>> 0) {
      break L150;
     }
     $53 = HEAP32[$adb + 28 + ($i_0_i_i << 2) >> 2] | 0; //@line 1054
     if ((HEAPU8[$53 + 4 | 0] | 0) == ($46 | 0)) {
      break;
     } else {
      $i_0_i_i = $i_0_i_i + 1 | 0; //@line 1064
     }
    }
    if (($53 | 0) == 0) {
     break;
    }
    HEAP8[$13] = (FUNCTION_TABLE_iiii[HEAP32[$53 + 36 >> 2] & 127]($53, $14 & 3, $adb + 6 | 0) | 0) & 255; //@line 1078
    HEAP8[$adb + 3 | 0] = $cmd; //@line 1080
    break;
   }
   if (($15 | 0) != 1) {
    _mac_log_deb(58184, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $14, tempInt) | 0); //@line 1087
    break;
   }
   HEAP8[$adb + 1 | 0] = 1; //@line 1091
   $72 = $14 >>> 4; //@line 1092
   $74 = HEAP32[$adb + 24 >> 2] | 0; //@line 1094
   $i_0_i_i19 = 0; //@line 1096
   while (1) {
    if ($i_0_i_i19 >>> 0 >= $74 >>> 0) {
     break L150;
    }
    $79 = HEAP32[$adb + 28 + ($i_0_i_i19 << 2) >> 2] | 0; //@line 1105
    if ((HEAPU8[$79 + 4 | 0] | 0) == ($72 | 0)) {
     break;
    } else {
     $i_0_i_i19 = $i_0_i_i19 + 1 | 0; //@line 1115
    }
   }
   if (($79 | 0) == 0) {
    break;
   }
   FUNCTION_TABLE_vi[HEAP32[$79 + 32 >> 2] & 1023]($79); //@line 1126
  }
 } while (0);
 if (($poll | 0) == 0) {
  STACKTOP = sp; //@line 1133
  return;
 }
 $93 = $14 >>> 4; //@line 1136
 $94 = $adb + 24 | 0; //@line 1137
 $95 = HEAP32[$94 >> 2] | 0; //@line 1138
 if (($95 | 0) == 0) {
  STACKTOP = sp; //@line 1142
  return;
 }
 $97 = $adb + 116 | 0; //@line 1145
 $98 = $adb + 112 | 0; //@line 1146
 $i_010_i = 0;
 $100 = $95;
 while (1) {
  $102 = HEAP32[$adb + 28 + ($i_010_i << 2) >> 2] | 0; //@line 1153
  do {
   if ((HEAP8[$102 + 7 | 0] | 0) == 0) {
    $124 = $100; //@line 1160
   } else {
    if ((HEAPU8[$102 + 4 | 0] | 0) == ($93 | 0)) {
     $124 = $100; //@line 1168
     break;
    }
    if ((HEAP32[$102 + 20 >> 2] & 8192 | 0) == 0) {
     $124 = $100; //@line 1177
     break;
    }
    if ((HEAP8[$1] | 0) == 1) {
     $124 = $100; //@line 1184
     break;
    }
    HEAP8[$1] = 1; //@line 1187
    $120 = HEAP32[$97 >> 2] | 0; //@line 1188
    if (($120 | 0) == 0) {
     $124 = $100; //@line 1192
     break;
    }
    FUNCTION_TABLE_vii[$120 & 511](HEAP32[$98 >> 2] | 0, 1); //@line 1196
    $124 = HEAP32[$94 >> 2] | 0; //@line 1199
   }
  } while (0);
  $125 = $i_010_i + 1 | 0; //@line 1203
  if ($125 >>> 0 < $124 >>> 0) {
   $i_010_i = $125;
   $100 = $124;
  } else {
   break;
  }
 }
 STACKTOP = sp; //@line 1212
 return;
}
function _adb_kbd_set_keypad_mode($kbd, $motion) {
 $kbd = $kbd | 0;
 $motion = $motion | 0;
 var $3 = 0, $5 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $15 = 0, $tmp_08_i = 0, $18 = 0, $19$1 = 0, $21 = 0, $23 = 0, $30 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $37 = 0, $39 = 0, $40 = 0, $tmp_08_i7 = 0, $43 = 0, $44$1 = 0, $46 = 0, $48 = 0;
 $3 = HEAP32[$kbd + 320 >> 2] | 0; //@line 1232
 if (($motion | 0) == 0) {
  $30 = HEAP32[2260] | 0; //@line 1235
  if (($30 | 0) != 0) {
   $32 = $3 | 0; //@line 1239
   $34 = 9040;
   $33 = $30;
   do {
    $35 = HEAP32[$32 >> 2] | 0; //@line 1245
    L217 : do {
     if (($35 | 0) != 0) {
      $37 = $34; //@line 1250
      $tmp_08_i7 = $3;
      $40 = $35;
      $39 = $33;
      while (1) {
       if (($40 | 0) == ($39 | 0)) {
        $43 = $tmp_08_i7; //@line 1260
        $44$1 = HEAP32[$37 + 4 >> 2] | 0; //@line 1264
        HEAP32[$43 >> 2] = HEAP32[$37 >> 2]; //@line 1266
        HEAP32[$43 + 4 >> 2] = $44$1; //@line 1268
       }
       $46 = $tmp_08_i7 + 8 | 0; //@line 1271
       $48 = HEAP32[$46 >> 2] | 0; //@line 1273
       if (($48 | 0) == 0) {
        break L217;
       }
       $tmp_08_i7 = $46;
       $40 = $48;
       $39 = HEAP32[$34 >> 2] | 0;
      }
     }
    } while (0);
    $34 = $34 + 8 | 0; //@line 1285
    $33 = HEAP32[$34 >> 2] | 0; //@line 1286
   } while (($33 | 0) != 0);
  }
  HEAP8[$kbd + 316 | 0] = 0; //@line 1297
  return;
 } else {
  $5 = HEAP32[2234] | 0; //@line 1301
  if (($5 | 0) != 0) {
   $7 = $3 | 0; //@line 1305
   $9 = 8936;
   $8 = $5;
   do {
    $10 = HEAP32[$7 >> 2] | 0; //@line 1311
    L201 : do {
     if (($10 | 0) != 0) {
      $12 = $9; //@line 1316
      $tmp_08_i = $3;
      $15 = $10;
      $14 = $8;
      while (1) {
       if (($15 | 0) == ($14 | 0)) {
        $18 = $tmp_08_i; //@line 1326
        $19$1 = HEAP32[$12 + 4 >> 2] | 0; //@line 1330
        HEAP32[$18 >> 2] = HEAP32[$12 >> 2]; //@line 1332
        HEAP32[$18 + 4 >> 2] = $19$1; //@line 1334
       }
       $21 = $tmp_08_i + 8 | 0; //@line 1337
       $23 = HEAP32[$21 >> 2] | 0; //@line 1339
       if (($23 | 0) == 0) {
        break L201;
       }
       $tmp_08_i = $21;
       $15 = $23;
       $14 = HEAP32[$9 >> 2] | 0;
      }
     }
    } while (0);
    $9 = $9 + 8 | 0; //@line 1351
    $8 = HEAP32[$9 >> 2] | 0; //@line 1352
   } while (($8 | 0) != 0);
  }
  HEAP8[$kbd + 316 | 0] = 1; //@line 1363
  return;
 }
}
function _adb_kbd_get_keypad_mode($kbd) {
 $kbd = $kbd | 0;
 return HEAP8[$kbd + 316 | 0] | 0; //@line 1380
}
function _adb_kbd_talk_done($dev, $reg) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 var $2 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1392
 if (($reg | 0) != 0) {
  return;
 }
 HEAP8[$2 + 48 | 0] = 0; //@line 1400
 HEAP8[$2 + 7 | 0] = (HEAP32[$2 + 52 >> 2] | 0) != (HEAP32[$2 + 56 >> 2] | 0) | 0; //@line 1410
 return;
}
function _adb_mouse_move($mse, $button, $dx, $dy) {
 $mse = $mse | 0;
 $button = $button | 0;
 $dx = $dx | 0;
 $dy = $dy | 0;
 var $1 = 0, $9 = 0, $11 = 0, $12 = 0, $14 = 0, $_phi_trans_insert = 0, $_off0 = 0, $19 = 0;
 $1 = $mse + 56 | 0; //@line 1427
 if (((HEAP32[$1 >> 2] ^ $button) & 1 | 0) != 0) {
  HEAP32[$mse + 52 >> 2] = 1; //@line 1435
 }
 HEAP32[$1 >> 2] = $button; //@line 1438
 $9 = $mse + 60 | 0; //@line 1439
 $11 = (HEAP32[$9 >> 2] | 0) + $dx | 0; //@line 1441
 HEAP32[$9 >> 2] = $11; //@line 1442
 $12 = $mse + 64 | 0; //@line 1443
 $14 = (HEAP32[$12 >> 2] | 0) + $dy | 0; //@line 1445
 HEAP32[$12 >> 2] = $14; //@line 1446
 $_phi_trans_insert = $mse + 52 | 0; //@line 1449
 if (($11 | $14 | 0) == 0) {
  $_off0 = HEAP32[$_phi_trans_insert >> 2] & 255; //@line 1455
  $19 = $mse + 7 | 0; //@line 1457
  HEAP8[$19] = $_off0; //@line 1458
  return;
 } else {
  HEAP32[$_phi_trans_insert >> 2] = 1; //@line 1462
  $_off0 = 1; //@line 1464
  $19 = $mse + 7 | 0; //@line 1466
  HEAP8[$19] = $_off0; //@line 1467
  return;
 }
}
function _adb_mouse_talk_done($dev, $reg) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 var $2 = 0, $5 = 0, $10 = 0, $_off016 = 0, $22 = 0, $24 = 0, $25 = 0, $29 = 0, $31 = 0, $32 = 0, $_off0 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1485
 if (($reg | 0) != 0) {
  return;
 }
 $5 = $2 + 48 | 0; //@line 1492
 if ((HEAP8[$5] | 0) == 0) {
  return;
 }
 HEAP8[$5] = 0; //@line 1500
 $10 = $2 + 52 | 0; //@line 1502
 HEAP32[$10 >> 2] = 0; //@line 1503
 if ((HEAP32[$2 + 68 >> 2] | 0) == (HEAP32[$2 + 56 >> 2] | 0)) {
  $_off016 = 0; //@line 1513
 } else {
  HEAP32[$10 >> 2] = 1; //@line 1515
  $_off016 = 1; //@line 1517
 }
 $22 = HEAP32[$2 + 72 >> 2] | 0; //@line 1522
 $24 = $2 + 60 | 0; //@line 1524
 $25 = HEAP32[$24 >> 2] | 0; //@line 1525
 HEAP32[$24 >> 2] = $25 - $22; //@line 1527
 $29 = HEAP32[$2 + 76 >> 2] | 0; //@line 1530
 $31 = $2 + 64 | 0; //@line 1532
 $32 = HEAP32[$31 >> 2] | 0; //@line 1533
 HEAP32[$31 >> 2] = $32 - $29; //@line 1535
 if (($25 | 0) == ($22 | 0) & ($32 | 0) == ($29 | 0)) {
  $_off0 = $_off016; //@line 1541
 } else {
  HEAP32[$10 >> 2] = 1; //@line 1543
  $_off0 = 1; //@line 1545
 }
 HEAP8[$dev + 7 | 0] = $_off0; //@line 1549
 return;
}
function _adb_kbd_set_key($kbd, $event, $key) {
 $kbd = $kbd | 0;
 $event = $event | 0;
 $key = $key | 0;
 var $map_0 = 0, $5 = 0, $6 = 0, $11 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $28 = 0, $29 = 0, $31 = 0, $32 = 0, $_pre_phi18 = 0, $_pre_phi = 0, sp = 0;
 sp = STACKTOP; //@line 1567
 $map_0 = HEAP32[$kbd + 320 >> 2] | 0; //@line 1571
 while (1) {
  $5 = HEAP32[$map_0 >> 2] | 0; //@line 1575
  $6 = ($5 | 0) == 0; //@line 1576
  if ($6 | ($5 | 0) == ($key | 0)) {
   break;
  } else {
   $map_0 = $map_0 + 8 | 0; //@line 1584
  }
 }
 if ($6) {
  $11 = _pce_key_to_string($key) | 0; //@line 1589
  _pce_log(2, 58152, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $key, HEAP32[tempInt + 8 >> 2] = ($11 | 0) != 0 ? $11 : 56152, tempInt) | 0); //@line 1592
  STACKTOP = sp; //@line 1594
  return;
 }
 do {
  if (($event | 0) == 1) {
   $16 = $kbd + 56 | 0; //@line 1599
   $17 = HEAP32[$16 >> 2] | 0; //@line 1600
   $19 = $17 + 1 & 255; //@line 1602
   $20 = $kbd + 52 | 0; //@line 1603
   if (($19 | 0) == (HEAP32[$20 >> 2] | 0)) {
    $_pre_phi = $20;
    $_pre_phi18 = $16;
    break;
   }
   HEAP8[$kbd + 60 + $17 | 0] = HEAP8[$map_0 + 4 | 0] | 0; //@line 1614
   HEAP32[$16 >> 2] = $19; //@line 1615
   $_pre_phi = $20;
   $_pre_phi18 = $16;
  } else if (($event | 0) == 2) {
   $28 = $kbd + 56 | 0; //@line 1619
   $29 = HEAP32[$28 >> 2] | 0; //@line 1620
   $31 = $29 + 1 & 255; //@line 1622
   $32 = $kbd + 52 | 0; //@line 1623
   if (($31 | 0) == (HEAP32[$32 >> 2] | 0)) {
    $_pre_phi = $32;
    $_pre_phi18 = $28;
    break;
   }
   HEAP8[$kbd + 60 + $29 | 0] = HEAP8[$map_0 + 4 | 0] | -128; //@line 1635
   HEAP32[$28 >> 2] = $31; //@line 1636
   $_pre_phi = $32;
   $_pre_phi18 = $28;
  } else {
   $_pre_phi = $kbd + 52 | 0;
   $_pre_phi18 = $kbd + 56 | 0;
  }
 } while (0);
 HEAP8[$kbd + 7 | 0] = (HEAP32[$_pre_phi >> 2] | 0) != (HEAP32[$_pre_phi18 >> 2] | 0) | 0; //@line 1653
 STACKTOP = sp; //@line 1655
 return;
}
function _adb_kbd_del($dev) {
 $dev = $dev | 0;
 var $2 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1666
 _free(HEAP32[$2 + 320 >> 2] | 0); //@line 1671
 _free($2); //@line 1672
 return;
}
function _adb_kbd_reset($dev) {
 $dev = $dev | 0;
 var $2 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1684
 _adb_dev_reset($dev); //@line 1685
 HEAP8[$2 + 48 | 0] = 0; //@line 1687
 HEAP32[$2 + 52 >> 2] = 0; //@line 1690
 HEAP32[$2 + 56 >> 2] = 0; //@line 1693
 return;
}
function _adb_kbd_flush($dev) {
 $dev = $dev | 0;
 var $2 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1705
 _adb_dev_flush($dev); //@line 1706
 HEAP8[$2 + 48 | 0] = 0; //@line 1708
 HEAP32[$2 + 52 >> 2] = 0; //@line 1711
 HEAP32[$2 + 56 >> 2] = 0; //@line 1714
 return;
}
function _adb_kbd_talk($dev, $reg, $buf) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 $buf = $buf | 0;
 var $3 = 0, $4 = 0, $5 = 0, $10 = 0, $11 = 0, $14 = 0, $18 = 0, $20 = 0, $23 = 0, $27 = 0, $31 = 0, $_pre_phi_i = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 1730
 if (($reg | 0) == 2) {
  HEAP8[$buf] = -1; //@line 1732
  HEAP8[$buf + 1 | 0] = -1; //@line 1734
  _mac_log_deb(43320, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 1735
  $_0 = 2; //@line 1737
  STACKTOP = sp; //@line 1739
  return $_0 | 0; //@line 1740
 } else if (($reg | 0) == 0) {
  $3 = HEAP32[$dev >> 2] | 0; //@line 1743
  $4 = $3; //@line 1744
  $5 = $3 + 48 | 0; //@line 1745
  if ((HEAP8[$5] | 0) == 0) {
   $10 = $3 + 52 | 0; //@line 1751
   $11 = HEAP32[$10 >> 2] | 0; //@line 1752
   $14 = HEAP32[$3 + 56 >> 2] | 0; //@line 1755
   if (($11 | 0) == ($14 | 0)) {
    $_0 = 0; //@line 1759
    STACKTOP = sp; //@line 1761
    return $_0 | 0; //@line 1762
   }
   $18 = HEAP8[$4 + 60 + $11 | 0] | 0; //@line 1765
   $20 = $11 + 1 & 255; //@line 1767
   HEAP32[$10 >> 2] = $20; //@line 1768
   if (($20 | 0) == ($14 | 0)) {
    $27 = 255; //@line 1772
   } else {
    $23 = HEAP8[$4 + 60 + $20 | 0] | 0; //@line 1775
    HEAP32[$10 >> 2] = $11 + 2 & 255; //@line 1778
    $27 = $23 & 255; //@line 1781
   }
   $31 = $dev + 8 | 0; //@line 1787
   HEAP32[$31 >> 2] = $27 | ($18 & 255) << 8; //@line 1788
   $_pre_phi_i = $31; //@line 1790
  } else {
   $_pre_phi_i = $dev + 8 | 0; //@line 1794
  }
  HEAP8[$5] = 1; //@line 1797
  HEAP8[$buf] = (HEAP32[$_pre_phi_i >> 2] | 0) >>> 8 & 255; //@line 1801
  HEAP8[$buf + 1 | 0] = HEAP32[$_pre_phi_i >> 2] & 255; //@line 1805
  $_0 = 2; //@line 1807
  STACKTOP = sp; //@line 1809
  return $_0 | 0; //@line 1810
 } else if (($reg | 0) != 3) {
  _mac_log_deb(46784, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $reg, tempInt) | 0); //@line 1812
 }
 $_0 = _adb_dev_talk($dev, $reg, $buf) | 0; //@line 1816
 STACKTOP = sp; //@line 1818
 return $_0 | 0; //@line 1819
}
function _adb_kbd_listen($dev, $reg, $buf, $cnt) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var sp = 0;
 sp = STACKTOP; //@line 1831
 do {
  if (($reg | 0) != 3) {
   _mac_log_deb(50880, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $reg, tempInt) | 0); //@line 1836
   if (!(($reg | 0) == 2 & ($cnt | 0) == 2)) {
    break;
   }
   HEAP32[$dev + 16 >> 2] = (HEAPU8[$buf] | 0) << 8 | (HEAPU8[$buf + 1 | 0] | 0); //@line 1852
   STACKTOP = sp; //@line 1854
   return;
  }
 } while (0);
 _adb_dev_listen($dev, $reg, $buf, $cnt); //@line 1858
 STACKTOP = sp; //@line 1859
 return;
}
function _adb_kbd_new() {
 var $1 = 0, $2 = 0, $n_0_i_i = 0, $28 = 0, $30 = 0, $31 = 0, $34 = 0, $_0_i_i = 0, $_0 = 0;
 $1 = _malloc(324) | 0; //@line 1872
 $2 = $1; //@line 1873
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 1877
  return $_0 | 0; //@line 1880
 }
 _adb_dev_init($1, 2, 2); //@line 1883
 HEAP32[$1 >> 2] = $1; //@line 1885
 HEAP32[$1 + 24 >> 2] = 2; //@line 1888
 HEAP32[$1 + 28 >> 2] = 142; //@line 1891
 HEAP32[$1 + 32 >> 2] = 8; //@line 1894
 HEAP32[$1 + 36 >> 2] = 68; //@line 1897
 HEAP32[$1 + 40 >> 2] = 128; //@line 1900
 HEAP32[$1 + 44 >> 2] = 6; //@line 1903
 HEAP32[$1 + 52 >> 2] = 0; //@line 1906
 HEAP32[$1 + 56 >> 2] = 0; //@line 1909
 HEAP8[$1 + 316 | 0] = 0; //@line 1911
 $n_0_i_i = 0; //@line 1913
 while (1) {
  $28 = $n_0_i_i + 1 | 0; //@line 1919
  if ((HEAP32[9144 + ($n_0_i_i << 3) >> 2] | 0) == 0) {
   break;
  } else {
   $n_0_i_i = $28; //@line 1924
  }
 }
 $30 = $28 << 3; //@line 1927
 $31 = _malloc($30) | 0; //@line 1928
 if (($31 | 0) == 0) {
  $_0_i_i = 0; //@line 1932
 } else {
  $34 = $31; //@line 1934
  _memcpy($31 | 0, 9144, $30) | 0; //@line 1935
  $_0_i_i = $34; //@line 1937
 }
 HEAP32[$1 + 320 >> 2] = $_0_i_i; //@line 1942
 $_0 = $2; //@line 1944
 return $_0 | 0; //@line 1947
}
function _adb_mouse_del($dev) {
 $dev = $dev | 0;
 _free(HEAP32[$dev >> 2] | 0); //@line 1958
 return;
}
function _adb_mouse_reset($dev) {
 $dev = $dev | 0;
 var $2 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1970
 _adb_dev_reset($dev); //@line 1971
 _memset($2 + 52 | 0, 0, 28); //@line 1974
 HEAP32[$dev + 8 >> 2] = 32896; //@line 1975
 return;
}
function _adb_mouse_flush($dev) {
 $dev = $dev | 0;
 var $2 = 0;
 $2 = HEAP32[$dev >> 2] | 0; //@line 1987
 _adb_dev_flush($dev); //@line 1988
 _memset($2 + 52 | 0, 0, 28); //@line 1990
 return;
}
function _adb_mouse_talk($dev, $reg, $buf) {
 $dev = $dev | 0;
 $reg = $reg | 0;
 $buf = $buf | 0;
 var $4 = 0, $15 = 0, $20 = 0, $25 = 0, $26 = 0, $32 = 0, $33 = 0, $r_0_i_i = 0, $40 = 0, $41 = 0, $r_0_i25_i = 0, $50 = 0, $_0 = 0;
 if (($reg | 0) != 0) {
  $_0 = _adb_dev_talk($dev, $reg, $buf) | 0; //@line 2014
  return $_0 | 0; //@line 2017
 }
 $4 = HEAP32[$dev >> 2] | 0; //@line 2020
 if ((HEAP32[$4 + 52 >> 2] | 0) == 0) {
  $_0 = 0; //@line 2027
  return $_0 | 0; //@line 2030
 }
 HEAP8[$4 + 48 | 0] = 1; //@line 2033
 $15 = $4 + 68 | 0; //@line 2038
 HEAP32[$15 >> 2] = HEAP32[$4 + 56 >> 2]; //@line 2039
 $20 = $4 + 72 | 0; //@line 2044
 HEAP32[$20 >> 2] = HEAP32[$4 + 60 >> 2]; //@line 2045
 $25 = $4 + 76 | 0; //@line 2050
 HEAP32[$25 >> 2] = HEAP32[$4 + 64 >> 2]; //@line 2051
 $26 = $dev + 8 | 0; //@line 2052
 HEAP32[$26 >> 2] = 32896; //@line 2053
 if ((HEAP32[$15 >> 2] & 1 | 0) == 0) {
  $32 = 32896; //@line 2059
 } else {
  HEAP32[$26 >> 2] = 128; //@line 2061
  $32 = 128; //@line 2063
 }
 $33 = HEAP32[$20 >> 2] | 0; //@line 2066
 if (($33 | 0) < 0) {
  $r_0_i_i = ($33 | 0) < -63 ? 65 : $33 & 127; //@line 2074
 } else {
  $r_0_i_i = ($33 | 0) > 63 ? 63 : $33; //@line 2078
 }
 $40 = $r_0_i_i | $32; //@line 2081
 HEAP32[$26 >> 2] = $40; //@line 2082
 $41 = HEAP32[$25 >> 2] | 0; //@line 2083
 if (($41 | 0) < 0) {
  $r_0_i25_i = ($41 | 0) < -63 ? 65 : $41 & 127; //@line 2091
 } else {
  $r_0_i25_i = ($41 | 0) > 63 ? 63 : $41; //@line 2095
 }
 $50 = $r_0_i25_i << 8 | $40 & 33023; //@line 2100
 HEAP32[$26 >> 2] = $50; //@line 2101
 HEAP8[$buf] = $50 >>> 8 & 255; //@line 2104
 HEAP8[$buf + 1 | 0] = HEAP32[$26 >> 2] & 255; //@line 2108
 $_0 = 2; //@line 2110
 return $_0 | 0; //@line 2113
}
function _adb_mouse_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(80) | 0; //@line 2123
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 2127
  return $_0 | 0; //@line 2130
 }
 _adb_dev_init($1, 3, 1); //@line 2134
 HEAP32[$1 >> 2] = $1; //@line 2136
 HEAP32[$1 + 24 >> 2] = 316; //@line 2139
 HEAP32[$1 + 28 >> 2] = 236; //@line 2142
 HEAP32[$1 + 32 >> 2] = 326; //@line 2145
 HEAP32[$1 + 36 >> 2] = 74; //@line 2148
 HEAP32[$1 + 40 >> 2] = 82; //@line 2151
 _memset($1 + 52 | 0, 0, 28); //@line 2153
 $_0 = $1; //@line 2155
 return $_0 | 0; //@line 2158
}
function _mac_prt_state($sim, $str) {
 $sim = $sim | 0;
 $str = $str | 0;
 var $cmd = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $i_014_i = 0, $53 = 0, $56 = 0, $59 = 0, $62 = 0, $72 = 0, $74 = 0, $76 = 0, $78 = 0, $82 = 0, $84 = 0, $86 = 0, $88 = 0, $90 = 0, $94 = 0, $96 = 0, $99 = 0, $101 = 0, $105 = 0, $107 = 0, $111 = 0, $114 = 0, $116 = 0, $118 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 2180
 STACKTOP = STACKTOP + 264 | 0; //@line 2180
 $cmd = sp | 0; //@line 2181
 _cmd_set_str($cmd, $str); //@line 2182
 if ((_cmd_match_eol($cmd) | 0) != 0) {
  STACKTOP = sp; //@line 2187
  return;
 }
 if ((_cmd_match_eol($cmd) | 0) != 0) {
  STACKTOP = sp; //@line 2194
  return;
 }
 $5 = $sim + 49 | 0; //@line 2197
 $6 = $sim + 48 | 0; //@line 2198
 $7 = $sim + 50 | 0; //@line 2199
 $8 = $sim + 51 | 0; //@line 2200
 $9 = $sim + 124 | 0; //@line 2201
 $10 = $sim + 44 | 0; //@line 2202
 $11 = $sim + 45 | 0; //@line 2203
 $12 = $sim + 68 | 0; //@line 2204
 $13 = $sim + 52 | 0; //@line 2205
 $14 = $sim + 46 | 0; //@line 2206
 $15 = $sim + 47 | 0; //@line 2207
 $16 = $sim + 42 | 0; //@line 2208
 $17 = $sim + 43 | 0; //@line 2209
 $18 = $sim + 69 | 0; //@line 2210
 $19 = $sim + 56 | 0; //@line 2211
 $20 = $sim + 54 | 0; //@line 2212
 $21 = $sim + 40 | 0; //@line 2213
 $22 = $sim + 41 | 0; //@line 2214
 $23 = $sim + 60 | 0; //@line 2215
 $24 = $sim + 4624 | 0; //@line 2216
 $25 = $sim + 4625 | 0; //@line 2217
 $26 = $sim + 64 | 0; //@line 2218
 $27 = $sim + 62 | 0; //@line 2219
 $28 = $sim + 1424 | 0; //@line 2220
 $29 = $sim + 8 | 0; //@line 2221
 $30 = $sim + 4 | 0; //@line 2222
 L348 : while (1) {
  do {
   if ((_cmd_match($cmd, 46504) | 0) == 0) {
    if ((_cmd_match($cmd, 45832) | 0) != 0) {
     _pce_prt_sep(34056); //@line 2234
     _mem_prt_state(HEAP32[$29 >> 2] | 0, HEAP32[_stdout >> 2] | 0); //@line 2237
     break;
    }
    if ((_cmd_match($cmd, 45480) | 0) == 0) {
     if ((_cmd_match($cmd, 45152) | 0) == 0) {
      break L348;
     }
     _pce_prt_sep(36864); //@line 2251
     $72 = HEAPU8[$6] | 0; //@line 2255
     $74 = HEAPU8[$7] | 0; //@line 2257
     $76 = HEAPU8[$8] | 0; //@line 2259
     $78 = HEAPU8[$9] | 0; //@line 2261
     _pce_printf(36328, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = HEAPU8[$5] | 0, HEAP32[tempInt + 8 >> 2] = $72, HEAP32[tempInt + 16 >> 2] = $74, HEAP32[tempInt + 24 >> 2] = $76, HEAP32[tempInt + 32 >> 2] = $78, tempInt) | 0); //@line 2262
     $82 = HEAPU8[$11] | 0; //@line 2266
     $84 = HEAPU8[$12] | 0; //@line 2268
     $86 = HEAPU16[$13 >> 1] | 0; //@line 2270
     $88 = HEAPU8[$14] | 0; //@line 2272
     $90 = HEAPU8[$15] | 0; //@line 2274
     _pce_printf(36040, (tempInt = STACKTOP, STACKTOP = STACKTOP + 48 | 0, HEAP32[tempInt >> 2] = HEAPU8[$10] | 0, HEAP32[tempInt + 8 >> 2] = $82, HEAP32[tempInt + 16 >> 2] = $84, HEAP32[tempInt + 24 >> 2] = $86, HEAP32[tempInt + 32 >> 2] = $88, HEAP32[tempInt + 40 >> 2] = $90, tempInt) | 0); //@line 2275
     $94 = HEAPU8[$17] | 0; //@line 2279
     $96 = HEAPU8[$18] | 0; //@line 2281
     $99 = (HEAP32[$19 >> 2] | 0) != 0 ? 42 : 32; //@line 2284
     $101 = HEAPU16[$20 >> 1] | 0; //@line 2286
     _pce_printf(35720, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = HEAPU8[$16] | 0, HEAP32[tempInt + 8 >> 2] = $94, HEAP32[tempInt + 16 >> 2] = $96, HEAP32[tempInt + 24 >> 2] = $99, HEAP32[tempInt + 32 >> 2] = $101, tempInt) | 0); //@line 2287
     $105 = HEAPU8[$22] | 0; //@line 2291
     $107 = HEAPU16[$23 >> 1] | 0; //@line 2293
     _pce_printf(35440, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = HEAPU8[$21] | 0, HEAP32[tempInt + 8 >> 2] = $105, HEAP32[tempInt + 16 >> 2] = 0, HEAP32[tempInt + 24 >> 2] = $107, tempInt) | 0); //@line 2294
     $111 = HEAPU8[$25] | 0; //@line 2298
     $114 = (HEAP32[$26 >> 2] | 0) != 0 ? 42 : 32; //@line 2301
     $116 = HEAPU16[$27 >> 1] | 0; //@line 2303
     _pce_printf(35144, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = HEAPU8[$24] | 0, HEAP32[tempInt + 8 >> 2] = $111, HEAP32[tempInt + 16 >> 2] = 0, HEAP32[tempInt + 24 >> 2] = $114, HEAP32[tempInt + 32 >> 2] = $116, tempInt) | 0); //@line 2304
     break;
    } else {
     _pce_prt_sep(34896); //@line 2307
     _pce_printf(34656, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAPU8[$28] | 0, tempInt) | 0); //@line 2310
     $i_014_i = 0; //@line 2312
     do {
      $53 = HEAPU8[$sim + 132 + $i_014_i | 0] | 0; //@line 2317
      $56 = HEAPU8[$sim + 148 + $i_014_i | 0] | 0; //@line 2320
      $59 = HEAPU8[$sim + 772 + $i_014_i | 0] | 0; //@line 2323
      $62 = HEAPU8[$sim + 788 + $i_014_i | 0] | 0; //@line 2326
      _pce_printf(34376, (tempInt = STACKTOP, STACKTOP = STACKTOP + 64 | 0, HEAP32[tempInt >> 2] = $i_014_i, HEAP32[tempInt + 8 >> 2] = $53, HEAP32[tempInt + 16 >> 2] = $i_014_i, HEAP32[tempInt + 24 >> 2] = $56, HEAP32[tempInt + 32 >> 2] = $i_014_i, HEAP32[tempInt + 40 >> 2] = $59, HEAP32[tempInt + 48 >> 2] = $i_014_i, HEAP32[tempInt + 56 >> 2] = $62, tempInt) | 0); //@line 2327
      $i_014_i = $i_014_i + 1 | 0; //@line 2328
     } while ($i_014_i >>> 0 < 16);
    }
   } else {
    _mac_prt_state_cpu(HEAP32[$30 >> 2] | 0); //@line 2340
   }
  } while (0);
  if ((_cmd_match_eol($cmd) | 0) != 0) {
   label = 292; //@line 2348
   break;
  }
 }
 if ((label | 0) == 292) {
  STACKTOP = sp; //@line 2353
  return;
 }
 $118 = _cmd_get_str($cmd) | 0; //@line 2356
 _pce_printf(44824, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $118, tempInt) | 0); //@line 2357
 STACKTOP = sp; //@line 2359
 return;
}
function _mac_log_mem($ext, $addr, $type) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $type = $type | 0;
 return;
}
function _mac_prt_state_cpu($c) {
 $c = $c | 0;
 var $op = 0, $str = 0, $1 = 0, $2 = 0, $3 = 0, $11 = 0.0, $12 = 0, $14 = 0, $37 = 0, $38 = 0, $40 = 0, $44 = 0, $46 = 0, $50 = 0, $52 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $60 = 0, $62 = 0, $64 = 0, $65 = 0, $69 = 0, $71 = 0, $73 = 0, $74 = 0, $78 = 0, $79 = 0, $81 = 0, $83 = 0, $85 = 0, $86 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, sp = 0;
 sp = STACKTOP; //@line 2390
 STACKTOP = STACKTOP + 608 | 0; //@line 2390
 $op = sp | 0; //@line 2391
 $str = sp + 352 | 0; //@line 2392
 _pce_prt_sep(33832); //@line 2393
 $1 = _e68_get_opcnt($c) | 0; //@line 2394
 $2 = _e68_get_clkcnt($c) | 0; //@line 2395
 $3 = _e68_get_delay($c) | 0; //@line 2396
 if (($1 | 0) == 0) {
  $11 = 1.0; //@line 2400
 } else {
  $11 = +(($3 + $2 | 0) >>> 0 >>> 0) / +($1 >>> 0 >>> 0); //@line 2407
 }
 _pce_printf(33416, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $2, HEAP32[tempInt + 8 >> 2] = $1, HEAP32[tempInt + 16 >> 2] = $3, HEAPF64[tempInt + 24 >> 3] = $11, tempInt) | 0); //@line 2410
 $12 = $c + 166 | 0; //@line 2411
 $14 = HEAPU16[$12 >> 1] | 0; //@line 2413
 $37 = _e68_get_exception($c) | 0; //@line 2436
 $38 = _e68_get_exception_name($c) | 0; //@line 2437
 $40 = (_e68_get_last_trap_a($c) | 0) & 65535; //@line 2439
 $44 = (HEAPU16[$12 >> 1] | 0) >>> 8 & 7; //@line 2443
 $46 = HEAP32[$c + 364 >> 2] | 0; //@line 2445
 _pce_printf(33024, (tempInt = STACKTOP, STACKTOP = STACKTOP + 112 | 0, HEAP32[tempInt >> 2] = $14, HEAP32[tempInt + 8 >> 2] = ($14 & 32768 | 0) != 0 ? 84 : 45, HEAP32[tempInt + 16 >> 2] = ($14 & 8192 | 0) != 0 ? 83 : 45, HEAP32[tempInt + 24 >> 2] = $14 & 255, HEAP32[tempInt + 32 >> 2] = ($14 & 1 | 0) != 0 ? 67 : 45, HEAP32[tempInt + 40 >> 2] = ($14 & 2 | 0) != 0 ? 86 : 45, HEAP32[tempInt + 48 >> 2] = ($14 & 4 | 0) != 0 ? 90 : 45, HEAP32[tempInt + 56 >> 2] = ($14 & 8 | 0) != 0 ? 78 : 45, HEAP32[tempInt + 64 >> 2] = ($14 & 16 | 0) != 0 ? 88 : 45, HEAP32[tempInt + 72 >> 2] = $37, HEAP32[tempInt + 80 >> 2] = $38, HEAP32[tempInt + 88 >> 2] = $40, HEAP32[tempInt + 96 >> 2] = $44, HEAP32[tempInt + 104 >> 2] = $46, tempInt) | 0); //@line 2446
 $50 = HEAP32[$c + 104 >> 2] | 0; //@line 2450
 $52 = HEAP32[$c + 120 >> 2] | 0; //@line 2452
 $54 = HEAP32[$c + 136 >> 2] | 0; //@line 2454
 $55 = $c + 152 | 0; //@line 2455
 $56 = HEAP32[$55 >> 2] | 0; //@line 2456
 _pce_printf(32680, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = HEAP32[$c + 88 >> 2], HEAP32[tempInt + 8 >> 2] = $50, HEAP32[tempInt + 16 >> 2] = $52, HEAP32[tempInt + 24 >> 2] = $54, HEAP32[tempInt + 32 >> 2] = $56, tempInt) | 0); //@line 2457
 $58 = HEAP32[$c + 92 >> 2] | 0; //@line 2459
 $60 = HEAP32[$c + 108 >> 2] | 0; //@line 2461
 $62 = HEAP32[$c + 124 >> 2] | 0; //@line 2463
 $64 = HEAP32[$c + 140 >> 2] | 0; //@line 2465
 $65 = _e68_get_last_pc($c, 0) | 0; //@line 2466
 _pce_printf(32536, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = $58, HEAP32[tempInt + 8 >> 2] = $60, HEAP32[tempInt + 16 >> 2] = $62, HEAP32[tempInt + 24 >> 2] = $64, HEAP32[tempInt + 32 >> 2] = $65, tempInt) | 0); //@line 2467
 $69 = HEAP32[$c + 112 >> 2] | 0; //@line 2471
 $71 = HEAP32[$c + 128 >> 2] | 0; //@line 2473
 $73 = HEAP32[$c + 144 >> 2] | 0; //@line 2475
 $74 = $c + 334 | 0; //@line 2476
 $78 = $c + 148 | 0; //@line 2480
 $79 = HEAP32[((HEAP8[$74] | 0) == 0 ? $78 : $c + 168 | 0) >> 2] | 0; //@line 2482
 _pce_printf(32416, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = HEAP32[$c + 96 >> 2], HEAP32[tempInt + 8 >> 2] = $69, HEAP32[tempInt + 16 >> 2] = $71, HEAP32[tempInt + 24 >> 2] = $73, HEAP32[tempInt + 32 >> 2] = $79, tempInt) | 0); //@line 2483
 $81 = HEAP32[$c + 100 >> 2] | 0; //@line 2485
 $83 = HEAP32[$c + 116 >> 2] | 0; //@line 2487
 $85 = HEAP32[$c + 132 >> 2] | 0; //@line 2489
 $86 = HEAP32[$78 >> 2] | 0; //@line 2490
 if ((HEAP8[$74] | 0) != 0) {
  $93 = $86; //@line 2495
  _pce_printf(32232, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = $81, HEAP32[tempInt + 8 >> 2] = $83, HEAP32[tempInt + 16 >> 2] = $85, HEAP32[tempInt + 24 >> 2] = $86, HEAP32[tempInt + 32 >> 2] = $93, tempInt) | 0); //@line 2497
  $94 = HEAP32[$55 >> 2] | 0; //@line 2498
  _e68_dasm_mem($c, $op, $94); //@line 2499
  $95 = $str | 0; //@line 2500
  _mac_dasm_str($95, $op); //@line 2501
  $96 = HEAP32[$55 >> 2] | 0; //@line 2502
  _pce_printf(42352, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $96, HEAP32[tempInt + 8 >> 2] = $95, tempInt) | 0); //@line 2503
  STACKTOP = sp; //@line 2504
  return;
 }
 $93 = HEAP32[$c + 172 >> 2] | 0; //@line 2510
 _pce_printf(32232, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = $81, HEAP32[tempInt + 8 >> 2] = $83, HEAP32[tempInt + 16 >> 2] = $85, HEAP32[tempInt + 24 >> 2] = $86, HEAP32[tempInt + 32 >> 2] = $93, tempInt) | 0); //@line 2512
 $94 = HEAP32[$55 >> 2] | 0; //@line 2513
 _e68_dasm_mem($c, $op, $94); //@line 2514
 $95 = $str | 0; //@line 2515
 _mac_dasm_str($95, $op); //@line 2516
 $96 = HEAP32[$55 >> 2] | 0; //@line 2517
 _pce_printf(42352, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $96, HEAP32[tempInt + 8 >> 2] = $95, tempInt) | 0); //@line 2518
 STACKTOP = sp; //@line 2519
 return;
}
function _mac_run($sim) {
 $sim = $sim | 0;
 var $1 = 0, $6 = 0, $7 = 0;
 $1 = $sim + 4680 | 0; //@line 2531
 _pce_start($1); //@line 2532
 _mac_clock_discontinuity($sim); //@line 2533
 _mac_clock(HEAP32[15588] | 0, 0); //@line 2535
 _mac_clock(HEAP32[15588] | 0, 0); //@line 2537
 if ((HEAP32[$1 >> 2] | 0) != 0) {
  _pce_stop(); //@line 2542
  return;
 }
 $6 = $sim + 4676 | 0; //@line 2546
 $7 = $sim + 3480 | 0; //@line 2547
 do {
  if ((HEAP8[$6] | 0) != 0) {
   do {
    _pce_usleep(5e4) | 0; //@line 2555
    _trm_check(HEAP32[$7 >> 2] | 0); //@line 2557
   } while ((HEAP8[$6] | 0) != 0);
  }
  _mac_clock(HEAP32[15588] | 0, 0); //@line 2567
  _mac_clock(HEAP32[15588] | 0, 0); //@line 2569
 } while ((HEAP32[$1 >> 2] | 0) == 0);
 _pce_stop(); //@line 2577
 return;
}
function _mac_run_emscripten($sim) {
 $sim = $sim | 0;
 HEAP32[15692] = $sim; //@line 2588
 _pce_start($sim + 4680 | 0); //@line 2590
 _mac_clock_discontinuity($sim); //@line 2591
 _emscripten_set_main_loop(4, 100, 1) | 0; //@line 2592
 return;
}
function _mac_run_emscripten_step() {
 var $mousex = 0, $mousey = 0, $1 = 0, $3 = 0, $5 = 0, $i_011 = 0, $11 = 0, $17 = 0, $18 = 0, $24 = 0, $27 = 0, $28 = 0, $35 = 0, $48 = 0, $49 = 0, $50 = 0, $57 = 0, $70 = 0, $71 = 0, $72 = 0, $79 = 0, $92 = 0, $93 = 0, $94 = 0, $101 = 0, $114 = 0, $115 = 0, $116 = 0, $123 = 0, $136 = 0, $137 = 0, $138 = 0, $145 = 0, $158 = 0, $175 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 2620
 STACKTOP = STACKTOP + 16 | 0; //@line 2620
 $mousex = sp | 0; //@line 2621
 $mousey = sp + 8 | 0; //@line 2622
 $1 = _SDL_GetVideoInfo() | 0; //@line 2623
 $3 = HEAP32[$1 + 12 >> 2] | 0; //@line 2625
 $5 = HEAP32[$1 + 16 >> 2] | 0; //@line 2627
 $i_011 = 0; //@line 2629
 while (1) {
  do {
   if ((($i_011 | 0) % 100 | 0 | 0) == 0) {
    _SDL_GetMouseState($mousex | 0, $mousey | 0) | 0; //@line 2637
    $11 = HEAP32[$mousex >> 2] | 0; //@line 2638
    if (($11 | 0) > ($3 | 0)) {
     $17 = $3; //@line 2642
    } else {
     $17 = ($11 | 0) < 0 ? 0 : $11; //@line 2647
    }
    HEAP32[$mousex >> 2] = $17; //@line 2650
    $18 = HEAP32[$mousey >> 2] | 0; //@line 2651
    if (($18 | 0) > ($5 | 0)) {
     $24 = $5; //@line 2655
    } else {
     $24 = ($18 | 0) < 0 ? 0 : $18; //@line 2660
    }
    HEAP32[$mousey >> 2] = $24; //@line 2663
    $27 = HEAP32[(HEAP32[15692] | 0) + 4 >> 2] | 0; //@line 2666
    $28 = $24 & 65535; //@line 2667
    if ((HEAP32[$27 + 36 >> 2] | 0) >>> 0 > 2089) {
     $35 = $27 + 32 | 0; //@line 2675
     HEAP8[(HEAP32[$35 >> 2] | 0) + 2088 | 0] = ($28 & 65535) >>> 8 & 255; //@line 2678
     HEAP8[(HEAP32[$35 >> 2] | 0) + 2089 | 0] = $24 & 255; //@line 2682
    } else {
     FUNCTION_TABLE_viii[HEAP32[$27 + 24 >> 2] & 63](HEAP32[$27 + 4 >> 2] | 0, 2088, $28); //@line 2689
    }
    $48 = HEAP32[(HEAP32[15692] | 0) + 4 >> 2] | 0; //@line 2693
    $49 = HEAP32[$mousex >> 2] | 0; //@line 2694
    $50 = $49 & 65535; //@line 2695
    if ((HEAP32[$48 + 36 >> 2] | 0) >>> 0 > 2091) {
     $57 = $48 + 32 | 0; //@line 2703
     HEAP8[(HEAP32[$57 >> 2] | 0) + 2090 | 0] = ($50 & 65535) >>> 8 & 255; //@line 2706
     HEAP8[(HEAP32[$57 >> 2] | 0) + 2091 | 0] = $49 & 255; //@line 2710
    } else {
     FUNCTION_TABLE_viii[HEAP32[$48 + 24 >> 2] & 63](HEAP32[$48 + 4 >> 2] | 0, 2090, $50); //@line 2717
    }
    $70 = HEAP32[(HEAP32[15692] | 0) + 4 >> 2] | 0; //@line 2721
    $71 = HEAP32[$mousey >> 2] | 0; //@line 2722
    $72 = $71 & 65535; //@line 2723
    if ((HEAP32[$70 + 36 >> 2] | 0) >>> 0 > 2093) {
     $79 = $70 + 32 | 0; //@line 2731
     HEAP8[(HEAP32[$79 >> 2] | 0) + 2092 | 0] = ($72 & 65535) >>> 8 & 255; //@line 2734
     HEAP8[(HEAP32[$79 >> 2] | 0) + 2093 | 0] = $71 & 255; //@line 2738
    } else {
     FUNCTION_TABLE_viii[HEAP32[$70 + 24 >> 2] & 63](HEAP32[$70 + 4 >> 2] | 0, 2092, $72); //@line 2745
    }
    $92 = HEAP32[(HEAP32[15692] | 0) + 4 >> 2] | 0; //@line 2749
    $93 = HEAP32[$mousex >> 2] | 0; //@line 2750
    $94 = $93 & 65535; //@line 2751
    if ((HEAP32[$92 + 36 >> 2] | 0) >>> 0 > 2095) {
     $101 = $92 + 32 | 0; //@line 2759
     HEAP8[(HEAP32[$101 >> 2] | 0) + 2094 | 0] = ($94 & 65535) >>> 8 & 255; //@line 2762
     HEAP8[(HEAP32[$101 >> 2] | 0) + 2095 | 0] = $93 & 255; //@line 2766
    } else {
     FUNCTION_TABLE_viii[HEAP32[$92 + 24 >> 2] & 63](HEAP32[$92 + 4 >> 2] | 0, 2094, $94); //@line 2773
    }
    $114 = HEAP32[(HEAP32[15692] | 0) + 4 >> 2] | 0; //@line 2777
    $115 = HEAP32[$mousey >> 2] | 0; //@line 2778
    $116 = $115 & 65535; //@line 2779
    if ((HEAP32[$114 + 36 >> 2] | 0) >>> 0 > 2097) {
     $123 = $114 + 32 | 0; //@line 2787
     HEAP8[(HEAP32[$123 >> 2] | 0) + 2096 | 0] = ($116 & 65535) >>> 8 & 255; //@line 2790
     HEAP8[(HEAP32[$123 >> 2] | 0) + 2097 | 0] = $115 & 255; //@line 2794
    } else {
     FUNCTION_TABLE_viii[HEAP32[$114 + 24 >> 2] & 63](HEAP32[$114 + 4 >> 2] | 0, 2096, $116); //@line 2801
    }
    $136 = HEAP32[(HEAP32[15692] | 0) + 4 >> 2] | 0; //@line 2805
    $137 = HEAP32[$mousex >> 2] | 0; //@line 2806
    $138 = $137 & 65535; //@line 2807
    if ((HEAP32[$136 + 36 >> 2] | 0) >>> 0 > 2099) {
     $145 = $136 + 32 | 0; //@line 2815
     HEAP8[(HEAP32[$145 >> 2] | 0) + 2098 | 0] = ($138 & 65535) >>> 8 & 255; //@line 2818
     HEAP8[(HEAP32[$145 >> 2] | 0) + 2099 | 0] = $137 & 255; //@line 2822
     break;
    } else {
     FUNCTION_TABLE_viii[HEAP32[$136 + 24 >> 2] & 63](HEAP32[$136 + 4 >> 2] | 0, 2098, $138); //@line 2830
     break;
    }
   }
  } while (0);
  _mac_clock(HEAP32[15588] | 0, 0); //@line 2836
  _mac_clock(HEAP32[15588] | 0, 0); //@line 2838
  $158 = HEAP32[15692] | 0; //@line 2839
  if ((HEAP32[$158 + 4680 >> 2] | 0) != 0) {
   break;
  }
  if ((HEAP8[$158 + 4676 | 0] | 0) != 0) {
   do {
    _pce_usleep(5e4) | 0; //@line 2853
    _trm_check(HEAP32[(HEAP32[15692] | 0) + 3480 >> 2] | 0); //@line 2857
   } while ((HEAP8[(HEAP32[15692] | 0) + 4676 | 0] | 0) != 0);
  }
  $175 = $i_011 + 1 | 0; //@line 2868
  if (($175 | 0) < 1e4) {
   $i_011 = $175; //@line 2872
  } else {
   label = 343; //@line 2874
   break;
  }
 }
 if ((label | 0) == 343) {
  STACKTOP = sp; //@line 2879
  return;
 }
 _pce_stop(); //@line 2882
 _emscripten_cancel_main_loop() | 0; //@line 2883
 STACKTOP = sp; //@line 2885
 return;
}
function _mac_cmd($sim, $cmd) {
 $sim = $sim | 0;
 $cmd = $cmd | 0;
 var $1 = 0, $cnt_i_i = 0, $insn_i_i = 0, $op_i_i = 0, $addr_i = 0, $cnt_i44 = 0, $op_i = 0, $str_i = 0, $n_i = 0, $val_i36 = 0, $sym_i = 0, $dis_i = 0, $cnt_i28 = 0, $da_i = 0, $val_i = 0, $tn_i_i = 0, $addr_i_i = 0, $cnt_i = 0, $2 = 0, $3 = 0, $21 = 0, $35 = 0, $45 = 0, $46 = 0, $47 = 0, $49 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $82 = 0, $110 = 0, $112 = 0, $115 = 0, $122 = 0, $124 = 0, $141 = 0, $162 = 0, $164 = 0, $165 = 0, $167 = 0, $168 = 0, $169 = 0, $170 = 0, $176 = 0, $181 = 0, $182 = 0, $194 = 0, $213 = 0, $215 = 0, $231 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $257 = 0, $280 = 0, $293 = 0, $304 = 0, $322 = 0, $323 = 0, $352 = 0, $_pre13_i = 0, $355 = 0, $i_07_i = 0, $358 = 0, $383 = 0, $388 = 0, $390 = 0, $398 = 0, $407 = 0, $411 = 0, $412 = 0, $415 = 0, $417 = 0, $418 = 0, $pc_026_i_i = 0, $sync_025_i_i = 0, $ins_n_024_i_i = 0, $ins_j_023_i_i = 0, $ins_i_022_i_i = 0, $424 = 0, $ins_i_1_i_i = 0, $ins_j_1_i_i = 0, $ins_n_1_i_i = 0, $sync_1_i_i = 0, $437 = 0, $_pre_i_i = 0, $ins_i_2_ph_i_i = 0, $ins_i_221_i_i = 0, $448 = 0, $463 = 0, $464 = 0, $466 = 0, $i_08_i = 0, $472 = 0, $473 = 0, $476 = 0, $477 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 2949
 STACKTOP = STACKTOP + 3032 | 0; //@line 2949
 $1 = sp | 0; //@line 2950
 $cnt_i_i = sp + 8 | 0; //@line 2951
 $insn_i_i = sp + 16 | 0; //@line 2952
 $op_i_i = sp + 1040 | 0; //@line 2953
 $addr_i = sp + 1392 | 0; //@line 2954
 $cnt_i44 = sp + 1400 | 0; //@line 2955
 $op_i = sp + 1408 | 0; //@line 2956
 $str_i = sp + 1760 | 0; //@line 2957
 $n_i = sp + 2016 | 0; //@line 2958
 $val_i36 = sp + 2024 | 0; //@line 2959
 $sym_i = sp + 2032 | 0; //@line 2960
 $dis_i = sp + 2288 | 0; //@line 2961
 $cnt_i28 = sp + 2640 | 0; //@line 2962
 $da_i = sp + 2648 | 0; //@line 2963
 $val_i = sp + 3e3 | 0; //@line 2964
 $tn_i_i = sp + 3008 | 0; //@line 2965
 $addr_i_i = sp + 3016 | 0; //@line 2966
 $cnt_i = sp + 3024 | 0; //@line 2967
 $2 = $sim + 3480 | 0; //@line 2968
 $3 = HEAP32[$2 >> 2] | 0; //@line 2969
 if (($3 | 0) != 0) {
  _trm_check($3); //@line 2973
 }
 do {
  if ((_cmd_match($cmd, 44504) | 0) == 0) {
   if ((_cmd_match($cmd, 40072) | 0) != 0) {
    HEAP32[$cnt_i >> 2] = 1; //@line 2986
    _cmd_match_uint32($cmd, $cnt_i) | 0; //@line 2987
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    if ((HEAP32[$cnt_i >> 2] | 0) != 0) {
     do {
      _mac_clock($sim, 1); //@line 2999
      $21 = (HEAP32[$cnt_i >> 2] | 0) - 1 | 0; //@line 3001
      HEAP32[$cnt_i >> 2] = $21; //@line 3002
     } while (($21 | 0) != 0);
    }
    _mac_prt_state_cpu(HEAP32[$sim + 4 >> 2] | 0); //@line 3012
    break;
   }
   if ((_cmd_match($cmd, 31024) | 0) != 0) {
    if ((_cmd_match($cmd, 44504) | 0) != 0) {
     if ((_cmd_match_uint32($cmd, $addr_i_i) | 0) != 0) {
      $35 = $sim + 28 | 0; //@line 3029
      do {
       _bps_bp_add($35, _bp_addr_new(HEAP32[$addr_i_i >> 2] | 0) | 0) | 0; //@line 3034
      } while ((_cmd_match_uint32($cmd, $addr_i_i) | 0) != 0);
     }
     if ((_cmd_match_end($cmd) | 0) == 0) {
      break;
     }
     $45 = $sim + 4680 | 0; //@line 3049
     _pce_start($45); //@line 3050
     _mac_clock_discontinuity($sim); //@line 3051
     $46 = $sim + 4 | 0; //@line 3052
     $47 = $sim + 28 | 0; //@line 3053
     L456 : while (1) {
      $49 = _e68_get_opcnt(HEAP32[$46 >> 2] | 0) | 0; //@line 3057
      while (1) {
       if ((_e68_get_opcnt(HEAP32[$46 >> 2] | 0) | 0) != ($49 | 0)) {
        continue L456;
       }
       _mac_clock($sim, 0); //@line 3067
       if ((_bps_check($47, 0, HEAP32[(HEAP32[$46 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
        break L456;
       }
       if ((HEAP32[$45 >> 2] | 0) != 0) {
        break L456;
       }
      }
     }
     _pce_stop(); //@line 3087
     break;
    }
    if ((_cmd_match($cmd, 37304) | 0) == 0) {
     if ((_cmd_match_end($cmd) | 0) == 0) {
      break;
     }
     _mac_run($sim); //@line 3101
     break;
    }
    if ((_cmd_match_uint16($cmd, $tn_i_i) | 0) == 0) {
     HEAP16[$tn_i_i >> 1] = -1; //@line 3110
    }
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    $76 = $sim + 4 | 0; //@line 3119
    $78 = _e68_get_exception_cnt(HEAP32[$76 >> 2] | 0) | 0; //@line 3121
    $79 = $sim + 4680 | 0; //@line 3122
    _pce_start($79); //@line 3123
    _mac_clock_discontinuity($sim); //@line 3124
    $80 = $sim + 28 | 0; //@line 3125
    while (1) {
     $82 = _e68_get_opcnt(HEAP32[$76 >> 2] | 0) | 0; //@line 3129
     do {
      if ((_e68_get_opcnt(HEAP32[$76 >> 2] | 0) | 0) != ($82 | 0)) {
       break;
      }
      _mac_clock($sim, 0); //@line 3139
      if ((_bps_check($80, 0, HEAP32[(HEAP32[$76 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
       break;
      }
     } while ((HEAP32[$79 >> 2] | 0) == 0);
     if ((_bps_check($80, 0, HEAP32[(HEAP32[$76 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
      break;
     }
     if ((HEAP32[$79 >> 2] | 0) != 0) {
      break;
     }
     if ((_e68_get_exception_cnt(HEAP32[$76 >> 2] | 0) | 0) == ($78 | 0)) {
      continue;
     }
     $110 = (HEAP16[$tn_i_i >> 1] | 0) == -1; //@line 3183
     $112 = _e68_get_exception(HEAP32[$76 >> 2] | 0) | 0; //@line 3185
     if ($110) {
      label = 378; //@line 3188
      break;
     }
     if (($112 | 0) == (HEAPU16[$tn_i_i >> 1] | 0)) {
      label = 380; //@line 3196
      break;
     }
    }
    if ((label | 0) == 378) {
     $115 = _e68_get_exception_name(HEAP32[$76 >> 2] | 0) | 0; //@line 3202
     _pce_printf(37080, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $112, HEAP32[tempInt + 8 >> 2] = $115, tempInt) | 0); //@line 3203
    } else if ((label | 0) == 380) {
     $122 = _e68_get_exception(HEAP32[$76 >> 2] | 0) | 0; //@line 3208
     $124 = _e68_get_exception_name(HEAP32[$76 >> 2] | 0) | 0; //@line 3210
     _pce_printf(37080, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $122, HEAP32[tempInt + 8 >> 2] = $124, tempInt) | 0); //@line 3211
    }
    _pce_stop(); //@line 3214
    break;
   }
   if ((_cmd_match($cmd, 56064) | 0) != 0) {
    if ((_cmd_match_uint16($cmd, $val_i) | 0) == 0) {
     HEAP16[$val_i >> 1] = 2; //@line 3227
    }
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    $141 = $sim + 4 | 0; //@line 3236
    _e68_set_halt(HEAP32[$141 >> 2] | 0, HEAPU16[$val_i >> 1] | 0); //@line 3240
    _mac_prt_state_cpu(HEAP32[$141 >> 2] | 0); //@line 3242
    break;
   }
   if ((_cmd_match($cmd, 54008) | 0) != 0) {
    HEAP32[$cnt_i28 >> 2] = 1; //@line 3252
    do {
     if ((_cmd_match($cmd, 54008) | 0) != 0) {
      HEAP32[$cnt_i28 >> 2] = 2; //@line 3258
      if ((_cmd_match($cmd, 54008) | 0) == 0) {
       break;
      }
      do {
       HEAP32[$cnt_i28 >> 2] = (HEAP32[$cnt_i28 >> 2] | 0) + 1; //@line 3268
      } while ((_cmd_match($cmd, 54008) | 0) != 0);
     }
    } while (0);
    _cmd_match_uint32($cmd, $cnt_i28) | 0; //@line 3278
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    $162 = $sim + 4 | 0; //@line 3285
    $164 = _e68_get_exception_cnt(HEAP32[$162 >> 2] | 0) | 0; //@line 3287
    $165 = $sim + 4680 | 0; //@line 3288
    _pce_start($165); //@line 3289
    L503 : do {
     if ((HEAP32[$cnt_i28 >> 2] | 0) != 0) {
      $167 = $da_i | 0; //@line 3295
      $168 = $sim + 28 | 0; //@line 3296
      $169 = $da_i + 8 | 0; //@line 3297
      do {
       $170 = HEAP32[$162 >> 2] | 0; //@line 3300
       _e68_dasm_mem($170, $da_i, HEAP32[$170 + 152 >> 2] | 0); //@line 3303
       $176 = HEAP32[$162 >> 2] | 0; //@line 3307
       do {
        if ((HEAP32[$167 >> 2] & 4 | 0) == 0) {
         $194 = _e68_get_opcnt($176) | 0; //@line 3311
         while (1) {
          if ((_e68_get_opcnt(HEAP32[$162 >> 2] | 0) | 0) != ($194 | 0)) {
           break;
          }
          _mac_clock($sim, 0); //@line 3321
          if ((_bps_check($168, 0, HEAP32[(HEAP32[$162 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
           break L503;
          }
          if ((HEAP32[$165 >> 2] | 0) != 0) {
           break L503;
          }
         }
         if ((_e68_get_exception_cnt(HEAP32[$162 >> 2] | 0) | 0) == ($164 | 0)) {
          break;
         }
         $213 = HEAP32[$162 >> 2] | 0; //@line 3347
         $215 = HEAP32[$213 + 380 >> 2] | 0; //@line 3349
         if ((HEAP32[$213 + 152 >> 2] | 0) == ($215 | 0)) {
          break;
         }
         do {
          _mac_clock($sim, 0); //@line 3358
          if ((_bps_check($168, 0, HEAP32[(HEAP32[$162 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
           break L503;
          }
          if ((HEAP32[$165 >> 2] | 0) != 0) {
           break L503;
          }
         } while ((HEAP32[(HEAP32[$162 >> 2] | 0) + 152 >> 2] | 0) != ($215 | 0));
        } else {
         $181 = HEAP32[$169 >> 2] << 1; //@line 3389
         $182 = $181 + (HEAP32[$176 + 152 >> 2] | 0) | 0; //@line 3390
         if (($181 | 0) == 0) {
          break;
         }
         do {
          _mac_clock($sim, 0); //@line 3397
          if ((_bps_check($168, 0, HEAP32[(HEAP32[$162 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
           break L503;
          }
          if ((HEAP32[$165 >> 2] | 0) != 0) {
           break L503;
          }
         } while ((HEAP32[(HEAP32[$162 >> 2] | 0) + 152 >> 2] | 0) != ($182 | 0));
        }
       } while (0);
       $231 = (HEAP32[$cnt_i28 >> 2] | 0) - 1 | 0; //@line 3427
       HEAP32[$cnt_i28 >> 2] = $231; //@line 3428
      } while (($231 | 0) != 0);
     }
    } while (0);
    _pce_stop(); //@line 3437
    _mac_prt_state_cpu(HEAP32[$162 >> 2] | 0); //@line 3439
    break;
   }
   if ((_cmd_match($cmd, 52584) | 0) != 0) {
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    _mac_reset($sim); //@line 3453
    _mac_prt_state_cpu(HEAP32[$sim + 4 >> 2] | 0); //@line 3456
    break;
   }
   if ((_cmd_match($cmd, 51896) | 0) != 0) {
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    $251 = $sim + 4680 | 0; //@line 3471
    _pce_start($251); //@line 3472
    $252 = $sim + 4 | 0; //@line 3473
    $253 = $sim + 28 | 0; //@line 3474
    $254 = $dis_i | 0; //@line 3475
    while (1) {
     $257 = _e68_get_opcnt(HEAP32[$252 >> 2] | 0) | 0; //@line 3479
     do {
      if ((_e68_get_opcnt(HEAP32[$252 >> 2] | 0) | 0) != ($257 | 0)) {
       break;
      }
      _mac_clock($sim, 0); //@line 3489
      if ((_bps_check($253, 0, HEAP32[(HEAP32[$252 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
       break;
      }
     } while ((HEAP32[$251 >> 2] | 0) == 0);
     if ((_bps_check($253, 0, HEAP32[(HEAP32[$252 >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
      break;
     }
     if ((HEAP32[$251 >> 2] | 0) != 0) {
      break;
     }
     $280 = HEAP32[$252 >> 2] | 0; //@line 3525
     _e68_dasm_mem($280, $dis_i, HEAP32[$280 + 152 >> 2] | 0); //@line 3528
     if ((HEAP32[$254 >> 2] & 8 | 0) != 0) {
      label = 425; //@line 3534
      break;
     }
    }
    if ((label | 0) == 425) {
     _mac_prt_state_cpu(HEAP32[$252 >> 2] | 0); //@line 3540
    }
    _pce_stop(); //@line 3543
    break;
   }
   if ((_cmd_match($cmd, 50872) | 0) != 0) {
    $293 = $sym_i | 0; //@line 3552
    if ((_cmd_match_eol($cmd) | 0) != 0) {
     _mac_prt_state_cpu(HEAP32[$sim + 4 >> 2] | 0); //@line 3559
     break;
    }
    if ((_cmd_match_ident($cmd, $293, 256) | 0) == 0) {
     _cmd_error($cmd, 38368); //@line 3567
     break;
    }
    $304 = $sim + 4 | 0; //@line 3571
    if ((_e68_get_reg(HEAP32[$304 >> 2] | 0, $293, $val_i36) | 0) != 0) {
     _pce_printf(38056, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $293, tempInt) | 0); //@line 3577
     break;
    }
    if ((_cmd_match_eol($cmd) | 0) != 0) {
     _pce_printf(37840, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$val_i36 >> 2], tempInt) | 0); //@line 3586
     break;
    }
    if ((_cmd_match_uint32($cmd, $val_i36) | 0) == 0) {
     _cmd_error($cmd, 37592); //@line 3594
     break;
    }
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    $322 = HEAP32[$304 >> 2] | 0; //@line 3604
    $323 = HEAP32[$val_i36 >> 2] | 0; //@line 3605
    _e68_set_reg($322, $293, $323) | 0; //@line 3606
    _mac_prt_state_cpu(HEAP32[$304 >> 2] | 0); //@line 3608
    break;
   }
   if ((_cmd_match($cmd, 49152) | 0) != 0) {
    if ((_cmd_match_eol($cmd) | 0) == 0) {
     _mac_prt_state($sim, _cmd_get_str($cmd) | 0); //@line 3621
     break;
    } else {
     _mac_prt_state_cpu(HEAP32[$sim + 4 >> 2] | 0); //@line 3627
     break;
    }
   }
   if ((_cmd_match($cmd, 47976) | 0) != 0) {
    HEAP32[$n_i >> 2] = 1; //@line 3637
    do {
     if ((_cmd_match($cmd, 47976) | 0) != 0) {
      HEAP32[$n_i >> 2] = 2; //@line 3643
      if ((_cmd_match($cmd, 47976) | 0) == 0) {
       break;
      }
      do {
       HEAP32[$n_i >> 2] = (HEAP32[$n_i >> 2] | 0) + 1; //@line 3653
      } while ((_cmd_match($cmd, 47976) | 0) != 0);
     }
    } while (0);
    _cmd_match_uint32($cmd, $n_i) | 0; //@line 3663
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    $352 = $sim + 4680 | 0; //@line 3670
    _pce_start($352); //@line 3671
    $_pre13_i = $sim + 4 | 0; //@line 3674
    if ((HEAP32[$n_i >> 2] | 0) != 0) {
     $355 = $sim + 28 | 0; //@line 3677
     $i_07_i = 0; //@line 3679
     do {
      $358 = _e68_get_opcnt(HEAP32[$_pre13_i >> 2] | 0) | 0; //@line 3683
      do {
       if ((_e68_get_opcnt(HEAP32[$_pre13_i >> 2] | 0) | 0) != ($358 | 0)) {
        break;
       }
       _mac_clock($sim, 0); //@line 3693
       if ((_bps_check($355, 0, HEAP32[(HEAP32[$_pre13_i >> 2] | 0) + 152 >> 2] & 16777215, HEAP32[_stdout >> 2] | 0) | 0) != 0) {
        break;
       }
      } while ((HEAP32[$352 >> 2] | 0) == 0);
      $i_07_i = $i_07_i + 1 | 0; //@line 3712
     } while ($i_07_i >>> 0 < (HEAP32[$n_i >> 2] | 0) >>> 0);
    }
    _pce_stop(); //@line 3723
    _mac_prt_state_cpu(HEAP32[$_pre13_i >> 2] | 0); //@line 3725
    break;
   }
   if ((_cmd_match($cmd, 47368) | 0) == 0) {
    $_0 = 1; //@line 3733
    STACKTOP = sp; //@line 3735
    return $_0 | 0; //@line 3736
   }
   $383 = $str_i | 0; //@line 3741
   if (HEAP8[7752] | 0) {
    $390 = HEAP32[15694] | 0; //@line 3747
   } else {
    HEAP8[7752] = 1; //@line 3749
    $388 = HEAP32[(HEAP32[$sim + 4 >> 2] | 0) + 152 >> 2] | 0; //@line 3753
    HEAP32[15694] = $388; //@line 3754
    $390 = $388; //@line 3756
   }
   HEAP32[$addr_i >> 2] = $390; //@line 3759
   HEAP32[$cnt_i44 >> 2] = 16; //@line 3760
   if ((_cmd_match($cmd, 42968) | 0) == 0) {
    if ((_cmd_match_uint32($cmd, $addr_i) | 0) != 0) {
     _cmd_match_uint32($cmd, $cnt_i44) | 0; //@line 3769
    }
    if ((_cmd_match_end($cmd) | 0) == 0) {
     break;
    }
    if ((HEAP32[$cnt_i44 >> 2] | 0) == 0) {
     $476 = HEAP32[$addr_i >> 2] | 0; //@line 3784
    } else {
     $463 = $sim + 4 | 0; //@line 3786
     $464 = $op_i + 8 | 0; //@line 3787
     $i_08_i = 0;
     $466 = HEAP32[$addr_i >> 2] | 0;
     while (1) {
      _e68_dasm_mem(HEAP32[$463 >> 2] | 0, $op_i, $466); //@line 3795
      _mac_dasm_str($383, $op_i); //@line 3796
      _pce_printf(42352, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$addr_i >> 2], HEAP32[tempInt + 8 >> 2] = $383, tempInt) | 0); //@line 3798
      $472 = (HEAP32[$addr_i >> 2] | 0) + (HEAP32[$464 >> 2] << 1) | 0; //@line 3802
      HEAP32[$addr_i >> 2] = $472; //@line 3803
      $473 = $i_08_i + 1 | 0; //@line 3804
      if ($473 >>> 0 < (HEAP32[$cnt_i44 >> 2] | 0) >>> 0) {
       $i_08_i = $473;
       $466 = $472;
      } else {
       $476 = $472; //@line 3811
       break;
      }
     }
    }
    HEAP32[15694] = $476; //@line 3817
    break;
   }
   $398 = $sym_i | 0; //@line 3825
   HEAP32[$1 >> 2] = $390; //@line 3826
   HEAP32[$cnt_i_i >> 2] = 16; //@line 3827
   if ((_cmd_match_uint32($cmd, $1) | 0) != 0) {
    _cmd_match_uint32($cmd, $cnt_i_i) | 0; //@line 3832
   }
   if ((_cmd_match_end($cmd) | 0) == 0) {
    break;
   }
   $407 = HEAP32[$cnt_i_i >> 2] | 0; //@line 3841
   if ($407 >>> 0 > 256) {
    HEAP32[$cnt_i_i >> 2] = 256; //@line 3845
    $411 = 256; //@line 3847
   } else {
    $411 = $407; //@line 3849
   }
   $412 = HEAP32[$1 >> 2] | 0; //@line 3852
   $415 = ($411 * -12 | 0) + $412 & -2; //@line 3855
   if ($415 >>> 0 > $412 >>> 0) {
    break;
   }
   $417 = $sim + 4 | 0; //@line 3861
   $418 = $op_i_i + 8 | 0; //@line 3862
   $ins_i_022_i_i = 0;
   $ins_j_023_i_i = 0;
   $ins_n_024_i_i = 0;
   $sync_025_i_i = 5;
   $pc_026_i_i = $415;
   while (1) {
    do {
     if (($sync_025_i_i | 0) == 0) {
      HEAP32[$insn_i_i + ($ins_j_023_i_i << 2) >> 2] = $pc_026_i_i; //@line 3876
      $424 = $ins_j_023_i_i + 1 & 255; //@line 3878
      if (($424 | 0) == ($ins_i_022_i_i | 0)) {
       $sync_1_i_i = 0;
       $ins_n_1_i_i = $ins_n_024_i_i;
       $ins_j_1_i_i = $ins_i_022_i_i;
       $ins_i_1_i_i = $ins_i_022_i_i + 1 & 255;
       break;
      } else {
       $sync_1_i_i = 0;
       $ins_n_1_i_i = $ins_n_024_i_i + 1 | 0;
       $ins_j_1_i_i = $424;
       $ins_i_1_i_i = $ins_i_022_i_i;
       break;
      }
     } else {
      $sync_1_i_i = $sync_025_i_i - 1 | 0;
      $ins_n_1_i_i = $ins_n_024_i_i;
      $ins_j_1_i_i = $ins_j_023_i_i;
      $ins_i_1_i_i = $ins_i_022_i_i;
     }
    } while (0);
    _e68_dasm_mem(HEAP32[$417 >> 2] | 0, $op_i_i, $pc_026_i_i); //@line 3902
    $437 = (HEAP32[$418 >> 2] << 1) + $pc_026_i_i | 0; //@line 3905
    if ($437 >>> 0 > (HEAP32[$1 >> 2] | 0) >>> 0) {
     break;
    } else {
     $ins_i_022_i_i = $ins_i_1_i_i;
     $ins_j_023_i_i = $ins_j_1_i_i;
     $ins_n_024_i_i = $ins_n_1_i_i;
     $sync_025_i_i = $sync_1_i_i;
     $pc_026_i_i = $437;
    }
   }
   $_pre_i_i = HEAP32[$cnt_i_i >> 2] | 0; //@line 3915
   if ($ins_n_1_i_i >>> 0 > $_pre_i_i >>> 0) {
    $ins_i_2_ph_i_i = $ins_n_1_i_i + $ins_i_1_i_i - $_pre_i_i & 255; //@line 3923
   } else {
    $ins_i_2_ph_i_i = $ins_i_1_i_i; //@line 3925
   }
   if (($ins_i_2_ph_i_i | 0) == ($ins_j_1_i_i | 0)) {
    break;
   } else {
    $ins_i_221_i_i = $ins_i_2_ph_i_i; //@line 3933
   }
   do {
    $448 = HEAP32[$insn_i_i + ($ins_i_221_i_i << 2) >> 2] | 0; //@line 3938
    _e68_dasm_mem(HEAP32[$417 >> 2] | 0, $op_i_i, $448); //@line 3940
    _mac_dasm_str($398, $op_i_i); //@line 3941
    _pce_printf(42352, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $448, HEAP32[tempInt + 8 >> 2] = $398, tempInt) | 0); //@line 3942
    $ins_i_221_i_i = $ins_i_221_i_i + 1 & 255; //@line 3944
   } while (($ins_i_221_i_i | 0) != ($ins_j_1_i_i | 0));
  } else {
   _cmd_do_b($cmd, $sim + 28 | 0); //@line 3955
  }
 } while (0);
 $477 = HEAP32[$2 >> 2] | 0; //@line 3959
 if (($477 | 0) == 0) {
  $_0 = 0; //@line 3963
  STACKTOP = sp; //@line 3965
  return $_0 | 0; //@line 3966
 }
 _trm_set_msg_trm($477, 44168, 43832) | 0; //@line 3968
 $_0 = 0; //@line 3970
 STACKTOP = sp; //@line 3972
 return $_0 | 0; //@line 3973
}
function _mac_cmd_init($sim, $mon) {
 $sim = $sim | 0;
 $mon = $mon | 0;
 var $4 = 0;
 _mon_cmd_add($mon, 6920, 12) | 0; //@line 3984
 _mon_cmd_add_bp($mon) | 0; //@line 3985
 $4 = $sim + 4 | 0; //@line 3987
 HEAP32[(HEAP32[$4 >> 2] | 0) + 68 >> 2] = $sim; //@line 3990
 HEAP32[(HEAP32[$4 >> 2] | 0) + 72 >> 2] = 0; //@line 3993
 HEAP32[(HEAP32[$4 >> 2] | 0) + 76 >> 2] = 70; //@line 3996
 HEAP32[(HEAP32[$4 >> 2] | 0) + 80 >> 2] = 326; //@line 3999
 HEAP32[(HEAP32[$4 >> 2] | 0) + 84 >> 2] = 14; //@line 4002
 return;
}
function _mac_log_undef($ext, $ir) {
 $ext = $ext | 0;
 $ir = $ir | 0;
 var $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $13 = 0, $27 = 0, $_pre = 0, $28 = 0, $29 = 0, $_0_i = 0, $30 = 0, $32 = 0, $33 = 0, $37 = 0, $51 = 0, $_pre21 = 0, $52 = 0, $53 = 0, $_0_i12 = 0, $54 = 0, $56 = 0, $57 = 0, $61 = 0, $75 = 0, $_pre24 = 0, $76 = 0, $77 = 0, $_0_i14 = 0, $78 = 0, $80 = 0, $81 = 0, $85 = 0, $99 = 0, $_pre27 = 0, $100 = 0, $101 = 0, $_0_i16 = 0, $102 = 0, $104 = 0, $105 = 0, $109 = 0, $_0_i18 = 0, $124 = 0, sp = 0;
 sp = STACKTOP; //@line 4029
 $2 = $ext + 4 | 0; //@line 4031
 $4 = _e68_get_last_pc(HEAP32[$2 >> 2] | 0, 0) | 0; //@line 4033
 $5 = HEAP32[$2 >> 2] | 0; //@line 4034
 $6 = $4 & 16777215; //@line 4035
 $7 = $6 + 1 | 0; //@line 4036
 $9 = HEAP32[$5 + 36 >> 2] | 0; //@line 4038
 if ($7 >>> 0 < $9 >>> 0) {
  $13 = HEAP32[$5 + 32 >> 2] | 0; //@line 4043
  $_0_i = (HEAPU8[$13 + $6 | 0] | 0) << 8 | (HEAPU8[$13 + $7 | 0] | 0);
  $29 = $5;
  $28 = $9;
 } else {
  $27 = FUNCTION_TABLE_iii[HEAP32[$5 + 12 >> 2] & 63](HEAP32[$5 + 4 >> 2] | 0, $6) | 0; //@line 4059
  $_pre = HEAP32[$2 >> 2] | 0; //@line 4060
  $_0_i = $27;
  $29 = $_pre;
  $28 = HEAP32[$_pre + 36 >> 2] | 0;
 }
 $30 = $_0_i & 65535; //@line 4069
 $32 = $4 + 2 & 16777215; //@line 4071
 $33 = $32 + 1 | 0; //@line 4072
 if ($33 >>> 0 < $28 >>> 0) {
  $37 = HEAP32[$29 + 32 >> 2] | 0; //@line 4077
  $_0_i12 = (HEAPU8[$37 + $32 | 0] | 0) << 8 | (HEAPU8[$37 + $33 | 0] | 0);
  $53 = $29;
  $52 = $28;
 } else {
  $51 = FUNCTION_TABLE_iii[HEAP32[$29 + 12 >> 2] & 63](HEAP32[$29 + 4 >> 2] | 0, $32) | 0; //@line 4093
  $_pre21 = HEAP32[$2 >> 2] | 0; //@line 4094
  $_0_i12 = $51;
  $53 = $_pre21;
  $52 = HEAP32[$_pre21 + 36 >> 2] | 0;
 }
 $54 = $_0_i12 & 65535; //@line 4103
 $56 = $4 + 4 & 16777215; //@line 4105
 $57 = $56 + 1 | 0; //@line 4106
 if ($57 >>> 0 < $52 >>> 0) {
  $61 = HEAP32[$53 + 32 >> 2] | 0; //@line 4111
  $_0_i14 = (HEAPU8[$61 + $56 | 0] | 0) << 8 | (HEAPU8[$61 + $57 | 0] | 0);
  $77 = $53;
  $76 = $52;
 } else {
  $75 = FUNCTION_TABLE_iii[HEAP32[$53 + 12 >> 2] & 63](HEAP32[$53 + 4 >> 2] | 0, $56) | 0; //@line 4127
  $_pre24 = HEAP32[$2 >> 2] | 0; //@line 4128
  $_0_i14 = $75;
  $77 = $_pre24;
  $76 = HEAP32[$_pre24 + 36 >> 2] | 0;
 }
 $78 = $_0_i14 & 65535; //@line 4137
 $80 = $4 + 6 & 16777215; //@line 4139
 $81 = $80 + 1 | 0; //@line 4140
 if ($81 >>> 0 < $76 >>> 0) {
  $85 = HEAP32[$77 + 32 >> 2] | 0; //@line 4145
  $_0_i16 = (HEAPU8[$85 + $80 | 0] | 0) << 8 | (HEAPU8[$85 + $81 | 0] | 0);
  $101 = $77;
  $100 = $76;
 } else {
  $99 = FUNCTION_TABLE_iii[HEAP32[$77 + 12 >> 2] & 63](HEAP32[$77 + 4 >> 2] | 0, $80) | 0; //@line 4161
  $_pre27 = HEAP32[$2 >> 2] | 0; //@line 4162
  $_0_i16 = $99;
  $101 = $_pre27;
  $100 = HEAP32[$_pre27 + 36 >> 2] | 0;
 }
 $102 = $_0_i16 & 65535; //@line 4171
 $104 = $4 + 8 & 16777215; //@line 4173
 $105 = $104 + 1 | 0; //@line 4174
 if ($105 >>> 0 < $100 >>> 0) {
  $109 = HEAP32[$101 + 32 >> 2] | 0; //@line 4179
  $_0_i18 = (HEAPU8[$109 + $104 | 0] | 0) << 8 | (HEAPU8[$109 + $105 | 0] | 0); //@line 4189
  $124 = $_0_i18 & 65535; //@line 4191
  _pce_log(3, 43256, (tempInt = STACKTOP, STACKTOP = STACKTOP + 56 | 0, HEAP32[tempInt >> 2] = $4, HEAP32[tempInt + 8 >> 2] = $ir, HEAP32[tempInt + 16 >> 2] = $30, HEAP32[tempInt + 24 >> 2] = $54, HEAP32[tempInt + 32 >> 2] = $78, HEAP32[tempInt + 40 >> 2] = $102, HEAP32[tempInt + 48 >> 2] = $124, tempInt) | 0); //@line 4192
  STACKTOP = sp; //@line 4193
  return;
 } else {
  $_0_i18 = FUNCTION_TABLE_iii[HEAP32[$101 + 12 >> 2] & 63](HEAP32[$101 + 4 >> 2] | 0, $104) | 0; //@line 4202
  $124 = $_0_i18 & 65535; //@line 4204
  _pce_log(3, 43256, (tempInt = STACKTOP, STACKTOP = STACKTOP + 56 | 0, HEAP32[tempInt >> 2] = $4, HEAP32[tempInt + 8 >> 2] = $ir, HEAP32[tempInt + 16 >> 2] = $30, HEAP32[tempInt + 24 >> 2] = $54, HEAP32[tempInt + 32 >> 2] = $78, HEAP32[tempInt + 40 >> 2] = $102, HEAP32[tempInt + 48 >> 2] = $124, tempInt) | 0); //@line 4205
  STACKTOP = sp; //@line 4206
  return;
 }
}
function _mac_log_exception($ext, $tn) {
 $ext = $ext | 0;
 $tn = $tn | 0;
 var $2 = 0, $3 = 0, $5 = 0, $6 = 0, $12 = 0, $_0_i = 0, $35 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 4221
 $2 = $ext + 4 | 0; //@line 4223
 $3 = HEAP32[$2 >> 2] | 0; //@line 4224
 $5 = (_e68_get_last_pc($3, 0) | 0) & 16777215; //@line 4226
 $6 = $5 + 1 | 0; //@line 4227
 if ($6 >>> 0 < (HEAP32[$3 + 36 >> 2] | 0) >>> 0) {
  $12 = HEAP32[$3 + 32 >> 2] | 0; //@line 4234
  $_0_i = (HEAPU8[$12 + $5 | 0] | 0) << 8 | (HEAPU8[$12 + $6 | 0] | 0); //@line 4244
 } else {
  $_0_i = FUNCTION_TABLE_iii[HEAP32[$3 + 12 >> 2] & 63](HEAP32[$3 + 4 >> 2] | 0, $5) | 0; //@line 4252
 }
 if (($tn | 0) == 10) {
  _mac_sony_patch($ext + 2424 | 0); //@line 4258
  STACKTOP = sp; //@line 4260
  return;
 } else if (($tn | 0) == 0) {
  _mac_reset($ext); //@line 4264
  STACKTOP = sp; //@line 4266
  return;
 } else if (($tn | 0) == 25 | ($tn | 0) == 26 | ($tn | 0) == 32 | ($tn | 0) == 39 | ($tn | 0) == 40 | ($tn | 0) == 41 | ($tn | 0) == 42 | ($tn | 0) == 43 | ($tn | 0) == 44 | ($tn | 0) == 46) {
  STACKTOP = sp; //@line 4269
  return;
 } else {
  $35 = _e68_get_last_pc(HEAP32[$2 >> 2] | 0, 0) | 0; //@line 4274
  $37 = _e68_get_exception_name(HEAP32[$2 >> 2] | 0) | 0; //@line 4276
  _pce_log(3, 43632, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $35, HEAP32[tempInt + 8 >> 2] = $tn, HEAP32[tempInt + 16 >> 2] = $37, HEAP32[tempInt + 24 >> 2] = $_0_i & 65535, tempInt) | 0); //@line 4277
  STACKTOP = sp; //@line 4279
  return;
 }
}
function _mac_dasm_str($dst, $op) {
 $dst = $dst | 0;
 $op = $op | 0;
 var $tmp46 = 0, $tmp46_sub = 0, $1 = 0, $4 = 0, $i_053 = 0, $13 = 0, $i_150 = 0, $endptr45 = 0, $15 = 0, $18 = 0, $22 = 0, $27 = 0, $31 = 0, $38 = 0, $_ = 0, $42 = 0, $44 = 0, $leninc = 0, $46 = 0, $50 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $_pre_phi = 0, $63 = 0, $67 = 0, $68 = 0, $_0_lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 4299
 STACKTOP = STACKTOP + 256 | 0; //@line 4299
 $tmp46 = sp | 0; //@line 4300
 $tmp46_sub = $tmp46 | 0; //@line 4301
 HEAP8[$dst] = 0; //@line 4302
 $1 = $op + 8 | 0; //@line 4303
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  $i_150 = 0; //@line 4308
  label = 528; //@line 4309
 } else {
  $4 = $tmp46; //@line 4311
  $i_053 = 0; //@line 4313
  do {
   _sprintf($4 | 0, 42e3, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAPU16[$op + 12 + ($i_053 << 1) >> 1] | 0, tempInt) | 0) | 0; //@line 4319
   _strcat($dst | 0, $4 | 0) | 0; //@line 4320
   $i_053 = $i_053 + 1 | 0; //@line 4321
   $13 = HEAP32[$1 >> 2] | 0; //@line 4322
  } while ($i_053 >>> 0 < $13 >>> 0);
  if ($13 >>> 0 < 4) {
   $i_150 = $13; //@line 4334
   label = 528; //@line 4335
  }
 }
 if ((label | 0) == 528) {
  while (1) {
   label = 0; //@line 4340
   $endptr45 = $dst + (_strlen($dst | 0) | 0) | 0; //@line 4343
   HEAP8[$endptr45] = HEAP8[41656] | 0; //@line 4344
   HEAP8[$endptr45 + 1 | 0] = HEAP8[41657 | 0] | 0; //@line 4344
   HEAP8[$endptr45 + 2 | 0] = HEAP8[41658 | 0] | 0; //@line 4344
   HEAP8[$endptr45 + 3 | 0] = HEAP8[41659 | 0] | 0; //@line 4344
   HEAP8[$endptr45 + 4 | 0] = HEAP8[41660 | 0] | 0; //@line 4344
   HEAP8[$endptr45 + 5 | 0] = HEAP8[41661 | 0] | 0; //@line 4344
   $15 = $i_150 + 1 | 0; //@line 4345
   if ($15 >>> 0 < 4) {
    $i_150 = $15; //@line 4349
    label = 528; //@line 4350
   } else {
    break;
   }
  }
 }
 $18 = HEAP32[$op >> 2] | 0; //@line 4357
 do {
  if (($18 & 1 | 0) == 0) {
   if (($18 & 4 | 0) != 0) {
    $27 = $dst + (_strlen($dst | 0) | 0) | 0; //@line 4369
    tempBigInt = 62; //@line 4370
    HEAP8[$27] = tempBigInt & 255; //@line 4370
    tempBigInt = tempBigInt >> 8; //@line 4370
    HEAP8[$27 + 1 | 0] = tempBigInt & 255; //@line 4370
    break;
   }
   $31 = $dst + (_strlen($dst | 0) | 0) | 0; //@line 4378
   if (($18 & 16 | 0) == 0) {
    tempBigInt = 32; //@line 4381
    HEAP8[$31] = tempBigInt & 255; //@line 4381
    tempBigInt = tempBigInt >> 8; //@line 4381
    HEAP8[$31 + 1 | 0] = tempBigInt & 255; //@line 4381
    break;
   } else {
    tempBigInt = 60; //@line 4384
    HEAP8[$31] = tempBigInt & 255; //@line 4384
    tempBigInt = tempBigInt >> 8; //@line 4384
    HEAP8[$31 + 1 | 0] = tempBigInt & 255; //@line 4384
    break;
   }
  } else {
   $22 = $dst + (_strlen($dst | 0) | 0) | 0; //@line 4391
   tempBigInt = 42; //@line 4392
   HEAP8[$22] = tempBigInt & 255; //@line 4392
   tempBigInt = tempBigInt >> 8; //@line 4392
   HEAP8[$22 + 1 | 0] = tempBigInt & 255; //@line 4392
  }
 } while (0);
 $38 = _mac_get_trap_name(HEAPU16[$op + 12 >> 1] | 0) | 0; //@line 4399
 $_ = ($38 | 0) == 0 ? $op + 32 | 0 : $38; //@line 4402
 $42 = HEAP32[$op + 28 >> 2] | 0; //@line 4404
 if (($42 | 0) == 3) {
  $55 = $tmp46; //@line 4406
  $56 = $op + 96 | 0; //@line 4407
  $57 = $op + 160 | 0; //@line 4408
  $58 = $op + 224 | 0; //@line 4409
  _sprintf($55 | 0, 39288, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $_, HEAP32[tempInt + 8 >> 2] = $56, HEAP32[tempInt + 16 >> 2] = $57, HEAP32[tempInt + 24 >> 2] = $58, tempInt) | 0) | 0; //@line 4410
  $_pre_phi = $55; //@line 4412
 } else if (($42 | 0) == 1) {
  $46 = $tmp46; //@line 4414
  _sprintf($46 | 0, 40064, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $_, HEAP32[tempInt + 8 >> 2] = $op + 96, tempInt) | 0) | 0; //@line 4416
  $_pre_phi = $46; //@line 4418
 } else if (($42 | 0) == 2) {
  $50 = $tmp46; //@line 4420
  _sprintf($50 | 0, 39848, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $_, HEAP32[tempInt + 8 >> 2] = $op + 96, HEAP32[tempInt + 16 >> 2] = $op + 160, tempInt) | 0) | 0; //@line 4423
  $_pre_phi = $50; //@line 4425
 } else if (($42 | 0) == 0) {
  $44 = $tmp46; //@line 4427
  $leninc = (_strlen($_ | 0) | 0) + 1 | 0; //@line 4429
  _memcpy($44 | 0, $_ | 0, $leninc) | 0; //@line 4430
  $_pre_phi = $44; //@line 4432
 } else {
  HEAP32[$tmp46_sub >> 2] = 2960685; //@line 4434
  $_pre_phi = $tmp46; //@line 4437
 }
 _strcat($dst | 0, $_pre_phi | 0) | 0; //@line 4440
 $63 = $op + 288 | 0; //@line 4441
 if ((HEAP8[$63] | 0) == 0) {
  STACKTOP = sp; //@line 4446
  return;
 }
 $67 = _strlen($dst | 0) | 0; //@line 4449
 $68 = $dst + $67 | 0; //@line 4450
 if ($67 >>> 0 < 50) {
  _memset($68 | 0, 32, 50 - $67 | 0); //@line 4455
  $_0_lcssa = $dst + 50 | 0; //@line 4458
 } else {
  $_0_lcssa = $68; //@line 4460
 }
 HEAP8[$_0_lcssa] = HEAP8[38664] | 0; //@line 4463
 HEAP8[$_0_lcssa + 1 | 0] = HEAP8[38665 | 0] | 0; //@line 4463
 HEAP8[$_0_lcssa + 2 | 0] = HEAP8[38666 | 0] | 0; //@line 4463
 _strcat($_0_lcssa | 0, $63 | 0) | 0; //@line 4464
 STACKTOP = sp; //@line 4466
 return;
}
function _mac_hook($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $1 = 0, $3 = 0, $16 = 0, $17 = 0, $23 = 0, $27 = 0, $31 = 0, $35 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 4481
 $1 = $ext; //@line 4482
 if (($val | 0) == 3) {
  $3 = $ext + 2424 | 0; //@line 4485
  _mac_sony_insert($3, 1); //@line 4486
  _mac_sony_insert($3, 2); //@line 4487
  _mac_sony_insert($3, 3); //@line 4488
  _mac_sony_insert($3, 4); //@line 4489
  $_0 = 0; //@line 4490
  STACKTOP = sp; //@line 4492
  return $_0 | 0; //@line 4493
 } else if (($val | 0) == 4) {
  _pce_log(2, 44880, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[(HEAP32[$ext + 4 >> 2] | 0) + 152 >> 2], tempInt) | 0); //@line 4500
  $_0 = 0; //@line 4502
  STACKTOP = sp; //@line 4504
  return $_0 | 0; //@line 4505
 } else if (($val | 0) == 2) {
  _mac_set_msg($1, 48448, 54168) | 0; //@line 4507
  $_0 = 0; //@line 4509
  STACKTOP = sp; //@line 4511
  return $_0 | 0; //@line 4512
 } else if (($val | 0) == 0) {
  $_0 = 0; //@line 4514
  STACKTOP = sp; //@line 4516
  return $_0 | 0; //@line 4517
 } else if (($val | 0) == 1) {
  _mac_set_msg($1, 41304, 54168) | 0; //@line 4519
  $_0 = 0; //@line 4521
  STACKTOP = sp; //@line 4523
  return $_0 | 0; //@line 4524
 } else {
  $16 = $ext + 4 | 0; //@line 4527
  $17 = HEAP32[$16 >> 2] | 0; //@line 4528
  $23 = $ext + 2628 | 0; //@line 4534
  HEAP32[$23 >> 2] = HEAP32[$17 + 88 >> 2]; //@line 4535
  $27 = $ext + 2632 | 0; //@line 4539
  HEAP32[$27 >> 2] = HEAP32[$17 + 120 >> 2]; //@line 4540
  $31 = $ext + 2636 | 0; //@line 4544
  HEAP32[$31 >> 2] = HEAP32[$17 + 124 >> 2]; //@line 4545
  $35 = $ext + 2640 | 0; //@line 4549
  HEAP32[$35 >> 2] = HEAP32[$17 + 152 >> 2]; //@line 4550
  if ((_mac_sony_hook($ext + 2424 | 0, $val) | 0) == 0) {
   HEAP32[(HEAP32[$16 >> 2] | 0) + 88 >> 2] = HEAP32[$23 >> 2]; //@line 4558
   HEAP32[(HEAP32[$16 >> 2] | 0) + 120 >> 2] = HEAP32[$27 >> 2]; //@line 4562
   HEAP32[(HEAP32[$16 >> 2] | 0) + 124 >> 2] = HEAP32[$31 >> 2]; //@line 4566
   _e68_set_pc_prefetch(HEAP32[$16 >> 2] | 0, HEAP32[$35 >> 2] | 0); //@line 4569
   $_0 = 0; //@line 4571
   STACKTOP = sp; //@line 4573
   return $_0 | 0; //@line 4574
  } else {
   _mac_log_deb(41336, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $val, tempInt) | 0); //@line 4576
   $_0 = 1; //@line 4578
   STACKTOP = sp; //@line 4580
   return $_0 | 0; //@line 4581
  }
 }
 return 0;
}
function _mac_set_hotkey($sim, $key) {
 $sim = $sim | 0;
 $key = $key | 0;
 var $10 = 0, $11 = 0, $22 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 4594
 if (($key | 0) == 4) {
  _mac_set_msg($sim, 38992, 44576) | 0; //@line 4596
  STACKTOP = sp; //@line 4598
  return 0; //@line 4599
 } else if (($key | 0) == 5) {
  _mac_set_msg($sim, 38992, 41112) | 0; //@line 4601
  STACKTOP = sp; //@line 4603
  return 0; //@line 4604
 } else if (($key | 0) == 53 | ($key | 0) == 91) {
  $10 = $sim + 1744 | 0; //@line 4606
  $11 = HEAP32[$10 >> 2] | 0; //@line 4607
  do {
   if (($11 | 0) != 0) {
    if ((HEAP8[$11 + 280 | 0] | 0) == 0) {
     _mac_log_deb(35208, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 4617
     _mac_kbd_set_keypad_mode(HEAP32[$10 >> 2] | 0, 0); //@line 4619
     break;
    } else {
     _mac_log_deb(38112, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 4622
     _mac_kbd_set_keypad_mode(HEAP32[$10 >> 2] | 0, 1); //@line 4624
     break;
    }
   }
  } while (0);
  $22 = $sim + 1752 | 0; //@line 4630
  $23 = HEAP32[$22 >> 2] | 0; //@line 4631
  if (($23 | 0) == 0) {
   STACKTOP = sp; //@line 4635
   return 0; //@line 4636
  }
  if ((_adb_kbd_get_keypad_mode($23) | 0) == 0) {
   _mac_log_deb(38112, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 4642
   _adb_kbd_set_keypad_mode(HEAP32[$22 >> 2] | 0, 1); //@line 4644
   STACKTOP = sp; //@line 4645
   return 0; //@line 4646
  } else {
   _mac_log_deb(35208, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 4648
   _adb_kbd_set_keypad_mode(HEAP32[$22 >> 2] | 0, 0); //@line 4650
   STACKTOP = sp; //@line 4652
   return 0; //@line 4653
  }
 } else if (($key | 0) == 39) {
  _mac_interrupt($sim, 7, 1); //@line 4656
  _mac_interrupt($sim, 7, 0); //@line 4657
  STACKTOP = sp; //@line 4659
  return 0; //@line 4660
 } else if (($key | 0) == 2) {
  _mac_set_msg($sim, 38992, 53656) | 0; //@line 4662
  STACKTOP = sp; //@line 4664
  return 0; //@line 4665
 } else if (($key | 0) == 3) {
  _mac_set_msg($sim, 38992, 48088) | 0; //@line 4667
  STACKTOP = sp; //@line 4669
  return 0; //@line 4670
 } else {
  _pce_log(2, 32384, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $key, tempInt) | 0); //@line 4672
  STACKTOP = sp; //@line 4674
  return 0; //@line 4675
 }
 return 0;
}
function _iwm_drv_load($drv) {
 $drv = $drv | 0;
 var $1 = 0, $3 = 0, $5 = 0, $11 = 0, $23 = 0, $storemerge_i_i_i = 0, $26 = 0, $c_017_i_i = 0, $lba_016_i_i = 0, $28 = 0, $29 = 0, $32 = 0, $lba_28_us_i_i = 0, $s_07_us_i_i = 0, $35 = 0, $lba_112_us_i_i = 0, $h_011_us_i_i = 0, $lba_1_lcssa_i_i = 0, $47 = 0, $img_0_i = 0, $del_0_i = 0, $50 = 0, $img_1_ph = 0, $60 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 4692
 $1 = $drv + 20 | 0; //@line 4693
 HEAP8[$1] = 0; //@line 4694
 $3 = HEAP32[$drv + 4 >> 2] | 0; //@line 4696
 do {
  if (($3 | 0) == 0) {
   label = 593; //@line 4701
  } else {
   $5 = _pri_img_load($3, 0) | 0; //@line 4703
   if (($5 | 0) == 0) {
    label = 593; //@line 4707
    break;
   }
   HEAP8[$1] = 1; //@line 4710
   _mac_log_deb(32128, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$drv >> 2] | 0) + 1, tempInt) | 0); //@line 4714
   $img_1_ph = $5; //@line 4715
  }
 } while (0);
 L760 : do {
  if ((label | 0) == 593) {
   $11 = _dsks_get_disk(HEAP32[$drv + 8 >> 2] | 0, HEAP32[$drv + 12 >> 2] | 0) | 0; //@line 4724
   L762 : do {
    if (($11 | 0) != 0) {
     L764 : do {
      if ((_dsk_get_type($11) | 0) == 6) {
       $del_0_i = 0;
       $img_0_i = HEAP32[(HEAP32[$11 + 64 >> 2] | 0) + 68 >> 2] | 0;
      } else {
       $23 = _dsk_get_block_cnt($11) | 0; //@line 4742
       if (($23 | 0) == 800) {
        $storemerge_i_i_i = 1; //@line 4744
       } else if (($23 | 0) == 1600) {
        $storemerge_i_i_i = 2; //@line 4746
       } else {
        break L762;
       }
       $26 = _psi_img_new() | 0; //@line 4751
       if (($26 | 0) == 0) {
        break L762;
       } else {
        $lba_016_i_i = 0;
        $c_017_i_i = 0;
       }
       L770 : while (1) {
        $28 = $c_017_i_i >>> 4; //@line 4762
        $29 = 12 - $28 | 0; //@line 4763
        if (($28 | 0) == 12) {
         $lba_1_lcssa_i_i = $lba_016_i_i; //@line 4766
        } else {
         $h_011_us_i_i = 0;
         $lba_112_us_i_i = $lba_016_i_i;
         while (1) {
          $s_07_us_i_i = 0;
          $lba_28_us_i_i = $lba_112_us_i_i;
          do {
           $35 = _psi_sct_new($c_017_i_i, $h_011_us_i_i, $s_07_us_i_i, 512) | 0; //@line 4777
           if (($35 | 0) == 0) {
            label = 605; //@line 4781
            break L770;
           }
           _psi_img_add_sector($26, $35, $c_017_i_i, $h_011_us_i_i) | 0; //@line 4784
           if ((_dsk_read_lba($11, HEAP32[$35 + 24 >> 2] | 0, $lba_28_us_i_i, 1) | 0) != 0) {
            label = 606; //@line 4791
            break L770;
           }
           $lba_28_us_i_i = $lba_28_us_i_i + 1 | 0; //@line 4794
           $s_07_us_i_i = $s_07_us_i_i + 1 | 0; //@line 4795
          } while ($s_07_us_i_i >>> 0 < $29 >>> 0);
          $32 = $h_011_us_i_i + 1 | 0; //@line 4804
          if ($32 >>> 0 < $storemerge_i_i_i >>> 0) {
           $h_011_us_i_i = $32;
           $lba_112_us_i_i = $lba_28_us_i_i;
          } else {
           $lba_1_lcssa_i_i = $lba_28_us_i_i; //@line 4810
           break;
          }
         }
        }
        $47 = $c_017_i_i + 1 | 0; //@line 4816
        if ($47 >>> 0 < 80) {
         $lba_016_i_i = $lba_1_lcssa_i_i;
         $c_017_i_i = $47;
        } else {
         $del_0_i = $26;
         $img_0_i = $26;
         break L764;
        }
       }
       if ((label | 0) == 605) {
        _psi_img_del($26); //@line 4827
        break L762;
       } else if ((label | 0) == 606) {
        _psi_img_del($26); //@line 4832
        break L762;
       }
      }
     } while (0);
     if (($img_0_i | 0) == 0) {
      break;
     }
     $50 = _pri_encode_gcr($img_0_i) | 0; //@line 4845
     _psi_img_del($del_0_i); //@line 4846
     if (($50 | 0) == 0) {
      break;
     }
     _mac_log_deb(51944, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$drv >> 2] | 0) + 1, tempInt) | 0); //@line 4855
     $img_1_ph = $50; //@line 4857
     break L760;
    }
   } while (0);
   _mac_log_deb(47336, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$drv >> 2] | 0) + 1, tempInt) | 0); //@line 4864
   $_0 = 1; //@line 4866
   STACKTOP = sp; //@line 4868
   return $_0 | 0; //@line 4869
  }
 } while (0);
 $60 = $drv + 16 | 0; //@line 4873
 _pri_img_del(HEAP32[$60 >> 2] | 0); //@line 4875
 HEAP32[$60 >> 2] = $img_1_ph; //@line 4876
 HEAP8[$drv + 92 | 0] = 0; //@line 4878
 HEAP32[$drv + 48 >> 2] = 0; //@line 4880
 $_0 = 0; //@line 4882
 STACKTOP = sp; //@line 4884
 return $_0 | 0; //@line 4885
}
function _mac_iwm_set_motor_fct($iwm, $ext, $fct) {
 $iwm = $iwm | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$iwm + 320 >> 2] = $ext; //@line 4897
 HEAP32[$iwm + 324 >> 2] = $fct; //@line 4900
 return;
}
function _mac_iwm_set_disks($iwm, $dsks) {
 $iwm = $iwm | 0;
 $dsks = $dsks | 0;
 HEAP32[$iwm + 32 >> 2] = $dsks; //@line 4913
 HEAP32[$iwm + 128 >> 2] = $dsks; //@line 4915
 HEAP32[$iwm + 224 >> 2] = $dsks; //@line 4917
 return;
}
function _mac_iwm_set_disk_id($iwm, $drive, $id) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 $id = $id | 0;
 if ($drive >>> 0 >= 3) {
  return;
 }
 HEAP32[$iwm + 24 + ($drive * 96 | 0) + 12 >> 2] = $id; //@line 4937
 return;
}
function _mac_iwm_get_locked($iwm, $drive) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 var $_0 = 0;
 if ($drive >>> 0 > 2) {
  $_0 = 1; //@line 4953
  return $_0 | 0; //@line 4956
 }
 $_0 = (HEAP8[$iwm + 24 + ($drive * 96 | 0) + 21 | 0] | 0) != 0 | 0; //@line 4963
 return $_0 | 0; //@line 4966
}
function _mac_iwm_set_locked($iwm, $drive, $locked) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 $locked = $locked | 0;
 if ($drive >>> 0 > 2) {
  return;
 }
 HEAP8[$iwm + 24 + ($drive * 96 | 0) + 21 | 0] = ($locked | 0) != 0 | 0; //@line 4986
 return;
}
function _mac_iwm_set_auto_rotate($iwm, $drive, $val) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 $val = $val | 0;
 if ($drive >>> 0 > 2) {
  return;
 }
 HEAP8[$iwm + 24 + ($drive * 96 | 0) + 22 | 0] = ($val | 0) != 0 | 0; //@line 5009
 return;
}
function _mac_iwm_set_pwm($iwm, $buf, $cnt) {
 $iwm = $iwm | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $2 = 0, $_011 = 0, $pwm_010 = 0, $_089 = 0, $14 = 0, $15 = 0, $pwm_0_lcssa = 0;
 $1 = $iwm + 20 | 0; //@line 5025
 $2 = HEAP32[$1 >> 2] | 0; //@line 5026
 if (($cnt | 0) == 0) {
  $pwm_0_lcssa = $2; //@line 5030
 } else {
  $_089 = $cnt;
  $pwm_010 = $2;
  $_011 = $buf;
  while (1) {
   $14 = (((HEAPU8[6584 + (HEAP8[$_011] & 63) | 0] | 0) << 10) + ($pwm_010 * 31 | 0) | 0) >>> 5; //@line 5047
   $15 = $_089 - 1 | 0; //@line 5048
   if (($15 | 0) == 0) {
    $pwm_0_lcssa = $14; //@line 5052
    break;
   } else {
    $_089 = $15;
    $pwm_010 = $14;
    $_011 = $_011 + 1 | 0;
   }
  }
 }
 HEAP32[$1 >> 2] = $pwm_0_lcssa; //@line 5060
 HEAP32[(HEAP32[$iwm + 312 >> 2] | 0) + 88 >> 2] = $pwm_0_lcssa; //@line 5064
 return;
}
function _iwm_drv_save($drv) {
 $drv = $drv | 0;
 var $buf_i_i = 0, $1 = 0, $5 = 0, $13 = 0, $24 = 0, $28 = 0, $35 = 0, $37 = 0, $41 = 0, $42 = 0, $storemerge_i_i_i = 0, $lba_010_i_i = 0, $c_09_i_i = 0, $46 = 0, $lba_17_i_i = 0, $h_06_i_i = 0, $s_0_i_i = 0, $50 = 0, $55 = 0, $56 = 0, $cnt_0_i_i = 0, $63 = 0, $74 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 5082
 STACKTOP = STACKTOP + 512 | 0; //@line 5082
 $buf_i_i = sp | 0; //@line 5083
 $1 = $drv + 16 | 0; //@line 5084
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  $_0 = 1; //@line 5089
  STACKTOP = sp; //@line 5091
  return $_0 | 0; //@line 5092
 }
 $5 = $drv | 0; //@line 5094
 _mac_log_deb(43848, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$5 >> 2] | 0) + 1, tempInt) | 0); //@line 5097
 L822 : do {
  if ((HEAP8[$drv + 20 | 0] | 0) == 0) {
   $24 = _dsks_get_disk(HEAP32[$drv + 8 >> 2] | 0, HEAP32[$drv + 12 >> 2] | 0) | 0; //@line 5108
   do {
    if (($24 | 0) != 0) {
     $28 = _pri_decode_gcr(HEAP32[$1 >> 2] | 0) | 0; //@line 5114
     if (($28 | 0) == 0) {
      break;
     }
     if ((_dsk_get_type($24) | 0) == 6) {
      $35 = HEAP32[$24 + 64 >> 2] | 0; //@line 5125
      $37 = $35 + 68 | 0; //@line 5127
      _psi_img_del(HEAP32[$37 >> 2] | 0); //@line 5129
      HEAP32[$37 >> 2] = $28; //@line 5130
      HEAP8[$35 + 72 | 0] = 1; //@line 5132
      break L822;
     }
     $41 = $buf_i_i | 0; //@line 5136
     $42 = _dsk_get_block_cnt($24) | 0; //@line 5137
     if (($42 | 0) == 1600) {
      $storemerge_i_i_i = 2; //@line 5139
     } else if (($42 | 0) == 800) {
      $storemerge_i_i_i = 1; //@line 5141
     } else {
      _psi_img_del($28); //@line 5143
      break;
     }
     $c_09_i_i = 0;
     $lba_010_i_i = 0;
     L834 : while (1) {
      $46 = 12 - ($c_09_i_i >>> 4) | 0; //@line 5153
      $h_06_i_i = 0;
      $lba_17_i_i = $lba_010_i_i;
      do {
       $s_0_i_i = 0; //@line 5160
       while (1) {
        if ($s_0_i_i >>> 0 >= $46 >>> 0) {
         break;
        }
        $50 = _psi_img_get_sector($28, $c_09_i_i, $h_06_i_i, $s_0_i_i, 0) | 0; //@line 5168
        if (($50 | 0) == 0) {
         _memset($41 | 0, 0, 512); //@line 5172
        } else {
         $55 = HEAP16[$50 + 10 >> 1] | 0; //@line 5176
         $56 = $55 & 65535; //@line 5177
         if (($55 & 65535) < 512) {
          _memset($buf_i_i + $56 | 0, 0, 512 - $56 | 0); //@line 5183
          $cnt_0_i_i = $56; //@line 5185
         } else {
          $cnt_0_i_i = 512; //@line 5187
         }
         $63 = HEAP32[$50 + 24 >> 2] | 0; //@line 5191
         _memcpy($41 | 0, $63 | 0, $cnt_0_i_i) | 0; //@line 5192
        }
        if ((_dsk_write_lba($24, $41, $s_0_i_i + $lba_17_i_i | 0, 1) | 0) == 0) {
         $s_0_i_i = $s_0_i_i + 1 | 0; //@line 5200
        } else {
         label = 666; //@line 5202
         break L834;
        }
       }
       $lba_17_i_i = $lba_17_i_i + $46 | 0; //@line 5206
       $h_06_i_i = $h_06_i_i + 1 | 0; //@line 5207
      } while ($h_06_i_i >>> 0 < $storemerge_i_i_i >>> 0);
      $74 = $c_09_i_i + 1 | 0; //@line 5216
      if ($74 >>> 0 < 80) {
       $c_09_i_i = $74;
       $lba_010_i_i = $lba_17_i_i;
      } else {
       label = 664; //@line 5222
       break;
      }
     }
     if ((label | 0) == 666) {
      _psi_img_del($28); //@line 5227
      break;
     } else if ((label | 0) == 664) {
      _psi_img_del($28); //@line 5231
      break L822;
     }
    }
   } while (0);
   _mac_log_deb(37432, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$5 >> 2] | 0) + 1, tempInt) | 0); //@line 5239
   $_0 = 1; //@line 5241
   STACKTOP = sp; //@line 5243
   return $_0 | 0; //@line 5244
  } else {
   $13 = HEAP32[$drv + 4 >> 2] | 0; //@line 5247
   if (($13 | 0) != 0) {
    if ((_pri_img_save($13, HEAP32[$1 >> 2] | 0, 0) | 0) == 0) {
     break;
    }
   }
   _mac_log_deb(40512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$5 >> 2] | 0) + 1, tempInt) | 0); //@line 5261
   $_0 = 1; //@line 5263
   STACKTOP = sp; //@line 5265
   return $_0 | 0; //@line 5266
  }
 } while (0);
 HEAP8[$drv + 92 | 0] = 0; //@line 5270
 $_0 = 0; //@line 5272
 STACKTOP = sp; //@line 5274
 return $_0 | 0; //@line 5275
}
function _mac_iwm_init($iwm) {
 $iwm = $iwm | 0;
 HEAP8[$iwm | 0] = 0; //@line 5292
 HEAP8[$iwm + 1 | 0] = 0; //@line 5294
 HEAP8[$iwm + 3 | 0] = 0; //@line 5296
 HEAP8[$iwm + 4 | 0] = 0; //@line 5298
 HEAP8[$iwm + 5 | 0] = 127; //@line 5300
 HEAP8[$iwm + 6 | 0] = 0; //@line 5302
 _memset($iwm + 8 | 0, 0, 39); //@line 5306
 HEAP32[$iwm + 48 >> 2] = 80; //@line 5307
 HEAP32[$iwm + 52 >> 2] = 1; //@line 5309
 _memset($iwm + 56 | 0, 0, 5); //@line 5313
 _memset($iwm + 64 | 0, 0, 24); //@line 5315
 HEAP32[$iwm + 88 >> 2] = 65e3; //@line 5316
 HEAP32[$iwm + 92 >> 2] = 0; //@line 5318
 HEAP32[$iwm + 96 >> 2] = 0; //@line 5320
 HEAP32[$iwm + 100 >> 2] = 0; //@line 5322
 HEAP32[$iwm + 104 >> 2] = 783360; //@line 5324
 HEAP32[$iwm + 108 >> 2] = 0; //@line 5326
 HEAP8[$iwm + 116 | 0] = 0; //@line 5328
 HEAP32[$iwm + 120 >> 2] = 1; //@line 5330
 HEAP32[$iwm + 124 >> 2] = 0; //@line 5332
 HEAP32[$iwm + 128 >> 2] = 0; //@line 5334
 HEAP32[$iwm + 132 >> 2] = 1; //@line 5336
 _memset($iwm + 136 | 0, 0, 7); //@line 5340
 HEAP32[$iwm + 144 >> 2] = 80; //@line 5341
 HEAP32[$iwm + 148 >> 2] = 1; //@line 5343
 _memset($iwm + 152 | 0, 0, 5); //@line 5347
 _memset($iwm + 160 | 0, 0, 24); //@line 5349
 HEAP32[$iwm + 184 >> 2] = 65e3; //@line 5350
 HEAP32[$iwm + 188 >> 2] = 0; //@line 5352
 HEAP32[$iwm + 192 >> 2] = 0; //@line 5354
 HEAP32[$iwm + 196 >> 2] = 0; //@line 5356
 HEAP32[$iwm + 200 >> 2] = 783360; //@line 5358
 HEAP32[$iwm + 204 >> 2] = 0; //@line 5360
 HEAP8[$iwm + 212 | 0] = 0; //@line 5362
 HEAP32[$iwm + 216 >> 2] = 2; //@line 5364
 HEAP32[$iwm + 220 >> 2] = 0; //@line 5366
 HEAP32[$iwm + 224 >> 2] = 0; //@line 5368
 HEAP32[$iwm + 228 >> 2] = 2; //@line 5370
 _memset($iwm + 232 | 0, 0, 7); //@line 5374
 HEAP32[$iwm + 240 >> 2] = 80; //@line 5375
 HEAP32[$iwm + 244 >> 2] = 1; //@line 5377
 _memset($iwm + 248 | 0, 0, 5); //@line 5381
 _memset($iwm + 256 | 0, 0, 24); //@line 5383
 HEAP32[$iwm + 280 >> 2] = 65e3; //@line 5384
 HEAP32[$iwm + 284 >> 2] = 0; //@line 5386
 HEAP32[$iwm + 288 >> 2] = 0; //@line 5388
 HEAP32[$iwm + 292 >> 2] = 0; //@line 5390
 HEAP32[$iwm + 296 >> 2] = 783360; //@line 5392
 HEAP32[$iwm + 300 >> 2] = 0; //@line 5394
 HEAP8[$iwm + 308 | 0] = 0; //@line 5396
 HEAP32[$iwm + 312 >> 2] = $iwm + 24; //@line 5399
 HEAP8[$iwm + 316 | 0] = 0; //@line 5401
 HEAP32[$iwm + 320 >> 2] = 0; //@line 5403
 HEAP32[$iwm + 324 >> 2] = 0; //@line 5405
 return;
}
function _mac_iwm_set_heads($iwm, $drive, $heads) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 $heads = $heads | 0;
 var $_0 = 0;
 if ($drive >>> 0 > 2 | $heads >>> 0 > 2) {
  $_0 = 1; //@line 5424
  return $_0 | 0; //@line 5427
 }
 HEAP32[$iwm + 24 + ($drive * 96 | 0) + 28 >> 2] = $heads; //@line 5430
 if ((HEAP32[$iwm + 24 + ($drive * 96 | 0) + 44 >> 2] | 0) >>> 0 < $heads >>> 0) {
  $_0 = 0; //@line 5436
  return $_0 | 0; //@line 5439
 }
 _iwm_drv_select_track($iwm + 24 + ($drive * 96 | 0) | 0, HEAP32[$iwm + 24 + ($drive * 96 | 0) + 40 >> 2] | 0, 0); //@line 5444
 $_0 = 0; //@line 5446
 return $_0 | 0; //@line 5449
}
function _iwm_drv_select_track($drv, $c, $h) {
 $drv = $drv | 0;
 $c = $c | 0;
 $h = $h | 0;
 var $9 = 0, $10 = 0, $13 = 0, $15 = 0, $16 = 0, $19 = 0, $38 = 0, $40 = 0;
 if ((HEAP32[$drv + 24 >> 2] | 0) >>> 0 <= $c >>> 0) {
  return;
 }
 if ((HEAP32[$drv + 28 >> 2] | 0) >>> 0 <= $h >>> 0) {
  return;
 }
 $9 = $drv + 16 | 0; //@line 5480
 $10 = HEAP32[$9 >> 2] | 0; //@line 5481
 if (($10 | 0) == 0) {
  $13 = _pri_img_new() | 0; //@line 5485
  HEAP32[$9 >> 2] = $13; //@line 5486
  $15 = $13; //@line 5488
 } else {
  $15 = $10; //@line 5490
 }
 $16 = _pri_img_get_track($15, $c, $h, 1) | 0; //@line 5493
 if (($16 | 0) == 0) {
  return;
 }
 $19 = $16 + 4 | 0; //@line 5500
 do {
  if ((HEAP32[$19 >> 2] | 0) == 0) {
   if ((_pri_trk_set_size($16, HEAP32[16104 + (($c >>> 0 > 79 ? 4 : $c >>> 4) << 2) >> 2] | 0) | 0) == 0) {
    break;
   }
   return;
  }
 } while (0);
 if ((HEAP32[$16 >> 2] | 0) == 0) {
  _pri_trk_set_clock($16, 5e5); //@line 5526
 }
 HEAP32[$drv + 40 >> 2] = $c; //@line 5530
 HEAP32[$drv + 44 >> 2] = $h; //@line 5532
 HEAP32[$drv + 48 >> 2] = $16; //@line 5534
 $38 = HEAP32[$19 >> 2] | 0; //@line 5535
 HEAP32[$drv + 56 >> 2] = $38; //@line 5537
 $40 = $drv + 52 | 0; //@line 5538
 if ((HEAP32[$40 >> 2] | 0) >>> 0 < $38 >>> 0) {
  return;
 }
 HEAP32[$40 >> 2] = 0; //@line 5546
 return;
}
function _mac_iwm_set_fname($iwm, $drive, $fname) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 $fname = $fname | 0;
 var $3 = 0, $9 = 0, $10 = 0;
 if ($drive >>> 0 > 2) {
  return;
 }
 $3 = $iwm + 24 + ($drive * 96 | 0) + 4 | 0; //@line 5567
 _free(HEAP32[$3 >> 2] | 0); //@line 5569
 HEAP32[$3 >> 2] = 0; //@line 5570
 HEAP8[$iwm + 24 + ($drive * 96 | 0) + 20 | 0] = 0; //@line 5572
 if (($fname | 0) == 0) {
  return;
 }
 $9 = (_strlen($fname | 0) | 0) + 1 | 0; //@line 5580
 $10 = _malloc($9) | 0; //@line 5581
 if (($10 | 0) == 0) {
  return;
 }
 _memcpy($10 | 0, $fname | 0, $9) | 0; //@line 5588
 HEAP32[$3 >> 2] = $10; //@line 5589
 return;
}
function _mac_iwm_set_drive_sel($iwm, $val) {
 $iwm = $iwm | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $14 = 0, $15 = 0;
 $1 = $val << 24 >> 24 != 0; //@line 5604
 $2 = $iwm + 2 | 0; //@line 5605
 if ((HEAPU8[$2] | 0 | 0) == ($1 & 1 | 0)) {
  return;
 }
 HEAP8[$2] = $1 & 1; //@line 5616
 if ((HEAP8[$iwm | 0] & 32) != 0) {
  return;
 }
 $14 = $1 ? 2 : 0; //@line 5626
 $15 = $iwm + 24 + ($14 * 96 | 0) | 0; //@line 5627
 HEAP32[$iwm + 312 >> 2] = $15; //@line 5629
 _iwm_drv_select_track($15, HEAP32[$iwm + 24 + ($14 * 96 | 0) + 40 >> 2] | 0, HEAPU8[$iwm + 1 | 0] | 0); //@line 5635
 return;
}
function _mac_iwm_set_head_sel($iwm, $val) {
 $iwm = $iwm | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $5 = 0, $10 = 0;
 $1 = $val << 24 >> 24 != 0; //@line 5649
 $2 = $iwm + 1 | 0; //@line 5650
 $5 = $1 & 1; //@line 5653
 if ((HEAPU8[$2] | 0 | 0) == ($5 | 0)) {
  return;
 }
 HEAP8[$2] = $1 & 1; //@line 5661
 $10 = HEAP32[$iwm + 312 >> 2] | 0; //@line 5663
 if ((HEAP32[$10 + 44 >> 2] | 0) == ($5 | 0)) {
  return;
 }
 _iwm_drv_select_track($10, HEAP32[$10 + 40 >> 2] | 0, $5); //@line 5674
 return;
}
function _mac_iwm_insert($iwm, $drive) {
 $iwm = $iwm | 0;
 $drive = $drive | 0;
 var $3 = 0, $4 = 0;
 if ($drive >>> 0 > 2) {
  return;
 }
 $3 = $iwm + 24 + ($drive * 96 | 0) | 0; //@line 5694
 $4 = $iwm + 24 + ($drive * 96 | 0) + 34 | 0; //@line 5695
 if ((HEAP8[$4] | 0) != 0) {
  return;
 }
 if ((_iwm_drv_load($3) | 0) != 0) {
  return;
 }
 HEAP8[$4] = 1; //@line 5710
 _iwm_drv_select_track($3, HEAP32[$iwm + 24 + ($drive * 96 | 0) + 40 >> 2] | 0, HEAP32[$iwm + 24 + ($drive * 96 | 0) + 44 >> 2] | 0); //@line 5715
 return;
}
function _mac_iwm_get_uint8($iwm, $addr) {
 $iwm = $iwm | 0;
 $addr = $addr | 0;
 var $8 = 0, $9 = 0, $14 = 0, $15 = 0, $23 = 0, $iwm_idx17_val = 0, $27 = 0, $32 = 0, $33 = 0, $51 = 0, $60 = 0, $65 = 0, $83 = 0, $val_0_in_i_i = 0, $_0_i = 0, $99 = 0, $_0 = 0, label = 0;
 if (($addr & 1 | 0) == 0) {
  $_0 = 0; //@line 5745
  return $_0 | 0; //@line 5748
 }
 _mac_iwm_access_uint8($iwm, $addr >>> 9 & 15); //@line 5752
 $8 = HEAPU8[$iwm | 0] | 0; //@line 5755
 $9 = $8 & 192; //@line 5756
 if (($9 | 0) == 128) {
  $99 = HEAP8[$iwm + 5 | 0] | 0; //@line 5759
  return ((HEAPU16[$iwm + 14 >> 1] | 0) < 256 ? $99 | -128 : $99 & 127) | 0; //@line 5767
 } else if (($9 | 0) == 0) {
  if (($8 & 16 | 0) == 0) {
   $_0 = -1; //@line 5773
   return $_0 | 0; //@line 5776
  }
  $14 = $iwm + 13 | 0; //@line 5778
  $15 = HEAP8[$14] | 0; //@line 5779
  HEAP8[$14] = 0; //@line 5780
  $_0 = $15; //@line 5782
  return $_0 | 0; //@line 5785
 } else if (($9 | 0) == 64) {
  $23 = HEAP8[$iwm + 4 | 0] & 31 | HEAP8[$iwm + 3 | 0] & 96; //@line 5793
  $iwm_idx17_val = HEAP32[$iwm + 312 >> 2] | 0; //@line 5797
  $27 = ((HEAP8[$iwm + 1 | 0] | 0) != 0 ? 8 : 0) | $8 & 7; //@line 5801
  if (($27 | 0) == 1) {
   $32 = $iwm_idx17_val + 33 | 0; //@line 5803
   $33 = HEAP8[$32] | 0; //@line 5804
   HEAP8[$32] = 0; //@line 5805
   $_0_i = $33 << 24 >> 24 == 0 | 0; //@line 5809
   label = 752; //@line 5810
  } else if (($27 | 0) == 2) {
   $_0_i = (HEAP8[$iwm_idx17_val + 36 | 0] | 0) == 0 | 0; //@line 5817
   label = 752; //@line 5818
  } else if (($27 | 0) == 0) {
   $_0_i = (HEAP8[$iwm_idx17_val + 32 | 0] | 0) == 0 | 0; //@line 5825
   label = 752; //@line 5826
  } else if (($27 | 0) == 3) {
   $_0_i = (HEAP8[$iwm_idx17_val + 35 | 0] | 0) != 0 | 0; //@line 5833
   label = 752; //@line 5834
  } else if (($27 | 0) == 9) {
   $51 = HEAP8[$iwm_idx17_val + 21 | 0] | 0; //@line 5838
   do {
    if ((HEAP8[$iwm_idx17_val + 20 | 0] | 0) == 0) {
     $60 = _dsks_get_disk(HEAP32[$iwm_idx17_val + 8 >> 2] | 0, HEAP32[$iwm_idx17_val + 12 >> 2] | 0) | 0; //@line 5849
     if (($60 | 0) == 0) {
      $65 = $51; //@line 5853
      break;
     }
     $65 = (_dsk_get_readonly($60) | 0) == 0 ? $51 : 1; //@line 5859
    } else {
     $65 = $51; //@line 5861
    }
   } while (0);
   $_0_i = ($65 | 0) == 0 | 0; //@line 5868
   label = 752; //@line 5869
  } else if (($27 | 0) == 6) {
   $_0_i = (HEAP32[$iwm_idx17_val + 28 >> 2] | 0) >>> 0 > 1 | 0; //@line 5876
   label = 752; //@line 5877
  } else if (($27 | 0) == 10) {
   $_0_i = (HEAP32[$iwm_idx17_val + 40 >> 2] | 0) != 0 | 0; //@line 5884
   label = 752; //@line 5885
  } else if (($27 | 0) == 11) {
   if ((HEAP32[$iwm_idx17_val + 28 >> 2] | 0) == 1) {
    $83 = Math_imul(((65536 - (HEAP32[$iwm_idx17_val + 88 >> 2] | 0) | 0) * 120 | 0) >>> 15, HEAP32[$iwm_idx17_val + 60 >> 2] | 0) | 0; //@line 5899
    $val_0_in_i_i = ($83 >>> 0) / ((HEAP32[$iwm_idx17_val + 64 >> 2] | 0) >>> 0) | 0; //@line 5904
   } else {
    $val_0_in_i_i = (((HEAP32[$iwm_idx17_val + 52 >> 2] | 0) * 120 | 0) >>> 0) / ((HEAP32[$iwm_idx17_val + 56 >> 2] | 0) >>> 0) | 0; //@line 5912
   }
   $_0_i = $val_0_in_i_i & 1 ^ 1; //@line 5918
   label = 752; //@line 5919
  } else if (($27 | 0) == 8) {
   $_0_i = (HEAP8[$iwm_idx17_val + 34 | 0] | 0) == 0 | 0; //@line 5926
   label = 752; //@line 5927
  } else if (($27 | 0) == 4 | ($27 | 0) == 5 | ($27 | 0) == 7 | ($27 | 0) == 12 | ($27 | 0) == 14) {
   $_0 = $23;
   return $_0 | 0; //@line 5932
  }
  do {
   if ((label | 0) == 752) {
    if (($_0_i | 0) == 0) {
     $_0 = $23; //@line 5940
    } else {
     break;
    }
    return $_0 | 0; //@line 5946
   }
  } while (0);
  $_0 = $23 | -128; //@line 5951
  return $_0 | 0; //@line 5954
 } else {
  $_0 = 0; //@line 5956
  return $_0 | 0; //@line 5959
 }
 return 0;
}
function _mac_kbd_set_data_fct($kbd, $ext, $fct) {
 $kbd = $kbd | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$kbd + 288 >> 2] = $ext; //@line 5972
 HEAP32[$kbd + 292 >> 2] = $fct; //@line 5975
 return;
}
function _mac_kbd_set_intr_fct($kbd, $ext, $fct) {
 $kbd = $kbd | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$kbd + 296 >> 2] = $ext; //@line 5989
 HEAP32[$kbd + 300 >> 2] = $fct; //@line 5992
 return;
}
function _mac_kbd_set_model($kbd, $model, $intl) {
 $kbd = $kbd | 0;
 $model = $model | 0;
 $intl = $intl | 0;
 HEAP32[$kbd + 276 >> 2] = $model; //@line 6006
 HEAP32[$kbd + 284 >> 2] = ($intl | 0) == 0 ? 10848 : 12912; //@line 6010
 return 0; //@line 6012
}
function _mac_iwm_access_uint8($iwm, $reg) {
 $iwm = $iwm | 0;
 $reg = $reg | 0;
 var $1 = 0, $3 = 0, $7 = 0, $11 = 0, $15 = 0, $19 = 0, $23 = 0, $27 = 0, $31 = 0, $35 = 0, $38 = 0, $42 = 0, $45 = 0, $49 = 0, $55 = 0, $56 = 0, $64 = 0, $67 = 0, $75 = 0, $79 = 0, $83 = 0, $87 = 0, $_pre_phi = 0, $91 = 0, $95 = 0, $101 = 0, $102 = 0, $103 = 0, $_lobit_i = 0, $105 = 0, $116 = 0, $117 = 0, $121 = 0, $123 = 0, $128 = 0, $135 = 0, $137 = 0, $140 = 0, $i_0_i_i = 0, $v_0_i_i = 0, $151 = 0, $156 = 0, $175 = 0, $178 = 0, $181 = 0, $186 = 0, $187 = 0, $198 = 0, $199 = 0, $200 = 0, sp = 0;
 sp = STACKTOP; //@line 6041
 $1 = $reg & 15; //@line 6042
 if (($1 | 0) == 7) {
  $31 = $iwm | 0; //@line 6044
  HEAP8[$31] = HEAP8[$31] | 8; //@line 6047
  $_pre_phi = $31; //@line 6049
 } else if (($1 | 0) == 2) {
  $11 = $iwm | 0; //@line 6051
  HEAP8[$11] = HEAP8[$11] & -3; //@line 6054
  $_pre_phi = $11; //@line 6056
 } else if (($1 | 0) == 1) {
  $7 = $iwm | 0; //@line 6058
  HEAP8[$7] = HEAP8[$7] | 1; //@line 6061
  $_pre_phi = $7; //@line 6063
 } else if (($1 | 0) == 3) {
  $15 = $iwm | 0; //@line 6065
  HEAP8[$15] = HEAP8[$15] | 2; //@line 6068
  $_pre_phi = $15; //@line 6070
 } else if (($1 | 0) == 9) {
  $42 = $iwm | 0; //@line 6072
  HEAP8[$42] = HEAP8[$42] | 16; //@line 6075
  $45 = $iwm + 3 | 0; //@line 6076
  HEAP8[$45] = HEAP8[$45] | 32; //@line 6079
  $_pre_phi = $42; //@line 6081
 } else if (($1 | 0) == 6) {
  $27 = $iwm | 0; //@line 6083
  HEAP8[$27] = HEAP8[$27] & -9; //@line 6086
  $_pre_phi = $27; //@line 6088
 } else if (($1 | 0) == 0) {
  $3 = $iwm | 0; //@line 6090
  HEAP8[$3] = HEAP8[$3] & -2; //@line 6093
  $_pre_phi = $3; //@line 6095
 } else if (($1 | 0) == 8) {
  $35 = $iwm | 0; //@line 6097
  HEAP8[$35] = HEAP8[$35] & -17; //@line 6100
  $38 = $iwm + 3 | 0; //@line 6101
  HEAP8[$38] = HEAP8[$38] & -33; //@line 6104
  $_pre_phi = $35; //@line 6106
 } else if (($1 | 0) == 5) {
  $23 = $iwm | 0; //@line 6108
  HEAP8[$23] = HEAP8[$23] | 4; //@line 6111
  $_pre_phi = $23; //@line 6113
 } else if (($1 | 0) == 4) {
  $19 = $iwm | 0; //@line 6115
  HEAP8[$19] = HEAP8[$19] & -5; //@line 6118
  $_pre_phi = $19; //@line 6120
 } else if (($1 | 0) == 12) {
  $75 = $iwm | 0; //@line 6122
  HEAP8[$75] = HEAP8[$75] & -65; //@line 6125
  $_pre_phi = $75; //@line 6127
 } else if (($1 | 0) == 10) {
  $49 = $iwm | 0; //@line 6129
  HEAP8[$49] = HEAP8[$49] & -33; //@line 6132
  $55 = (HEAP8[$iwm + 2 | 0] | 0) != 0 ? 2 : 0; //@line 6136
  $56 = $iwm + 24 + ($55 * 96 | 0) | 0; //@line 6137
  HEAP32[$iwm + 312 >> 2] = $56; //@line 6139
  _iwm_drv_select_track($56, HEAP32[$iwm + 24 + ($55 * 96 | 0) + 40 >> 2] | 0, HEAPU8[$iwm + 1 | 0] | 0); //@line 6145
  $_pre_phi = $49; //@line 6147
 } else if (($1 | 0) == 11) {
  $64 = $iwm | 0; //@line 6149
  HEAP8[$64] = HEAP8[$64] | 32; //@line 6152
  $67 = $iwm + 120 | 0; //@line 6153
  HEAP32[$iwm + 312 >> 2] = $67; //@line 6155
  _iwm_drv_select_track($67, HEAP32[$iwm + 160 >> 2] | 0, HEAPU8[$iwm + 1 | 0] | 0); //@line 6161
  $_pre_phi = $64; //@line 6163
 } else if (($1 | 0) == 13) {
  $79 = $iwm | 0; //@line 6165
  HEAP8[$79] = HEAP8[$79] | 64; //@line 6168
  $_pre_phi = $79; //@line 6170
 } else if (($1 | 0) == 14) {
  $83 = $iwm | 0; //@line 6172
  HEAP8[$83] = HEAP8[$83] & 127; //@line 6175
  $_pre_phi = $83; //@line 6177
 } else if (($1 | 0) == 15) {
  $87 = $iwm | 0; //@line 6179
  HEAP8[$87] = HEAP8[$87] | -128; //@line 6182
  $_pre_phi = $87; //@line 6184
 } else {
  $_pre_phi = $iwm | 0; //@line 6188
 }
 $91 = HEAP8[$_pre_phi] | 0; //@line 6191
 if (($91 & 8) == 0) {
  $175 = $91; //@line 6196
 } else {
  $95 = $91 & 255; //@line 6198
  $101 = ((HEAP8[$iwm + 1 | 0] | 0) != 0 ? 4 : 0) | $95 & 3; //@line 6204
  $102 = $95 & 4; //@line 6205
  $103 = ($102 | 0) != 0; //@line 6206
  $_lobit_i = $102 >>> 2; //@line 6207
  $105 = HEAP32[$iwm + 312 >> 2] | 0; //@line 6209
  do {
   if (($101 | 0) == 0) {
    HEAP8[$105 + 32 | 0] = ($_lobit_i ^ 1) & 255; //@line 6215
   } else if (($101 | 0) == 1) {
    if (($_lobit_i | 0) != 0) {
     break;
    }
    $116 = $105 + 40 | 0; //@line 6226
    $117 = HEAP32[$116 >> 2] | 0; //@line 6227
    do {
     if ((HEAP8[$105 + 32 | 0] | 0) == 0) {
      if (($117 | 0) == 0) {
       $128 = 0; //@line 6234
       break;
      }
      $121 = $117 - 1 | 0; //@line 6237
      HEAP32[$116 >> 2] = $121; //@line 6238
      $128 = $121; //@line 6240
     } else {
      $123 = $117 + 1 | 0; //@line 6242
      if ($123 >>> 0 >= (HEAP32[$105 + 24 >> 2] | 0) >>> 0) {
       $128 = $117; //@line 6248
       break;
      }
      HEAP32[$116 >> 2] = $123; //@line 6251
      $128 = $123; //@line 6253
     }
    } while (0);
    HEAP8[$105 + 33 | 0] = 1; //@line 6258
    _iwm_drv_select_track($105, $128, HEAP32[$105 + 44 >> 2] | 0); //@line 6261
    $135 = HEAP32[$116 >> 2] | 0; //@line 6265
    _pce_printf(51536, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = (HEAP32[$105 >> 2] | 0) + 1, HEAP32[tempInt + 8 >> 2] = $135, tempInt) | 0); //@line 6266
   } else if (($101 | 0) == 2) {
    $137 = $105 + 36 | 0; //@line 6269
    $140 = $_lobit_i ^ 1; //@line 6272
    if ((HEAP8[$137] | 0) == ($140 | 0)) {
     $i_0_i_i = 0; //@line 6276
    } else {
     HEAP8[$137] = $140 & 255; //@line 6279
     $i_0_i_i = 0; //@line 6281
    }
    while (1) {
     if ($i_0_i_i >>> 0 >= 3) {
      $v_0_i_i = 0; //@line 6288
      break;
     }
     if ((HEAP8[$iwm + 24 + ($i_0_i_i * 96 | 0) + 36 | 0] | 0) == 0) {
      $i_0_i_i = $i_0_i_i + 1 | 0; //@line 6297
     } else {
      $v_0_i_i = 1; //@line 6299
      break;
     }
    }
    $151 = $iwm + 316 | 0; //@line 6304
    if ((HEAP8[$151] | 0) == $v_0_i_i << 24 >> 24) {
     break;
    }
    HEAP8[$151] = $v_0_i_i; //@line 6311
    $156 = HEAP32[$iwm + 324 >> 2] | 0; //@line 6313
    if (($156 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$156 & 511](HEAP32[$iwm + 320 >> 2] | 0, $v_0_i_i); //@line 6321
   } else if (($101 | 0) == 3) {
    if (!$103) {
     break;
    }
    HEAP8[$105 + 34 | 0] = 0; //@line 6329
    _mac_log_deb(31392, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$105 >> 2] | 0) + 1, tempInt) | 0); //@line 6333
    if ((HEAP8[$105 + 92 | 0] | 0) == 0) {
     break;
    }
    _iwm_drv_save($105) | 0; //@line 6341
   } else if (($101 | 0) == 4) {
    if (!$103) {
     break;
    }
    HEAP8[$105 + 35 | 0] = 0; //@line 6349
   }
  } while (0);
  $175 = HEAP8[$_pre_phi] | 0; //@line 6354
 }
 if ($175 << 24 >> 24 <= -1) {
  STACKTOP = sp; //@line 6360
  return;
 }
 $178 = $iwm + 5 | 0; //@line 6363
 HEAP8[$178] = HEAP8[$178] | 64; //@line 6366
 $181 = $iwm + 6 | 0; //@line 6367
 if ((HEAP8[$181] | 0) == 0) {
  STACKTOP = sp; //@line 6372
  return;
 }
 HEAP8[$181] = 0; //@line 6375
 $186 = HEAP32[$iwm + 312 >> 2] | 0; //@line 6377
 $187 = $186 + 76 | 0; //@line 6378
 do {
  if ((HEAP32[$187 >> 2] | 0) >>> 0 > (HEAP32[$186 + 56 >> 2] | 0) >>> 0) {
   if ((HEAP8[$186 + 22 | 0] | 0) == 0) {
    break;
   }
   $198 = HEAP32[$186 + 48 >> 2] | 0; //@line 6394
   $199 = $186 + 52 | 0; //@line 6395
   $200 = HEAP32[$199 >> 2] | 0; //@line 6396
   _pri_trk_rotate($198, $200) | 0; //@line 6397
   HEAP32[$199 >> 2] = 0; //@line 6398
  }
 } while (0);
 HEAP32[$187 >> 2] = 0; //@line 6402
 STACKTOP = sp; //@line 6404
 return;
}
function _mac_iwm_set_uint8($iwm, $addr, $val) {
 $iwm = $iwm | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $8 = 0, $14 = 0;
 if (($addr & 1 | 0) == 0) {
  return;
 }
 _mac_iwm_access_uint8($iwm, $addr >>> 9 & 15); //@line 6427
 $8 = HEAPU8[$iwm | 0] | 0; //@line 6430
 if (($8 & 192 | 0) != 192) {
  return;
 }
 if (($8 & 16 | 0) == 0) {
  HEAP8[$iwm + 4 | 0] = $val; //@line 6443
  return;
 }
 $14 = $iwm + 6 | 0; //@line 6447
 if ((HEAP8[$14] | 0) == 0) {
  HEAP8[$14] = 1; //@line 6452
  HEAP32[$iwm + 8 >> 2] = 0; //@line 6454
  HEAP32[(HEAP32[$iwm + 312 >> 2] | 0) + 76 >> 2] = 0; //@line 6458
 }
 HEAP16[$iwm + 14 >> 1] = $val & 255 | -256; //@line 6464
 return;
}
function _mac_iwm_clock($iwm, $cnt) {
 $iwm = $iwm | 0;
 $cnt = $cnt | 0;
 var $2 = 0, $7 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $19 = 0, $storemerge = 0, $26 = 0, $28 = 0, $31 = 0, $33 = 0, $38 = 0, $42 = 0, $43 = 0, $47 = 0, $48 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $m_0_ph_i = 0, $p_0_ph_i = 0, $62 = 0, $64 = 0, $m_0_i = 0, $71 = 0, $74 = 0, $85 = 0, $86 = 0, $89 = 0, $91 = 0, $storemerge_i = 0, $106 = 0, $123 = 0, $127 = 0, $128 = 0, $130 = 0, $131 = 0, $138 = 0, $139 = 0, $140 = 0, $142 = 0, $p_026_i = 0, $m_025_i = 0, $143 = 0, $147 = 0, $153 = 0, $159 = 0, $170 = 0, $m_1_i = 0, $p_1_i = 0, $171 = 0, $174 = 0, $175 = 0, $179 = 0, label = 0;
 $2 = HEAP32[$iwm + 312 >> 2] | 0; //@line 6497
 if ((HEAP8[$2 + 36 | 0] | 0) == 0) {
  return;
 }
 $7 = $2 + 84 | 0; //@line 6506
 $10 = (HEAP32[$7 >> 2] | 0) + ($cnt * 5e5 | 0) | 0; //@line 6509
 $12 = HEAP32[$2 + 80 >> 2] | 0; //@line 6511
 $13 = ($10 >>> 0) / ($12 >>> 0) | 0; //@line 6512
 HEAP32[$7 >> 2] = ($10 >>> 0) % ($12 >>> 0) | 0; //@line 6514
 $15 = $2 + 56 | 0; //@line 6515
 $16 = HEAP32[$15 >> 2] | 0; //@line 6516
 if (($16 | 0) == 0) {
  $26 = 0; //@line 6520
 } else {
  $19 = $2 + 52 | 0; //@line 6522
  $storemerge = (HEAP32[$19 >> 2] | 0) + $13 | 0; //@line 6526
  while (1) {
   if ($storemerge >>> 0 < $16 >>> 0) {
    break;
   } else {
    $storemerge = $storemerge - $16 | 0; //@line 6535
   }
  }
  HEAP32[$19 >> 2] = $storemerge; //@line 6538
  $26 = $16; //@line 6539
 }
 $28 = HEAP32[$2 + 64 >> 2] | 0; //@line 6543
 do {
  if (($28 | 0) != 0) {
   $31 = $2 + 60 | 0; //@line 6548
   $33 = (HEAP32[$31 >> 2] | 0) + $13 | 0; //@line 6550
   HEAP32[$31 >> 2] = $33; //@line 6551
   if ($33 >>> 0 < $28 >>> 0) {
    break;
   }
   HEAP32[$31 >> 2] = $33 - $28; //@line 6558
  }
 } while (0);
 $38 = $iwm + 6 | 0; //@line 6562
 L1061 : do {
  if ((HEAP8[$38] | 0) == 0) {
   if ((HEAPU8[$iwm | 0] | 0) >= 64) {
    break;
   }
   $123 = HEAP32[$2 + 48 >> 2] | 0; //@line 6576
   if (($123 | 0) == 0 | ($26 | 0) == 0) {
    break;
   }
   $127 = $2 + 68 | 0; //@line 6584
   $128 = HEAP32[$127 >> 2] | 0; //@line 6585
   $130 = HEAP32[$123 + 8 >> 2] | 0; //@line 6587
   $131 = $2 + 52 | 0; //@line 6588
   if (($128 | 0) == (HEAP32[$131 >> 2] | 0)) {
    break;
   }
   $138 = $iwm + 12 | 0; //@line 6599
   $139 = $iwm + 16 | 0; //@line 6600
   $140 = $iwm + 13 | 0; //@line 6601
   $m_025_i = 128 >>> (($128 & 7) >>> 0) & 255;
   $p_026_i = $128 >>> 3;
   $142 = HEAP8[$138] | 0;
   while (1) {
    $143 = $142 << 1; //@line 6609
    $147 = (HEAP8[$130 + $p_026_i | 0] & $m_025_i) << 24 >> 24 != 0; //@line 6613
    HEAP8[$138] = $147 & 1 | $143; //@line 6616
    do {
     if ($147) {
      HEAP32[$139 >> 2] = 0; //@line 6620
     } else {
      $153 = (HEAP32[$139 >> 2] | 0) + 1 | 0; //@line 6624
      HEAP32[$139 >> 2] = $153; //@line 6625
      if ($153 >>> 0 <= 7) {
       break;
      }
      HEAP32[$139 >> 2] = 0; //@line 6631
      HEAP8[$138] = $143 | 1; //@line 6633
     }
    } while (0);
    $159 = (HEAP32[$127 >> 2] | 0) + 1 | 0; //@line 6638
    HEAP32[$127 >> 2] = $159; //@line 6639
    do {
     if ($159 >>> 0 < (HEAP32[$15 >> 2] | 0) >>> 0) {
      if ($m_025_i << 24 >> 24 == 1) {
       $p_1_i = $p_026_i + 1 | 0;
       $m_1_i = -128;
       $170 = $159;
       break;
      } else {
       $p_1_i = $p_026_i;
       $m_1_i = ($m_025_i & 255) >>> 1;
       $170 = $159;
       break;
      }
     } else {
      HEAP32[$127 >> 2] = 0; //@line 6658
      $p_1_i = 0;
      $m_1_i = -128;
      $170 = 0;
     }
    } while (0);
    $171 = HEAP8[$138] | 0; //@line 6666
    if ($171 << 24 >> 24 < 0) {
     HEAP8[$140] = $171; //@line 6670
     HEAP8[$138] = 0; //@line 6671
     $175 = 0;
     $174 = HEAP32[$127 >> 2] | 0;
    } else {
     $175 = $171;
     $174 = $170;
    }
    if (($174 | 0) == (HEAP32[$131 >> 2] | 0)) {
     break;
    } else {
     $m_025_i = $m_1_i;
     $p_026_i = $p_1_i;
     $142 = $175;
    }
   }
  } else {
   $42 = $2 + 48 | 0; //@line 6690
   $43 = HEAP32[$42 >> 2] | 0; //@line 6691
   if (($43 | 0) == 0 | ($26 | 0) == 0) {
    break;
   }
   $47 = $2 + 72 | 0; //@line 6699
   $48 = HEAP32[$47 >> 2] | 0; //@line 6700
   $54 = HEAP32[$43 + 8 >> 2] | 0; //@line 6706
   $55 = $2 + 52 | 0; //@line 6707
   $56 = $iwm + 8 | 0; //@line 6708
   $57 = $iwm + 14 | 0; //@line 6709
   $58 = $iwm + 12 | 0; //@line 6710
   $59 = $2 + 92 | 0; //@line 6711
   $60 = $2 + 76 | 0; //@line 6712
   $p_0_ph_i = $48 >>> 3;
   $m_0_ph_i = 128 >>> (($48 & 7) >>> 0) & 255;
   $61 = $48;
   L1064 : while (1) {
    $62 = $54 + $p_0_ph_i | 0; //@line 6719
    $m_0_i = $m_0_ph_i;
    $64 = $61;
    while (1) {
     if (($64 | 0) == (HEAP32[$55 >> 2] | 0)) {
      break L1061;
     }
     if ((HEAP32[$56 >> 2] | 0) == 0) {
      $71 = HEAP16[$57 >> 1] | 0; //@line 6734
      if (($71 & 65535) < 256) {
       break L1064;
      }
      $89 = $71 & 255; //@line 6740
      HEAP8[$58] = $89; //@line 6741
      HEAP32[$56 >> 2] = 8; //@line 6742
      HEAP16[$57 >> 1] = 0; //@line 6743
      $91 = $89; //@line 6745
     } else {
      $91 = HEAP8[$58] | 0; //@line 6749
     }
     if ($91 << 24 >> 24 < 0) {
      $storemerge_i = HEAP8[$62] | $m_0_i; //@line 6758
     } else {
      $storemerge_i = HEAP8[$62] & ~$m_0_i; //@line 6763
     }
     HEAP8[$62] = $storemerge_i; //@line 6766
     HEAP8[$59] = 1; //@line 6767
     HEAP8[$58] = HEAP8[$58] << 1; //@line 6770
     HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) - 1; //@line 6773
     $106 = (HEAP32[$47 >> 2] | 0) + 1 | 0; //@line 6775
     HEAP32[$47 >> 2] = $106; //@line 6776
     HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 1; //@line 6779
     if ($106 >>> 0 >= (HEAP32[$15 >> 2] | 0) >>> 0) {
      label = 854; //@line 6784
      break;
     }
     if ($m_0_i << 24 >> 24 == 1) {
      label = 857; //@line 6790
      break;
     }
     $m_0_i = ($m_0_i & 255) >>> 1;
     $64 = $106;
    }
    if ((label | 0) == 854) {
     label = 0; //@line 6798
     HEAP32[$47 >> 2] = 0; //@line 6799
     $p_0_ph_i = 0;
     $m_0_ph_i = -128;
     $61 = 0;
     continue;
    } else if ((label | 0) == 857) {
     label = 0; //@line 6805
     $p_0_ph_i = $p_0_ph_i + 1 | 0;
     $m_0_ph_i = -128;
     $61 = $106;
     continue;
    }
   }
   $74 = $iwm + 5 | 0; //@line 6812
   HEAP8[$74] = HEAP8[$74] & -65; //@line 6815
   HEAP32[$56 >> 2] = 0; //@line 6816
   HEAP8[$38] = 0; //@line 6817
   do {
    if ((HEAP32[$60 >> 2] | 0) >>> 0 > (HEAP32[$15 >> 2] | 0) >>> 0) {
     if ((HEAP8[$2 + 22 | 0] | 0) == 0) {
      break;
     }
     $85 = HEAP32[$42 >> 2] | 0; //@line 6831
     $86 = HEAP32[$55 >> 2] | 0; //@line 6832
     _pri_trk_rotate($85, $86) | 0; //@line 6833
     HEAP32[$55 >> 2] = 0; //@line 6834
    }
   } while (0);
   HEAP32[$60 >> 2] = 0; //@line 6838
  }
 } while (0);
 $179 = HEAP32[$2 + 52 >> 2] | 0; //@line 6843
 HEAP32[$2 + 68 >> 2] = $179; //@line 6845
 HEAP32[$2 + 72 >> 2] = $179; //@line 6847
 return;
}
function _mac_kbd_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(304) | 0; //@line 6859
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 6863
  return $_0 | 0; //@line 6866
 }
 HEAP8[$1 + 264 | 0] = 0; //@line 6871
 HEAP32[$1 >> 2] = 0; //@line 6874
 HEAP32[$1 + 4 >> 2] = 0; //@line 6877
 _memset($1 + 268 | 0, 0, 13); //@line 6880
 _memset($1 + 288 | 0, 0, 16); //@line 6881
 HEAP32[$1 + 284 >> 2] = 10848; //@line 6882
 $_0 = $1; //@line 6884
 return $_0 | 0; //@line 6887
}
function _mac_kbd_set_keypad_mode($kbd, $motion) {
 $kbd = $kbd | 0;
 $motion = $motion | 0;
 var $3 = 0, $5 = 0, $7 = 0, $8 = 0, $tmp_0_i = 0, $11 = 0, $17 = 0, $18 = 0, $24 = 0, $26 = 0, $27 = 0, $tmp_0_i5 = 0, $30 = 0, $36 = 0, $37 = 0, label = 0;
 $3 = HEAP32[$kbd + 284 >> 2] | 0; //@line 6903
 if (($motion | 0) == 0) {
  $24 = HEAP32[3750] | 0; //@line 6906
  if (($24 | 0) != 0) {
   $27 = 15e3;
   $26 = $24;
   do {
    $tmp_0_i5 = $3; //@line 6915
    while (1) {
     $30 = HEAP32[$tmp_0_i5 >> 2] | 0; //@line 6919
     if (($30 | 0) == 0) {
      break;
     }
     if (($30 | 0) == ($26 | 0)) {
      label = 895; //@line 6929
      break;
     } else {
      $tmp_0_i5 = $tmp_0_i5 + 24 | 0; //@line 6932
     }
    }
    if ((label | 0) == 895) {
     label = 0; //@line 6936
     $36 = $tmp_0_i5; //@line 6937
     $37 = $27; //@line 6938
     HEAP32[$36 >> 2] = HEAP32[$37 >> 2]; //@line 6939
     HEAP32[$36 + 4 >> 2] = HEAP32[$37 + 4 >> 2]; //@line 6939
     HEAP32[$36 + 8 >> 2] = HEAP32[$37 + 8 >> 2]; //@line 6939
     HEAP32[$36 + 12 >> 2] = HEAP32[$37 + 12 >> 2]; //@line 6939
     HEAP32[$36 + 16 >> 2] = HEAP32[$37 + 16 >> 2]; //@line 6939
     HEAP32[$36 + 20 >> 2] = HEAP32[$37 + 20 >> 2]; //@line 6939
    }
    $27 = $27 + 24 | 0; //@line 6942
    $26 = HEAP32[$27 >> 2] | 0; //@line 6943
   } while (($26 | 0) != 0);
  }
  HEAP8[$kbd + 280 | 0] = 1; //@line 6954
  return;
 } else {
  $5 = HEAP32[3888] | 0; //@line 6958
  if (($5 | 0) != 0) {
   $8 = 15552;
   $7 = $5;
   do {
    $tmp_0_i = $3; //@line 6967
    while (1) {
     $11 = HEAP32[$tmp_0_i >> 2] | 0; //@line 6971
     if (($11 | 0) == 0) {
      break;
     }
     if (($11 | 0) == ($7 | 0)) {
      label = 888; //@line 6981
      break;
     } else {
      $tmp_0_i = $tmp_0_i + 24 | 0; //@line 6984
     }
    }
    if ((label | 0) == 888) {
     label = 0; //@line 6988
     $17 = $tmp_0_i; //@line 6989
     $18 = $8; //@line 6990
     HEAP32[$17 >> 2] = HEAP32[$18 >> 2]; //@line 6991
     HEAP32[$17 + 4 >> 2] = HEAP32[$18 + 4 >> 2]; //@line 6991
     HEAP32[$17 + 8 >> 2] = HEAP32[$18 + 8 >> 2]; //@line 6991
     HEAP32[$17 + 12 >> 2] = HEAP32[$18 + 12 >> 2]; //@line 6991
     HEAP32[$17 + 16 >> 2] = HEAP32[$18 + 16 >> 2]; //@line 6991
     HEAP32[$17 + 20 >> 2] = HEAP32[$18 + 20 >> 2]; //@line 6991
    }
    $8 = $8 + 24 | 0; //@line 6994
    $7 = HEAP32[$8 >> 2] | 0; //@line 6995
   } while (($7 | 0) != 0);
  }
  HEAP8[$kbd + 280 | 0] = 0; //@line 7006
  return;
 }
}
function _mac_kbd_set_data($kbd, $val) {
 $kbd = $kbd | 0;
 $val = $val | 0;
 HEAP8[$kbd + 264 | 0] = $val; //@line 7021
 return;
}
function _mac_kbd_set_key($kbd, $event, $key) {
 $kbd = $kbd | 0;
 $event = $event | 0;
 $key = $key | 0;
 var $_0 = 0, $map_0 = 0, $9 = 0, $10 = 0, $15 = 0, $21 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $i_05_i = 0, $37 = 0, $38 = 0, $39 = 0, $43 = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $i_05_i19 = 0, $59 = 0, $60 = 0, $61 = 0, sp = 0;
 sp = STACKTOP; //@line 7040
 if (($key | 0) == 2) {
  $_0 = 71; //@line 7044
 } else {
  $_0 = ($key | 0) == 3 ? 75 : $key; //@line 7049
 }
 $map_0 = HEAP32[$kbd + 284 >> 2] | 0; //@line 7055
 while (1) {
  $9 = HEAP32[$map_0 >> 2] | 0; //@line 7059
  $10 = ($9 | 0) == 0; //@line 7060
  if ($10 | ($9 | 0) == ($_0 | 0)) {
   break;
  } else {
   $map_0 = $map_0 + 24 | 0; //@line 7068
  }
 }
 if ($10) {
  $15 = _pce_key_to_string($_0) | 0; //@line 7073
  _pce_log(2, 31224, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $_0, HEAP32[tempInt + 8 >> 2] = ($15 | 0) != 0 ? $15 : 51488, tempInt) | 0); //@line 7076
  STACKTOP = sp; //@line 7078
  return;
 }
 if (($event | 0) == 1) {
  $21 = HEAP16[$map_0 + 4 >> 1] | 0; //@line 7083
  $22 = $21 & 65535; //@line 7084
  if ($21 << 16 >> 16 == 0) {
   STACKTOP = sp; //@line 7088
   return;
  }
  $24 = $kbd + 4 | 0; //@line 7091
  $25 = $kbd | 0; //@line 7092
  $i_05_i = 0;
  $27 = HEAP32[$24 >> 2] | 0;
  while (1) {
   if ($27 >>> 0 > 255) {
    $38 = $27; //@line 7102
   } else {
    HEAP8[((HEAP32[$25 >> 2] | 0) + $27 & 255) + ($kbd + 8) | 0] = HEAP8[$map_0 + 6 + $i_05_i | 0] | 0; //@line 7110
    $37 = (HEAP32[$24 >> 2] | 0) + 1 | 0; //@line 7112
    HEAP32[$24 >> 2] = $37; //@line 7113
    $38 = $37; //@line 7115
   }
   $39 = $i_05_i + 1 | 0; //@line 7118
   if ($39 >>> 0 < $22 >>> 0) {
    $i_05_i = $39;
    $27 = $38;
   } else {
    break;
   }
  }
  STACKTOP = sp; //@line 7127
  return;
 } else if (($event | 0) == 2) {
  $43 = HEAP16[$map_0 + 14 >> 1] | 0; //@line 7131
  $44 = $43 & 65535; //@line 7132
  if ($43 << 16 >> 16 == 0) {
   STACKTOP = sp; //@line 7136
   return;
  }
  $46 = $kbd + 4 | 0; //@line 7139
  $47 = $kbd | 0; //@line 7140
  $i_05_i19 = 0;
  $49 = HEAP32[$46 >> 2] | 0;
  while (1) {
   if ($49 >>> 0 > 255) {
    $60 = $49; //@line 7150
   } else {
    HEAP8[((HEAP32[$47 >> 2] | 0) + $49 & 255) + ($kbd + 8) | 0] = HEAP8[$map_0 + 16 + $i_05_i19 | 0] | 0; //@line 7158
    $59 = (HEAP32[$46 >> 2] | 0) + 1 | 0; //@line 7160
    HEAP32[$46 >> 2] = $59; //@line 7161
    $60 = $59; //@line 7163
   }
   $61 = $i_05_i19 + 1 | 0; //@line 7166
   if ($61 >>> 0 < $44 >>> 0) {
    $i_05_i19 = $61;
    $49 = $60;
   } else {
    break;
   }
  }
  STACKTOP = sp; //@line 7175
  return;
 } else {
  STACKTOP = sp; //@line 7178
  return;
 }
}
function _mac_kbd_set_uint8($kbd, $val) {
 $kbd = $kbd | 0;
 $val = $val | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 7190
 $1 = $val & 255; //@line 7191
 if (($1 | 0) == 20) {
  HEAP32[$kbd + 268 >> 2] = 0; //@line 7194
  HEAP32[$kbd + 272 >> 2] = 1; //@line 7196
  STACKTOP = sp; //@line 7198
  return;
 } else if (($1 | 0) == 22) {
  HEAP32[$kbd >> 2] = 0; //@line 7202
  HEAP32[$kbd + 4 >> 2] = 1; //@line 7204
  HEAP8[$kbd + 8 | 0] = (HEAP32[$kbd + 276 >> 2] << 1 & 14 | 1) & 255; //@line 7212
  HEAP32[$kbd + 268 >> 2] = 0; //@line 7214
  HEAP32[$kbd + 272 >> 2] = 1; //@line 7216
  STACKTOP = sp; //@line 7218
  return;
 } else if (($1 | 0) == 16) {
  HEAP32[$kbd + 268 >> 2] = 1958400; //@line 7222
  HEAP32[$kbd + 272 >> 2] = 1; //@line 7224
  STACKTOP = sp; //@line 7226
  return;
 } else {
  _mac_log_deb(47104, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $1, tempInt) | 0); //@line 7229
  STACKTOP = sp; //@line 7231
  return;
 }
}
function _mac_kbd_clock($kbd, $cnt) {
 $kbd = $kbd | 0;
 $cnt = $cnt | 0;
 var $5 = 0, $9 = 0, $10 = 0, $13 = 0, $15 = 0, $23 = 0, $30 = 0, $31 = 0, $37 = 0;
 if ((HEAP8[$kbd + 264 | 0] | 0) == 0) {
  return;
 }
 $5 = $kbd + 272 | 0; //@line 7255
 if ((HEAP32[$5 >> 2] | 0) == 0) {
  return;
 }
 $9 = $kbd + 4 | 0; //@line 7263
 $10 = HEAP32[$9 >> 2] | 0; //@line 7264
 if (($10 | 0) != 0) {
  $13 = $kbd | 0; //@line 7268
  $15 = HEAP32[$kbd + 292 >> 2] | 0; //@line 7270
  if (($15 | 0) == 0) {
   $23 = $10; //@line 7274
  } else {
   FUNCTION_TABLE_vii[$15 & 511](HEAP32[$kbd + 288 >> 2] | 0, HEAP8[(HEAP32[$13 >> 2] | 0) + ($kbd + 8) | 0] | 0); //@line 7281
   $23 = HEAP32[$9 >> 2] | 0; //@line 7284
  }
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 1 & 255; //@line 7290
  HEAP32[$9 >> 2] = $23 - 1; //@line 7292
  HEAP32[$5 >> 2] = 0; //@line 7293
  HEAP32[$kbd + 268 >> 2] = 0; //@line 7295
  return;
 }
 $30 = $kbd + 268 | 0; //@line 7300
 $31 = HEAP32[$30 >> 2] | 0; //@line 7301
 if ($31 >>> 0 > $cnt >>> 0) {
  HEAP32[$30 >> 2] = $31 - $cnt; //@line 7306
  return;
 }
 $37 = HEAP32[$kbd + 292 >> 2] | 0; //@line 7312
 if (($37 | 0) != 0) {
  FUNCTION_TABLE_vii[$37 & 511](HEAP32[$kbd + 288 >> 2] | 0, 123); //@line 7318
 }
 HEAP32[$5 >> 2] = 0; //@line 7321
 return;
}
function _mac_interrupt($sim, $level, $val) {
 $sim = $sim | 0;
 $level = $level | 0;
 $val = $val | 0;
 var $2 = 0, $4 = 0, $8 = 0, $11 = 0, $15 = 0, $17 = 0, $i_0_i = 0, $val_0_in_i = 0, $val_0_i = 0;
 $2 = 1 << $level; //@line 7337
 if (($val | 0) == 0) {
  $11 = $sim + 4652 | 0; //@line 7341
  $15 = (HEAPU8[$11] | 0) & ($2 ^ 255) & 255; //@line 7345
  HEAP8[$11] = $15; //@line 7346
  $17 = $15; //@line 7347
 } else {
  $4 = $sim + 4652 | 0; //@line 7349
  $8 = (HEAPU8[$4] | 0 | $2) & 255; //@line 7353
  HEAP8[$4] = $8; //@line 7354
  $17 = $8; //@line 7356
 }
 $val_0_in_i = $17 & 255;
 $i_0_i = 0;
 while (1) {
  $val_0_i = $val_0_in_i >>> 1; //@line 7365
  if (($val_0_i | 0) == 0) {
   break;
  } else {
   $val_0_in_i = $val_0_i;
   $i_0_i = $i_0_i + 1 | 0;
  }
 }
 _e68_interrupt(HEAP32[$sim + 4 >> 2] | 0, $i_0_i); //@line 7377
 return;
}
function _mac_interrupt_osi($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $9 = 0, $10 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $29 = 0, $57 = 0;
 if ($val << 24 >> 24 == 0) {
  return;
 }
 do {
  if ((_mac_sony_check($ext + 2424 | 0) | 0) != 0) {
   $9 = $ext + 4 | 0; //@line 7409
   $10 = HEAP32[$9 >> 2] | 0; //@line 7410
   if ((HEAP16[$10 + 166 >> 1] & 1792) == 1792) {
    break;
   }
   $18 = (HEAP32[$10 + 148 >> 2] | 0) - 4 | 0; //@line 7421
   $20 = HEAP32[$10 + 152 >> 2] | 0; //@line 7423
   $21 = $18 & 16777215; //@line 7424
   $22 = $21 + 3 | 0; //@line 7425
   if ($22 >>> 0 < (HEAP32[$10 + 36 >> 2] | 0) >>> 0) {
    $29 = $10 + 32 | 0; //@line 7433
    HEAP8[(HEAP32[$29 >> 2] | 0) + $21 | 0] = $20 >>> 24 & 255; //@line 7436
    HEAP8[(HEAP32[$29 >> 2] | 0) + ($21 + 1) | 0] = $20 >>> 16 & 255; //@line 7442
    HEAP8[(HEAP32[$29 >> 2] | 0) + ($21 + 2) | 0] = $20 >>> 8 & 255; //@line 7448
    HEAP8[(HEAP32[$29 >> 2] | 0) + $22 | 0] = $20 & 255; //@line 7452
   } else {
    FUNCTION_TABLE_viii[HEAP32[$10 + 28 >> 2] & 63](HEAP32[$10 + 4 >> 2] | 0, $21, $20); //@line 7459
   }
   HEAP32[(HEAP32[$9 >> 2] | 0) + 148 >> 2] = $18; //@line 7463
   _e68_set_pc_prefetch(HEAP32[$9 >> 2] | 0, HEAP32[$ext + 2468 >> 2] | 0); //@line 7468
  }
 } while (0);
 $57 = $ext + 36 | 0; //@line 7473
 _e6522_set_ca2_inp($57, 0); //@line 7474
 _e6522_set_ca2_inp($57, 1); //@line 7475
 return;
}
function _mac_init($sim, $ini) {
 $sim = $sim | 0;
 $ini = $ini | 0;
 var $addr2_i = 0, $w_i = 0, $h_i = 0, $bright_i = 0, $col0_i = 0, $col1_i = 0, $addr_i70 = 0, $freq_i = 0, $driver_i71 = 0, $format_hd_as_dd_i = 0, $var_i = 0, $def_i = 0, $val_i = 0, $addr_i66 = 0, $size_i67 = 0, $id_i = 0, $drive_i68 = 0, $vendor_i = 0, $product_i = 0, $single_i = 0, $locked_i = 0, $rotate_i = 0, $inserted_i = 0, $drive_i = 0, $disk_i = 0, $fname_i64 = 0, $mouse_i = 0, $keyboard_i = 0, $motion_i63 = 0, $model_i62 = 0, $intl_i = 0, $motion_i = 0, $fname_i = 0, $start_i = 0, $realtime_i = 0, $romdisk_i = 0, $port_i = 0, $multichar_i = 0, $driver_i = 0, $addr_i60 = 0, $size_i61 = 0, $addr_i = 0, $size_i = 0, $model_i59 = 0, $speed_i = 0, $memtest_i = 0, $model_i = 0, $1 = 0, $2 = 0, $8 = 0, $10 = 0, $11 = 0, $17 = 0, $21 = 0, $39 = 0, $40 = 0, $41 = 0, $43 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $61 = 0, $69 = 0, $76 = 0, $88 = 0, $92 = 0, $93 = 0, $94 = 0, $109 = 0, $112 = 0, $116 = 0, $117 = 0, $120 = 0, $127 = 0, $131 = 0, $132 = 0, $135 = 0, $142 = 0, $143 = 0, $144 = 0, $sct_014_i = 0, $150 = 0, $151 = 0, $155 = 0, $160 = 0, $161 = 0, $174 = 0, $180 = 0, $181 = 0, $184 = 0, $188 = 0, $203 = 0, $210 = 0, $211 = 0, $216 = 0, $221 = 0, $224 = 0, $225 = 0, $228 = 0, $229 = 0, $243 = 0, $244 = 0, $245 = 0, $250 = 0, $254 = 0, $258 = 0, $264 = 0, $267 = 0, $268 = 0, $277 = 0, $281 = 0, $283 = 0, $286 = 0, $294 = 0, $295 = 0, $297 = 0, $sctdev_022_i = 0, $n_021_i = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $351 = 0, $357 = 0, $358 = 0, $362 = 0, $367 = 0, $sctdev_020_i = 0, $374 = 0, $375 = 0, $376 = 0, $386 = 0, $389 = 0, $392 = 0, $405 = 0, $408 = 0, $411 = 0, $412 = 0, $417 = 0, $420 = 0, $423 = 0, $424 = 0, $429 = 0, $432 = 0, $435 = 0, $436 = 0, $441 = 0, $444 = 0, $446 = 0, $447 = 0, $451 = 0, $455 = 0, $457 = 0, $__i = 0, $464 = 0, $465 = 0, $468 = 0, $469 = 0, $473 = 0, $477 = 0, $485 = 0, $499 = 0, $501 = 0, $__i72 = 0, $511 = 0, $512 = 0, $514 = 0, $515 = 0, $516 = 0, $527 = 0, $531 = 0, $535 = 0, $i_031_i = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, sp = 0;
 sp = STACKTOP; //@line 7556
 STACKTOP = STACKTOP + 400 | 0; //@line 7556
 $addr2_i = sp | 0; //@line 7557
 $w_i = sp + 8 | 0; //@line 7558
 $h_i = sp + 16 | 0; //@line 7559
 $bright_i = sp + 24 | 0; //@line 7560
 $col0_i = sp + 32 | 0; //@line 7561
 $col1_i = sp + 40 | 0; //@line 7562
 $addr_i70 = sp + 48 | 0; //@line 7563
 $freq_i = sp + 56 | 0; //@line 7564
 $driver_i71 = sp + 64 | 0; //@line 7565
 $format_hd_as_dd_i = sp + 72 | 0; //@line 7566
 $var_i = sp + 80 | 0; //@line 7567
 $def_i = sp + 112 | 0; //@line 7568
 $val_i = sp + 120 | 0; //@line 7569
 $addr_i66 = sp + 128 | 0; //@line 7570
 $size_i67 = sp + 136 | 0; //@line 7571
 $id_i = sp + 144 | 0; //@line 7572
 $drive_i68 = sp + 152 | 0; //@line 7573
 $vendor_i = sp + 160 | 0; //@line 7574
 $product_i = sp + 168 | 0; //@line 7575
 $single_i = sp + 176 | 0; //@line 7576
 $locked_i = sp + 184 | 0; //@line 7577
 $rotate_i = sp + 192 | 0; //@line 7578
 $inserted_i = sp + 200 | 0; //@line 7579
 $drive_i = sp + 208 | 0; //@line 7580
 $disk_i = sp + 216 | 0; //@line 7581
 $fname_i64 = sp + 224 | 0; //@line 7582
 $mouse_i = sp + 232 | 0; //@line 7583
 $keyboard_i = sp + 240 | 0; //@line 7584
 $motion_i63 = sp + 248 | 0; //@line 7585
 $model_i62 = sp + 256 | 0; //@line 7586
 $intl_i = sp + 264 | 0; //@line 7587
 $motion_i = sp + 272 | 0; //@line 7588
 $fname_i = sp + 280 | 0; //@line 7589
 $start_i = sp + 288 | 0; //@line 7590
 $realtime_i = sp + 296 | 0; //@line 7591
 $romdisk_i = sp + 304 | 0; //@line 7592
 $port_i = sp + 312 | 0; //@line 7593
 $multichar_i = sp + 320 | 0; //@line 7594
 $driver_i = sp + 328 | 0; //@line 7595
 $addr_i60 = sp + 336 | 0; //@line 7596
 $size_i61 = sp + 344 | 0; //@line 7597
 $addr_i = sp + 352 | 0; //@line 7598
 $size_i = sp + 360 | 0; //@line 7599
 $model_i59 = sp + 368 | 0; //@line 7600
 $speed_i = sp + 376 | 0; //@line 7601
 $memtest_i = sp + 384 | 0; //@line 7602
 $model_i = sp + 392 | 0; //@line 7603
 $1 = $sim + 3480 | 0; //@line 7604
 HEAP32[$1 >> 2] = 0; //@line 7605
 $2 = $sim + 3476 | 0; //@line 7606
 HEAP32[$2 >> 2] = 0; //@line 7607
 HEAP32[$sim + 4632 >> 2] = 0; //@line 7609
 HEAP8[$sim + 4652 | 0] = 0; //@line 7612
 HEAP8[$sim + 4676 | 0] = 0; //@line 7614
 HEAP32[$sim + 4680 >> 2] = 0; //@line 7616
 $8 = $sim + 4684 | 0; //@line 7617
 _memset($sim + 4656 | 0, 0, 14); //@line 7619
 HEAP32[$8 >> 2] = 1; //@line 7620
 $10 = $sim + 4688 | 0; //@line 7621
 HEAP32[$10 >> 2] = 1; //@line 7622
 $11 = $sim + 4696 | 0; //@line 7623
 HEAP32[$11 >> 2] = 0; //@line 7624
 HEAP32[$sim + 4692 >> 2] = 0; //@line 7626
 _memset($sim + 4712 | 0, 0, 24); //@line 7630
 _bps_init($sim + 28 | 0); //@line 7631
 $17 = _ini_next_sct($ini, 0, 57648) | 0; //@line 7633
 _ini_get_string(($17 | 0) == 0 ? $ini : $17, 35104, $model_i, 57584) | 0; //@line 7636
 _pce_log_tag(2, 57552, 57496, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$model_i >> 2], tempInt) | 0); //@line 7638
 $21 = HEAP32[$model_i >> 2] | 0; //@line 7639
 do {
  if ((_strcmp($21 | 0, 57584) | 0) == 0) {
   HEAP32[$sim >> 2] = 1; //@line 7646
  } else {
   if ((_strcmp($21 | 0, 57440) | 0) == 0) {
    HEAP32[$sim >> 2] = 2; //@line 7654
    break;
   }
   if ((_strcmp($21 | 0, 57392) | 0) == 0) {
    HEAP32[$sim >> 2] = 4; //@line 7663
    break;
   } else {
    _pce_log(0, 57328, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $21, tempInt) | 0); //@line 7667
    HEAP32[$sim >> 2] = 1; //@line 7669
    break;
   }
  }
 } while (0);
 $39 = _mem_new() | 0; //@line 7675
 $40 = $sim + 8 | 0; //@line 7676
 HEAP32[$40 >> 2] = $39; //@line 7677
 $41 = $sim; //@line 7678
 _mem_set_fct($39, $41, 24, 2, 18, 4, 38, 10); //@line 7679
 $43 = $sim + 12 | 0; //@line 7681
 _ini_get_ram(HEAP32[$40 >> 2] | 0, $ini, $43) | 0; //@line 7682
 _ini_get_rom(HEAP32[$40 >> 2] | 0, $ini) | 0; //@line 7684
 HEAP32[$43 >> 2] = _mem_get_blk(HEAP32[$40 >> 2] | 0, 0) | 0; //@line 7687
 $50 = _mem_get_blk(HEAP32[$40 >> 2] | 0, 4194304) | 0; //@line 7689
 $51 = $sim + 16 | 0; //@line 7690
 HEAP32[$51 >> 2] = $50; //@line 7691
 $52 = $sim + 20 | 0; //@line 7692
 HEAP32[$52 >> 2] = 0; //@line 7693
 $53 = $sim + 24 | 0; //@line 7694
 HEAP32[$53 >> 2] = 0; //@line 7695
 $54 = HEAP32[$43 >> 2] | 0; //@line 7696
 do {
  if (($54 | 0) == 0) {
   _pce_log(0, 30144, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 7701
  } else {
   if (($50 | 0) == 0) {
    _pce_log(0, 58120, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 7707
    break;
   }
   $61 = _mem_blk_clone($54) | 0; //@line 7711
   HEAP32[$52 >> 2] = $61; //@line 7712
   _mem_blk_set_addr($61, 6291456); //@line 7713
   if ((_mem_blk_get_size(HEAP32[$52 >> 2] | 0) | 0) >>> 0 > 2097152) {
    _mem_blk_set_size(HEAP32[$52 >> 2] | 0, 2097152); //@line 7720
   }
   $69 = _mem_blk_clone(HEAP32[$51 >> 2] | 0) | 0; //@line 7724
   HEAP32[$53 >> 2] = $69; //@line 7725
   _mem_blk_set_addr($69, 0); //@line 7726
   HEAP32[$sim + 4628 >> 2] = 0; //@line 7728
   _ini_get_bool($ini, 58072, $memtest_i, 1) | 0; //@line 7729
   if ((HEAP32[$memtest_i >> 2] | 0) != 0) {
    break;
   }
   _pce_log_tag(2, 57880, 57744, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 7736
   $76 = HEAP32[$sim >> 2] | 0; //@line 7738
   if (($76 & 1 | 0) != 0) {
    _mem_set_uint32_be(HEAP32[$40 >> 2] | 0, 686, 4194304); //@line 7744
    break;
   }
   if (($76 & 6 | 0) == 0) {
    break;
   }
   _mem_set_uint32_be(HEAP32[$40 >> 2] | 0, 3324, 1464619843); //@line 7755
  }
 } while (0);
 $88 = _ini_next_sct($ini, 0, 30440) | 0; //@line 7761
 _ini_get_string($88, 35104, $model_i59, 43472) | 0; //@line 7762
 _ini_get_uint16($88, 30392, $speed_i, 0) | 0; //@line 7763
 $92 = HEAP32[$speed_i >> 2] | 0; //@line 7765
 _pce_log_tag(2, 30352, 30288, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$model_i59 >> 2], HEAP32[tempInt + 8 >> 2] = $92, tempInt) | 0); //@line 7766
 $93 = _e68_new() | 0; //@line 7767
 $94 = $sim + 4 | 0; //@line 7768
 HEAP32[$94 >> 2] = $93; //@line 7769
 if (($93 | 0) != 0) {
  if ((_mac_set_cpu_model($sim, HEAP32[$model_i59 >> 2] | 0) | 0) != 0) {
   _pce_log(0, 30208, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$model_i59 >> 2], tempInt) | 0); //@line 7779
  }
  _e68_set_mem_fct(HEAP32[$94 >> 2] | 0, HEAP32[$40 >> 2] | 0, 26, 12, 22, 12, 22, 16); //@line 7785
  _e68_set_reset_fct(HEAP32[$94 >> 2] | 0, $41, 184); //@line 7787
  _e68_set_hook_fct(HEAP32[$94 >> 2] | 0, $41, 36); //@line 7789
  _e68_set_address_check(HEAP32[$94 >> 2] | 0, 0); //@line 7791
  $109 = HEAP32[$speed_i >> 2] | 0; //@line 7792
  HEAP32[$8 >> 2] = $109; //@line 7793
  HEAP32[$10 >> 2] = $109; //@line 7794
 }
 $112 = _ini_next_sct($ini, 0, 31136) | 0; //@line 7799
 _ini_get_uint32($112, 58056, $addr_i, 15720448) | 0; //@line 7800
 _ini_get_uint32($112, 45112, $size_i, 8192) | 0; //@line 7801
 $116 = HEAP32[$size_i >> 2] | 0; //@line 7803
 _pce_log_tag(2, 31096, 44440, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$addr_i >> 2], HEAP32[tempInt + 8 >> 2] = $116, tempInt) | 0); //@line 7804
 $117 = $sim + 36 | 0; //@line 7805
 _e6522_init($117, 9); //@line 7806
 _e6522_set_irq_fct($117, $41, 238); //@line 7807
 _e6522_set_ora_fct($117, $41, 288); //@line 7808
 _e6522_set_orb_fct($117, $41, 290); //@line 7809
 $120 = _mem_blk_new(HEAP32[$addr_i >> 2] | 0, HEAP32[$size_i >> 2] | 0, 0) | 0; //@line 7812
 if (($120 | 0) != 0) {
  _mem_blk_set_fct($120, $117, 4, 32, 10, 24, 2, 18); //@line 7817
  _mem_add_blk(HEAP32[$40 >> 2] | 0, $120, 1); //@line 7819
 }
 $127 = _ini_next_sct($ini, 0, 31216) | 0; //@line 7824
 _ini_get_uint32($127, 58056, $addr_i60, 8388608) | 0; //@line 7825
 _ini_get_uint32($127, 45112, $size_i61, 4194304) | 0; //@line 7826
 $131 = HEAP32[$size_i61 >> 2] | 0; //@line 7828
 _pce_log_tag(2, 31184, 44440, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$addr_i60 >> 2], HEAP32[tempInt + 8 >> 2] = $131, tempInt) | 0); //@line 7829
 $132 = $sim + 128 | 0; //@line 7830
 _e8530_init($132); //@line 7831
 _e8530_set_irq_fct($132, $41, 46); //@line 7832
 _e8530_set_clock($132, 3672e3, 3672e3, 3672e3); //@line 7833
 $135 = _mem_blk_new(HEAP32[$addr_i60 >> 2] | 0, HEAP32[$size_i61 >> 2] | 0, 0) | 0; //@line 7836
 if (($135 | 0) != 0) {
  _mem_blk_set_fct($135, $41, 30, 0, 0, 28, 0, 0); //@line 7840
  _mem_add_blk(HEAP32[$40 >> 2] | 0, $135, 1); //@line 7842
 }
 $142 = $sim + 3488 | 0; //@line 7848
 _mac_ser_init($142); //@line 7849
 _mac_ser_set_scc($142, $132, 0); //@line 7850
 $143 = $sim + 4056 | 0; //@line 7851
 _mac_ser_init($143); //@line 7852
 _mac_ser_set_scc($143, $132, 1); //@line 7853
 $144 = _ini_next_sct($ini, 0, 32040) | 0; //@line 7854
 if (($144 | 0) != 0) {
  $sct_014_i = $144; //@line 7858
  do {
   _ini_get_uint16($sct_014_i, 31912, $port_i, 0) | 0; //@line 7861
   _ini_get_uint16($sct_014_i, 31864, $multichar_i, 1) | 0; //@line 7862
   _ini_get_string($sct_014_i, 49552, $driver_i, 0) | 0; //@line 7863
   $150 = HEAP32[$multichar_i >> 2] | 0; //@line 7865
   $151 = HEAP32[$driver_i >> 2] | 0; //@line 7866
   _pce_log_tag(2, 31656, 31512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$port_i >> 2], HEAP32[tempInt + 8 >> 2] = $150, HEAP32[tempInt + 16 >> 2] = ($151 | 0) != 0 ? $151 : 48288, tempInt) | 0); //@line 7869
   $sct_014_i = _ini_next_sct($ini, $sct_014_i, 32040) | 0; //@line 7870
   $155 = HEAP32[$port_i >> 2] | 0; //@line 7871
   do {
    if ($155 >>> 0 > 1) {
     _pce_log(0, 31360, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $155, tempInt) | 0); //@line 7876
    } else {
     $160 = HEAP32[$multichar_i >> 2] | 0; //@line 7879
     _e8530_set_multichar($132, $155, $160, $160); //@line 7880
     $161 = HEAP32[$driver_i >> 2] | 0; //@line 7881
     if (($161 | 0) == 0) {
      break;
     }
     if ((_mac_ser_set_driver($sim + 3488 + ((HEAP32[$port_i >> 2] | 0) * 568 | 0) | 0, $161) | 0) == 0) {
      break;
     }
     _pce_log(0, 31288, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$driver_i >> 2], tempInt) | 0); //@line 7896
    }
   } while (0);
  } while (($sct_014_i | 0) != 0);
 }
 $174 = _ini_next_sct($ini, 0, 34016) | 0; //@line 7913
 _ini_get_string($174, 40280, $fname_i, 33784) | 0; //@line 7914
 _ini_get_bool($174, 33360, $realtime_i, 1) | 0; //@line 7915
 _ini_get_bool($174, 32976, $romdisk_i, 0) | 0; //@line 7916
 _ini_get_string($174, 32664, $start_i, 0) | 0; //@line 7917
 $180 = HEAP32[$realtime_i >> 2] | 0; //@line 7919
 $181 = HEAP32[$start_i >> 2] | 0; //@line 7920
 $184 = HEAP32[$romdisk_i >> 2] | 0; //@line 7923
 _pce_log_tag(2, 32528, 32336, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = HEAP32[$fname_i >> 2], HEAP32[tempInt + 8 >> 2] = $180, HEAP32[tempInt + 16 >> 2] = ($181 | 0) != 0 ? $181 : 32224, HEAP32[tempInt + 24 >> 2] = $184, tempInt) | 0); //@line 7924
 HEAP32[$sim + 4672 >> 2] = _strdup(HEAP32[$fname_i >> 2] | 0) | 0; //@line 7928
 $188 = $sim + 1428 | 0; //@line 7929
 _mac_rtc_init($188); //@line 7930
 _mac_rtc_set_data_fct($188, $41, 98); //@line 7931
 _mac_rtc_set_osi_fct($188, $41, 118); //@line 7932
 _mac_rtc_set_realtime($188, HEAP32[$realtime_i >> 2] | 0); //@line 7934
 if ((_mac_rtc_load_file($188, HEAP32[$fname_i >> 2] | 0) | 0) != 0) {
  _pce_log(0, 32096, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 7940
 }
 if ((HEAP32[$romdisk_i >> 2] | 0) != 0) {
  HEAP8[$sim + 1548 | 0] = 0; //@line 7948
  HEAP8[$sim + 1549 | 0] = 6; //@line 7950
  HEAP8[$sim + 1550 | 0] = -1; //@line 7952
  HEAP8[$sim + 1551 | 0] = -53; //@line 7954
 }
 $203 = HEAP32[$start_i >> 2] | 0; //@line 7957
 if (($203 | 0) == 0) {
  _mac_rtc_set_time($188, 0, 1); //@line 7961
 } else {
  _mac_rtc_set_time_str($188, $203); //@line 7963
 }
 $210 = $sim + 1744 | 0; //@line 7969
 HEAP32[$210 >> 2] = 0; //@line 7970
 $211 = $sim | 0; //@line 7971
 do {
  if ((HEAP32[$211 >> 2] & 1 | 0) != 0) {
   $216 = _ini_next_sct($ini, 0, 37792) | 0; //@line 7978
   _ini_get_uint16($216, 35104, $model_i62, 1) | 0; //@line 7979
   _ini_get_bool($216, 34856, $intl_i, 0) | 0; //@line 7980
   _ini_get_bool($216, 37544, $motion_i, 0) | 0; //@line 7981
   $221 = HEAP32[$intl_i >> 2] | 0; //@line 7983
   $224 = (HEAP32[$motion_i >> 2] | 0) != 0 ? 35680 : 35400; //@line 7986
   _pce_log_tag(2, 34616, 34304, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$model_i62 >> 2], HEAP32[tempInt + 8 >> 2] = $221, HEAP32[tempInt + 16 >> 2] = $224, tempInt) | 0); //@line 7987
   $225 = _mac_kbd_new() | 0; //@line 7988
   HEAP32[$210 >> 2] = $225; //@line 7989
   if (($225 | 0) == 0) {
    break;
   }
   $228 = HEAP32[$model_i62 >> 2] | 0; //@line 7995
   $229 = HEAP32[$intl_i >> 2] | 0; //@line 7996
   _mac_kbd_set_model($225, $228, $229) | 0; //@line 7997
   _mac_kbd_set_keypad_mode(HEAP32[$210 >> 2] | 0, HEAP32[$motion_i >> 2] | 0); //@line 8000
   _mac_kbd_set_data_fct(HEAP32[$210 >> 2] | 0, $117, 332); //@line 8003
   _mac_kbd_set_intr_fct(HEAP32[$210 >> 2] | 0, $41, 20); //@line 8005
   _e6522_set_shift_out_fct($117, HEAP32[$210 >> 2] | 0, 142); //@line 8008
   _e6522_set_cb2_fct($117, HEAP32[$210 >> 2] | 0, 168); //@line 8011
  }
 } while (0);
 $243 = $sim + 1748 | 0; //@line 8018
 HEAP32[$243 >> 2] = 0; //@line 8019
 $244 = $sim + 1756 | 0; //@line 8020
 HEAP32[$244 >> 2] = 0; //@line 8021
 $245 = $sim + 1752 | 0; //@line 8022
 HEAP32[$245 >> 2] = 0; //@line 8023
 do {
  if ((HEAP32[$211 >> 2] & 6 | 0) != 0) {
   $250 = _ini_next_sct($ini, 0, 38328) | 0; //@line 8030
   _ini_get_bool($250, 38016, $mouse_i, 1) | 0; //@line 8031
   _ini_get_bool($250, 37792, $keyboard_i, 1) | 0; //@line 8032
   _ini_get_bool($250, 37544, $motion_i63, 0) | 0; //@line 8033
   _pce_log_tag(2, 37264, 37032, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 8034
   $254 = _mac_adb_new() | 0; //@line 8035
   HEAP32[$243 >> 2] = $254; //@line 8036
   if (($254 | 0) == 0) {
    _pce_log(0, 36824, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 8040
    break;
   }
   $258 = $117; //@line 8044
   _adb_set_shift_in_fct($254, $258, 252); //@line 8045
   _adb_set_shift_out_fct(HEAP32[$243 >> 2] | 0, $258, 18); //@line 8047
   _adb_set_int_fct(HEAP32[$243 >> 2] | 0, $41, 204); //@line 8049
   do {
    if ((HEAP32[$mouse_i >> 2] | 0) != 0) {
     _pce_log_tag(2, 37264, 36280, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 8055
     $264 = _adb_mouse_new() | 0; //@line 8056
     HEAP32[$244 >> 2] = $264; //@line 8057
     if (($264 | 0) == 0) {
      break;
     }
     $267 = HEAP32[$243 >> 2] | 0; //@line 8063
     $268 = $264 | 0; //@line 8064
     _adb_add_device($267, $268) | 0; //@line 8065
    }
   } while (0);
   if ((HEAP32[$keyboard_i >> 2] | 0) == 0) {
    break;
   }
   _pce_log_tag(2, 37264, 35992, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAP32[$motion_i63 >> 2] | 0) != 0 ? 35680 : 35400, tempInt) | 0); //@line 8078
   $277 = _adb_kbd_new() | 0; //@line 8079
   HEAP32[$245 >> 2] = $277; //@line 8080
   if (($277 | 0) == 0) {
    break;
   }
   _adb_kbd_set_keypad_mode($277, HEAP32[$motion_i63 >> 2] | 0); //@line 8087
   $281 = HEAP32[$243 >> 2] | 0; //@line 8088
   $283 = HEAP32[$245 >> 2] | 0; //@line 8090
   _adb_add_device($281, $283) | 0; //@line 8091
  }
 } while (0);
 $286 = $sim + 3484 | 0; //@line 8096
 HEAP32[$286 >> 2] = _ini_get_disks($ini) | 0; //@line 8097
 $294 = _ini_next_sct($ini, 0, 41264) | 0; //@line 8105
 $295 = $sim + 1760 | 0; //@line 8106
 _mac_iwm_init($295); //@line 8107
 _mac_iwm_set_motor_fct($295, $41, 222); //@line 8108
 _mac_iwm_set_disks($295, HEAP32[$286 >> 2] | 0); //@line 8110
 _pce_log_tag(2, 41048, 40808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 13631488, tempInt) | 0); //@line 8111
 $297 = _ini_next_sct($294, 0, 43592) | 0; //@line 8112
 if (($297 | 0) != 0) {
  $n_021_i = 0;
  $sctdev_022_i = $297;
  do {
   _ini_get_uint16($sctdev_022_i, 43592, $drive_i, $n_021_i) | 0; //@line 8120
   _ini_get_uint16($sctdev_022_i, 40584, $disk_i, HEAP32[$drive_i >> 2] | 0) | 0; //@line 8122
   _ini_get_string($sctdev_022_i, 40280, $fname_i64, 0) | 0; //@line 8123
   _ini_get_bool($sctdev_022_i, 40016, $single_i, 0) | 0; //@line 8124
   _ini_get_bool($sctdev_022_i, 39784, $locked_i, 0) | 0; //@line 8125
   _ini_get_bool($sctdev_022_i, 39232, $inserted_i, 0) | 0; //@line 8126
   _ini_get_bool($sctdev_022_i, 38944, $rotate_i, 0) | 0; //@line 8127
   $310 = (HEAP32[$single_i >> 2] | 0) != 0 ? 400 : 800; //@line 8131
   $311 = HEAP32[$locked_i >> 2] | 0; //@line 8132
   $312 = HEAP32[$rotate_i >> 2] | 0; //@line 8133
   $313 = HEAP32[$disk_i >> 2] | 0; //@line 8134
   $314 = HEAP32[$fname_i64 >> 2] | 0; //@line 8135
   _pce_log_tag(2, 41048, 38576, (tempInt = STACKTOP, STACKTOP = STACKTOP + 48 | 0, HEAP32[tempInt >> 2] = HEAP32[$drive_i >> 2], HEAP32[tempInt + 8 >> 2] = $310, HEAP32[tempInt + 16 >> 2] = $311, HEAP32[tempInt + 24 >> 2] = $312, HEAP32[tempInt + 32 >> 2] = $313, HEAP32[tempInt + 40 >> 2] = ($314 | 0) != 0 ? $314 : 48288, tempInt) | 0); //@line 8138
   _mac_iwm_set_heads($295, (HEAP32[$drive_i >> 2] | 0) - 1 | 0, (HEAP32[$single_i >> 2] | 0) != 0 ? 1 : 2) | 0; //@line 8144
   _mac_iwm_set_disk_id($295, (HEAP32[$drive_i >> 2] | 0) - 1 | 0, HEAP32[$disk_i >> 2] | 0); //@line 8148
   _mac_iwm_set_fname($295, (HEAP32[$drive_i >> 2] | 0) - 1 | 0, HEAP32[$fname_i64 >> 2] | 0); //@line 8152
   _mac_iwm_set_locked($295, (HEAP32[$drive_i >> 2] | 0) - 1 | 0, HEAP32[$locked_i >> 2] | 0); //@line 8156
   _mac_iwm_set_auto_rotate($295, (HEAP32[$drive_i >> 2] | 0) - 1 | 0, HEAP32[$rotate_i >> 2] | 0); //@line 8160
   if ((HEAP32[$inserted_i >> 2] | 0) != 0) {
    _mac_iwm_insert($295, (HEAP32[$drive_i >> 2] | 0) - 1 | 0); //@line 8167
   }
   $n_021_i = (HEAP32[$drive_i >> 2] | 0) + 1 | 0; //@line 8171
   $sctdev_022_i = _ini_next_sct($294, $sctdev_022_i, 43592) | 0; //@line 8172
  } while (($sctdev_022_i | 0) != 0);
 }
 $351 = _ini_next_sct($ini, 0, 45448) | 0; //@line 8188
 do {
  if (($351 | 0) != 0) {
   _ini_get_uint32($351, 58056, $addr_i66, 5767168) | 0; //@line 8193
   _ini_get_uint32($351, 45112, $size_i67, 524288) | 0; //@line 8194
   $357 = HEAP32[$size_i67 >> 2] | 0; //@line 8196
   _pce_log_tag(2, 44792, 44440, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$addr_i66 >> 2], HEAP32[tempInt + 8 >> 2] = $357, tempInt) | 0); //@line 8197
   $358 = $sim + 2088 | 0; //@line 8198
   _mac_scsi_init($358); //@line 8199
   _mac_scsi_set_disks($358, HEAP32[$286 >> 2] | 0); //@line 8201
   $362 = _mem_blk_new(HEAP32[$addr_i66 >> 2] | 0, HEAP32[$size_i67 >> 2] | 0, 0) | 0; //@line 8204
   if (($362 | 0) == 0) {
    break;
   }
   _mem_blk_set_fct($362, $358, 28, 8, 0, 36, 30, 0); //@line 8211
   _mem_add_blk(HEAP32[$40 >> 2] | 0, $362, 1); //@line 8213
   $367 = _ini_next_sct($351, 0, 44136) | 0; //@line 8214
   if (($367 | 0) == 0) {
    break;
   } else {
    $sctdev_020_i = $367; //@line 8220
   }
   do {
    _ini_get_uint16($sctdev_020_i, 43840, $id_i, 0) | 0; //@line 8224
    _ini_get_uint16($sctdev_020_i, 43592, $drive_i68, 0) | 0; //@line 8225
    _ini_get_string($sctdev_020_i, 43224, $vendor_i, 42928) | 0; //@line 8226
    _ini_get_string($sctdev_020_i, 42304, $product_i, 41960) | 0; //@line 8227
    $374 = HEAP32[$drive_i68 >> 2] | 0; //@line 8229
    $375 = HEAP32[$vendor_i >> 2] | 0; //@line 8230
    $376 = HEAP32[$product_i >> 2] | 0; //@line 8231
    _pce_log_tag(2, 44792, 41584, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = HEAP32[$id_i >> 2], HEAP32[tempInt + 8 >> 2] = $374, HEAP32[tempInt + 16 >> 2] = $375, HEAP32[tempInt + 24 >> 2] = $376, tempInt) | 0); //@line 8232
    _mac_scsi_set_drive($358, HEAP32[$id_i >> 2] | 0, HEAP32[$drive_i68 >> 2] | 0); //@line 8235
    _mac_scsi_set_drive_vendor($358, HEAP32[$id_i >> 2] | 0, HEAP32[$vendor_i >> 2] | 0); //@line 8238
    _mac_scsi_set_drive_product($358, HEAP32[$id_i >> 2] | 0, HEAP32[$product_i >> 2] | 0); //@line 8241
    $sctdev_020_i = _ini_next_sct($351, $sctdev_020_i, 44136) | 0; //@line 8242
   } while (($sctdev_020_i | 0) != 0);
  }
 } while (0);
 $386 = $var_i | 0; //@line 8254
 $389 = _ini_next_sct($ini, 0, 47624) | 0; //@line 8257
 _ini_get_uint16($389, 47304, $def_i, 30) | 0; //@line 8258
 _ini_get_bool($389, 47024, $format_hd_as_dd_i, 0) | 0; //@line 8259
 $392 = $sim + 2424 | 0; //@line 8260
 _mac_sony_init($392, ($389 | 0) != 0 | 0); //@line 8263
 _mac_sony_set_mem($392, HEAP32[$40 >> 2] | 0); //@line 8265
 _mac_sony_set_disks($392, HEAP32[$286 >> 2] | 0); //@line 8267
 HEAP8[$sim + 2484 | 0] = HEAP32[$format_hd_as_dd_i >> 2] & 255; //@line 8271
 if (($389 | 0) != 0) {
  if ((HEAP32[15668] & 1 | 0) == 0) {
   _sprintf($386 | 0, 46720, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 1, tempInt) | 0) | 0; //@line 8280
   $408 = HEAP32[$def_i >> 2] | 0; //@line 8281
   _ini_get_uint16($389, $386, $val_i, $408) | 0; //@line 8282
   $411 = HEAP32[$val_i >> 2] | 0; //@line 8284
  } else {
   $405 = HEAP32[15670] | 0; //@line 8286
   HEAP32[$val_i >> 2] = $405; //@line 8287
   $411 = $405; //@line 8289
  }
  _mac_sony_set_delay($392, 0, $411); //@line 8292
  $412 = HEAP32[$val_i >> 2] | 0; //@line 8293
  _pce_log_tag(2, 46464, 45776, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 1, HEAP32[tempInt + 8 >> 2] = $412, tempInt) | 0); //@line 8294
  if ((HEAP32[15668] & 2 | 0) == 0) {
   _sprintf($386 | 0, 46720, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 2, tempInt) | 0) | 0; //@line 8300
   $420 = HEAP32[$def_i >> 2] | 0; //@line 8301
   _ini_get_uint16($389, $386, $val_i, $420) | 0; //@line 8302
   $423 = HEAP32[$val_i >> 2] | 0; //@line 8304
  } else {
   $417 = HEAP32[15671] | 0; //@line 8306
   HEAP32[$val_i >> 2] = $417; //@line 8307
   $423 = $417; //@line 8309
  }
  _mac_sony_set_delay($392, 1, $423); //@line 8312
  $424 = HEAP32[$val_i >> 2] | 0; //@line 8313
  _pce_log_tag(2, 46464, 45776, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 2, HEAP32[tempInt + 8 >> 2] = $424, tempInt) | 0); //@line 8314
  if ((HEAP32[15668] & 4 | 0) == 0) {
   _sprintf($386 | 0, 46720, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 3, tempInt) | 0) | 0; //@line 8320
   $432 = HEAP32[$def_i >> 2] | 0; //@line 8321
   _ini_get_uint16($389, $386, $val_i, $432) | 0; //@line 8322
   $435 = HEAP32[$val_i >> 2] | 0; //@line 8324
  } else {
   $429 = HEAP32[15672] | 0; //@line 8326
   HEAP32[$val_i >> 2] = $429; //@line 8327
   $435 = $429; //@line 8329
  }
  _mac_sony_set_delay($392, 2, $435); //@line 8332
  $436 = HEAP32[$val_i >> 2] | 0; //@line 8333
  _pce_log_tag(2, 46464, 45776, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 3, HEAP32[tempInt + 8 >> 2] = $436, tempInt) | 0); //@line 8334
  if ((HEAP32[15668] & 8 | 0) == 0) {
   _sprintf($386 | 0, 46720, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 4, tempInt) | 0) | 0; //@line 8340
   $444 = HEAP32[$def_i >> 2] | 0; //@line 8341
   _ini_get_uint16($389, $386, $val_i, $444) | 0; //@line 8342
   $446 = HEAP32[$val_i >> 2] | 0; //@line 8344
  } else {
   $441 = HEAP32[15673] | 0; //@line 8346
   HEAP32[$val_i >> 2] = $441; //@line 8347
   $446 = $441; //@line 8349
  }
  _mac_sony_set_delay($392, 3, $446); //@line 8352
  $447 = HEAP32[$val_i >> 2] | 0; //@line 8353
  _pce_log_tag(2, 46464, 45776, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 4, HEAP32[tempInt + 8 >> 2] = $447, tempInt) | 0); //@line 8354
 }
 $451 = $sim + 2644 | 0; //@line 8359
 _mac_sound_init($451); //@line 8360
 do {
  if ((HEAP32[$43 >> 2] | 0) != 0) {
   $455 = _ini_next_sct($ini, 0, 50816) | 0; //@line 8366
   $457 = _mem_blk_get_size(HEAP32[$43 >> 2] | 0) | 0; //@line 8368
   $__i = $457 >>> 0 < 768 ? 0 : $457 - 768 | 0; //@line 8371
   HEAP32[$addr_i70 >> 2] = $__i; //@line 8372
   _ini_get_uint32($455, 58056, $addr_i70, $__i) | 0; //@line 8373
   _ini_get_uint32($455, 50496, $freq_i, 6e3) | 0; //@line 8374
   _ini_get_string($455, 49552, $driver_i71, 0) | 0; //@line 8375
   $464 = HEAP32[$freq_i >> 2] | 0; //@line 8377
   $465 = HEAP32[$driver_i71 >> 2] | 0; //@line 8378
   _pce_log_tag(2, 49072, 48680, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$addr_i70 >> 2], HEAP32[tempInt + 8 >> 2] = $464, HEAP32[tempInt + 16 >> 2] = ($465 | 0) != 0 ? $465 : 48288, tempInt) | 0); //@line 8381
   $468 = HEAP32[$addr_i70 >> 2] | 0; //@line 8382
   $469 = $sim + 4644 | 0; //@line 8383
   HEAP32[$469 >> 2] = $468; //@line 8384
   HEAP32[$sim + 4648 >> 2] = $468 - 23552; //@line 8387
   $473 = _mem_blk_get_data(HEAP32[$43 >> 2] | 0) | 0; //@line 8389
   _mac_sound_set_sbuf($451, $473 + (HEAP32[$469 >> 2] | 0) | 0); //@line 8392
   _mac_sound_set_lowpass($451, HEAP32[$freq_i >> 2] | 0); //@line 8394
   $477 = HEAP32[$driver_i71 >> 2] | 0; //@line 8395
   if (($477 | 0) == 0) {
    break;
   }
   if ((_mac_sound_set_driver($451, $477) | 0) == 0) {
    break;
   }
   _pce_log(0, 47896, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$driver_i71 >> 2], tempInt) | 0); //@line 8408
  }
 } while (0);
 $485 = _ini_get_terminal($ini, HEAP32[15586] | 0) | 0; //@line 8413
 HEAP32[$1 >> 2] = $485; //@line 8414
 if (($485 | 0) != 0) {
  _trm_set_msg_fct($485, $41, 70); //@line 8418
  _trm_set_key_fct(HEAP32[$1 >> 2] | 0, $41, 32); //@line 8420
  _trm_set_mouse_fct(HEAP32[$1 >> 2] | 0, $41, 4); //@line 8422
 }
 if ((HEAP32[$43 >> 2] | 0) == 0) {
  $560 = HEAP32[$40 >> 2] | 0; //@line 8435
  $561 = _pce_load_mem_ini($560, $ini) | 0; //@line 8436
  $562 = HEAP32[$1 >> 2] | 0; //@line 8437
  $563 = _trm_set_msg_trm($562, 30944, 51240) | 0; //@line 8438
  $564 = $sim + 4700 | 0; //@line 8439
  HEAP32[$564 >> 2] = 0; //@line 8440
  $565 = $sim + 4704 | 0; //@line 8441
  HEAP32[$565 >> 2] = 0; //@line 8442
  $566 = _pce_get_interval_us($565) | 0; //@line 8443
  HEAP32[$11 >> 2] = 0; //@line 8444
  STACKTOP = sp; //@line 8445
  return;
 }
 $499 = _ini_next_sct($ini, 0, 30936) | 0; //@line 8448
 $501 = _mem_blk_get_size(HEAP32[$43 >> 2] | 0) | 0; //@line 8450
 $__i72 = $501 >>> 0 < 22784 ? 0 : $501 - 22784 | 0; //@line 8453
 _ini_get_uint32($499, 58056, $addr2_i, $__i72) | 0; //@line 8454
 _ini_get_uint16($499, 57264, $w_i, 512) | 0; //@line 8455
 _ini_get_uint16($499, 56072, $h_i, 342) | 0; //@line 8456
 _ini_get_uint32($499, 55304, $col0_i, 0) | 0; //@line 8457
 _ini_get_uint32($499, 54640, $col1_i, 16777215) | 0; //@line 8458
 _ini_get_uint16($499, 53944, $bright_i, 1e3) | 0; //@line 8459
 $511 = HEAP32[$w_i >> 2] | 0; //@line 8461
 $512 = HEAP32[$h_i >> 2] | 0; //@line 8462
 $514 = ((HEAP32[$bright_i >> 2] | 0) >>> 0) / 10 | 0; //@line 8464
 _pce_log_tag(2, 53376, 52488, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = HEAP32[$addr2_i >> 2], HEAP32[tempInt + 8 >> 2] = $511, HEAP32[tempInt + 16 >> 2] = $512, HEAP32[tempInt + 24 >> 2] = $514, tempInt) | 0); //@line 8465
 $515 = HEAP32[$addr2_i >> 2] | 0; //@line 8466
 $516 = $sim + 4636 | 0; //@line 8467
 HEAP32[$516 >> 2] = $515; //@line 8468
 if (($__i72 | 0) == ($515 | 0) & $515 >>> 0 > 32767) {
  HEAP32[$sim + 4640 >> 2] = $__i72 - 32768; //@line 8476
 } else {
  HEAP32[$sim + 4640 >> 2] = $515; //@line 8480
 }
 $527 = _mac_video_new(HEAP32[$w_i >> 2] | 0, HEAP32[$h_i >> 2] | 0) | 0; //@line 8484
 HEAP32[$2 >> 2] = $527; //@line 8485
 if (($527 | 0) == 0) {
  $560 = HEAP32[$40 >> 2] | 0; //@line 8489
  $561 = _pce_load_mem_ini($560, $ini) | 0; //@line 8490
  $562 = HEAP32[$1 >> 2] | 0; //@line 8491
  $563 = _trm_set_msg_trm($562, 30944, 51240) | 0; //@line 8492
  $564 = $sim + 4700 | 0; //@line 8493
  HEAP32[$564 >> 2] = 0; //@line 8494
  $565 = $sim + 4704 | 0; //@line 8495
  HEAP32[$565 >> 2] = 0; //@line 8496
  $566 = _pce_get_interval_us($565) | 0; //@line 8497
  HEAP32[$11 >> 2] = 0; //@line 8498
  STACKTOP = sp; //@line 8499
  return;
 }
 _mac_video_set_vbi_fct($527, $41, 246); //@line 8502
 _mac_set_vbuf($sim, HEAP32[$516 >> 2] | 0); //@line 8504
 $531 = HEAP32[$1 >> 2] | 0; //@line 8505
 if (($531 | 0) != 0) {
  _mac_video_set_terminal(HEAP32[$2 >> 2] | 0, $531); //@line 8510
  $535 = HEAP32[$1 >> 2] | 0; //@line 8511
  _trm_open($535, 512, 342) | 0; //@line 8512
 }
 _mac_video_set_color(HEAP32[$2 >> 2] | 0, HEAP32[$col0_i >> 2] | 0, HEAP32[$col1_i >> 2] | 0); //@line 8518
 _mac_video_set_brightness(HEAP32[$2 >> 2] | 0, ((((HEAP32[$bright_i >> 2] | 0) * 255 | 0) + 500 | 0) >>> 0) / 1e3 | 0); //@line 8524
 if ((Math_imul((HEAP32[$w_i >> 2] | 0) >>> 3, HEAP32[$h_i >> 2] | 0) | 0) == 0) {
  $560 = HEAP32[$40 >> 2] | 0; //@line 8532
  $561 = _pce_load_mem_ini($560, $ini) | 0; //@line 8533
  $562 = HEAP32[$1 >> 2] | 0; //@line 8534
  $563 = _trm_set_msg_trm($562, 30944, 51240) | 0; //@line 8535
  $564 = $sim + 4700 | 0; //@line 8536
  HEAP32[$564 >> 2] = 0; //@line 8537
  $565 = $sim + 4704 | 0; //@line 8538
  HEAP32[$565 >> 2] = 0; //@line 8539
  $566 = _pce_get_interval_us($565) | 0; //@line 8540
  HEAP32[$11 >> 2] = 0; //@line 8541
  STACKTOP = sp; //@line 8542
  return;
 } else {
  $i_031_i = 0; //@line 8545
 }
 do {
  _mem_set_uint8(HEAP32[$40 >> 2] | 0, (HEAP32[$516 >> 2] | 0) + $i_031_i | 0, -1); //@line 8552
  $i_031_i = $i_031_i + 1 | 0; //@line 8553
 } while ($i_031_i >>> 0 < (Math_imul((HEAP32[$w_i >> 2] | 0) >>> 3, HEAP32[$h_i >> 2] | 0) | 0) >>> 0);
 $560 = HEAP32[$40 >> 2] | 0; //@line 8566
 $561 = _pce_load_mem_ini($560, $ini) | 0; //@line 8567
 $562 = HEAP32[$1 >> 2] | 0; //@line 8568
 $563 = _trm_set_msg_trm($562, 30944, 51240) | 0; //@line 8569
 $564 = $sim + 4700 | 0; //@line 8570
 HEAP32[$564 >> 2] = 0; //@line 8571
 $565 = $sim + 4704 | 0; //@line 8572
 HEAP32[$565 >> 2] = 0; //@line 8573
 $566 = _pce_get_interval_us($565) | 0; //@line 8574
 HEAP32[$11 >> 2] = 0; //@line 8575
 STACKTOP = sp; //@line 8576
 return;
}
function _mac_clock_discontinuity($sim) {
 $sim = $sim | 0;
 var $2 = 0;
 HEAP32[$sim + 4700 >> 2] = 0; //@line 8587
 $2 = $sim + 4704 | 0; //@line 8588
 HEAP32[$2 >> 2] = 0; //@line 8589
 _pce_get_interval_us($2) | 0; //@line 8590
 HEAP32[$sim + 4696 >> 2] = 0; //@line 8592
 return;
}
function _mac_new($ini) {
 $ini = $ini | 0;
 var $1 = 0, $2 = 0, $_0 = 0;
 $1 = _malloc(4736) | 0; //@line 8603
 $2 = $1; //@line 8604
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 8608
  return $_0 | 0; //@line 8611
 }
 _mac_init($2, $ini); //@line 8613
 $_0 = $2; //@line 8615
 return $_0 | 0; //@line 8618
}
function _mac_set_pause($sim, $pause) {
 $sim = $sim | 0;
 $pause = $pause | 0;
 var $1 = 0, $6 = 0;
 $1 = ($pause | 0) != 0; //@line 8628
 HEAP8[$sim + 4676 | 0] = $1 & 1; //@line 8631
 if ($1) {
  return;
 }
 HEAP32[$sim + 4700 >> 2] = 0; //@line 8638
 $6 = $sim + 4704 | 0; //@line 8639
 HEAP32[$6 >> 2] = 0; //@line 8640
 _pce_get_interval_us($6) | 0; //@line 8641
 HEAP32[$sim + 4696 >> 2] = 0; //@line 8643
 return;
}
function _mac_set_speed($sim, $idx, $factor) {
 $sim = $sim | 0;
 $idx = $idx | 0;
 $factor = $factor | 0;
 var $5 = 0, $7 = 0, $13 = 0, $15 = 0, $v_1_1_i = 0, $21 = 0, sp = 0;
 sp = STACKTOP; //@line 8658
 if ($idx >>> 0 > 1) {
  STACKTOP = sp; //@line 8662
  return;
 }
 HEAP32[$sim + 4688 + ($idx << 2) >> 2] = $factor; //@line 8666
 $5 = HEAP32[$sim + 4688 >> 2] | 0; //@line 8668
 $7 = HEAP32[$sim + 4692 >> 2] | 0; //@line 8670
 if (($7 | 0) == 0) {
  $v_1_1_i = $5; //@line 8674
 } else {
  $v_1_1_i = ($5 | 0) == 0 | $7 >>> 0 < $5 >>> 0 ? $7 : $5; //@line 8681
 }
 $21 = $sim + 4684 | 0; //@line 8684
 if (($v_1_1_i | 0) == (HEAP32[$21 >> 2] | 0)) {
  STACKTOP = sp; //@line 8689
  return;
 }
 _mac_log_deb(31040, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $v_1_1_i, tempInt) | 0); //@line 8692
 _mac_rtc_set_realtime($sim + 1428 | 0, ($v_1_1_i | 0) != 1 | 0); //@line 8696
 HEAP32[$21 >> 2] = $v_1_1_i; //@line 8697
 $13 = $sim + 4696 | 0; //@line 8698
 HEAP32[$13 >> 2] = 0; //@line 8699
 HEAP32[$sim + 4700 >> 2] = 0; //@line 8701
 $15 = $sim + 4704 | 0; //@line 8702
 HEAP32[$15 >> 2] = 0; //@line 8703
 _pce_get_interval_us($15) | 0; //@line 8704
 HEAP32[$13 >> 2] = 0; //@line 8705
 STACKTOP = sp; //@line 8707
 return;
}
function _mac_set_msg_trm($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $2 = 0, $_0 = 0;
 $2 = HEAP32[$sim + 3480 >> 2] | 0; //@line 8720
 if (($2 | 0) == 0) {
  $_0 = 1; //@line 8724
  return $_0 | 0; //@line 8727
 }
 $_0 = _trm_set_msg_trm($2, $msg, $val) | 0; //@line 8731
 return $_0 | 0; //@line 8734
}
function _mac_set_cpu_model($sim, $model) {
 $sim = $sim | 0;
 $model = $model | 0;
 var $_0 = 0;
 if ((_strcmp($model | 0, 43472) | 0) == 0) {
  _e68_set_68000(HEAP32[$sim + 4 >> 2] | 0); //@line 8751
  $_0 = 0; //@line 8753
  return $_0 | 0; //@line 8756
 }
 if ((_strcmp($model | 0, 40176) | 0) == 0) {
  _e68_set_68010(HEAP32[$sim + 4 >> 2] | 0); //@line 8764
  $_0 = 0; //@line 8766
  return $_0 | 0; //@line 8769
 }
 if ((_strcmp($model | 0, 37176) | 0) != 0) {
  $_0 = 1; //@line 8775
  return $_0 | 0; //@line 8778
 }
 _e68_set_68020(HEAP32[$sim + 4 >> 2] | 0); //@line 8782
 $_0 = 0; //@line 8783
 return $_0 | 0; //@line 8786
}
function _mac_reset($sim) {
 $sim = $sim | 0;
 var $1 = 0, $14 = 0, $15 = 0, $22 = 0, $23 = 0, $24 = 0, $31 = 0, $49 = 0, $51 = 0, $58 = 0, $77 = 0, $79 = 0, $85 = 0, $92 = 0, sp = 0;
 sp = STACKTOP; //@line 8804
 $1 = $sim + 4632 | 0; //@line 8805
 if ((HEAP32[$1 >> 2] | 0) != 0) {
  STACKTOP = sp; //@line 8810
  return;
 }
 HEAP32[$1 >> 2] = 1; //@line 8813
 _mac_log_deb(34144, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 8814
 HEAP8[$sim + 4652 | 0] = 0; //@line 8817
 _memset($sim + 4656 | 0, 0, 14); //@line 8820
 do {
  if ((HEAP32[$sim >> 2] & 1 | 0) == 0) {
   _mac_set_overlay($sim, 0); //@line 8827
   $14 = $sim + 16 | 0; //@line 8828
   $15 = HEAP32[$14 >> 2] | 0; //@line 8829
   if (($15 | 0) == 0) {
    break;
   }
   if ((HEAP32[$15 + 40 >> 2] | 0) >>> 0 <= 7) {
    break;
   }
   $22 = $sim + 4 | 0; //@line 8842
   $23 = HEAP32[$22 >> 2] | 0; //@line 8843
   $24 = _mem_blk_get_uint32_be($15, 0) | 0; //@line 8844
   if ((HEAP32[$23 + 36 >> 2] | 0) >>> 0 > 3) {
    $31 = $23 + 32 | 0; //@line 8852
    HEAP8[HEAP32[$31 >> 2] | 0] = $24 >>> 24 & 255; //@line 8854
    HEAP8[(HEAP32[$31 >> 2] | 0) + 1 | 0] = $24 >>> 16 & 255; //@line 8859
    HEAP8[(HEAP32[$31 >> 2] | 0) + 2 | 0] = $24 >>> 8 & 255; //@line 8864
    HEAP8[(HEAP32[$31 >> 2] | 0) + 3 | 0] = $24 & 255; //@line 8868
   } else {
    FUNCTION_TABLE_viii[HEAP32[$23 + 28 >> 2] & 63](HEAP32[$23 + 4 >> 2] | 0, 0, $24); //@line 8875
   }
   $49 = HEAP32[$22 >> 2] | 0; //@line 8877
   $51 = _mem_blk_get_uint32_be(HEAP32[$14 >> 2] | 0, 4) | 0; //@line 8879
   if ((HEAP32[$49 + 36 >> 2] | 0) >>> 0 > 7) {
    $58 = $49 + 32 | 0; //@line 8887
    HEAP8[(HEAP32[$58 >> 2] | 0) + 4 | 0] = $51 >>> 24 & 255; //@line 8890
    HEAP8[(HEAP32[$58 >> 2] | 0) + 5 | 0] = $51 >>> 16 & 255; //@line 8895
    HEAP8[(HEAP32[$58 >> 2] | 0) + 6 | 0] = $51 >>> 8 & 255; //@line 8900
    HEAP8[(HEAP32[$58 >> 2] | 0) + 7 | 0] = $51 & 255; //@line 8904
    break;
   } else {
    FUNCTION_TABLE_viii[HEAP32[$49 + 28 >> 2] & 63](HEAP32[$49 + 4 >> 2] | 0, 4, $51); //@line 8912
    break;
   }
  } else {
   _mac_set_overlay($sim, 1); //@line 8916
  }
 } while (0);
 $77 = $sim + 36 | 0; //@line 8920
 _e6522_reset($77); //@line 8921
 HEAP8[$sim + 4624 | 0] = -9; //@line 8923
 $79 = $sim + 4625 | 0; //@line 8924
 HEAP8[$79] = -1; //@line 8925
 _e6522_set_ira_inp($77, -9); //@line 8926
 _e6522_set_irb_inp($77, HEAP8[$79] | 0); //@line 8928
 _mac_sony_reset($sim + 2424 | 0); //@line 8930
 _mac_scsi_reset($sim + 2088 | 0); //@line 8932
 _e8530_reset($sim + 128 | 0); //@line 8934
 $85 = HEAP32[$sim + 1748 >> 2] | 0; //@line 8936
 if (($85 | 0) != 0) {
  _adb_reset($85); //@line 8940
 }
 _e68_reset(HEAP32[$sim + 4 >> 2] | 0); //@line 8945
 HEAP32[$sim + 4700 >> 2] = 0; //@line 8947
 $92 = $sim + 4704 | 0; //@line 8948
 HEAP32[$92 >> 2] = 0; //@line 8949
 _pce_get_interval_us($92) | 0; //@line 8950
 HEAP32[$sim + 4696 >> 2] = 0; //@line 8952
 HEAP32[$1 >> 2] = 0; //@line 8953
 STACKTOP = sp; //@line 8955
 return;
}
function _mac_clock($sim, $n) {
 $sim = $sim | 0;
 $n = $n | 0;
 var $6 = 0, $_0 = 0, $10 = 0, $clkdiv_0 = 0, $cpuclk_0 = 0, $20 = 0, $22$0 = 0, $23 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $_lcssa51 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $_pre = 0, $46 = 0, $48 = 0, $58 = 0, $64 = 0, $66 = 0, $70 = 0, $77 = 0, $78 = 0, $81 = 0, $84 = 0, $85 = 0, $storemerge28_i = 0, $90 = 0, $95 = 0, $storemerge29_i = 0, $102 = 0, $103 = 0, $106 = 0, $109 = 0, $110 = 0, $storemerge_i = 0, $117 = 0, $120 = 0, $storemerge27_i = 0, $129 = 0, $131 = 0, $136 = 0, $140 = 0, $142 = 0, $145 = 0, $149 = 0, $151 = 0, $154 = 0, $155 = 0, $160 = 0, $161 = 0, $165 = 0, $166 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 8984
 if (($n | 0) == 0) {
  $6 = HEAP32[(HEAP32[$sim + 4 >> 2] | 0) + 372 >> 2] | 0; //@line 8991
  $_0 = ($6 | 0) == 0 ? 1 : $6; //@line 8995
 } else {
  $_0 = $n; //@line 8997
 }
 $10 = HEAP32[$sim + 4684 >> 2] | 0; //@line 9001
 if (($10 | 0) == 0) {
  $cpuclk_0 = (HEAP32[$sim + 4696 >> 2] | 0) + $_0 | 0;
  $clkdiv_0 = 1;
 } else {
  $cpuclk_0 = $_0;
  $clkdiv_0 = $10;
 }
 _e68_clock(HEAP32[$sim + 4 >> 2] | 0, $cpuclk_0); //@line 9017
 _mac_sound_clock($sim + 2644 | 0, $cpuclk_0); //@line 9019
 $20 = $sim + 4712 | 0; //@line 9022
 $22$0 = _i64Add(HEAP32[$20 >> 2] | 0, HEAP32[$20 + 4 >> 2] | 0, $_0, 0) | 0;
 HEAP32[$20 >> 2] = $22$0; //@line 9029
 HEAP32[$20 + 4 >> 2] = tempRet0; //@line 9031
 $23 = $sim + 4720 | 0; //@line 9032
 $25 = (HEAP32[$23 >> 2] | 0) + $_0 | 0; //@line 9034
 HEAP32[$23 >> 2] = $25; //@line 9035
 $27 = $sim + 4724 | 0; //@line 9037
 $28 = HEAP32[$27 >> 2] | 0; //@line 9038
 if ($25 >>> 0 < $clkdiv_0 >>> 0) {
  $_lcssa51 = $28; //@line 9041
 } else {
  $30 = $28;
  $29 = $25;
  do {
   $30 = $30 + 1 | 0; //@line 9047
   $29 = $29 - $clkdiv_0 | 0; //@line 9048
  } while ($29 >>> 0 >= $clkdiv_0 >>> 0);
  HEAP32[$27 >> 2] = $30; //@line 9057
  HEAP32[$23 >> 2] = $29; //@line 9058
  $_lcssa51 = $30; //@line 9060
 }
 if ($_lcssa51 >>> 0 < 10) {
  STACKTOP = sp; //@line 9066
  return;
 }
 $37 = ($_lcssa51 >>> 0) / 10 | 0; //@line 9069
 $38 = $sim + 36 | 0; //@line 9070
 _e6522_clock($38, $37); //@line 9071
 $39 = $sim + 1748 | 0; //@line 9072
 $40 = HEAP32[$39 >> 2] | 0; //@line 9073
 $_pre = $37 * 10 | 0; //@line 9075
 if (($40 | 0) != 0) {
  _mac_adb_clock($40, $_pre); //@line 9078
 }
 _mac_iwm_clock($sim + 1760 | 0, $37); //@line 9082
 HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) - $_pre; //@line 9085
 $46 = $sim + 4728 | 0; //@line 9086
 $48 = (HEAP32[$46 >> 2] | 0) + $_pre | 0; //@line 9088
 HEAP32[$46 >> 2] = $48; //@line 9089
 if ($48 >>> 0 < 256) {
  STACKTOP = sp; //@line 9093
  return;
 }
 _mac_video_clock(HEAP32[$sim + 3476 >> 2] | 0, $48); //@line 9098
 _mac_ser_clock($sim + 3488 | 0, HEAP32[$46 >> 2] | 0); //@line 9101
 _mac_ser_clock($sim + 4056 | 0, HEAP32[$46 >> 2] | 0); //@line 9104
 $58 = HEAP32[$sim + 1744 >> 2] | 0; //@line 9106
 if (($58 | 0) != 0) {
  _mac_kbd_clock($58, HEAP32[$46 >> 2] | 0); //@line 9111
 }
 $64 = $sim + 4732 | 0; //@line 9115
 $66 = (HEAP32[$64 >> 2] | 0) + (HEAP32[$46 >> 2] | 0) | 0; //@line 9117
 HEAP32[$64 >> 2] = $66; //@line 9118
 HEAP32[$46 >> 2] = 0; //@line 9119
 if ($66 >>> 0 < 8192) {
  STACKTOP = sp; //@line 9123
  return;
 }
 $70 = HEAP32[$sim + 3480 >> 2] | 0; //@line 9127
 if (($70 | 0) != 0) {
  _trm_check($70); //@line 9131
 }
 do {
  if ((HEAP32[$39 >> 2] | 0) == 0) {
   $77 = $sim + 4656 | 0; //@line 9139
   $78 = HEAP32[$77 >> 2] | 0; //@line 9140
   if (($78 + 1 | 0) >>> 0 > 2) {
    $81 = $sim + 4668 | 0; //@line 9145
    $84 = $sim + 4625 | 0; //@line 9148
    $85 = HEAP8[$84] | 0; //@line 9149
    $storemerge28_i = (HEAP8[$81] | 0) == 0 ? $85 | 16 : $85 & -17; //@line 9152
    HEAP8[$84] = $storemerge28_i; //@line 9153
    if (($78 | 0) > 0) {
     $90 = $storemerge28_i ^ 16; //@line 9157
     HEAP8[$84] = $90; //@line 9158
     $storemerge29_i = $78 - 2 | 0;
     $95 = $90;
    } else {
     $storemerge29_i = $78 + 2 | 0;
     $95 = $storemerge28_i;
    }
    HEAP32[$77 >> 2] = $storemerge29_i; //@line 9168
    _e6522_set_irb_inp($38, $95); //@line 9169
    _e8530_set_dcd_a($sim + 128 | 0, HEAP8[$81] | 0); //@line 9172
    HEAP8[$81] = (HEAP8[$81] | 0) == 0 | 0; //@line 9176
   }
   $102 = $sim + 4660 | 0; //@line 9179
   $103 = HEAP32[$102 >> 2] | 0; //@line 9180
   if (($103 + 1 | 0) >>> 0 <= 2) {
    break;
   }
   $106 = $sim + 4669 | 0; //@line 9187
   $109 = $sim + 4625 | 0; //@line 9190
   $110 = HEAP8[$109] | 0; //@line 9191
   $storemerge_i = (HEAP8[$106] | 0) == 0 ? $110 | 32 : $110 & -33; //@line 9194
   HEAP8[$109] = $storemerge_i; //@line 9195
   if (($103 | 0) > 0) {
    $storemerge27_i = $103 - 2 | 0;
    $120 = $storemerge_i;
   } else {
    $117 = $storemerge_i ^ 32; //@line 9203
    HEAP8[$109] = $117; //@line 9204
    $storemerge27_i = $103 + 2 | 0;
    $120 = $117;
   }
   HEAP32[$102 >> 2] = $storemerge27_i; //@line 9210
   _e6522_set_irb_inp($38, $120); //@line 9211
   _e8530_set_dcd_b($sim + 128 | 0, HEAP8[$106] | 0); //@line 9214
   HEAP8[$106] = (HEAP8[$106] | 0) == 0 | 0; //@line 9218
  }
 } while (0);
 _mac_rtc_clock($sim + 1428 | 0, HEAP32[$64 >> 2] | 0); //@line 9224
 $129 = $sim + 4700 | 0; //@line 9226
 $131 = (HEAP32[$129 >> 2] | 0) + (HEAP32[$64 >> 2] | 0) | 0; //@line 9228
 HEAP32[$129 >> 2] = $131; //@line 9229
 do {
  if ($131 >>> 0 > 31333) {
   HEAP32[$129 >> 2] = $131 - 31334; //@line 9235
   $136 = _pce_get_interval_us($sim + 4704 | 0) | 0; //@line 9237
   do {
    if ($136 >>> 0 < 4e3) {
     $140 = $sim + 4708 | 0; //@line 9243
     $142 = (HEAP32[$140 >> 2] | 0) + (4e3 - $136) | 0; //@line 9245
     HEAP32[$140 >> 2] = $142; //@line 9246
     if (($142 | 0) <= 0) {
      $166 = $142;
      $165 = $140;
      break;
     }
     $145 = $sim + 4696 | 0; //@line 9253
     HEAP32[$145 >> 2] = (HEAP32[$145 >> 2] | 0) + 1; //@line 9256
     $160 = $142; //@line 9258
     label = 1151; //@line 9259
    } else {
     $149 = $sim + 4708 | 0; //@line 9261
     $151 = (HEAP32[$149 >> 2] | 0) + (4e3 - $136) | 0; //@line 9264
     HEAP32[$149 >> 2] = $151; //@line 9265
     if (($151 | 0) >= 0) {
      $160 = $151; //@line 9269
      label = 1151; //@line 9270
      break;
     }
     $154 = $sim + 4696 | 0; //@line 9273
     $155 = HEAP32[$154 >> 2] | 0; //@line 9274
     if (($155 | 0) == 0) {
      $160 = $151; //@line 9278
      label = 1151; //@line 9279
      break;
     }
     HEAP32[$154 >> 2] = $155 - 1; //@line 9283
     $160 = $151; //@line 9285
     label = 1151; //@line 9286
    }
   } while (0);
   do {
    if ((label | 0) == 1151) {
     $161 = $sim + 4708 | 0; //@line 9292
     if (($160 | 0) <= 9999) {
      $166 = $160;
      $165 = $161;
      break;
     }
     _pce_usleep($160) | 0; //@line 9299
     $166 = HEAP32[$161 >> 2] | 0;
     $165 = $161;
    }
   } while (0);
   if (($166 | 0) >= -1e6) {
    break;
   }
   _mac_log_deb(31960, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 9312
   HEAP32[$165 >> 2] = (HEAP32[$165 >> 2] | 0) + 1e6; //@line 9315
  }
 } while (0);
 HEAP32[$64 >> 2] = 0; //@line 9319
 STACKTOP = sp; //@line 9321
 return;
}
function _mac_interrupt_vbi($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $pbuf = 0, $4 = 0, $8 = 0, $10 = 0, $i_010 = 0, $14 = 0, $31 = 0, $v_1_i = 0, $41 = 0, $44 = 0, sp = 0;
 sp = STACKTOP; //@line 9337
 STACKTOP = STACKTOP + 376 | 0; //@line 9337
 $pbuf = sp | 0; //@line 9338
 if ($val << 24 >> 24 == 0) {
  STACKTOP = sp; //@line 9342
  return;
 }
 $4 = $ext + 36 | 0; //@line 9346
 _e6522_set_ca1_inp($4, 0); //@line 9347
 _e6522_set_ca1_inp($4, 1); //@line 9348
 _mac_sound_vbl($ext + 2644 | 0); //@line 9351
 $8 = $ext + 8 | 0; //@line 9353
 $10 = $ext + 4644 | 0; //@line 9355
 $i_010 = 0; //@line 9357
 while (1) {
  $14 = $i_010 + 1 | 0; //@line 9362
  HEAP8[$pbuf + $i_010 | 0] = _mem_get_uint8(HEAP32[$8 >> 2] | 0, $14 + (HEAP32[$10 >> 2] | 0) | 0) | 0; //@line 9366
  if ($14 >>> 0 < 370) {
   $i_010 = $14; //@line 9370
  } else {
   break;
  }
 }
 if ((HEAP32[$ext >> 2] & 4 | 0) == 0) {
  _mac_iwm_set_pwm($ext + 1760 | 0, $pbuf | 0, 370); //@line 9384
  STACKTOP = sp; //@line 9385
  return;
 }
 $31 = (HEAPU8[7064 + (HEAP8[$pbuf | 0] & 63) | 0] | 0) * 370 | 0; //@line 9395
 if ($31 >>> 0 < 370) {
  $v_1_i = 1; //@line 9399
 } else {
  $v_1_i = $31 >>> 0 > 11839 ? 31 : ($31 >>> 0) / 370 | 0; //@line 9405
 }
 $41 = (((((31 - $v_1_i | 0) * 223 | 0) + 15 | 0) >>> 0) / 30 | 0) + 32 | 0; //@line 9412
 $44 = HEAP32[$ext + 3476 >> 2] | 0; //@line 9415
 if (($44 | 0) == 0) {
  STACKTOP = sp; //@line 9419
  return;
 }
 if ((HEAP32[$44 + 28 >> 2] | 0) == ($41 | 0)) {
  STACKTOP = sp; //@line 9427
  return;
 }
 _mac_video_set_brightness($44, $41); //@line 9430
 STACKTOP = sp; //@line 9432
 return;
}
function _mac_set_vbuf($sim, $addr) {
 $sim = $sim | 0;
 $addr = $addr | 0;
 var $1 = 0, $12 = 0, $18 = 0, $19 = 0, $vbuf_0 = 0;
 $1 = $sim + 12 | 0; //@line 9445
 do {
  if ((_mem_blk_get_size(HEAP32[$1 >> 2] | 0) | 0) >>> 0 > $addr >>> 0) {
   $vbuf_0 = (_mem_blk_get_data(HEAP32[$1 >> 2] | 0) | 0) + $addr | 0; //@line 9456
  } else {
   $12 = _mem_get_blk(HEAP32[$sim + 8 >> 2] | 0, $addr) | 0; //@line 9460
   if (($12 | 0) != 0) {
    $18 = _mem_blk_get_data($12) | 0; //@line 9464
    $19 = _mem_blk_get_addr($12) | 0; //@line 9465
    $vbuf_0 = $18 + ($19 - (HEAP32[$sim + 4636 >> 2] | 0)) | 0; //@line 9470
    break;
   }
   _mac_video_set_vbuf(HEAP32[$sim + 3476 >> 2] | 0, 0); //@line 9475
   return;
  }
 } while (0);
 _mac_video_set_vbuf(HEAP32[$sim + 3476 >> 2] | 0, $vbuf_0); //@line 9484
 return;
}
function _mac_set_key($ext, $event, $key) {
 $ext = $ext | 0;
 $event = $event | 0;
 $key = $key | 0;
 var $3 = 0, $8 = 0, $14 = 0;
 if (($event | 0) == 3) {
  $3 = $ext; //@line 9502
  _mac_set_hotkey($3, $key) | 0; //@line 9503
  return;
 }
 $8 = HEAP32[$ext + 1744 >> 2] | 0; //@line 9510
 if (($8 | 0) != 0) {
  _mac_kbd_set_key($8, $event, $key); //@line 9514
 }
 $14 = HEAP32[$ext + 1752 >> 2] | 0; //@line 9519
 if (($14 | 0) == 0) {
  return;
 }
 _adb_kbd_set_key($14, $event, $key); //@line 9526
 return;
}
function _mac_set_mouse($ext, $dx, $dy, $but) {
 $ext = $ext | 0;
 $dx = $dx | 0;
 $dy = $dy | 0;
 $but = $but | 0;
 var $1 = 0, $10 = 0, $17 = 0, $22 = 0, $32 = 0, $35 = 0, $36 = 0, $storemerge = 0, $47 = 0, $51 = 0;
 $1 = $ext + 4676 | 0; //@line 9546
 if ((HEAP8[$1] | 0) != 0) {
  if (($but | 0) == 0) {
   return;
  }
  HEAP8[$1] = 0; //@line 9557
  HEAP32[$ext + 4700 >> 2] = 0; //@line 9560
  $10 = $ext + 4704 | 0; //@line 9562
  HEAP32[$10 >> 2] = 0; //@line 9563
  _pce_get_interval_us($10) | 0; //@line 9564
  HEAP32[$ext + 4696 >> 2] = 0; //@line 9567
  return;
 }
 $17 = HEAP32[$ext + 1756 >> 2] | 0; //@line 9574
 if (($17 | 0) != 0) {
  _adb_mouse_move($17, $but, $dx, $dy); //@line 9578
  return;
 }
 $22 = $ext + 4664 | 0; //@line 9584
 if ((($but & 2 ^ 2) & (HEAP32[$22 >> 2] ^ $but) | 0) != 0) {
  $32 = HEAP32[$ext + 3480 >> 2] | 0; //@line 9595
  _trm_set_msg_trm($32, 51848, 51328) | 0; //@line 9596
 }
 $35 = $ext + 4625 | 0; //@line 9599
 $36 = HEAP8[$35] | 0; //@line 9600
 $storemerge = ($but & 1 | 0) == 0 ? $36 | 8 : $36 & -9; //@line 9605
 HEAP8[$35] = $storemerge; //@line 9606
 if ($storemerge << 24 >> 24 != $36 << 24 >> 24) {
  _e6522_set_irb_inp($ext + 36 | 0, $storemerge); //@line 9612
 }
 $47 = $ext + 4656 | 0; //@line 9616
 HEAP32[$47 >> 2] = (HEAP32[$47 >> 2] | 0) + $dx; //@line 9619
 $51 = $ext + 4660 | 0; //@line 9621
 HEAP32[$51 >> 2] = (HEAP32[$51 >> 2] | 0) + $dy; //@line 9624
 HEAP32[$22 >> 2] = $but; //@line 9625
 return;
}
function _mac_set_iwm_motor($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $7 = 0, $14 = 0, $18 = 0, $v_1_1_i_i = 0, $25 = 0, sp = 0;
 sp = STACKTOP; //@line 9640
 $1 = $val << 24 >> 24 != 0; //@line 9641
 $2 = $1 ? 4 : 0; //@line 9642
 HEAP32[$ext + 4692 >> 2] = $2; //@line 9645
 $7 = HEAP32[$ext + 4688 >> 2] | 0; //@line 9648
 if ($1) {
  $v_1_1_i_i = ($7 | 0) == 0 | $2 >>> 0 < $7 >>> 0 ? $2 : $7; //@line 9656
 } else {
  $v_1_1_i_i = $7; //@line 9658
 }
 $25 = $ext + 4684 | 0; //@line 9662
 if (($v_1_1_i_i | 0) == (HEAP32[$25 >> 2] | 0)) {
  STACKTOP = sp; //@line 9667
  return;
 }
 _mac_log_deb(31040, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $v_1_1_i_i, tempInt) | 0); //@line 9670
 _mac_rtc_set_realtime($ext + 1428 | 0, ($v_1_1_i_i | 0) != 1 | 0); //@line 9675
 HEAP32[$25 >> 2] = $v_1_1_i_i; //@line 9676
 $14 = $ext + 4696 | 0; //@line 9678
 HEAP32[$14 >> 2] = 0; //@line 9679
 HEAP32[$ext + 4700 >> 2] = 0; //@line 9682
 $18 = $ext + 4704 | 0; //@line 9684
 HEAP32[$18 >> 2] = 0; //@line 9685
 _pce_get_interval_us($18) | 0; //@line 9686
 HEAP32[$14 >> 2] = 0; //@line 9687
 STACKTOP = sp; //@line 9689
 return;
}
function _sig_int($s) {
 $s = $s | 0;
 HEAP32[15590] = 1; //@line 9698
 return;
}
function _mac_set_adb_int($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $2 = 0, $3 = 0, $storemerge = 0;
 $2 = $ext + 4625 | 0; //@line 9711
 $3 = HEAP8[$2] | 0; //@line 9712
 $storemerge = $val << 24 >> 24 == 0 ? $3 | 8 : $3 & -9; //@line 9715
 HEAP8[$2] = $storemerge; //@line 9716
 _e6522_set_irb_inp($ext + 36 | 0, $storemerge); //@line 9719
 return;
}
function _mac_set_rtc_data($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $2 = 0, $3 = 0, $storemerge = 0;
 $2 = $ext + 4625 | 0; //@line 9732
 $3 = HEAP8[$2] | 0; //@line 9733
 $storemerge = $val << 24 >> 24 == 0 ? $3 & -2 : $3 | 1; //@line 9736
 HEAP8[$2] = $storemerge; //@line 9737
 _e6522_set_irb_inp($ext + 36 | 0, $storemerge); //@line 9740
 return;
}
function _mac_interrupt_scc($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $2 = 0, $3 = 0, $storemerge = 0, $i_0_i_i = 0, $val_0_in_i_i = 0, $val_0_i_i = 0;
 $2 = $ext + 4652 | 0; //@line 9754
 $3 = HEAP8[$2] | 0; //@line 9755
 $storemerge = $val << 24 >> 24 == 0 ? $3 & -5 : $3 | 4; //@line 9758
 HEAP8[$2] = $storemerge; //@line 9759
 $val_0_in_i_i = $storemerge & 255;
 $i_0_i_i = 0;
 while (1) {
  $val_0_i_i = $val_0_in_i_i >>> 1; //@line 9766
  if (($val_0_i_i | 0) == 0) {
   break;
  } else {
   $val_0_in_i_i = $val_0_i_i;
   $i_0_i_i = $i_0_i_i + 1 | 0;
  }
 }
 _e68_interrupt(HEAP32[$ext + 4 >> 2] | 0, $i_0_i_i); //@line 9779
 return;
}
function _mac_scc_get_uint8($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 var $val_0 = 0;
 if (($addr | 0) == 2097148) {
  $val_0 = _e8530_get_data_b($ext + 128 | 0) | 0; //@line 9797
 } else if (($addr | 0) == 2097144) {
  $val_0 = _e8530_get_ctl_b($ext + 128 | 0) | 0; //@line 9803
 } else if (($addr | 0) == 2097146) {
  $val_0 = _e8530_get_ctl_a($ext + 128 | 0) | 0; //@line 9809
 } else if (($addr | 0) == 2097150) {
  $val_0 = _e8530_get_data_a($ext + 128 | 0) | 0; //@line 9815
 } else {
  $val_0 = -1; //@line 9817
 }
 return $val_0 | 0; //@line 9821
}
function _mac_scc_set_uint8($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 if (($addr | 0) == 4194301) {
  _e8530_set_data_b($ext + 128 | 0, $val); //@line 9835
 } else if (($addr | 0) == 4194303) {
  _e8530_set_data_a($ext + 128 | 0, $val); //@line 9840
 } else if (($addr | 0) == 4194299) {
  _e8530_set_ctl_a($ext + 128 | 0, $val); //@line 9845
 } else if (($addr | 0) == 4194297) {
  _e8530_set_ctl_b($ext + 128 | 0, $val); //@line 9850
 }
 return;
}
function _mac_interrupt_via($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $2 = 0, $3 = 0, $storemerge = 0, $i_0_i_i = 0, $val_0_in_i_i = 0, $val_0_i_i = 0;
 $2 = $ext + 4652 | 0; //@line 9866
 $3 = HEAP8[$2] | 0; //@line 9867
 $storemerge = $val << 24 >> 24 == 0 ? $3 & -3 : $3 | 2; //@line 9870
 HEAP8[$2] = $storemerge; //@line 9871
 $val_0_in_i_i = $storemerge & 255;
 $i_0_i_i = 0;
 while (1) {
  $val_0_i_i = $val_0_in_i_i >>> 1; //@line 9878
  if (($val_0_i_i | 0) == 0) {
   break;
  } else {
   $val_0_in_i_i = $val_0_i_i;
   $i_0_i_i = $i_0_i_i + 1 | 0;
  }
 }
 _e68_interrupt(HEAP32[$ext + 4 >> 2] | 0, $i_0_i_i); //@line 9891
 return;
}
function _mac_set_via_port_a($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $8 = 0, $13 = 0, $addr_0_in_in = 0, $55 = 0, $_pn_in_in = 0, sp = 0;
 sp = STACKTOP; //@line 9909
 $1 = $ext; //@line 9910
 $2 = $ext + 4624 | 0; //@line 9911
 $3 = HEAP8[$2] | 0; //@line 9912
 $4 = $val & 255; //@line 9913
 if ($3 << 24 >> 24 == $val << 24 >> 24) {
  STACKTOP = sp; //@line 9917
  return;
 }
 HEAP8[$2] = $val; //@line 9920
 $8 = ($3 ^ $val) & 255; //@line 9922
 do {
  if (($8 & 16 | 0) != 0) {
   $13 = HEAP32[$ext >> 2] | 0; //@line 9929
   if (($13 & 1 | 0) != 0) {
    _mac_set_overlay($1, $4 >>> 4 & 1); //@line 9936
    break;
   }
   if (($13 & 6 | 0) == 0) {
    break;
   }
   _mac_iwm_set_drive_sel($ext + 1760 | 0, ($val & 255) >>> 4 & 1); //@line 9950
  }
 } while (0);
 if (($8 & 32 | 0) != 0) {
  _mac_iwm_set_head_sel($ext + 1760 | 0, ($val & 255) >>> 5 & 1); //@line 9962
 }
 if (($8 & 64 | 0) != 0) {
  if (($4 & 64 | 0) == 0) {
   _mac_log_deb(30912, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 9973
   $addr_0_in_in = $ext + 4640 | 0; //@line 9975
  } else {
   _mac_log_deb(31e3, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 9977
   $addr_0_in_in = $ext + 4636 | 0; //@line 9980
  }
  _mac_set_vbuf($1, HEAP32[$addr_0_in_in >> 2] | 0); //@line 9985
 }
 do {
  if (($8 & 8 | 0) != 0) {
   if ((HEAP32[$ext >> 2] & 1 | 0) == 0) {
    break;
   }
   $55 = _mem_blk_get_data(HEAP32[$ext + 12 >> 2] | 0) | 0; //@line 10004
   if (($4 & 8 | 0) == 0) {
    _mac_log_deb(30552, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 10009
    $_pn_in_in = $ext + 4648 | 0; //@line 10011
   } else {
    _mac_log_deb(30672, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 10013
    $_pn_in_in = $ext + 4644 | 0; //@line 10016
   }
   _mac_sound_set_sbuf($ext + 2644 | 0, $55 + (HEAP32[$_pn_in_in >> 2] | 0) | 0); //@line 10024
  }
 } while (0);
 if (($8 & 7 | 0) == 0) {
  STACKTOP = sp; //@line 10032
  return;
 }
 _mac_sound_set_volume($ext + 2644 | 0, $4 & 7); //@line 10038
 STACKTOP = sp; //@line 10040
 return;
}
function _mac_set_via_port_b($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $16 = 0;
 $1 = $ext + 4625 | 0; //@line 10053
 $2 = HEAP8[$1] | 0; //@line 10054
 if ($2 << 24 >> 24 == $val << 24 >> 24) {
  return;
 }
 HEAP8[$1] = $val; //@line 10061
 _mac_rtc_set_uint8($ext + 1428 | 0, $val); //@line 10064
 if (($2 ^ $val) << 24 >> 24 < 0) {
  _mac_sound_set_enable($ext + 2644 | 0, ($val & 255) >>> 7 & 255 ^ 1); //@line 10074
 }
 $16 = HEAP32[$ext + 1748 >> 2] | 0; //@line 10079
 if (($16 | 0) == 0) {
  return;
 }
 _mac_adb_set_state($16, ($val & 255) >>> 4 & 3); //@line 10088
 return;
}
function _mac_set_reset($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 if ($val << 24 >> 24 == 0) {
  return;
 }
 _mac_reset($ext); //@line 10108
 return;
}
function _mac_log_deb($msg, varrp) {
 $msg = $msg | 0;
 varrp = varrp | 0;
 var $va = 0, $1 = 0, $pc_0 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 10121
 STACKTOP = STACKTOP + 16 | 0; //@line 10121
 $va = sp | 0; //@line 10122
 $1 = HEAP32[15588] | 0; //@line 10123
 if (($1 | 0) == 0) {
  $pc_0 = 0; //@line 10127
 } else {
  $pc_0 = (_e68_get_last_pc(HEAP32[$1 + 4 >> 2] | 0, 0) | 0) & 16777215; //@line 10134
 }
 _pce_log(3, 45928, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $pc_0, tempInt) | 0); //@line 10137
 $9 = $va; //@line 10139
 HEAP32[$9 >> 2] = varrp; //@line 10140
 HEAP32[$9 + 4 >> 2] = 0; //@line 10140
 _pce_log_va(3, $msg, $va | 0); //@line 10141
 STACKTOP = sp; //@line 10143
 return;
}
function _mac_atexit() {
 _pce_set_fd_interactive(0, 1); //@line 10151
 return;
}
function _cmd_get_sym1833($sim, $sym, $val) {
 $sim = $sim | 0;
 $sym = $sym | 0;
 $val = $val | 0;
 return (_e68_get_reg(HEAP32[$sim + 4 >> 2] | 0, $sym, $val) | 0) != 0 | 0; //@line 10170
}
function _cmd_set_sym1835($sim, $sym, $val) {
 $sim = $sim | 0;
 $sym = $sym | 0;
 $val = $val | 0;
 return (_e68_set_reg(HEAP32[$sim + 4 >> 2] | 0, $sym, $val) | 0) != 0 | 0; //@line 10187
}
function _mac_set_overlay($sim, $overlay) {
 $sim = $sim | 0;
 $overlay = $overlay | 0;
 var $1 = 0, $3 = 0, $7 = 0, $8 = 0, $27 = 0, $30 = 0, $32 = 0;
 $1 = $sim + 4628 | 0; //@line 10200
 $3 = ($overlay | 0) != 0; //@line 10202
 if ((HEAP32[$1 >> 2] | 0) == ($3 & 1 | 0)) {
  return;
 }
 $7 = $sim + 8 | 0; //@line 10210
 $8 = HEAP32[$7 >> 2] | 0; //@line 10211
 if ($3) {
  _mem_rmv_blk($8, HEAP32[$sim + 12 >> 2] | 0); //@line 10216
  _mem_add_blk(HEAP32[$7 >> 2] | 0, HEAP32[$sim + 24 >> 2] | 0, 0); //@line 10220
  _mem_add_blk(HEAP32[$7 >> 2] | 0, HEAP32[$sim + 20 >> 2] | 0, 0); //@line 10224
  _e68_set_ram(HEAP32[$sim + 4 >> 2] | 0, 0, 0); //@line 10227
  HEAP32[$1 >> 2] = 1; //@line 10228
  return;
 } else {
  _mem_rmv_blk($8, HEAP32[$sim + 24 >> 2] | 0); //@line 10235
  _mem_rmv_blk(HEAP32[$7 >> 2] | 0, HEAP32[$sim + 20 >> 2] | 0); //@line 10239
  $27 = $sim + 12 | 0; //@line 10241
  _mem_add_blk(HEAP32[$7 >> 2] | 0, HEAP32[$27 >> 2] | 0, 0); //@line 10243
  $30 = HEAP32[$sim + 4 >> 2] | 0; //@line 10245
  $32 = _mem_blk_get_data(HEAP32[$27 >> 2] | 0) | 0; //@line 10247
  _e68_set_ram($30, $32, _mem_blk_get_size(HEAP32[$27 >> 2] | 0) | 0); //@line 10250
  HEAP32[$1 >> 2] = 0; //@line 10251
  return;
 }
}
function _mac_mem_get_uint8($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 var $5 = 0, $8 = 0, $11 = 0, $18 = 0, $21 = 0, $25 = 0, $addr12_ph = 0, $_off7 = 0, $_0 = 0, label = 0;
 do {
  if ($addr >>> 0 < 4194304) {
   $5 = HEAP32[$ext + 12 >> 2] | 0; //@line 10274
   if (($5 | 0) == 0) {
    break;
   }
   $8 = _mem_blk_get_size($5) | 0; //@line 10280
   if (($8 | 0) == 0) {
    break;
   }
   $11 = ($addr >>> 0) % ($8 >>> 0) | 0; //@line 10286
   if (($11 | 0) != ($addr | 0)) {
    $addr12_ph = $11; //@line 10290
    label = 1300; //@line 10291
   }
  } else {
   if ($addr >>> 0 >= 5767168) {
    break;
   }
   $18 = HEAP32[$ext + 16 >> 2] | 0; //@line 10301
   if (($18 | 0) == 0) {
    break;
   }
   $21 = _mem_blk_get_size($18) | 0; //@line 10307
   if (($21 | 0) == 0) {
    break;
   }
   $25 = (($addr >>> 0) % ($21 >>> 0) | 0) + 4194304 | 0; //@line 10314
   if (($25 | 0) != ($addr | 0)) {
    $addr12_ph = $25; //@line 10318
    label = 1300; //@line 10319
   }
  }
 } while (0);
 if ((label | 0) == 1300) {
  $_0 = _mem_get_uint8(HEAP32[$ext + 8 >> 2] | 0, $addr12_ph) | 0; //@line 10330
  return $_0 | 0; //@line 10333
 }
 if (($addr - 5767168 | 0) >>> 0 < 524288) {
  $_0 = 0; //@line 10339
  return $_0 | 0; //@line 10342
 }
 $_off7 = $addr - 12582912 | 0; //@line 10344
 if ($_off7 >>> 0 < 2097152) {
  $_0 = _mac_iwm_get_uint8($ext + 1760 | 0, $_off7) | 0; //@line 10352
  return $_0 | 0; //@line 10355
 } else {
  $_0 = ($addr & 15728640 | 0) == 13631488 ? -86 : 0; //@line 10361
  return $_0 | 0; //@line 10364
 }
 return 0;
}
function _sig_segv($s) {
 $s = $s | 0;
 var $5 = 0;
 _pce_set_fd_interactive(0, 1); //@line 10375
 _fwrite(51584, 32, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 10377
 _fflush(HEAP32[_stderr >> 2] | 0) | 0; //@line 10379
 $5 = HEAP32[15588] | 0; //@line 10380
 if (($5 | 0) == 0) {
  _exit(1); //@line 10384
 }
 if ((HEAP32[$5 + 4 >> 2] | 0) == 0) {
  _exit(1); //@line 10392
 }
 _mac_prt_state($5, 56232); //@line 10395
 _exit(1); //@line 10397
}
function _sig_term($s) {
 $s = $s | 0;
 _pce_set_fd_interactive(0, 1); //@line 10407
 _fprintf(HEAP32[_stderr >> 2] | 0, 49784, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $s, tempInt) | 0) | 0; //@line 10409
 _fflush(HEAP32[_stderr >> 2] | 0) | 0; //@line 10411
 _exit(1); //@line 10412
}
function _main($argc, $argv) {
 $argc = $argc | 0;
 $argv = $argv | 0;
 var $optarg = 0, $3 = 0, $7 = 0, $9 = 0, $cfg_023 = 0, $29 = 0, $33 = 0, $34 = 0, $37 = 0, $63 = 0, $cfg_0_be = 0, $88 = 0, $94 = 0, $cfg_0_lcssa24 = 0, $103 = 0, $_ = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 10436
 STACKTOP = STACKTOP + 8 | 0; //@line 10436
 $optarg = sp | 0; //@line 10437
 _pce_log_init(); //@line 10438
 _pce_log_add_fp(HEAP32[_stderr >> 2] | 0, 0, 2) | 0; //@line 10440
 $3 = _ini_sct_new(0) | 0; //@line 10441
 HEAP32[15674] = $3; //@line 10442
 if (($3 | 0) == 0) {
  $_0 = 1; //@line 10446
  STACKTOP = sp; //@line 10448
  return $_0 | 0; //@line 10449
 }
 _ini_str_init(62648); //@line 10451
 _pce_log_set_level(HEAP32[_stderr >> 2] | 0, 3); //@line 10453
 $7 = _pce_getopt($argc, $argv, $optarg, 7128) | 0; //@line 10454
 do {
  if (($7 | 0) == -1) {
   _pce_log(2, 52296, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 10459
   $cfg_0_lcssa24 = 42456; //@line 10461
   label = 1343; //@line 10462
  } else {
   $cfg_023 = 42456;
   $9 = $7;
   while (1) {
    if (($9 | 0) < 0) {
     $_0 = 1; //@line 10471
     label = 1351; //@line 10472
     break;
    }
    if (($9 | 0) == 98) {
     HEAP32[15668] = HEAP32[15668] | 1; //@line 10478
     HEAP32[15670] = _strtoul(HEAP32[HEAP32[$optarg >> 2] >> 2] | 0, 0, 0) | 0; //@line 10482
     $cfg_0_be = $cfg_023; //@line 10484
    } else if (($9 | 0) == 112) {
     _ini_str_add(62648, 31680, HEAP32[HEAP32[$optarg >> 2] >> 2] | 0, 30720) | 0; //@line 10488
     $cfg_0_be = $cfg_023; //@line 10490
    } else if (($9 | 0) == 86) {
     label = 1324; //@line 10492
     break;
    } else if (($9 | 0) == 113) {
     _pce_log_set_level(HEAP32[_stderr >> 2] | 0, 0); //@line 10496
     $cfg_0_be = $cfg_023; //@line 10498
    } else if (($9 | 0) == 115) {
     _ini_str_add(62648, 57912, HEAP32[HEAP32[$optarg >> 2] >> 2] | 0, 33480) | 0; //@line 10502
     $cfg_0_be = $cfg_023; //@line 10504
    } else if (($9 | 0) == 116) {
     HEAP32[15586] = HEAP32[HEAP32[$optarg >> 2] >> 2]; //@line 10508
     $cfg_0_be = $cfg_023; //@line 10510
    } else if (($9 | 0) == 63) {
     label = 1323; //@line 10512
     break;
    } else if (($9 | 0) == 66) {
     $29 = _strtoul(HEAP32[HEAP32[$optarg >> 2] >> 2] | 0, 0, 0) | 0; //@line 10517
     if (($29 | 0) == 0 | $29 >>> 0 > 3) {
      label = 1327; //@line 10523
      break;
     }
     $37 = $29 - 1 | 0; //@line 10526
     HEAP32[15668] = HEAP32[15668] | 1 << $37; //@line 10530
     HEAP32[62680 + ($37 << 2) >> 2] = _strtoul(HEAP32[(HEAP32[$optarg >> 2] | 0) + 4 >> 2] | 0, 0, 0) | 0; //@line 10536
     $cfg_0_be = $cfg_023; //@line 10538
    } else if (($9 | 0) == 108) {
     _pce_log_add_fname(HEAP32[HEAP32[$optarg >> 2] >> 2] | 0, 3) | 0; //@line 10542
     $cfg_0_be = $cfg_023; //@line 10544
    } else if (($9 | 0) == 99) {
     $cfg_0_be = HEAP32[HEAP32[$optarg >> 2] >> 2] | 0; //@line 10549
    } else if (($9 | 0) == 118) {
     _pce_log_set_level(HEAP32[_stderr >> 2] | 0, 3); //@line 10552
     $cfg_0_be = $cfg_023; //@line 10554
    } else if (($9 | 0) == 114 | ($9 | 0) == 82) {
     $cfg_0_be = $cfg_023;
    } else if (($9 | 0) == 73) {
     _ini_str_add(62648, HEAP32[HEAP32[$optarg >> 2] >> 2] | 0, 33480, 0) | 0; //@line 10560
     $cfg_0_be = $cfg_023; //@line 10562
    } else if (($9 | 0) == 100) {
     _pce_path_set(HEAP32[HEAP32[$optarg >> 2] >> 2] | 0) | 0; //@line 10566
     $cfg_0_be = $cfg_023; //@line 10568
    } else if (($9 | 0) == 105) {
     if ((_ini_read_str(HEAP32[15674] | 0, HEAP32[HEAP32[$optarg >> 2] >> 2] | 0) | 0) == 0) {
      $cfg_0_be = $cfg_023; //@line 10577
     } else {
      label = 1332; //@line 10579
      break;
     }
    } else if (($9 | 0) == 0) {
     label = 1341; //@line 10583
     break;
    } else {
     $_0 = 1; //@line 10586
     label = 1350; //@line 10587
     break;
    }
    $88 = _pce_getopt($argc, $argv, $optarg, 7128) | 0; //@line 10591
    if (($88 | 0) == -1) {
     label = 1342; //@line 10595
     break;
    } else {
     $cfg_023 = $cfg_0_be;
     $9 = $88;
    }
   }
   if ((label | 0) == 1327) {
    $33 = HEAP32[_stderr >> 2] | 0; //@line 10602
    $34 = HEAP32[$argv >> 2] | 0; //@line 10603
    _fprintf($33 | 0, 39336, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $34, HEAP32[tempInt + 8 >> 2] = $29, tempInt) | 0) | 0; //@line 10604
    $_0 = 1; //@line 10606
    STACKTOP = sp; //@line 10608
    return $_0 | 0; //@line 10609
   } else if ((label | 0) == 1324) {
    _fwrite(51712, 93, 1, HEAP32[_stdout >> 2] | 0) | 0; //@line 10613
    _fflush(HEAP32[_stdout >> 2] | 0) | 0; //@line 10615
    $_0 = 0; //@line 10617
    STACKTOP = sp; //@line 10619
    return $_0 | 0; //@line 10620
   } else if ((label | 0) == 1323) {
    _pce_getopt_help(51200, 50704, 7128); //@line 10623
    _fflush(HEAP32[_stdout >> 2] | 0) | 0; //@line 10625
    $_0 = 0; //@line 10627
    STACKTOP = sp; //@line 10629
    return $_0 | 0; //@line 10630
   } else if ((label | 0) == 1350) {
    STACKTOP = sp; //@line 10634
    return $_0 | 0; //@line 10635
   } else if ((label | 0) == 1351) {
    STACKTOP = sp; //@line 10639
    return $_0 | 0; //@line 10640
   } else if ((label | 0) == 1332) {
    $63 = HEAP32[HEAP32[$optarg >> 2] >> 2] | 0; //@line 10646
    _fprintf(HEAP32[_stderr >> 2] | 0, 36408, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$argv >> 2], HEAP32[tempInt + 8 >> 2] = $63, tempInt) | 0) | 0; //@line 10647
    $_0 = 1; //@line 10649
    STACKTOP = sp; //@line 10651
    return $_0 | 0; //@line 10652
   } else if ((label | 0) == 1341) {
    $94 = HEAP32[HEAP32[$optarg >> 2] >> 2] | 0; //@line 10658
    _fprintf(HEAP32[_stderr >> 2] | 0, 57056, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$argv >> 2], HEAP32[tempInt + 8 >> 2] = $94, tempInt) | 0) | 0; //@line 10659
    $_0 = 1; //@line 10661
    STACKTOP = sp; //@line 10663
    return $_0 | 0; //@line 10664
   } else if ((label | 0) == 1342) {
    _pce_log(2, 52296, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 10667
    if (($cfg_0_be | 0) == 0) {
     break;
    } else {
     $cfg_0_lcssa24 = $cfg_0_be; //@line 10673
     label = 1343; //@line 10674
     break;
    }
   }
  }
 } while (0);
 do {
  if ((label | 0) == 1343) {
   _pce_log_tag(2, 54504, 53824, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $cfg_0_lcssa24, tempInt) | 0); //@line 10683
   if ((_ini_read(HEAP32[15674] | 0, $cfg_0_lcssa24) | 0) == 0) {
    break;
   }
   _pce_log(0, 53208, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 10691
   $_0 = 1; //@line 10693
   STACKTOP = sp; //@line 10695
   return $_0 | 0; //@line 10696
  }
 } while (0);
 $103 = _ini_next_sct(HEAP32[15674] | 0, 0, 55896) | 0; //@line 10700
 $_ = ($103 | 0) == 0 ? HEAP32[15674] | 0 : $103; //@line 10703
 if ((_ini_str_eval(62648, $_, 1) | 0) == 0) {
  _atexit(2) | 0; //@line 10708
  _SDL_Init(0) | 0; //@line 10709
  _pce_path_ini($_) | 0; //@line 10710
  _signal(2, 216) | 0; //@line 10711
  _signal(11, 424) | 0; //@line 10712
  _signal(15, 416) | 0; //@line 10713
  _pce_console_init(HEAP32[_stdin >> 2] | 0, HEAP32[_stdout >> 2] | 0); //@line 10716
  HEAP32[15588] = _mac_new($_) | 0; //@line 10718
  _mon_init(62384); //@line 10719
  _mon_set_cmd_fct(62384, 14, HEAP32[15588] | 0); //@line 10722
  _mon_set_msg_fct(62384, 70, HEAP32[15588] | 0); //@line 10725
  _mon_set_get_mem_fct(62384, HEAP32[(HEAP32[15588] | 0) + 8 >> 2] | 0, 26); //@line 10730
  _mon_set_set_mem_fct(62384, HEAP32[(HEAP32[15588] | 0) + 8 >> 2] | 0, 12); //@line 10735
  _mon_set_memory_mode(62384, 0); //@line 10736
  _cmd_init(HEAP32[15588] | 0, 20, 38); //@line 10739
  _mac_cmd_init(HEAP32[15588] | 0, 62384); //@line 10741
  _mac_reset(HEAP32[15588] | 0); //@line 10743
  _mac_run_emscripten(HEAP32[15588] | 0); //@line 10745
  _exit(1); //@line 10746
  return 0; //@line 10747
 } else {
  $_0 = 1; //@line 10749
  STACKTOP = sp; //@line 10751
  return $_0 | 0; //@line 10752
 }
 return 0;
}
function _mac_mem_get_uint16($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 var $5 = 0, $8 = 0, $11 = 0, $18 = 0, $21 = 0, $25 = 0, $addr6_ph = 0, $_0 = 0, label = 0;
 do {
  if ($addr >>> 0 < 4194304) {
   $5 = HEAP32[$ext + 12 >> 2] | 0; //@line 10772
   if (($5 | 0) == 0) {
    $_0 = 0; //@line 10776
    break;
   }
   $8 = _mem_blk_get_size($5) | 0; //@line 10779
   if (($8 | 0) == 0) {
    $_0 = 0; //@line 10783
    break;
   }
   $11 = ($addr >>> 0) % ($8 >>> 0) | 0; //@line 10786
   if (($11 | 0) == ($addr | 0)) {
    $_0 = 0; //@line 10790
   } else {
    $addr6_ph = $11; //@line 10792
    label = 1366; //@line 10793
   }
  } else {
   if ($addr >>> 0 >= 5767168) {
    $_0 = 0; //@line 10799
    break;
   }
   $18 = HEAP32[$ext + 16 >> 2] | 0; //@line 10804
   if (($18 | 0) == 0) {
    $_0 = 0; //@line 10808
    break;
   }
   $21 = _mem_blk_get_size($18) | 0; //@line 10811
   if (($21 | 0) == 0) {
    $_0 = 0; //@line 10815
    break;
   }
   $25 = (($addr >>> 0) % ($21 >>> 0) | 0) + 4194304 | 0; //@line 10819
   if (($25 | 0) == ($addr | 0)) {
    $_0 = 0; //@line 10823
   } else {
    $addr6_ph = $25; //@line 10825
    label = 1366; //@line 10826
   }
  }
 } while (0);
 if ((label | 0) == 1366) {
  $_0 = _mem_get_uint16_be(HEAP32[$ext + 8 >> 2] | 0, $addr6_ph) | 0; //@line 10837
 }
 return $_0 | 0; //@line 10841
}
function _mac_mem_get_uint32($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 var $5 = 0, $8 = 0, $11 = 0, $18 = 0, $21 = 0, $25 = 0, $addr6_ph = 0, $_0 = 0, label = 0;
 do {
  if ($addr >>> 0 < 4194304) {
   $5 = HEAP32[$ext + 12 >> 2] | 0; //@line 10860
   if (($5 | 0) == 0) {
    $_0 = 0; //@line 10864
    break;
   }
   $8 = _mem_blk_get_size($5) | 0; //@line 10867
   if (($8 | 0) == 0) {
    $_0 = 0; //@line 10871
    break;
   }
   $11 = ($addr >>> 0) % ($8 >>> 0) | 0; //@line 10874
   if (($11 | 0) == ($addr | 0)) {
    $_0 = 0; //@line 10878
   } else {
    $addr6_ph = $11; //@line 10880
    label = 1376; //@line 10881
   }
  } else {
   if ($addr >>> 0 >= 5767168) {
    $_0 = 0; //@line 10887
    break;
   }
   $18 = HEAP32[$ext + 16 >> 2] | 0; //@line 10892
   if (($18 | 0) == 0) {
    $_0 = 0; //@line 10896
    break;
   }
   $21 = _mem_blk_get_size($18) | 0; //@line 10899
   if (($21 | 0) == 0) {
    $_0 = 0; //@line 10903
    break;
   }
   $25 = (($addr >>> 0) % ($21 >>> 0) | 0) + 4194304 | 0; //@line 10907
   if (($25 | 0) == ($addr | 0)) {
    $_0 = 0; //@line 10911
   } else {
    $addr6_ph = $25; //@line 10913
    label = 1376; //@line 10914
   }
  }
 } while (0);
 if ((label | 0) == 1376) {
  $_0 = _mem_get_uint32_be(HEAP32[$ext + 8 >> 2] | 0, $addr6_ph) | 0; //@line 10925
 }
 return $_0 | 0; //@line 10929
}
function _mac_mem_set_uint8($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $5 = 0, $8 = 0, $11 = 0, $18 = 0, $21 = 0, $25 = 0, $addr14_ph = 0, $addr1415 = 0, label = 0;
 do {
  if ($addr >>> 0 < 4194304) {
   $5 = HEAP32[$ext + 12 >> 2] | 0; //@line 10950
   if (($5 | 0) == 0) {
    return;
   }
   $8 = _mem_blk_get_size($5) | 0; //@line 10957
   if (($8 | 0) == 0) {
    return;
   }
   $11 = ($addr >>> 0) % ($8 >>> 0) | 0; //@line 10964
   if (($11 | 0) != ($addr | 0)) {
    $addr14_ph = $11; //@line 10968
    label = 1386; //@line 10969
    break;
   }
   return;
  } else {
   if ($addr >>> 0 >= 5767168) {
    $addr1415 = $addr; //@line 10978
    break;
   }
   $18 = HEAP32[$ext + 16 >> 2] | 0; //@line 10983
   if (($18 | 0) == 0) {
    $addr1415 = $addr; //@line 10987
    break;
   }
   $21 = _mem_blk_get_size($18) | 0; //@line 10990
   if (($21 | 0) == 0) {
    $addr1415 = $addr; //@line 10994
    break;
   }
   $25 = (($addr >>> 0) % ($21 >>> 0) | 0) + 4194304 | 0; //@line 10998
   if (($25 | 0) == ($addr | 0)) {
    $addr1415 = $addr; //@line 11002
   } else {
    $addr14_ph = $25; //@line 11004
    label = 1386; //@line 11005
   }
  }
 } while (0);
 if ((label | 0) == 1386) {
  _mem_set_uint8(HEAP32[$ext + 8 >> 2] | 0, $addr14_ph, $val); //@line 11014
  $addr1415 = $addr14_ph; //@line 11016
 }
 if (!(($addr1415 - 5767168 | 0) >>> 0 > 524287 & $addr1415 >>> 0 > 12582911 & $addr1415 >>> 0 < 14680064)) {
  return;
 }
 _mac_iwm_set_uint8($ext + 1760 | 0, $addr1415 - 12582912 | 0, $val); //@line 11033
 return;
}
function _mac_mem_set_uint16($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $5 = 0, $8 = 0, $11 = 0, $18 = 0, $21 = 0, $25 = 0, $addr6_ph = 0;
 do {
  if ($addr >>> 0 < 4194304) {
   $5 = HEAP32[$ext + 12 >> 2] | 0; //@line 11055
   if (($5 | 0) == 0) {
    return;
   }
   $8 = _mem_blk_get_size($5) | 0; //@line 11062
   if (($8 | 0) == 0) {
    return;
   }
   $11 = ($addr >>> 0) % ($8 >>> 0) | 0; //@line 11069
   if (($11 | 0) != ($addr | 0)) {
    $addr6_ph = $11; //@line 11073
    break;
   }
   return;
  } else {
   if ($addr >>> 0 >= 5767168) {
    return;
   }
   $18 = HEAP32[$ext + 16 >> 2] | 0; //@line 11087
   if (($18 | 0) == 0) {
    return;
   }
   $21 = _mem_blk_get_size($18) | 0; //@line 11094
   if (($21 | 0) == 0) {
    return;
   }
   $25 = (($addr >>> 0) % ($21 >>> 0) | 0) + 4194304 | 0; //@line 11102
   if (($25 | 0) != ($addr | 0)) {
    $addr6_ph = $25; //@line 11106
    break;
   }
   return;
  }
 } while (0);
 _mem_set_uint16_be(HEAP32[$ext + 8 >> 2] | 0, $addr6_ph, $val); //@line 11117
 return;
}
function _mac_mem_set_uint32($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $5 = 0, $8 = 0, $11 = 0, $18 = 0, $21 = 0, $25 = 0, $addr6_ph = 0;
 do {
  if ($addr >>> 0 < 4194304) {
   $5 = HEAP32[$ext + 12 >> 2] | 0; //@line 11139
   if (($5 | 0) == 0) {
    return;
   }
   $8 = _mem_blk_get_size($5) | 0; //@line 11146
   if (($8 | 0) == 0) {
    return;
   }
   $11 = ($addr >>> 0) % ($8 >>> 0) | 0; //@line 11153
   if (($11 | 0) != ($addr | 0)) {
    $addr6_ph = $11; //@line 11157
    break;
   }
   return;
  } else {
   if ($addr >>> 0 >= 5767168) {
    return;
   }
   $18 = HEAP32[$ext + 16 >> 2] | 0; //@line 11171
   if (($18 | 0) == 0) {
    return;
   }
   $21 = _mem_blk_get_size($18) | 0; //@line 11178
   if (($21 | 0) == 0) {
    return;
   }
   $25 = (($addr >>> 0) % ($21 >>> 0) | 0) + 4194304 | 0; //@line 11186
   if (($25 | 0) != ($addr | 0)) {
    $addr6_ph = $25; //@line 11190
    break;
   }
   return;
  }
 } while (0);
 _mem_set_uint32_be(HEAP32[$ext + 8 >> 2] | 0, $addr6_ph, $val); //@line 11201
 return;
}
function _mac_set_msg($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $_sim = 0, $_val = 0, $lst_0 = 0, $8 = 0, $20 = 0, $23 = 0, $_0 = 0, label = 0;
 $_sim = ($sim | 0) == 0 ? HEAP32[15588] | 0 : $sim; //@line 11219
 if (($msg | 0) == 0) {
  $_0 = 1; //@line 11223
  return $_0 | 0; //@line 11226
 }
 $_val = ($val | 0) == 0 ? 62856 : $val; //@line 11229
 $lst_0 = 6400; //@line 11231
 while (1) {
  $8 = HEAP32[$lst_0 >> 2] | 0; //@line 11235
  if (($8 | 0) == 0) {
   break;
  }
  if ((_msg_is_message($8, $msg) | 0) == 0) {
   $lst_0 = $lst_0 + 8 | 0; //@line 11246
  } else {
   label = 1435; //@line 11248
   break;
  }
 }
 if ((label | 0) == 1435) {
  $_0 = FUNCTION_TABLE_iiii[HEAP32[$lst_0 + 4 >> 2] & 127]($_sim, $msg, $_val) | 0; //@line 11257
  return $_0 | 0; //@line 11260
 }
 $20 = HEAP32[$_sim + 3480 >> 2] | 0; //@line 11263
 do {
  if (($20 | 0) != 0) {
   $23 = _trm_set_msg_trm($20, $msg, $_val) | 0; //@line 11268
   if (($23 | 0) > -1) {
    $_0 = $23; //@line 11272
   } else {
    break;
   }
   return $_0 | 0; //@line 11278
  }
 } while (0);
 $_0 = 1; //@line 11282
 return $_0 | 0; //@line 11285
}
function _mac_set_msg_emu_cpu_model($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11295
 if ((_mac_set_cpu_model($sim, $val) | 0) == 0) {
  $_0 = 0; //@line 11300
  STACKTOP = sp; //@line 11302
  return $_0 | 0; //@line 11303
 }
 _pce_log(0, 41472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $val, tempInt) | 0); //@line 11305
 $_0 = 1; //@line 11307
 STACKTOP = sp; //@line 11309
 return $_0 | 0; //@line 11310
}
function _mac_set_msg_emu_cpu_speed($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $f = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11320
 STACKTOP = STACKTOP + 8 | 0; //@line 11320
 $f = sp | 0; //@line 11321
 if ((_msg_get_uint($val, $f) | 0) != 0) {
  $_0 = 1; //@line 11326
  STACKTOP = sp; //@line 11328
  return $_0 | 0; //@line 11329
 }
 _mac_set_speed($sim, 0, HEAP32[$f >> 2] | 0); //@line 11332
 $_0 = 0; //@line 11334
 STACKTOP = sp; //@line 11336
 return $_0 | 0; //@line 11337
}
function _mac_set_msg_emu_cpu_speed_step($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $v = 0, $7 = 0, $_ = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11348
 STACKTOP = STACKTOP + 8 | 0; //@line 11348
 $v = sp | 0; //@line 11349
 if ((_msg_get_sint($val, $v) | 0) != 0) {
  $_0 = 1; //@line 11354
  STACKTOP = sp; //@line 11356
  return $_0 | 0; //@line 11357
 }
 $7 = (HEAP32[$v >> 2] | 0) + (HEAP32[$sim + 4684 >> 2] | 0) | 0; //@line 11362
 $_ = ($7 | 0) < 1 ? 1 : $7; //@line 11364
 HEAP32[$v >> 2] = $_; //@line 11365
 _mac_set_speed($sim, 0, $_); //@line 11366
 $_0 = 0; //@line 11368
 STACKTOP = sp; //@line 11370
 return $_0 | 0; //@line 11371
}
function _mac_set_msg_emu_disk_commit($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $drv = 0, $4 = 0, $r_0_ph = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 11383
 STACKTOP = STACKTOP + 16 | 0; //@line 11383
 $1 = sp | 0; //@line 11384
 $drv = sp + 8 | 0; //@line 11385
 HEAP32[$1 >> 2] = $val; //@line 11386
 if ((_strcmp($val | 0, 44056) | 0) == 0) {
  _pce_log(2, 43752, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 11391
  if ((_dsks_commit(HEAP32[$sim + 3484 >> 2] | 0) | 0) == 0) {
   $_0 = 0; //@line 11398
   STACKTOP = sp; //@line 11400
   return $_0 | 0; //@line 11401
  }
  _pce_log(0, 43496, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 11403
  $_0 = 1; //@line 11405
  STACKTOP = sp; //@line 11407
  return $_0 | 0; //@line 11408
 }
 $4 = $sim + 3484 | 0; //@line 11410
 $r_0_ph = 0; //@line 11412
 L1848 : while (1) {
  do {
   if ((HEAP8[HEAP32[$1 >> 2] | 0] | 0) == 0) {
    $_0 = $r_0_ph; //@line 11421
    label = 1470; //@line 11422
    break L1848;
   }
   if ((_msg_get_prefix_uint($1, $drv, 48168, 47824) | 0) != 0) {
    break L1848;
   }
   _pce_log(2, 42864, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$drv >> 2], tempInt) | 0); //@line 11432
  } while ((_dsks_set_msg(HEAP32[$4 >> 2] | 0, HEAP32[$drv >> 2] | 0, 42208, 0) | 0) == 0);
  _pce_log(0, 41864, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$drv >> 2], tempInt) | 0); //@line 11443
  $r_0_ph = 1; //@line 11445
 }
 if ((label | 0) == 1470) {
  STACKTOP = sp; //@line 11449
  return $_0 | 0; //@line 11450
 }
 _pce_log(0, 43096, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$1 >> 2], tempInt) | 0); //@line 11453
 $_0 = 1; //@line 11455
 STACKTOP = sp; //@line 11457
 return $_0 | 0; //@line 11458
}
function _mac_set_msg_emu_disk_eject($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $drv = 0, $4 = 0, $13 = 0, $15 = 0, $18 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 11470
 STACKTOP = STACKTOP + 16 | 0; //@line 11470
 $1 = sp | 0; //@line 11471
 $drv = sp + 8 | 0; //@line 11472
 HEAP32[$1 >> 2] = $val; //@line 11473
 if ((HEAP8[$val] | 0) == 0) {
  $_0 = 0; //@line 11478
  STACKTOP = sp; //@line 11480
  return $_0 | 0; //@line 11481
 }
 $4 = $sim + 3484 | 0; //@line 11483
 while (1) {
  if ((_msg_get_prefix_uint($1, $drv, 48168, 47824) | 0) != 0) {
   break;
  }
  $13 = _dsks_get_disk(HEAP32[$4 >> 2] | 0, HEAP32[$drv >> 2] | 0) | 0; //@line 11494
  $15 = HEAP32[$drv >> 2] | 0; //@line 11496
  if (($13 | 0) == 0) {
   _pce_log(0, 44640, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $15, tempInt) | 0); //@line 11499
  } else {
   _pce_log(2, 44320, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $15, tempInt) | 0); //@line 11502
   $18 = HEAP32[$4 >> 2] | 0; //@line 11503
   _dsks_rmv_disk($18, $13) | 0; //@line 11504
   _dsk_del($13); //@line 11505
  }
  if ((HEAP8[HEAP32[$1 >> 2] | 0] | 0) == 0) {
   $_0 = 0; //@line 11512
   label = 1484; //@line 11513
   break;
  }
 }
 if ((label | 0) == 1484) {
  STACKTOP = sp; //@line 11519
  return $_0 | 0; //@line 11520
 }
 _pce_log(0, 45008, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$1 >> 2], tempInt) | 0); //@line 11523
 $_0 = 1; //@line 11525
 STACKTOP = sp; //@line 11527
 return $_0 | 0; //@line 11528
}
function _mac_set_msg_emu_disk_insert($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 return (_dsk_insert(HEAP32[$sim + 3484 >> 2] | 0, $val, 1) | 0) != 0 | 0; //@line 11545
}
function _mac_set_msg_emu_disk_ro($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $drv = 0, $7 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11556
 STACKTOP = STACKTOP + 8 | 0; //@line 11556
 $drv = sp | 0; //@line 11557
 if ((_msg_get_uint($val, $drv) | 0) != 0) {
  $_0 = 1; //@line 11562
  STACKTOP = sp; //@line 11564
  return $_0 | 0; //@line 11565
 }
 $7 = _dsks_get_disk(HEAP32[$sim + 3484 >> 2] | 0, HEAP32[$drv >> 2] | 0) | 0; //@line 11570
 if (($7 | 0) == 0) {
  $_0 = 0; //@line 11574
  STACKTOP = sp; //@line 11576
  return $_0 | 0; //@line 11577
 }
 _pce_log(2, 45344, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$drv >> 2], tempInt) | 0); //@line 11580
 _dsk_set_readonly($7, 1); //@line 11581
 $_0 = 0; //@line 11583
 STACKTOP = sp; //@line 11585
 return $_0 | 0; //@line 11586
}
function _mac_set_msg_emu_disk_rw($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $drv = 0, $7 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11597
 STACKTOP = STACKTOP + 8 | 0; //@line 11597
 $drv = sp | 0; //@line 11598
 if ((_msg_get_uint($val, $drv) | 0) != 0) {
  $_0 = 1; //@line 11603
  STACKTOP = sp; //@line 11605
  return $_0 | 0; //@line 11606
 }
 $7 = _dsks_get_disk(HEAP32[$sim + 3484 >> 2] | 0, HEAP32[$drv >> 2] | 0) | 0; //@line 11611
 if (($7 | 0) == 0) {
  $_0 = 0; //@line 11615
  STACKTOP = sp; //@line 11617
  return $_0 | 0; //@line 11618
 }
 _pce_log(2, 45672, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$drv >> 2], tempInt) | 0); //@line 11621
 _dsk_set_readonly($7, 0); //@line 11622
 $_0 = 0; //@line 11624
 STACKTOP = sp; //@line 11626
 return $_0 | 0; //@line 11627
}
function _mac_set_msg_emu_iwm_ro($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $drv = 0, $4 = 0, $7 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11638
 STACKTOP = STACKTOP + 8 | 0; //@line 11638
 $drv = sp | 0; //@line 11639
 if ((_msg_get_uint($val, $drv) | 0) != 0) {
  $_0 = 1; //@line 11644
  STACKTOP = sp; //@line 11646
  return $_0 | 0; //@line 11647
 }
 $4 = HEAP32[$drv >> 2] | 0; //@line 11649
 if (($4 | 0) == 0) {
  _pce_log(2, 46632, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 11653
  $7 = $sim + 1760 | 0; //@line 11654
  _mac_iwm_set_locked($7, 0, 1); //@line 11655
  _mac_iwm_set_locked($7, 1, 1); //@line 11656
  _mac_iwm_set_locked($7, 2, 1); //@line 11657
  $_0 = 0; //@line 11659
  STACKTOP = sp; //@line 11661
  return $_0 | 0; //@line 11662
 } else {
  _pce_log(2, 46352, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $4, tempInt) | 0); //@line 11664
  _mac_iwm_set_locked($sim + 1760 | 0, (HEAP32[$drv >> 2] | 0) - 1 | 0, 1); //@line 11668
  $_0 = 0; //@line 11669
  STACKTOP = sp; //@line 11671
  return $_0 | 0; //@line 11672
 }
 return 0;
}
function _mac_set_msg_emu_iwm_rw($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $drv = 0, $4 = 0, $7 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11684
 STACKTOP = STACKTOP + 8 | 0; //@line 11684
 $drv = sp | 0; //@line 11685
 if ((_msg_get_uint($val, $drv) | 0) != 0) {
  $_0 = 1; //@line 11690
  STACKTOP = sp; //@line 11692
  return $_0 | 0; //@line 11693
 }
 $4 = HEAP32[$drv >> 2] | 0; //@line 11695
 if (($4 | 0) == 0) {
  _pce_log(2, 47208, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 11699
  $7 = $sim + 1760 | 0; //@line 11700
  _mac_iwm_set_locked($7, 0, 0); //@line 11701
  _mac_iwm_set_locked($7, 1, 0); //@line 11702
  _mac_iwm_set_locked($7, 2, 0); //@line 11703
  $_0 = 0; //@line 11705
  STACKTOP = sp; //@line 11707
  return $_0 | 0; //@line 11708
 } else {
  _pce_log(2, 46936, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $4, tempInt) | 0); //@line 11710
  _mac_iwm_set_locked($sim + 1760 | 0, (HEAP32[$drv >> 2] | 0) - 1 | 0, 0); //@line 11714
  $_0 = 0; //@line 11715
  STACKTOP = sp; //@line 11717
  return $_0 | 0; //@line 11718
 }
 return 0;
}
function _mac_set_msg_emu_iwm_status($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, sp = 0;
 sp = STACKTOP; //@line 11729
 $1 = $sim + 1760 | 0; //@line 11730
 $2 = _mac_iwm_get_locked($1, 0) | 0; //@line 11731
 _pce_printf(47504, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 1, HEAP32[tempInt + 8 >> 2] = $2, tempInt) | 0); //@line 11732
 $3 = _mac_iwm_get_locked($1, 1) | 0; //@line 11733
 _pce_printf(47504, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 2, HEAP32[tempInt + 8 >> 2] = $3, tempInt) | 0); //@line 11734
 $4 = _mac_iwm_get_locked($1, 2) | 0; //@line 11735
 _pce_printf(47504, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 3, HEAP32[tempInt + 8 >> 2] = $4, tempInt) | 0); //@line 11736
 STACKTOP = sp; //@line 11737
 return 0; //@line 11738
}
function _mac_set_msg_emu_exit($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 HEAP32[$sim + 4680 >> 2] = 2; //@line 11750
 _mon_set_terminate(62384, 1); //@line 11751
 return 0; //@line 11753
}
function _mac_set_msg_emu_pause($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $v = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11763
 STACKTOP = STACKTOP + 8 | 0; //@line 11763
 $v = sp | 0; //@line 11764
 if ((_msg_get_bool($val, $v) | 0) != 0) {
  $_0 = 1; //@line 11769
  STACKTOP = sp; //@line 11771
  return $_0 | 0; //@line 11772
 }
 _mac_set_pause($sim, HEAP32[$v >> 2] | 0); //@line 11775
 $_0 = 0; //@line 11777
 STACKTOP = sp; //@line 11779
 return $_0 | 0; //@line 11780
}
function _mac_set_msg_emu_pause_toggle($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 _mac_set_pause($sim, (HEAP8[$sim + 4676 | 0] | 0) == 0 | 0); //@line 11795
 return 0; //@line 11797
}
function _mac_set_msg_emu_realtime($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $v = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11807
 STACKTOP = STACKTOP + 8 | 0; //@line 11807
 $v = sp | 0; //@line 11808
 if ((_msg_get_bool($val, $v) | 0) != 0) {
  $_0 = 1; //@line 11813
  STACKTOP = sp; //@line 11815
  return $_0 | 0; //@line 11816
 }
 _mac_set_speed($sim, 0, (HEAP32[$v >> 2] | 0) != 0 | 0); //@line 11821
 $_0 = 0; //@line 11823
 STACKTOP = sp; //@line 11825
 return $_0 | 0; //@line 11826
}
function _mac_set_msg_emu_realtime_toggle($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 if ((HEAP32[$sim + 4688 >> 2] | 0) == 0) {
  _mac_set_speed($sim, 0, 1); //@line 11842
  return 0; //@line 11844
 } else {
  _mac_set_speed($sim, 0, 0); //@line 11846
  return 0; //@line 11849
 }
 return 0;
}
function _mac_set_msg_emu_reset($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 _mac_reset($sim); //@line 11860
 return 0; //@line 11862
}
function _mac_set_msg_emu_serport_driver($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $idx = 0, $5 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 11873
 STACKTOP = STACKTOP + 16 | 0; //@line 11873
 $1 = sp | 0; //@line 11874
 $idx = sp + 8 | 0; //@line 11875
 HEAP32[$1 >> 2] = $val; //@line 11876
 if ((_msg_get_prefix_uint($1, $idx, 48168, 47824) | 0) != 0) {
  $_0 = 1; //@line 11881
  STACKTOP = sp; //@line 11883
  return $_0 | 0; //@line 11884
 }
 $5 = HEAP32[$idx >> 2] | 0; //@line 11886
 if ($5 >>> 0 > 1) {
  $_0 = 1; //@line 11890
  STACKTOP = sp; //@line 11892
  return $_0 | 0; //@line 11893
 }
 $_0 = (_mac_ser_set_driver($sim + 3488 + ($5 * 568 | 0) | 0, HEAP32[$1 >> 2] | 0) | 0) != 0 | 0; //@line 11901
 STACKTOP = sp; //@line 11903
 return $_0 | 0; //@line 11904
}
function _mac_rtc_time_from_string($str) {
 $str = $str | 0;
 var $s_0_i = 0, $2 = 0, $6 = 0, $v_020_i = 0, $s_119_i = 0, $10 = 0, $11 = 0, $12 = 0, $storemerge15_i = 0, $14 = 0, $16 = 0, $19 = 0, $24 = 0, $26 = 0, $i_021_i = 0, $t_020_i = 0, $30 = 0, $31 = 0, $t_0_lcssa_i = 0, $_0_i6 = 0, $_0_i = 0, $47 = 0, $s_0_i_1 = 0, $49 = 0, $51 = 0, $v_020_i_1 = 0, $s_119_i_1 = 0, $55 = 0, $56 = 0, $57 = 0, $storemerge15_i_1 = 0, $61 = 0, $s_0_i_2 = 0, $63 = 0, $65 = 0, $v_020_i_2 = 0, $s_119_i_2 = 0, $69 = 0, $70 = 0, $71 = 0, $storemerge15_i_2 = 0, $75 = 0, $s_0_i_3 = 0, $77 = 0, $79 = 0, $v_020_i_3 = 0, $s_119_i_3 = 0, $83 = 0, $84 = 0, $85 = 0, $storemerge15_i_3 = 0, $89 = 0, $s_0_i_4 = 0, $91 = 0, $93 = 0, $v_020_i_4 = 0, $s_119_i_4 = 0, $97 = 0, $98 = 0, $99 = 0, $storemerge15_i_4 = 0, $103 = 0, $s_0_i_5 = 0, $105 = 0, $107 = 0, $v_020_i_5 = 0, $s_119_i_5 = 0, $111 = 0, $112 = 0, $113 = 0, $117 = 0, $120 = 0, $_ = 0, label = 0;
 $s_0_i = $str; //@line 11933
 while (1) {
  $2 = HEAP8[$s_0_i] | 0; //@line 11936
  if (($2 - 48 & 255) <= 9) {
   $s_119_i = $s_0_i;
   $v_020_i = 0;
   $6 = $2;
   label = 1547; //@line 11942
   break;
  }
  if ($2 << 24 >> 24 == 0) {
   $14 = 0;
   $storemerge15_i = $s_0_i;
   break;
  } else {
   $s_0_i = $s_0_i + 1 | 0; //@line 11952
  }
 }
 if ((label | 0) == 1547) {
  while (1) {
   label = 0; //@line 11957
   $10 = ($6 << 24 >> 24) - 48 + ($v_020_i * 10 | 0) | 0; //@line 11964
   $11 = $s_119_i + 1 | 0; //@line 11965
   $12 = HEAP8[$11] | 0; //@line 11966
   if (($12 - 48 & 255) < 10) {
    $s_119_i = $11;
    $v_020_i = $10;
    $6 = $12;
    label = 1547; //@line 11972
   } else {
    $14 = $10;
    $storemerge15_i = $11;
    break;
   }
  }
 }
 $s_0_i_1 = $storemerge15_i; //@line 11982
 while (1) {
  $49 = HEAP8[$s_0_i_1] | 0; //@line 11985
  if (($49 - 48 & 255) <= 9) {
   $s_119_i_1 = $s_0_i_1;
   $v_020_i_1 = 0;
   $51 = $49;
   label = 1557; //@line 11991
   break;
  }
  if ($49 << 24 >> 24 == 0) {
   $61 = 0;
   $storemerge15_i_1 = $s_0_i_1;
   break;
  } else {
   $s_0_i_1 = $s_0_i_1 + 1 | 0; //@line 12001
  }
 }
 if ((label | 0) == 1557) {
  while (1) {
   label = 0; //@line 12006
   $55 = ($51 << 24 >> 24) - 48 + ($v_020_i_1 * 10 | 0) | 0; //@line 12013
   $56 = $s_119_i_1 + 1 | 0; //@line 12014
   $57 = HEAP8[$56] | 0; //@line 12015
   if (($57 - 48 & 255) < 10) {
    $s_119_i_1 = $56;
    $v_020_i_1 = $55;
    $51 = $57;
    label = 1557; //@line 12021
   } else {
    $61 = $55;
    $storemerge15_i_1 = $56;
    break;
   }
  }
 }
 $s_0_i_2 = $storemerge15_i_1; //@line 12031
 while (1) {
  $63 = HEAP8[$s_0_i_2] | 0; //@line 12034
  if (($63 - 48 & 255) <= 9) {
   $s_119_i_2 = $s_0_i_2;
   $v_020_i_2 = 0;
   $65 = $63;
   label = 1561; //@line 12040
   break;
  }
  if ($63 << 24 >> 24 == 0) {
   $75 = 0;
   $storemerge15_i_2 = $s_0_i_2;
   break;
  } else {
   $s_0_i_2 = $s_0_i_2 + 1 | 0; //@line 12050
  }
 }
 if ((label | 0) == 1561) {
  while (1) {
   label = 0; //@line 12055
   $69 = ($65 << 24 >> 24) - 48 + ($v_020_i_2 * 10 | 0) | 0; //@line 12062
   $70 = $s_119_i_2 + 1 | 0; //@line 12063
   $71 = HEAP8[$70] | 0; //@line 12064
   if (($71 - 48 & 255) < 10) {
    $s_119_i_2 = $70;
    $v_020_i_2 = $69;
    $65 = $71;
    label = 1561; //@line 12070
   } else {
    $75 = $69;
    $storemerge15_i_2 = $70;
    break;
   }
  }
 }
 $s_0_i_3 = $storemerge15_i_2; //@line 12080
 while (1) {
  $77 = HEAP8[$s_0_i_3] | 0; //@line 12083
  if (($77 - 48 & 255) <= 9) {
   $s_119_i_3 = $s_0_i_3;
   $v_020_i_3 = 0;
   $79 = $77;
   label = 1565; //@line 12089
   break;
  }
  if ($77 << 24 >> 24 == 0) {
   $89 = 0;
   $storemerge15_i_3 = $s_0_i_3;
   break;
  } else {
   $s_0_i_3 = $s_0_i_3 + 1 | 0; //@line 12099
  }
 }
 if ((label | 0) == 1565) {
  while (1) {
   label = 0; //@line 12104
   $83 = ($79 << 24 >> 24) - 48 + ($v_020_i_3 * 10 | 0) | 0; //@line 12111
   $84 = $s_119_i_3 + 1 | 0; //@line 12112
   $85 = HEAP8[$84] | 0; //@line 12113
   if (($85 - 48 & 255) < 10) {
    $s_119_i_3 = $84;
    $v_020_i_3 = $83;
    $79 = $85;
    label = 1565; //@line 12119
   } else {
    $89 = $83;
    $storemerge15_i_3 = $84;
    break;
   }
  }
 }
 $s_0_i_4 = $storemerge15_i_3; //@line 12129
 while (1) {
  $91 = HEAP8[$s_0_i_4] | 0; //@line 12132
  if (($91 - 48 & 255) <= 9) {
   $s_119_i_4 = $s_0_i_4;
   $v_020_i_4 = 0;
   $93 = $91;
   label = 1569; //@line 12138
   break;
  }
  if ($91 << 24 >> 24 == 0) {
   $103 = 0;
   $storemerge15_i_4 = $s_0_i_4;
   break;
  } else {
   $s_0_i_4 = $s_0_i_4 + 1 | 0; //@line 12148
  }
 }
 if ((label | 0) == 1569) {
  while (1) {
   label = 0; //@line 12153
   $97 = ($93 << 24 >> 24) - 48 + ($v_020_i_4 * 10 | 0) | 0; //@line 12160
   $98 = $s_119_i_4 + 1 | 0; //@line 12161
   $99 = HEAP8[$98] | 0; //@line 12162
   if (($99 - 48 & 255) < 10) {
    $s_119_i_4 = $98;
    $v_020_i_4 = $97;
    $93 = $99;
    label = 1569; //@line 12168
   } else {
    $103 = $97;
    $storemerge15_i_4 = $98;
    break;
   }
  }
 }
 $s_0_i_5 = $storemerge15_i_4; //@line 12178
 while (1) {
  $105 = HEAP8[$s_0_i_5] | 0; //@line 12181
  if (($105 - 48 & 255) <= 9) {
   $s_119_i_5 = $s_0_i_5;
   $v_020_i_5 = 0;
   $107 = $105;
   label = 1573; //@line 12187
   break;
  }
  if ($105 << 24 >> 24 == 0) {
   $117 = 0; //@line 12194
   break;
  } else {
   $s_0_i_5 = $s_0_i_5 + 1 | 0; //@line 12197
  }
 }
 if ((label | 0) == 1573) {
  while (1) {
   label = 0; //@line 12202
   $111 = ($107 << 24 >> 24) - 48 + ($v_020_i_5 * 10 | 0) | 0; //@line 12209
   $112 = $s_119_i_5 + 1 | 0; //@line 12210
   $113 = HEAP8[$112] | 0; //@line 12211
   if (($113 - 48 & 255) < 10) {
    $s_119_i_5 = $112;
    $v_020_i_5 = $111;
    $107 = $113;
    label = 1573; //@line 12217
   } else {
    $117 = $111; //@line 12219
    break;
   }
  }
 }
 $120 = ($61 | 0) == 0 ? 0 : $61 - 1 | 0; //@line 12227
 $_ = ($75 | 0) == 0 ? 0 : $75 - 1 | 0; //@line 12230
 do {
  if ($14 >>> 0 < 1904 | $120 >>> 0 > 11) {
   $_0_i6 = 0; //@line 12237
  } else {
   $16 = $14 - 1904 | 0; //@line 12239
   $19 = $16 & 3; //@line 12242
   $24 = (($16 >>> 2) * 1461 | 0) + ($19 * 365 | 0) + (($19 | 0) != 0) | 0; //@line 12247
   $26 = ($19 | 0) == 0 ? 7704 : 7656; //@line 12249
   if (($120 | 0) == 0) {
    $t_0_lcssa_i = $24; //@line 12253
   } else {
    $t_020_i = $24;
    $i_021_i = 0;
    while (1) {
     $30 = (HEAP32[$26 + ($i_021_i << 2) >> 2] | 0) + $t_020_i | 0; //@line 12261
     $31 = $i_021_i + 1 | 0; //@line 12262
     if ($31 >>> 0 < $120 >>> 0) {
      $t_020_i = $30;
      $i_021_i = $31;
     } else {
      $t_0_lcssa_i = $30; //@line 12268
      break;
     }
    }
   }
   if ((HEAP32[$26 + ($120 << 2) >> 2] | 0) >>> 0 <= $_ >>> 0) {
    $_0_i6 = 0; //@line 12279
    break;
   }
   $_0_i6 = ($t_0_lcssa_i + $_ | 0) * 86400 | 0; //@line 12285
  }
 } while (0);
 if ($89 >>> 0 > 23 | $103 >>> 0 > 59 | $117 >>> 0 > 59) {
  $_0_i = 0; //@line 12296
  $47 = $_0_i + $_0_i6 | 0; //@line 12298
  return $47 | 0; //@line 12300
 }
 $_0_i = ((($89 * 60 | 0) + $103 | 0) * 60 | 0) + $117 | 0; //@line 12307
 $47 = $_0_i + $_0_i6 | 0; //@line 12309
 return $47 | 0; //@line 12311
}
function _mac_rtc_set_data_fct($rtc, $ext, $fct) {
 $rtc = $rtc | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$rtc + 292 >> 2] = $ext; //@line 12323
 HEAP32[$rtc + 296 >> 2] = $fct; //@line 12326
 return;
}
function _mac_rtc_set_osi_fct($rtc, $ext, $fct) {
 $rtc = $rtc | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$rtc + 304 >> 2] = $ext; //@line 12340
 HEAP32[$rtc + 308 >> 2] = $fct; //@line 12343
 return;
}
function _mac_rtc_set_realtime($rtc, $realtime) {
 $rtc = $rtc | 0;
 $realtime = $realtime | 0;
 HEAP32[$rtc + 284 >> 2] = ($realtime | 0) != 0; //@line 12358
 return;
}
function _mac_set_msg_emu_serport_file($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $idx = 0, $5 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 12371
 STACKTOP = STACKTOP + 16 | 0; //@line 12371
 $1 = sp | 0; //@line 12372
 $idx = sp + 8 | 0; //@line 12373
 HEAP32[$1 >> 2] = $val; //@line 12374
 if ((_msg_get_prefix_uint($1, $idx, 48168, 47824) | 0) != 0) {
  $_0 = 1; //@line 12379
  STACKTOP = sp; //@line 12381
  return $_0 | 0; //@line 12382
 }
 $5 = HEAP32[$idx >> 2] | 0; //@line 12384
 if ($5 >>> 0 > 1) {
  $_0 = 1; //@line 12388
  STACKTOP = sp; //@line 12390
  return $_0 | 0; //@line 12391
 }
 $_0 = (_mac_ser_set_file($sim + 3488 + ($5 * 568 | 0) | 0, HEAP32[$1 >> 2] | 0) | 0) != 0 | 0; //@line 12399
 STACKTOP = sp; //@line 12401
 return $_0 | 0; //@line 12402
}
function _mac_set_msg_emu_stop($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 _mac_set_msg_trm($sim, 48976, 48600) | 0; //@line 12413
 HEAP32[$sim + 4680 >> 2] = 1; //@line 12415
 return 0; //@line 12417
}
function _mac_set_msg_emu_video_brightness($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $br = 0, $4 = 0, $storemerge = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 12428
 STACKTOP = STACKTOP + 8 | 0; //@line 12428
 $br = sp | 0; //@line 12429
 if ((_msg_get_uint($val, $br) | 0) != 0) {
  $_0 = 1; //@line 12434
  STACKTOP = sp; //@line 12436
  return $_0 | 0; //@line 12437
 }
 $4 = HEAP32[$br >> 2] | 0; //@line 12439
 if ($4 >>> 0 > 999) {
  $storemerge = 255; //@line 12443
 } else {
  $storemerge = ($4 << 8 >>> 0) / 1e3 | 0; //@line 12447
 }
 HEAP32[$br >> 2] = $storemerge; //@line 12450
 _mac_video_set_brightness(HEAP32[$sim + 3476 >> 2] | 0, $storemerge); //@line 12453
 $_0 = 0; //@line 12455
 STACKTOP = sp; //@line 12457
 return $_0 | 0; //@line 12458
}
function _mac_set_msg_mac_insert($sim, $msg, $val) {
 $sim = $sim | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $drv = 0, $3 = 0, $20 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 12470
 STACKTOP = STACKTOP + 8 | 0; //@line 12470
 $drv = sp | 0; //@line 12471
 if ((HEAP8[$val] | 0) == 0) {
  $3 = $sim + 2424 | 0; //@line 12476
  if ((HEAP8[$sim + 2426 | 0] | 0) == 0) {
   $_0 = 0; //@line 12482
   STACKTOP = sp; //@line 12484
   return $_0 | 0; //@line 12485
  }
  _mac_sony_insert($3, 1); //@line 12487
  _mac_sony_insert($3, 2); //@line 12488
  _mac_sony_insert($3, 3); //@line 12489
  $_0 = 0; //@line 12491
  STACKTOP = sp; //@line 12493
  return $_0 | 0; //@line 12494
 }
 if ((_msg_get_uint($val, $drv) | 0) != 0) {
  $_0 = 1; //@line 12500
  STACKTOP = sp; //@line 12502
  return $_0 | 0; //@line 12503
 }
 if ((HEAP8[$sim + 2426 | 0] | 0) == 0) {
  $20 = HEAP32[$drv >> 2] | 0; //@line 12511
  _mac_iwm_insert($sim + 1760 | 0, ($20 | 0) == 0 ? 0 : $20 - 1 | 0); //@line 12515
  $_0 = 0; //@line 12516
  STACKTOP = sp; //@line 12518
  return $_0 | 0; //@line 12519
 } else {
  _mac_sony_insert($sim + 2424 | 0, HEAP32[$drv >> 2] | 0); //@line 12523
  $_0 = 0; //@line 12525
  STACKTOP = sp; //@line 12527
  return $_0 | 0; //@line 12528
 }
 return 0;
}
function _mac_rtc_init($rtc) {
 $rtc = $rtc | 0;
 HEAP32[$rtc + 304 >> 2] = 0; //@line 12540
 HEAP32[$rtc + 308 >> 2] = 0; //@line 12542
 HEAP8[$rtc + 312 | 0] = 0; //@line 12544
 _memset($rtc | 0, 0, 258); //@line 12549
 _memset($rtc + 260 | 0, 0, 20); //@line 12551
 _memset($rtc + 283 | 0, 0, 18); //@line 12552
 HEAP8[$rtc + 16 | 0] = -88; //@line 12553
 HEAP8[$rtc + 19 | 0] = 34; //@line 12555
 HEAP8[$rtc + 30 | 0] = 100; //@line 12557
 HEAP8[$rtc + 8 | 0] = 24; //@line 12559
 HEAP8[$rtc + 9 | 0] = -120; //@line 12561
 HEAP8[$rtc + 11 | 0] = 32; //@line 12563
 return;
}
function _mac_rtc_load_file($rtc, $fname) {
 $rtc = $rtc | 0;
 $fname = $fname | 0;
 var $1 = 0, $6 = 0, $_0 = 0;
 $1 = _fopen($fname | 0, 46616) | 0; //@line 12576
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 12580
  return $_0 | 0; //@line 12583
 }
 $6 = (_fread($rtc | 0, 1, 256, $1 | 0) | 0) == 256; //@line 12587
 _fclose($1 | 0) | 0; //@line 12588
 if (!$6) {
  $_0 = 1; //@line 12591
  return $_0 | 0; //@line 12594
 }
 HEAP8[$rtc + 256 | 0] = -128; //@line 12597
 HEAP8[$rtc + 257 | 0] = 0; //@line 12599
 $_0 = 0; //@line 12601
 return $_0 | 0; //@line 12604
}
function _mac_rtc_set_time($rtc, $time, $rel) {
 $rtc = $rtc | 0;
 $time = $time | 0;
 $rel = $rel | 0;
 var $1 = 0, $13 = 0, $15 = 0;
 $1 = _time(0) | 0; //@line 12618
 HEAP32[$rtc + 260 >> 2] = $1 + 2082844800; //@line 12621
 if (($rel | 0) == 0) {
  $13 = ((HEAPU8[$rtc + 237 | 0] | 0) << 8 | (HEAPU8[$rtc + 238 | 0] | 0)) << 8; //@line 12637
  $15 = $13 | (HEAPU8[$rtc + 239 | 0] | 0); //@line 12639
  HEAP32[$rtc + 264 >> 2] = -2082844800 - $1 + $time - (($13 & 8388608 | 0) == 0 ? $15 : $15 | -16777216); //@line 12646
  return;
 } else {
  HEAP32[$rtc + 264 >> 2] = $time; //@line 12651
  return;
 }
}
function _mac_rtc_set_time_str($rtc, $str) {
 $rtc = $rtc | 0;
 $str = $str | 0;
 var $8 = 0, $9 = 0, $16 = 0, $18 = 0;
 if (($str | 0) == 0) {
  HEAP32[$rtc + 260 >> 2] = (_time(0) | 0) + 2082844800; //@line 12674
  HEAP32[$rtc + 264 >> 2] = 0; //@line 12676
  return;
 } else {
  $8 = _mac_rtc_time_from_string($str) | 0; //@line 12681
  $9 = _time(0) | 0; //@line 12682
  HEAP32[$rtc + 260 >> 2] = $9 + 2082844800; //@line 12685
  $16 = ((HEAPU8[$rtc + 237 | 0] | 0) << 8 | (HEAPU8[$rtc + 238 | 0] | 0)) << 8; //@line 12696
  $18 = $16 | (HEAPU8[$rtc + 239 | 0] | 0); //@line 12698
  HEAP32[$rtc + 264 >> 2] = $8 - 2082844800 - $9 - (($16 & 8388608 | 0) == 0 ? $18 : $18 | -16777216); //@line 12707
  return;
 }
}
function _mac_scsi_get_uint16($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 return 0; //@line 12720
}
function _mac_scsi_set_disks($scsi, $dsks) {
 $scsi = $scsi | 0;
 $dsks = $dsks | 0;
 HEAP32[$scsi + 332 >> 2] = $dsks; //@line 12731
 return;
}
function _mac_scsi_set_drive_vendor($scsi, $id, $vendor) {
 $scsi = $scsi | 0;
 $id = $id | 0;
 $vendor = $vendor | 0;
 var $1 = 0, $2 = 0, $_1 = 0, $10 = 0, $_1_1 = 0, $18 = 0, $_1_2 = 0, $26 = 0, $_1_3 = 0, $34 = 0, $_1_4 = 0, $42 = 0, $_1_5 = 0, $50 = 0, $_1_6 = 0, $58 = 0, $60 = 0, $storemerge = 0;
 $1 = $id & 7; //@line 12749
 $2 = HEAP8[$vendor] | 0; //@line 12750
 if ($2 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 8 | 0] = 32; //@line 12755
  $_1 = $vendor; //@line 12757
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 8 | 0] = $2; //@line 12761
  $_1 = $vendor + 1 | 0; //@line 12762
 }
 $10 = HEAP8[$_1] | 0; //@line 12765
 if ($10 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 9 | 0] = 32; //@line 12770
  $_1_1 = $_1; //@line 12772
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 9 | 0] = $10; //@line 12776
  $_1_1 = $_1 + 1 | 0; //@line 12777
 }
 $18 = HEAP8[$_1_1] | 0; //@line 12780
 if ($18 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 10 | 0] = 32; //@line 12785
  $_1_2 = $_1_1; //@line 12787
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 10 | 0] = $18; //@line 12791
  $_1_2 = $_1_1 + 1 | 0; //@line 12792
 }
 $26 = HEAP8[$_1_2] | 0; //@line 12795
 if ($26 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 11 | 0] = 32; //@line 12800
  $_1_3 = $_1_2; //@line 12802
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 11 | 0] = $26; //@line 12806
  $_1_3 = $_1_2 + 1 | 0; //@line 12807
 }
 $34 = HEAP8[$_1_3] | 0; //@line 12810
 if ($34 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 12 | 0] = 32; //@line 12815
  $_1_4 = $_1_3; //@line 12817
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 12 | 0] = $34; //@line 12821
  $_1_4 = $_1_3 + 1 | 0; //@line 12822
 }
 $42 = HEAP8[$_1_4] | 0; //@line 12825
 if ($42 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 13 | 0] = 32; //@line 12830
  $_1_5 = $_1_4; //@line 12832
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 13 | 0] = $42; //@line 12836
  $_1_5 = $_1_4 + 1 | 0; //@line 12837
 }
 $50 = HEAP8[$_1_5] | 0; //@line 12840
 if ($50 << 24 >> 24 == 0) {
  HEAP8[$scsi + 76 + ($1 << 5) + 14 | 0] = 32; //@line 12845
  $_1_6 = $_1_5; //@line 12847
 } else {
  HEAP8[$scsi + 76 + ($1 << 5) + 14 | 0] = $50; //@line 12851
  $_1_6 = $_1_5 + 1 | 0; //@line 12852
 }
 $58 = HEAP8[$_1_6] | 0; //@line 12855
 $60 = $scsi + 76 + ($1 << 5) + 15 | 0; //@line 12857
 if ($58 << 24 >> 24 == 0) {
  $storemerge = 32; //@line 12861
  HEAP8[$60] = $storemerge; //@line 12863
  return;
 } else {
  $storemerge = $58; //@line 12867
  HEAP8[$60] = $storemerge; //@line 12869
  return;
 }
}
function _mac_scsi_set_drive_product($scsi, $id, $product) {
 $scsi = $scsi | 0;
 $id = $id | 0;
 $product = $product | 0;
 var $1 = 0, $_09 = 0, $i_08 = 0, $3 = 0, $_1 = 0, $11 = 0;
 $1 = $id & 7; //@line 12884
 $i_08 = 0;
 $_09 = $product;
 while (1) {
  $3 = HEAP8[$_09] | 0; //@line 12890
  if ($3 << 24 >> 24 == 0) {
   HEAP8[$scsi + 76 + ($1 << 5) + 16 + $i_08 | 0] = 32; //@line 12895
   $_1 = $_09; //@line 12897
  } else {
   HEAP8[$scsi + 76 + ($1 << 5) + 16 + $i_08 | 0] = $3; //@line 12901
   $_1 = $_09 + 1 | 0; //@line 12902
  }
  $11 = $i_08 + 1 | 0; //@line 12905
  if ($11 >>> 0 < 16) {
   $i_08 = $11;
   $_09 = $_1;
  } else {
   break;
  }
 }
 return;
}
function _mac_rtc_set_uint8($rtc, $val) {
 $rtc = $rtc | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $3 = 0, $18 = 0, $21 = 0, $22 = 0, $_lobit = 0, $26 = 0, $31 = 0, $35 = 0, $37 = 0, $42 = 0, $44 = 0, $45 = 0, $47 = 0, $50 = 0, $51 = 0, $54 = 0, $62 = 0, $92 = 0, $93 = 0, $108 = 0, $112 = 0, $140 = 0;
 $1 = $rtc + 283 | 0; //@line 12941
 $2 = HEAP8[$1] | 0; //@line 12942
 $3 = $val & 255; //@line 12943
 HEAP8[$1] = $val; //@line 12944
 if (($3 & 4 | 0) != 0) {
  HEAP32[$rtc + 272 >> 2] = 0; //@line 12950
  HEAP32[$rtc + 268 >> 2] = 0; //@line 12952
  HEAP32[$rtc + 276 >> 2] = 0; //@line 12954
  return;
 }
 if ((($3 & 2 ^ 2) & (($2 ^ $val) & 255) | 0) == 0) {
  return;
 }
 $18 = $rtc + 268 | 0; //@line 12970
 $21 = $rtc + 282 | 0; //@line 12973
 $22 = HEAP8[$21] | 0; //@line 12974
 if ((HEAP32[$18 >> 2] | 0) != 0) {
  $_lobit = ($22 & 255) >>> 7; //@line 12977
  HEAP8[$rtc + 300 | 0] = $_lobit; //@line 12979
  $26 = HEAP32[$rtc + 296 >> 2] | 0; //@line 12981
  if (($26 | 0) == 0) {
   $31 = $22; //@line 12985
  } else {
   FUNCTION_TABLE_vii[$26 & 511](HEAP32[$rtc + 292 >> 2] | 0, $_lobit); //@line 12989
   $31 = HEAP8[$21] | 0; //@line 12992
  }
  HEAP8[$21] = $31 << 1 | ($31 & 255) >>> 7; //@line 12998
  $35 = $rtc + 276 | 0; //@line 12999
  $37 = (HEAP32[$35 >> 2] | 0) + 1 | 0; //@line 13001
  HEAP32[$35 >> 2] = $37; //@line 13002
  if ($37 >>> 0 <= 7) {
   return;
  }
  HEAP32[$35 >> 2] = 0; //@line 13009
  HEAP32[$18 >> 2] = 0; //@line 13010
  HEAP32[$rtc + 272 >> 2] = 0; //@line 13012
  return;
 }
 $42 = $22 << 1; //@line 13017
 $44 = $42 | $val & 1; //@line 13019
 HEAP8[$21] = $44; //@line 13020
 $45 = $rtc + 276 | 0; //@line 13021
 $47 = (HEAP32[$45 >> 2] | 0) + 1 | 0; //@line 13023
 HEAP32[$45 >> 2] = $47; //@line 13024
 if ($47 >>> 0 <= 7) {
  return;
 }
 $50 = $rtc + 272 | 0; //@line 13031
 $51 = HEAP32[$50 >> 2] | 0; //@line 13032
 do {
  if (($51 | 0) == 0) {
   HEAP8[$rtc + 280 | 0] = $44; //@line 13036
   $54 = $44 & 255; //@line 13037
   if (($54 & 120 | 0) == 56) {
    HEAP32[$50 >> 2] = 2; //@line 13042
    break;
   }
   if (($54 & 128 | 0) == 0) {
    HEAP32[$50 >> 2] = 1; //@line 13050
    break;
   }
   $62 = $54 >>> 2; //@line 13053
   do {
    if (($54 & 227 | 0) == 129) {
     HEAP8[$21] = (HEAP32[$rtc + 260 >> 2] | 0) >>> (($62 << 3 & 24) >>> 0) & 255; //@line 13065
    } else {
     if (($54 & 243 | 0) == 161) {
      HEAP8[$21] = HEAP8[$rtc + ($62 & 3 | 8) | 0] | 0; //@line 13076
      break;
     }
     if (($54 & 195 | 0) == 193) {
      HEAP8[$21] = HEAP8[$rtc + ($62 & 15 | 16) | 0] | 0; //@line 13088
      break;
     } else {
      HEAP8[$21] = 0; //@line 13092
      break;
     }
    }
   } while (0);
   HEAP32[$50 >> 2] = 0; //@line 13097
   HEAP32[$18 >> 2] = 1; //@line 13098
  } else if (($51 | 0) == 1) {
   $92 = HEAP8[$rtc + 280 | 0] | 0; //@line 13102
   $93 = $92 & 255; //@line 13103
   do {
    if ($92 << 24 >> 24 == 53) {
     HEAP8[$rtc + 256 | 0] = $42 & -128; //@line 13110
    } else {
     if ((HEAP8[$rtc + 256 | 0] | 0) < 0) {
      break;
     }
     if (($93 & 227 | 0) == 1) {
      $108 = $93 >>> 2 << 3 & 24; //@line 13126
      $112 = $rtc + 260 | 0; //@line 13130
      HEAP32[$112 >> 2] = HEAP32[$112 >> 2] & ~(255 << $108) | ($44 & 255) << $108; //@line 13135
      break;
     }
     if (($93 & 243 | 0) == 33) {
      HEAP8[$rtc + ($93 >>> 2 & 3 | 8) | 0] = $44; //@line 13147
      break;
     }
     if ($92 << 24 >> 24 == 49) {
      HEAP8[$rtc + 257 | 0] = $44; //@line 13155
      break;
     }
     if (($93 & 195 | 0) != 65) {
      break;
     }
     HEAP8[$rtc + ($93 >>> 2 & 15 | 16) | 0] = $44; //@line 13169
    }
   } while (0);
   HEAP32[$50 >> 2] = 0; //@line 13173
  } else if (($51 | 0) == 3) {
   if ((HEAP8[$rtc + 256 | 0] | 0) >= 0) {
    HEAP8[$rtc + (HEAPU8[$rtc + 280 | 0] << 5 & 224 | (HEAPU8[$rtc + 281 | 0] | 0) >>> 2 & 31) | 0] = $44; //@line 13193
   }
   HEAP32[$50 >> 2] = 0; //@line 13196
  } else if (($51 | 0) == 2) {
   HEAP8[$rtc + 281 | 0] = $44; //@line 13200
   $140 = HEAP8[$rtc + 280 | 0] | 0; //@line 13202
   if ($140 << 24 >> 24 < 0) {
    HEAP8[$21] = HEAP8[$rtc + (($140 & 255) << 5 & 224 | ($42 & 255) >>> 2 & 31) | 0] | 0; //@line 13215
    HEAP32[$50 >> 2] = 0; //@line 13216
    HEAP32[$18 >> 2] = 1; //@line 13217
    break;
   } else {
    HEAP32[$50 >> 2] = 3; //@line 13221
    break;
   }
  }
 } while (0);
 HEAP32[$45 >> 2] = 0; //@line 13226
 return;
}
function _mac_rtc_clock($rtc, $n) {
 $rtc = $rtc | 0;
 $n = $n | 0;
 var $1 = 0, $2 = 0, $8 = 0, $13 = 0, $15 = 0, $22 = 0, $24 = 0, $26 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $37 = 0, $40 = 0, $45 = 0, $50 = 0;
 $1 = $rtc + 260 | 0; //@line 13245
 $2 = HEAP32[$1 >> 2] | 0; //@line 13246
 if ((HEAP32[$rtc + 284 >> 2] | 0) == 0) {
  $24 = $rtc + 288 | 0; //@line 13252
  $26 = (HEAP32[$24 >> 2] | 0) + $n | 0; //@line 13254
  HEAP32[$24 >> 2] = $26; //@line 13255
  if ($26 >>> 0 > 7833600) {
   HEAP32[$24 >> 2] = $26 - 7833600; //@line 13260
   $30 = $2 + 1 | 0; //@line 13261
   HEAP32[$1 >> 2] = $30; //@line 13262
   $32 = $30; //@line 13264
  } else {
   $32 = $2; //@line 13266
  }
  $33 = $rtc + 264 | 0; //@line 13269
  $35 = $32 + (HEAP32[$33 >> 2] | 0) | 0; //@line 13271
  HEAP32[$1 >> 2] = $35; //@line 13272
  HEAP32[$33 >> 2] = 0; //@line 13273
  $37 = $35; //@line 13274
 } else {
  $8 = (_time(0) | 0) + 2082844800 | 0; //@line 13277
  $13 = (HEAPU8[$rtc + 237 | 0] << 8 | HEAPU8[$rtc + 238 | 0]) << 8; //@line 13288
  $15 = $13 | HEAPU8[$rtc + 239 | 0]; //@line 13290
  $22 = (($13 & 8388608 | 0) == 0 ? $15 : $15 | -16777216) + $8 + (HEAP32[$rtc + 264 >> 2] | 0) | 0; //@line 13298
  HEAP32[$1 >> 2] = $22; //@line 13299
  $37 = $22; //@line 13301
 }
 if (($37 | 0) == ($2 | 0)) {
  return;
 }
 $40 = $rtc + 312 | 0; //@line 13310
 do {
  if ((HEAP8[$40] | 0) != 1) {
   HEAP8[$40] = 1; //@line 13316
   $45 = HEAP32[$rtc + 308 >> 2] | 0; //@line 13318
   if (($45 | 0) == 0) {
    break;
   }
   FUNCTION_TABLE_vii[$45 & 511](HEAP32[$rtc + 304 >> 2] | 0, 1); //@line 13326
   if ((HEAP8[$40] | 0) != 0) {
    break;
   }
   return;
  }
 } while (0);
 HEAP8[$40] = 0; //@line 13337
 $50 = HEAP32[$rtc + 308 >> 2] | 0; //@line 13339
 if (($50 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$50 & 511](HEAP32[$rtc + 304 >> 2] | 0, 0); //@line 13348
 return;
}
function _mac_scsi_init($scsi) {
 $scsi = $scsi | 0;
 var $9 = 0;
 HEAP8[$scsi + 9 | 0] = 0; //@line 13364
 HEAP8[$scsi + 10 | 0] = 0; //@line 13366
 HEAP8[$scsi + 11 | 0] = 0; //@line 13368
 HEAP32[$scsi + 16 >> 2] = 0; //@line 13370
 HEAP32[$scsi + 20 >> 2] = 0; //@line 13372
 HEAP32[$scsi + 40 >> 2] = 0; //@line 13374
 HEAP32[$scsi + 44 >> 2] = 0; //@line 13376
 $9 = $scsi; //@line 13378
 HEAP32[$9 >> 2] = 0; //@line 13382
 HEAP32[$9 + 4 >> 2] = 0; //@line 13384
 HEAP32[$scsi + 48 >> 2] = 4096; //@line 13385
 HEAP32[$scsi + 52 >> 2] = _malloc(4096) | 0; //@line 13388
 HEAP32[$scsi + 60 >> 2] = 4080; //@line 13390
 HEAP32[$scsi + 64 >> 2] = 4; //@line 13392
 HEAP32[$scsi + 68 >> 2] = 0; //@line 13394
 HEAP32[$scsi + 72 >> 2] = 0; //@line 13396
 HEAP32[$scsi + 76 >> 2] = 0; //@line 13398
 HEAP32[$scsi + 108 >> 2] = 0; //@line 13400
 HEAP32[$scsi + 140 >> 2] = 0; //@line 13402
 HEAP32[$scsi + 172 >> 2] = 0; //@line 13404
 HEAP32[$scsi + 204 >> 2] = 0; //@line 13406
 HEAP32[$scsi + 236 >> 2] = 0; //@line 13408
 HEAP32[$scsi + 268 >> 2] = 0; //@line 13410
 HEAP32[$scsi + 300 >> 2] = 0; //@line 13412
 HEAP32[$scsi + 332 >> 2] = 0; //@line 13414
 return;
}
function _mac_scsi_set_drive($scsi, $id, $drive) {
 $scsi = $scsi | 0;
 $id = $id | 0;
 $drive = $drive | 0;
 var $1 = 0, $5 = 0, $st$1$0 = 0, $st$2$1 = 0, $6 = 0;
 $1 = $id & 7; //@line 13428
 HEAP32[$scsi + 76 + ($1 << 5) >> 2] = 1; //@line 13430
 HEAP32[$scsi + 76 + ($1 << 5) + 4 >> 2] = $drive; //@line 13432
 $5 = $scsi + 76 + ($1 << 5) + 8 | 0; //@line 13434
 $st$1$0 = $5 | 0; //@line 13437
 tempBigInt = 541410128; //@line 13438
 HEAP8[$st$1$0] = tempBigInt & 255; //@line 13438
 tempBigInt = tempBigInt >> 8; //@line 13438
 HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 13438
 tempBigInt = tempBigInt >> 8; //@line 13438
 HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 13438
 tempBigInt = tempBigInt >> 8; //@line 13438
 HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 13438
 $st$2$1 = $5 + 4 | 0; //@line 13439
 tempBigInt = 538976288; //@line 13440
 HEAP8[$st$2$1] = tempBigInt & 255; //@line 13440
 tempBigInt = tempBigInt >> 8; //@line 13440
 HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 13440
 tempBigInt = tempBigInt >> 8; //@line 13440
 HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 13440
 tempBigInt = tempBigInt >> 8; //@line 13440
 HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 13440
 $6 = $scsi + 76 + ($1 << 5) + 16 | 0; //@line 13441
 _memcpy($6 | 0, 55104, 16) | 0; //@line 13442
 return;
}
function _mac_scsi_get_uint8($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 var $8 = 0, $30 = 0, $31 = 0, $storemerge_i = 0, $35 = 0, $40 = 0, $41 = 0, $44 = 0, $51 = 0, $52 = 0, $55 = 0, $61 = 0, $66 = 0, $67 = 0, $70 = 0, $77 = 0, $78 = 0, $81 = 0, $val_0 = 0, sp = 0;
 sp = STACKTOP; //@line 13462
 $8 = (HEAP32[$ext + 60 >> 2] & $addr) >>> ((HEAP32[$ext + 64 >> 2] | 0) >>> 0); //@line 13470
 do {
  if (($8 | 0) == 2) {
   $val_0 = HEAP8[$ext + 7 | 0] | 0; //@line 13476
  } else if (($8 | 0) == 3) {
   $val_0 = HEAP8[$ext + 8 | 0] & 15; //@line 13482
  } else if (($8 | 0) == 5) {
   $30 = $ext + 11 | 0; //@line 13492
   $31 = HEAP8[$30] | 0; //@line 13493
   $storemerge_i = (((HEAPU8[$ext + 9 | 0] | 0) >>> 2 ^ HEAP8[$ext + 8 | 0]) & 7) == 0 ? $31 | 8 : $31 & -9; //@line 13496
   HEAP8[$30] = $storemerge_i; //@line 13497
   $val_0 = $storemerge_i; //@line 13499
  } else if (($8 | 0) == 4) {
   $val_0 = HEAP8[$ext + 9 | 0] | 0; //@line 13504
  } else if (($8 | 0) == 1) {
   $val_0 = HEAP8[$ext + 6 | 0] | 0; //@line 13509
  } else if (($8 | 0) == 6 | ($8 | 0) == 38) {
   $35 = $ext; //@line 13511
   if ((HEAP32[$35 >> 2] | 0) != 5) {
    $val_0 = 0; //@line 13516
    break;
   }
   $40 = $ext + 40 | 0; //@line 13520
   $41 = HEAP32[$40 >> 2] | 0; //@line 13521
   $44 = HEAP32[$ext + 44 >> 2] | 0; //@line 13524
   if ($41 >>> 0 >= $44 >>> 0) {
    $val_0 = 0; //@line 13528
    break;
   }
   $51 = HEAP8[(HEAP32[$ext + 52 >> 2] | 0) + $41 | 0] | 0; //@line 13535
   $52 = $41 + 1 | 0; //@line 13536
   HEAP32[$40 >> 2] = $52; //@line 13537
   if ($52 >>> 0 < $44 >>> 0) {
    $val_0 = $51; //@line 13541
    break;
   }
   HEAP32[$35 >> 2] = 7; //@line 13544
   $55 = $ext + 9 | 0; //@line 13545
   HEAP8[$55] = HEAP8[$55] & -125 | 108; //@line 13549
   HEAP8[$ext + 5 | 0] = 0; //@line 13551
   $val_0 = $51; //@line 13553
  } else if (($8 | 0) == 7) {
   $val_0 = -1; //@line 13555
  } else if (($8 | 0) == 32) {
   $61 = $ext; //@line 13557
   if ((HEAP32[$61 >> 2] | 0) != 5) {
    $val_0 = 0; //@line 13562
    break;
   }
   $66 = $ext + 40 | 0; //@line 13566
   $67 = HEAP32[$66 >> 2] | 0; //@line 13567
   $70 = HEAP32[$ext + 44 >> 2] | 0; //@line 13570
   if ($67 >>> 0 >= $70 >>> 0) {
    $val_0 = 0; //@line 13574
    break;
   }
   $77 = HEAP8[(HEAP32[$ext + 52 >> 2] | 0) + $67 | 0] | 0; //@line 13581
   $78 = $67 + 1 | 0; //@line 13582
   HEAP32[$66 >> 2] = $78; //@line 13583
   if ($78 >>> 0 < $70 >>> 0) {
    $val_0 = $77; //@line 13587
    break;
   }
   HEAP32[$61 >> 2] = 7; //@line 13590
   $81 = $ext + 9 | 0; //@line 13591
   HEAP8[$81] = HEAP8[$81] & -125 | 108; //@line 13595
   HEAP8[$ext + 5 | 0] = 0; //@line 13597
   $val_0 = $77; //@line 13599
  } else if (($8 | 0) == 0) {
   $val_0 = HEAP8[$ext + 5 | 0] | 0; //@line 13604
  } else {
   _mac_log_deb(48944, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 8 >> 2] = 255, tempInt) | 0); //@line 13606
   $val_0 = -1; //@line 13608
  }
 } while (0);
 STACKTOP = sp; //@line 13612
 return $val_0 | 0; //@line 13613
}
function _mac_scsi_set_uint16($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 return;
}
function _mac_scsi_reset($scsi) {
 $scsi = $scsi | 0;
 var $4 = 0;
 HEAP8[$scsi + 9 | 0] = 0; //@line 13635
 HEAP8[$scsi + 10 | 0] = 0; //@line 13637
 $4 = $scsi; //@line 13639
 HEAP32[$4 >> 2] = 0; //@line 13643
 HEAP32[$4 + 4 >> 2] = 0; //@line 13645
 HEAP8[$scsi + 11 | 0] = 8; //@line 13646
 HEAP8[$scsi + 12 | 0] = 0; //@line 13648
 HEAP32[$scsi + 16 >> 2] = 0; //@line 13650
 HEAP32[$scsi + 20 >> 2] = 0; //@line 13652
 HEAP32[$scsi + 40 >> 2] = 0; //@line 13654
 HEAP32[$scsi + 44 >> 2] = 0; //@line 13656
 HEAP32[$scsi + 68 >> 2] = 0; //@line 13658
 HEAP32[$scsi + 72 >> 2] = 0; //@line 13660
 return;
}
function _mac_scsi_cmd_test_unit_ready($scsi) {
 $scsi = $scsi | 0;
 var $2 = 0;
 HEAP32[$scsi >> 2] = 7; //@line 13672
 $2 = $scsi + 9 | 0; //@line 13673
 HEAP8[$2] = HEAP8[$2] & -125 | 108; //@line 13677
 HEAP8[$scsi + 5 | 0] = 0; //@line 13679
 return;
}
function _mac_scsi_cmd_format_unit($scsi) {
 $scsi = $scsi | 0;
 var $2 = 0;
 HEAP32[$scsi >> 2] = 7; //@line 13691
 $2 = $scsi + 9 | 0; //@line 13692
 HEAP8[$2] = HEAP8[$2] & -125 | 108; //@line 13696
 HEAP8[$scsi + 5 | 0] = 0; //@line 13698
 return;
}
function _mac_scsi_set_uint8($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $1 = 0, $9 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $26 = 0, $32 = 0, $33 = 0, $35 = 0, $43 = 0, $45 = 0, $49 = 0, $51 = 0, $54 = 0, $70 = 0, $75 = 0, $94 = 0, $99 = 0, $105 = 0, $114 = 0, $124 = 0, $126 = 0, $138 = 0, $142 = 0, $148 = 0, $154 = 0, $155 = 0, $170 = 0, $187 = 0, $193 = 0, $202 = 0, $211 = 0, $221 = 0, $230 = 0, $234 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $248 = 0, $259 = 0, $260 = 0, $i_09_i_i = 0, $_08_i_i = 0, $264 = 0, $265 = 0, $i_0_lcssa_i_i = 0, $271 = 0, $274 = 0, $280 = 0, $288 = 0, $296 = 0, $312 = 0, $328 = 0, $338 = 0, $342 = 0, $343 = 0, $349 = 0, $350 = 0, $351 = 0, $357 = 0, $365 = 0, $369 = 0, $374 = 0, $375 = 0, $377 = 0, $386 = 0, $392 = 0, $397 = 0, sp = 0;
 sp = STACKTOP; //@line 13751
 $1 = $ext; //@line 13752
 $9 = (HEAP32[$ext + 60 >> 2] & $addr) >>> ((HEAP32[$ext + 64 >> 2] | 0) >>> 0); //@line 13760
 if (($9 | 0) == 32) {
  $369 = $ext; //@line 13762
  if ((HEAP32[$369 >> 2] | 0) != 6) {
   STACKTOP = sp; //@line 13767
   return;
  }
  $374 = $ext + 40 | 0; //@line 13771
  $375 = HEAP32[$374 >> 2] | 0; //@line 13772
  $377 = $ext + 44 | 0; //@line 13774
  if ($375 >>> 0 >= (HEAP32[$377 >> 2] | 0) >>> 0) {
   STACKTOP = sp; //@line 13779
   return;
  }
  HEAP8[(HEAP32[$ext + 52 >> 2] | 0) + $375 | 0] = $val; //@line 13786
  $386 = (HEAP32[$374 >> 2] | 0) + 1 | 0; //@line 13788
  HEAP32[$374 >> 2] = $386; //@line 13789
  if ($386 >>> 0 < (HEAP32[$377 >> 2] | 0) >>> 0) {
   STACKTOP = sp; //@line 13794
   return;
  }
  $392 = HEAP32[$ext + 72 >> 2] | 0; //@line 13799
  if (($392 | 0) == 0) {
   HEAP32[$369 >> 2] = 7; //@line 13803
   $397 = $ext + 9 | 0; //@line 13804
   HEAP8[$397] = HEAP8[$397] & -125 | 108; //@line 13808
   HEAP8[$ext + 5 | 0] = 2; //@line 13810
   STACKTOP = sp; //@line 13811
   return;
  } else {
   FUNCTION_TABLE_vi[$392 & 1023]($1); //@line 13815
   STACKTOP = sp; //@line 13817
   return;
  }
 } else if (($9 | 0) == 4) {
  HEAP8[$ext + 10 | 0] = $val; //@line 13822
  STACKTOP = sp; //@line 13824
  return;
 } else if (($9 | 0) == 0) {
  HEAP8[$ext + 4 | 0] = $val; //@line 13828
  STACKTOP = sp; //@line 13830
  return;
 } else if (($9 | 0) == 1) {
  $13 = $val & -97; //@line 13833
  $14 = $ext + 6 | 0; //@line 13834
  $16 = $13 & 255; //@line 13836
  $17 = HEAP8[$14] ^ $13; //@line 13837
  HEAP8[$14] = $13; //@line 13838
  $18 = $ext; //@line 13839
  $19 = HEAP32[$18 >> 2] | 0; //@line 13840
  if (($19 | 0) == 1) {
   if (($val & 4 & $17) << 24 >> 24 == 0) {
    STACKTOP = sp; //@line 13847
    return;
   }
   HEAP32[$18 >> 2] = 2; //@line 13850
   STACKTOP = sp; //@line 13852
   return;
  } else if (($19 | 0) == 4) {
   $26 = $17 & 255; //@line 13855
   if (($val & 16 & $17) << 24 >> 24 != 0) {
    $32 = $ext + 16 | 0; //@line 13862
    $33 = HEAP32[$32 >> 2] | 0; //@line 13863
    $35 = $ext + 20 | 0; //@line 13865
    if ($33 >>> 0 < (HEAP32[$35 >> 2] | 0) >>> 0) {
     HEAP8[$1 + 24 + $33 | 0] = HEAP8[$ext + 4 | 0] | 0; //@line 13873
     $43 = (HEAP32[$32 >> 2] | 0) + 1 | 0; //@line 13875
     HEAP32[$32 >> 2] = $43; //@line 13876
     $45 = $43; //@line 13878
    } else {
     $45 = $33; //@line 13880
    }
    do {
     if (($45 | 0) == 1) {
      $49 = HEAP8[$ext + 24 | 0] | 0; //@line 13888
      $51 = $ext + 68 | 0; //@line 13890
      HEAP32[$51 >> 2] = 0; //@line 13891
      HEAP32[$ext + 72 >> 2] = 0; //@line 13894
      $54 = $49 & 255; //@line 13895
      if (($54 | 0) == 3) {
       HEAP32[$35 >> 2] = 6; //@line 13897
       HEAP32[$51 >> 2] = 356; //@line 13898
       break;
      } else if (($54 | 0) == 10) {
       HEAP32[$35 >> 2] = 6; //@line 13902
       HEAP32[$51 >> 2] = 494; //@line 13903
       break;
      } else if (($54 | 0) == 18) {
       HEAP32[$35 >> 2] = 6; //@line 13907
       HEAP32[$51 >> 2] = 460; //@line 13908
       break;
      } else if (($54 | 0) == 21) {
       HEAP32[$35 >> 2] = 6; //@line 13912
       HEAP32[$51 >> 2] = 22; //@line 13913
       break;
      } else if (($54 | 0) == 26) {
       HEAP32[$35 >> 2] = 6; //@line 13917
       HEAP32[$51 >> 2] = 354; //@line 13918
       break;
      } else if (($54 | 0) == 27) {
       HEAP32[$35 >> 2] = 6; //@line 13922
       HEAP32[$51 >> 2] = 456; //@line 13923
       break;
      } else if (($54 | 0) == 37) {
       HEAP32[$35 >> 2] = 10; //@line 13927
       HEAP32[$51 >> 2] = 206; //@line 13928
       break;
      } else if (($54 | 0) == 40) {
       HEAP32[$35 >> 2] = 10; //@line 13932
       HEAP32[$51 >> 2] = 156; //@line 13933
       break;
      } else if (($54 | 0) == 42) {
       HEAP32[$35 >> 2] = 10; //@line 13937
       HEAP32[$51 >> 2] = 514; //@line 13938
       break;
      } else if (($54 | 0) == 47) {
       HEAP32[$35 >> 2] = 10; //@line 13942
       HEAP32[$51 >> 2] = 300; //@line 13943
       break;
      } else if (($54 | 0) == 60) {
       HEAP32[$35 >> 2] = 6; //@line 13947
       HEAP32[$51 >> 2] = 366; //@line 13948
       break;
      } else if (($54 | 0) == 4) {
       HEAP32[$35 >> 2] = 6; //@line 13952
       HEAP32[$51 >> 2] = 178; //@line 13953
       break;
      } else if (($54 | 0) == 0) {
       HEAP32[$35 >> 2] = 6; //@line 13957
       HEAP32[$51 >> 2] = 402; //@line 13958
       break;
      } else if (($54 | 0) == 8) {
       HEAP32[$35 >> 2] = 6; //@line 13962
       HEAP32[$51 >> 2] = 232; //@line 13963
       break;
      } else {
       _mac_log_deb(41832, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $54, tempInt) | 0); //@line 13967
       HEAP32[$18 >> 2] = 7; //@line 13968
       $70 = $ext + 9 | 0; //@line 13969
       HEAP8[$70] = HEAP8[$70] & -125 | 108; //@line 13973
       HEAP8[$ext + 5 | 0] = 2; //@line 13975
       break;
      }
     }
    } while (0);
    $75 = $ext + 9 | 0; //@line 13981
    HEAP8[$75] = HEAP8[$75] & -33; //@line 13984
   }
   if (($26 & ($16 & 16 ^ 16) | 0) == 0) {
    STACKTOP = sp; //@line 13993
    return;
   }
   if ((HEAP32[$ext + 16 >> 2] | 0) >>> 0 < (HEAP32[$ext + 20 >> 2] | 0) >>> 0) {
    $105 = $ext + 9 | 0; //@line 14005
    HEAP8[$105] = HEAP8[$105] | 32; //@line 14008
    STACKTOP = sp; //@line 14009
    return;
   }
   $94 = HEAP32[$ext + 68 >> 2] | 0; //@line 14014
   if (($94 | 0) == 0) {
    HEAP32[$18 >> 2] = 7; //@line 14018
    $99 = $ext + 9 | 0; //@line 14019
    HEAP8[$99] = HEAP8[$99] & -125 | 108; //@line 14023
    HEAP8[$ext + 5 | 0] = 2; //@line 14025
    STACKTOP = sp; //@line 14026
    return;
   } else {
    FUNCTION_TABLE_vi[$94 & 1023]($1); //@line 14030
    STACKTOP = sp; //@line 14032
    return;
   }
  } else if (($19 | 0) == 5) {
   if (($val & 16 & $17) << 24 >> 24 != 0) {
    $114 = $ext + 9 | 0; //@line 14042
    HEAP8[$114] = HEAP8[$114] & -33; //@line 14045
   }
   if (($17 & 255 & ($16 & 16 ^ 16) | 0) == 0) {
    STACKTOP = sp; //@line 14054
    return;
   }
   $124 = $ext + 40 | 0; //@line 14058
   $126 = (HEAP32[$124 >> 2] | 0) + 1 | 0; //@line 14060
   HEAP32[$124 >> 2] = $126; //@line 14061
   if ($126 >>> 0 < (HEAP32[$ext + 44 >> 2] | 0) >>> 0) {
    HEAP8[$ext + 5 | 0] = HEAP8[(HEAP32[$ext + 52 >> 2] | 0) + $126 | 0] | 0; //@line 14074
    $138 = $ext + 9 | 0; //@line 14075
    HEAP8[$138] = HEAP8[$138] | 32; //@line 14078
    STACKTOP = sp; //@line 14080
    return;
   } else {
    HEAP32[$18 >> 2] = 7; //@line 14083
    $142 = $ext + 9 | 0; //@line 14084
    HEAP8[$142] = HEAP8[$142] & -125 | 108; //@line 14088
    HEAP8[$ext + 5 | 0] = 0; //@line 14090
    STACKTOP = sp; //@line 14091
    return;
   }
  } else if (($19 | 0) == 6) {
   $148 = $17 & 255; //@line 14095
   if (($val & 16 & $17) << 24 >> 24 != 0) {
    $154 = $ext + 40 | 0; //@line 14102
    $155 = HEAP32[$154 >> 2] | 0; //@line 14103
    if ($155 >>> 0 < (HEAP32[$ext + 44 >> 2] | 0) >>> 0) {
     HEAP8[(HEAP32[$ext + 52 >> 2] | 0) + $155 | 0] = HEAP8[$ext + 4 | 0] | 0; //@line 14116
     HEAP32[$154 >> 2] = (HEAP32[$154 >> 2] | 0) + 1; //@line 14119
    }
    $170 = $ext + 9 | 0; //@line 14122
    HEAP8[$170] = HEAP8[$170] & -33; //@line 14125
   }
   if (($148 & ($16 & 16 ^ 16) | 0) == 0) {
    STACKTOP = sp; //@line 14134
    return;
   }
   if ((HEAP32[$ext + 40 >> 2] | 0) >>> 0 < (HEAP32[$ext + 44 >> 2] | 0) >>> 0) {
    $193 = $ext + 9 | 0; //@line 14146
    HEAP8[$193] = HEAP8[$193] | 32; //@line 14149
    STACKTOP = sp; //@line 14150
    return;
   } else {
    HEAP32[$18 >> 2] = 7; //@line 14153
    $187 = $ext + 9 | 0; //@line 14154
    HEAP8[$187] = HEAP8[$187] & -125 | 108; //@line 14158
    HEAP8[$ext + 5 | 0] = 2; //@line 14160
    STACKTOP = sp; //@line 14162
    return;
   }
  } else if (($19 | 0) == 7) {
   if (($val & 16 & $17) << 24 >> 24 != 0) {
    $202 = $ext + 9 | 0; //@line 14172
    HEAP8[$202] = HEAP8[$202] & -33; //@line 14175
   }
   if (($17 & 255 & ($16 & 16 ^ 16) | 0) == 0) {
    STACKTOP = sp; //@line 14184
    return;
   }
   HEAP32[$18 >> 2] = 8; //@line 14187
   $211 = $ext + 9 | 0; //@line 14188
   HEAP8[$211] = HEAP8[$211] | 124; //@line 14191
   HEAP8[$ext + 5 | 0] = 0; //@line 14193
   STACKTOP = sp; //@line 14195
   return;
  } else if (($19 | 0) == 8) {
   if (($val & 16 & $17) << 24 >> 24 != 0) {
    $221 = $ext + 9 | 0; //@line 14204
    HEAP8[$221] = HEAP8[$221] & -33; //@line 14207
   }
   if (($17 & 255 & ($16 & 16 ^ 16) | 0) == 0) {
    STACKTOP = sp; //@line 14216
    return;
   }
   HEAP32[$18 >> 2] = 0; //@line 14219
   $230 = $ext + 9 | 0; //@line 14220
   HEAP8[$230] = HEAP8[$230] & -125; //@line 14223
   STACKTOP = sp; //@line 14225
   return;
  } else {
   STACKTOP = sp; //@line 14228
   return;
  }
 } else if (($9 | 0) == 3) {
  $342 = $ext + 8 | 0; //@line 14232
  $343 = HEAP8[$342] | 0; //@line 14233
  HEAP8[$342] = $val; //@line 14234
  if (($val & 2 & ($343 ^ 2)) << 24 >> 24 == 0) {
   STACKTOP = sp; //@line 14241
   return;
  }
  $349 = $ext; //@line 14244
  $350 = HEAP32[$349 >> 2] | 0; //@line 14245
  if (($350 | 0) == 5) {
   HEAP32[$349 >> 2] = 7; //@line 14247
   $351 = $ext + 9 | 0; //@line 14248
   HEAP8[$351] = HEAP8[$351] & -125 | 108; //@line 14252
   HEAP8[$ext + 5 | 0] = 0; //@line 14254
   STACKTOP = sp; //@line 14256
   return;
  } else if (($350 | 0) == 6) {
   HEAP32[$349 >> 2] = 7; //@line 14259
   $357 = $ext + 9 | 0; //@line 14260
   HEAP8[$357] = HEAP8[$357] & -125 | 108; //@line 14264
   HEAP8[$ext + 5 | 0] = 0; //@line 14266
   STACKTOP = sp; //@line 14268
   return;
  } else {
   STACKTOP = sp; //@line 14271
   return;
  }
 } else if (($9 | 0) == 2) {
  $234 = $ext + 7 | 0; //@line 14275
  $236 = $val & 255; //@line 14277
  $237 = HEAP8[$234] ^ $val; //@line 14278
  HEAP8[$234] = $val; //@line 14279
  $238 = $ext; //@line 14280
  $239 = HEAP32[$238 >> 2] | 0; //@line 14281
  L2325 : do {
   if (($239 | 0) == 0) {
    if (($val & 1 & $237) << 24 >> 24 == 0) {
     break;
    }
    HEAP32[$238 >> 2] = 1; //@line 14291
    HEAP8[$ext + 5 | 0] = HEAP8[$ext + 4 | 0] | 0; //@line 14295
    $248 = $ext + 6 | 0; //@line 14296
    HEAP8[$248] = HEAP8[$248] | 64; //@line 14299
   } else if (($239 | 0) == 2) {
    if (($237 & 255 & ($236 & 1 ^ 1) | 0) == 0) {
     break;
    }
    $259 = HEAP8[$ext + 4 | 0] | 0; //@line 14312
    $260 = $259 & 127; //@line 14313
    if ($260 << 24 >> 24 != 0 & ($259 & 1) == 0) {
     $_08_i_i = $260;
     $i_09_i_i = 0;
     while (1) {
      $264 = $i_09_i_i + 1 | 0; //@line 14324
      $265 = ($_08_i_i & 255) >>> 1; //@line 14325
      if ($265 << 24 >> 24 != 0 & ($265 & 1) == 0) {
       $_08_i_i = $265;
       $i_09_i_i = $264;
      } else {
       $i_0_lcssa_i_i = $264; //@line 14334
       break;
      }
     }
    } else {
     $i_0_lcssa_i_i = 0; //@line 14339
    }
    HEAP32[$ext + 56 >> 2] = $i_0_lcssa_i_i; //@line 14344
    $271 = $ext + 6 | 0; //@line 14345
    HEAP8[$271] = HEAP8[$271] & -9; //@line 14348
    $274 = $i_0_lcssa_i_i & 7; //@line 14349
    do {
     if ((HEAP32[$1 + 76 + ($274 << 5) >> 2] | 0) != 0) {
      $280 = HEAP32[$1 + 76 + ($274 << 5) + 4 >> 2] | 0; //@line 14357
      if (($280 | 0) == 65535) {
       break;
      }
      if ((_dsks_get_disk(HEAP32[$ext + 332 >> 2] | 0, $280) | 0) == 0) {
       break;
      }
      HEAP32[$238 >> 2] = 4; //@line 14372
      $288 = $ext + 9 | 0; //@line 14373
      HEAP8[$288] = HEAP8[$288] & -125 | 104; //@line 14377
      HEAP32[$ext + 16 >> 2] = 0; //@line 14380
      HEAP32[$ext + 20 >> 2] = 16; //@line 14383
      break L2325;
     }
    } while (0);
    HEAP32[$238 >> 2] = 0; //@line 14388
    $296 = $ext + 9 | 0; //@line 14389
    HEAP8[$296] = HEAP8[$296] & -125; //@line 14392
   } else if (($239 | 0) == 5) {
    if (($val & 2 & $237) << 24 >> 24 == 0) {
     break;
    }
    if ((HEAP32[$ext + 40 >> 2] | 0) >>> 0 >= (HEAP32[$ext + 44 >> 2] | 0) >>> 0) {
     break;
    }
    $312 = $ext + 11 | 0; //@line 14412
    HEAP8[$312] = HEAP8[$312] | 64; //@line 14415
   } else if (($239 | 0) == 6) {
    if (($val & 2 & $237) << 24 >> 24 == 0) {
     break;
    }
    if ((HEAP32[$ext + 40 >> 2] | 0) >>> 0 >= (HEAP32[$ext + 44 >> 2] | 0) >>> 0) {
     break;
    }
    $328 = $ext + 11 | 0; //@line 14436
    HEAP8[$328] = HEAP8[$328] | 64; //@line 14439
   }
  } while (0);
  if (($237 & 255 & ($236 & 2 ^ 2) | 0) == 0) {
   STACKTOP = sp; //@line 14450
   return;
  }
  $338 = $ext + 11 | 0; //@line 14453
  HEAP8[$338] = HEAP8[$338] & -65; //@line 14456
  STACKTOP = sp; //@line 14458
  return;
 } else if (($9 | 0) == 5) {
  $365 = $ext + 11 | 0; //@line 14461
  HEAP8[$365] = HEAP8[$365] | 64; //@line 14464
  STACKTOP = sp; //@line 14466
  return;
 } else if (($9 | 0) == 6 | ($9 | 0) == 7) {
  STACKTOP = sp; //@line 14469
  return;
 } else {
  _mac_log_deb(45304, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $9, HEAP32[tempInt + 8 >> 2] = $val & 255, tempInt) | 0); //@line 14473
  STACKTOP = sp; //@line 14475
  return;
 }
}
function _mac_scsi_cmd_sense($scsi) {
 $scsi = $scsi | 0;
 var $1 = 0, $7 = 0;
 $1 = $scsi + 52 | 0; //@line 14487
 _memset(HEAP32[$1 >> 2] | 0, 0, 13); //@line 14489
 HEAP8[HEAP32[$1 >> 2] | 0] = -16; //@line 14491
 HEAP32[$scsi + 40 >> 2] = 0; //@line 14493
 HEAP32[$scsi + 44 >> 2] = 13; //@line 14495
 HEAP32[$scsi >> 2] = 5; //@line 14497
 $7 = $scsi + 9 | 0; //@line 14498
 HEAP8[$7] = HEAP8[$7] & -125 | 100; //@line 14502
 HEAP8[$scsi + 5 | 0] = HEAP8[HEAP32[$1 >> 2] | 0] | 0; //@line 14506
 return;
}
function _mac_scsi_cmd_read6($scsi) {
 $scsi = $scsi | 0;
 var $16 = 0;
 $16 = HEAP8[$scsi + 28 | 0] | 0; //@line 14534
 _mac_scsi_cmd_read($scsi, ((HEAPU8[$scsi + 25 | 0] | 0) << 8 & 7936 | (HEAPU8[$scsi + 26 | 0] | 0)) << 8 | (HEAPU8[$scsi + 27 | 0] | 0), $16 << 24 >> 24 == 0 ? 256 : $16 & 255); //@line 14538
 return;
}
function _mac_scsi_cmd_write6($scsi) {
 $scsi = $scsi | 0;
 var $2 = 0, $_ = 0, $5 = 0, $6 = 0, $10 = 0, $12 = 0, $17 = 0, $27 = 0, sp = 0;
 sp = STACKTOP; //@line 14551
 $2 = HEAP8[$scsi + 28 | 0] | 0; //@line 14553
 $_ = $2 << 24 >> 24 == 0 ? 256 : $2 & 255; //@line 14556
 $5 = $_ << 9; //@line 14557
 $6 = $scsi + 48 | 0; //@line 14558
 do {
  if ((HEAP32[$6 >> 2] | 0) >>> 0 < $5 >>> 0) {
   $10 = $scsi + 52 | 0; //@line 14564
   $12 = _realloc(HEAP32[$10 >> 2] | 0, $5) | 0; //@line 14566
   if (($12 | 0) != 0) {
    HEAP32[$10 >> 2] = $12; //@line 14570
    HEAP32[$6 >> 2] = $5; //@line 14571
    break;
   }
   _mac_log_deb(38808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $_, tempInt) | 0); //@line 14575
   HEAP32[$scsi >> 2] = 7; //@line 14577
   $17 = $scsi + 9 | 0; //@line 14578
   HEAP8[$17] = HEAP8[$17] & -125 | 108; //@line 14582
   HEAP8[$scsi + 5 | 0] = 2; //@line 14584
   STACKTOP = sp; //@line 14586
   return;
  }
 } while (0);
 HEAP32[$scsi + 40 >> 2] = 0; //@line 14591
 HEAP32[$scsi + 44 >> 2] = $5; //@line 14593
 HEAP32[$scsi + 72 >> 2] = 144; //@line 14595
 HEAP32[$scsi >> 2] = 6; //@line 14597
 $27 = $scsi + 9 | 0; //@line 14598
 HEAP8[$27] = HEAP8[$27] & -125 | 96; //@line 14602
 STACKTOP = sp; //@line 14604
 return;
}
function _mac_scsi_cmd_mode_select($scsi) {
 $scsi = $scsi | 0;
 var $4 = 0;
 HEAP32[$scsi + 40 >> 2] = 0; //@line 14615
 HEAP32[$scsi + 44 >> 2] = 0; //@line 14617
 HEAP32[$scsi >> 2] = 6; //@line 14619
 $4 = $scsi + 9 | 0; //@line 14620
 HEAP8[$4] = HEAP8[$4] & -125 | 96; //@line 14624
 return;
}
function _mac_scsi_cmd_inquiry($scsi) {
 $scsi = $scsi | 0;
 var $4 = 0, $__i = 0, $8 = 0, $15 = 0, $16 = 0, $ld$0$0 = 0, $ld$1$1 = 0, $17$1 = 0, $st$2$0 = 0, $st$3$1 = 0, $19 = 0, $20 = 0, $26 = 0, $32 = 0;
 $4 = $scsi + 76 + ((HEAP32[$scsi + 56 >> 2] & 7) << 5) | 0; //@line 14643
 $__i = (HEAP32[$4 >> 2] | 0) == 0 ? 0 : $4; //@line 14647
 $8 = $scsi + 52 | 0; //@line 14648
 _memset(HEAP32[$8 >> 2] | 0, 0, 256); //@line 14650
 if (($__i | 0) != 0) {
  $15 = $__i + 8 | 0; //@line 14657
  $16 = (HEAP32[$8 >> 2] | 0) + 8 | 0; //@line 14658
  $ld$0$0 = $15 | 0; //@line 14659
  $ld$1$1 = $15 + 4 | 0; //@line 14661
  $17$1 = HEAPU8[$ld$1$1] | HEAPU8[$ld$1$1 + 1 | 0] << 8 | HEAPU8[$ld$1$1 + 2 | 0] << 16 | HEAPU8[$ld$1$1 + 3 | 0] << 24 | 0; //@line 14662
  $st$2$0 = $16 | 0; //@line 14663
  tempBigInt = HEAPU8[$ld$0$0] | HEAPU8[$ld$0$0 + 1 | 0] << 8 | HEAPU8[$ld$0$0 + 2 | 0] << 16 | HEAPU8[$ld$0$0 + 3 | 0] << 24 | 0; //@line 14664
  HEAP8[$st$2$0] = tempBigInt & 255; //@line 14664
  tempBigInt = tempBigInt >> 8; //@line 14664
  HEAP8[$st$2$0 + 1 | 0] = tempBigInt & 255; //@line 14664
  tempBigInt = tempBigInt >> 8; //@line 14664
  HEAP8[$st$2$0 + 2 | 0] = tempBigInt & 255; //@line 14664
  tempBigInt = tempBigInt >> 8; //@line 14664
  HEAP8[$st$2$0 + 3 | 0] = tempBigInt & 255; //@line 14664
  $st$3$1 = $16 + 4 | 0; //@line 14665
  tempBigInt = $17$1; //@line 14666
  HEAP8[$st$3$1] = tempBigInt & 255; //@line 14666
  tempBigInt = tempBigInt >> 8; //@line 14666
  HEAP8[$st$3$1 + 1 | 0] = tempBigInt & 255; //@line 14666
  tempBigInt = tempBigInt >> 8; //@line 14666
  HEAP8[$st$3$1 + 2 | 0] = tempBigInt & 255; //@line 14666
  tempBigInt = tempBigInt >> 8; //@line 14666
  HEAP8[$st$3$1 + 3 | 0] = tempBigInt & 255; //@line 14666
  $19 = (HEAP32[$8 >> 2] | 0) + 16 | 0; //@line 14668
  $20 = $__i + 16 | 0; //@line 14669
  _memcpy($19 | 0, $20 | 0, 16) | 0; //@line 14670
 }
 HEAP8[(HEAP32[$8 >> 2] | 0) + 4 | 0] = 32; //@line 14675
 HEAP32[$scsi + 40 >> 2] = 0; //@line 14677
 $26 = HEAP8[$scsi + 28 | 0] | 0; //@line 14679
 HEAP32[$scsi + 44 >> 2] = ($26 & 255) < 36 ? $26 & 255 : 36; //@line 14684
 HEAP32[$scsi >> 2] = 5; //@line 14686
 $32 = $scsi + 9 | 0; //@line 14687
 HEAP8[$32] = HEAP8[$32] & -125 | 100; //@line 14691
 HEAP8[$scsi + 5 | 0] = HEAP8[HEAP32[$8 >> 2] | 0] | 0; //@line 14695
 return;
}
function _mac_scsi_cmd_mode_sense($scsi) {
 $scsi = $scsi | 0;
 var $3 = 0, $9 = 0, $13 = 0, $16 = 0, $22 = 0, $24 = 0, $25 = 0, $28 = 0, $29 = 0, $59 = 0, $63 = 0, $74 = 0, sp = 0;
 sp = STACKTOP; //@line 14713
 $3 = HEAP32[$scsi + 56 >> 2] & 7; //@line 14716
 do {
  if ((HEAP32[$scsi + 76 + ($3 << 5) >> 2] | 0) != 0) {
   $9 = HEAP32[$scsi + 76 + ($3 << 5) + 4 >> 2] | 0; //@line 14724
   if (($9 | 0) == 65535) {
    break;
   }
   $13 = _dsks_get_disk(HEAP32[$scsi + 332 >> 2] | 0, $9) | 0; //@line 14732
   if (($13 | 0) == 0) {
    break;
   }
   $22 = $scsi + 52 | 0; //@line 14738
   _memset(HEAP32[$22 >> 2] | 0, 0, 512); //@line 14740
   $24 = $scsi + 40 | 0; //@line 14741
   HEAP32[$24 >> 2] = 0; //@line 14742
   $25 = $scsi + 44 | 0; //@line 14743
   HEAP32[$25 >> 2] = 0; //@line 14744
   $28 = HEAPU8[$scsi + 26 | 0] | 0; //@line 14747
   $29 = $28 & 63; //@line 14748
   do {
    if (($29 | 0) == 1) {
     HEAP8[HEAP32[$22 >> 2] | 0] = 1; //@line 14752
     HEAP8[(HEAP32[$22 >> 2] | 0) + 1 | 0] = 10; //@line 14755
     HEAP32[$25 >> 2] = 12; //@line 14756
    } else if (($29 | 0) == 3) {
     HEAP8[HEAP32[$22 >> 2] | 0] = 3; //@line 14760
     HEAP8[(HEAP32[$22 >> 2] | 0) + 1 | 0] = 22; //@line 14763
     HEAP32[$25 >> 2] = 24; //@line 14764
    } else if (($29 | 0) == 4) {
     HEAP8[HEAP32[$22 >> 2] | 0] = 4; //@line 14768
     HEAP8[(HEAP32[$22 >> 2] | 0) + 1 | 0] = 22; //@line 14771
     HEAP8[(HEAP32[$22 >> 2] | 0) + 2 | 0] = 0; //@line 14774
     _buf_set_uint16_be(HEAP32[$22 >> 2] | 0, 3, HEAP32[$13 + 32 >> 2] & 65535); //@line 14779
     HEAP8[(HEAP32[$22 >> 2] | 0) + 5 | 0] = HEAP32[$13 + 36 >> 2] & 255; //@line 14785
     _buf_set_uint16_be(HEAP32[$22 >> 2] | 0, 20, 3600); //@line 14787
     HEAP32[$25 >> 2] = 32; //@line 14788
    } else if (($29 | 0) == 48) {
     HEAP8[HEAP32[$22 >> 2] | 0] = 48; //@line 14792
     HEAP8[(HEAP32[$22 >> 2] | 0) + 1 | 0] = 33; //@line 14795
     $59 = (HEAP32[$22 >> 2] | 0) + 14 | 0; //@line 14797
     _memcpy($59 | 0, 53696, 20) | 0; //@line 14798
     HEAP32[$25 >> 2] = 34; //@line 14799
    } else {
     _mac_log_deb(53040, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $28, tempInt) | 0); //@line 14802
     if ((HEAP32[$25 >> 2] | 0) != 0) {
      break;
     }
     HEAP32[$scsi >> 2] = 7; //@line 14810
     $74 = $scsi + 9 | 0; //@line 14811
     HEAP8[$74] = HEAP8[$74] & -125 | 108; //@line 14815
     HEAP8[$scsi + 5 | 0] = 2; //@line 14817
     STACKTOP = sp; //@line 14818
     return;
    }
   } while (0);
   HEAP32[$scsi >> 2] = 5; //@line 14823
   $63 = $scsi + 9 | 0; //@line 14824
   HEAP8[$63] = HEAP8[$63] & -125 | 100; //@line 14828
   HEAP8[$scsi + 5 | 0] = HEAP8[(HEAP32[$22 >> 2] | 0) + (HEAP32[$24 >> 2] | 0) | 0] | 0; //@line 14834
   STACKTOP = sp; //@line 14836
   return;
  }
 } while (0);
 HEAP32[$scsi >> 2] = 7; //@line 14841
 $16 = $scsi + 9 | 0; //@line 14842
 HEAP8[$16] = HEAP8[$16] & -125 | 108; //@line 14846
 HEAP8[$scsi + 5 | 0] = 2; //@line 14848
 STACKTOP = sp; //@line 14850
 return;
}
function _mac_scsi_cmd_start_stop($scsi) {
 $scsi = $scsi | 0;
 var $4 = 0, $str_0 = 0, $13 = 0, sp = 0;
 sp = STACKTOP; //@line 14860
 $4 = HEAP8[$scsi + 28 | 0] & 3; //@line 14864
 if (($4 | 0) == 3) {
  $str_0 = 55048; //@line 14867
 } else if (($4 | 0) == 2) {
  $str_0 = 55712; //@line 14870
 } else if (($4 | 0) == 1) {
  $str_0 = 56888; //@line 14873
 } else if (($4 | 0) == 0) {
  $str_0 = 57720; //@line 14876
 } else {
  $str_0 = 0; //@line 14878
 }
 _mac_log_deb(54312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$scsi + 56 >> 2], HEAP32[tempInt + 8 >> 2] = $str_0, tempInt) | 0); //@line 14883
 HEAP32[$scsi >> 2] = 7; //@line 14885
 $13 = $scsi + 9 | 0; //@line 14886
 HEAP8[$13] = HEAP8[$13] & -125 | 108; //@line 14890
 HEAP8[$scsi + 5 | 0] = 0; //@line 14892
 STACKTOP = sp; //@line 14893
 return;
}
function _mac_scsi_cmd_read_capacity($scsi) {
 $scsi = $scsi | 0;
 var $3 = 0, $9 = 0, $13 = 0, $16 = 0, $22 = 0, $23 = 0, $30 = 0;
 $3 = HEAP32[$scsi + 56 >> 2] & 7; //@line 14909
 do {
  if ((HEAP32[$scsi + 76 + ($3 << 5) >> 2] | 0) != 0) {
   $9 = HEAP32[$scsi + 76 + ($3 << 5) + 4 >> 2] | 0; //@line 14917
   if (($9 | 0) == 65535) {
    break;
   }
   $13 = _dsks_get_disk(HEAP32[$scsi + 332 >> 2] | 0, $9) | 0; //@line 14925
   if (($13 | 0) == 0) {
    break;
   }
   $22 = _dsk_get_block_cnt($13) | 0; //@line 14931
   $23 = $scsi + 52 | 0; //@line 14932
   _buf_set_uint32_be(HEAP32[$23 >> 2] | 0, 0, $22 - 1 | 0); //@line 14935
   _buf_set_uint32_be(HEAP32[$23 >> 2] | 0, 4, 512); //@line 14937
   HEAP32[$scsi + 40 >> 2] = 0; //@line 14939
   HEAP32[$scsi + 44 >> 2] = 8; //@line 14941
   HEAP32[$scsi >> 2] = 5; //@line 14943
   $30 = $scsi + 9 | 0; //@line 14944
   HEAP8[$30] = HEAP8[$30] & -125 | 100; //@line 14948
   HEAP8[$scsi + 5 | 0] = HEAP8[HEAP32[$23 >> 2] | 0] | 0; //@line 14952
   return;
  }
 } while (0);
 HEAP32[$scsi >> 2] = 7; //@line 14959
 $16 = $scsi + 9 | 0; //@line 14960
 HEAP8[$16] = HEAP8[$16] & -125 | 108; //@line 14964
 HEAP8[$scsi + 5 | 0] = 2; //@line 14966
 return;
}
function _mac_scsi_cmd_read10($scsi) {
 $scsi = $scsi | 0;
 _mac_scsi_cmd_read($scsi, (((HEAPU8[$scsi + 26 | 0] | 0) << 8 | (HEAPU8[$scsi + 27 | 0] | 0)) << 8 | (HEAPU8[$scsi + 28 | 0] | 0)) << 8 | (HEAPU8[$scsi + 29 | 0] | 0), (HEAPU8[$scsi + 31 | 0] | 0) << 8 | (HEAPU8[$scsi + 32 | 0] | 0)); //@line 15007
 return;
}
function _mac_scsi_cmd_write10($scsi) {
 $scsi = $scsi | 0;
 var $8 = 0, $9 = 0, $10 = 0, $14 = 0, $16 = 0, $21 = 0, $31 = 0, sp = 0;
 sp = STACKTOP; //@line 15020
 $8 = (HEAPU8[$scsi + 31 | 0] | 0) << 8 | (HEAPU8[$scsi + 32 | 0] | 0); //@line 15028
 $9 = $8 << 9; //@line 15029
 $10 = $scsi + 48 | 0; //@line 15030
 do {
  if ((HEAP32[$10 >> 2] | 0) >>> 0 < $9 >>> 0) {
   $14 = $scsi + 52 | 0; //@line 15036
   $16 = _realloc(HEAP32[$14 >> 2] | 0, $9) | 0; //@line 15038
   if (($16 | 0) != 0) {
    HEAP32[$14 >> 2] = $16; //@line 15042
    HEAP32[$10 >> 2] = $9; //@line 15043
    break;
   }
   _mac_log_deb(38808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $8, tempInt) | 0); //@line 15047
   HEAP32[$scsi >> 2] = 7; //@line 15049
   $21 = $scsi + 9 | 0; //@line 15050
   HEAP8[$21] = HEAP8[$21] & -125 | 108; //@line 15054
   HEAP8[$scsi + 5 | 0] = 2; //@line 15056
   STACKTOP = sp; //@line 15058
   return;
  }
 } while (0);
 HEAP32[$scsi + 40 >> 2] = 0; //@line 15063
 HEAP32[$scsi + 44 >> 2] = $9; //@line 15065
 HEAP32[$scsi + 72 >> 2] = 520; //@line 15067
 HEAP32[$scsi >> 2] = 6; //@line 15069
 $31 = $scsi + 9 | 0; //@line 15070
 HEAP8[$31] = HEAP8[$31] & -125 | 96; //@line 15074
 STACKTOP = sp; //@line 15076
 return;
}
function _mac_scsi_cmd_verify10($scsi) {
 $scsi = $scsi | 0;
 var $3 = 0, $9 = 0, $16 = 0, $25 = 0;
 $3 = HEAP32[$scsi + 56 >> 2] & 7; //@line 15091
 do {
  if ((HEAP32[$scsi + 76 + ($3 << 5) >> 2] | 0) != 0) {
   $9 = HEAP32[$scsi + 76 + ($3 << 5) + 4 >> 2] | 0; //@line 15099
   if (($9 | 0) == 65535) {
    break;
   }
   if ((_dsks_get_disk(HEAP32[$scsi + 332 >> 2] | 0, $9) | 0) == 0) {
    break;
   }
   HEAP32[$scsi + 40 >> 2] = 0; //@line 15114
   HEAP32[$scsi + 44 >> 2] = 0; //@line 15116
   HEAP32[$scsi >> 2] = 7; //@line 15118
   $25 = $scsi + 9 | 0; //@line 15119
   HEAP8[$25] = HEAP8[$25] & -125 | 108; //@line 15123
   HEAP8[$scsi + 5 | 0] = 0; //@line 15125
   return;
  }
 } while (0);
 HEAP32[$scsi >> 2] = 7; //@line 15132
 $16 = $scsi + 9 | 0; //@line 15133
 HEAP8[$16] = HEAP8[$16] & -125 | 108; //@line 15137
 HEAP8[$scsi + 5 | 0] = 2; //@line 15139
 return;
}
function _mac_scsi_cmd_read_buffer($scsi) {
 $scsi = $scsi | 0;
 var $1 = 0, $6 = 0;
 $1 = $scsi + 52 | 0; //@line 15152
 _memset(HEAP32[$1 >> 2] | 0, 0, 512); //@line 15154
 HEAP32[$scsi + 40 >> 2] = 0; //@line 15156
 HEAP32[$scsi + 44 >> 2] = 4; //@line 15158
 HEAP32[$scsi >> 2] = 5; //@line 15160
 $6 = $scsi + 9 | 0; //@line 15161
 HEAP8[$6] = HEAP8[$6] & -125 | 100; //@line 15165
 HEAP8[$scsi + 5 | 0] = HEAP8[HEAP32[$1 >> 2] | 0] | 0; //@line 15169
 return;
}
function _mac_scsi_cmd_write10_finish($scsi) {
 $scsi = $scsi | 0;
 _mac_scsi_cmd_write_finish($scsi, (((HEAPU8[$scsi + 26 | 0] | 0) << 8 | (HEAPU8[$scsi + 27 | 0] | 0)) << 8 | (HEAPU8[$scsi + 28 | 0] | 0)) << 8 | (HEAPU8[$scsi + 29 | 0] | 0), (HEAPU8[$scsi + 31 | 0] | 0) << 8 | (HEAPU8[$scsi + 32 | 0] | 0)); //@line 15209
 return;
}
function _mac_scsi_cmd_write_finish($scsi, $lba, $cnt) {
 $scsi = $scsi | 0;
 $lba = $lba | 0;
 $cnt = $cnt | 0;
 var $3 = 0, $9 = 0, $13 = 0, $16 = 0, $22 = 0, $23 = 0, $24 = 0, $28 = 0, $40 = 0, $49 = 0, sp = 0;
 sp = STACKTOP; //@line 15226
 $3 = HEAP32[$scsi + 56 >> 2] & 7; //@line 15229
 do {
  if ((HEAP32[$scsi + 76 + ($3 << 5) >> 2] | 0) != 0) {
   $9 = HEAP32[$scsi + 76 + ($3 << 5) + 4 >> 2] | 0; //@line 15237
   if (($9 | 0) == 65535) {
    break;
   }
   $13 = _dsks_get_disk(HEAP32[$scsi + 332 >> 2] | 0, $9) | 0; //@line 15245
   if (($13 | 0) == 0) {
    break;
   }
   $22 = $cnt << 9; //@line 15251
   $23 = $scsi + 40 | 0; //@line 15252
   $24 = HEAP32[$23 >> 2] | 0; //@line 15253
   if (($22 | 0) != ($24 | 0)) {
    _mac_log_deb(35904, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $22, HEAP32[tempInt + 8 >> 2] = $24, tempInt) | 0); //@line 15257
    HEAP32[$scsi >> 2] = 7; //@line 15259
    $28 = $scsi + 9 | 0; //@line 15260
    HEAP8[$28] = HEAP8[$28] & -125 | 108; //@line 15264
    HEAP8[$scsi + 5 | 0] = 2; //@line 15266
    STACKTOP = sp; //@line 15268
    return;
   }
   if ((_dsk_write_lba($13, HEAP32[$scsi + 52 >> 2] | 0, $lba, $cnt) | 0) == 0) {
    HEAP32[$23 >> 2] = 0; //@line 15277
    HEAP32[$scsi + 44 >> 2] = 0; //@line 15279
    HEAP32[$scsi + 72 >> 2] = 0; //@line 15281
    HEAP32[$scsi >> 2] = 7; //@line 15283
    $49 = $scsi + 9 | 0; //@line 15284
    HEAP8[$49] = HEAP8[$49] & -125 | 108; //@line 15288
    HEAP8[$scsi + 5 | 0] = 0; //@line 15290
    STACKTOP = sp; //@line 15292
    return;
   } else {
    _mac_log_deb(32904, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 15295
    HEAP32[$scsi >> 2] = 7; //@line 15297
    $40 = $scsi + 9 | 0; //@line 15298
    HEAP8[$40] = HEAP8[$40] & -125 | 108; //@line 15302
    HEAP8[$scsi + 5 | 0] = 2; //@line 15304
    STACKTOP = sp; //@line 15306
    return;
   }
  }
 } while (0);
 HEAP32[$scsi >> 2] = 7; //@line 15312
 $16 = $scsi + 9 | 0; //@line 15313
 HEAP8[$16] = HEAP8[$16] & -125 | 108; //@line 15317
 HEAP8[$scsi + 5 | 0] = 2; //@line 15319
 STACKTOP = sp; //@line 15321
 return;
}
function _mac_scsi_cmd_read($scsi, $lba, $cnt) {
 $scsi = $scsi | 0;
 $lba = $lba | 0;
 $cnt = $cnt | 0;
 var $3 = 0, $9 = 0, $13 = 0, $16 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $29 = 0, $34 = 0, $39 = 0, $44 = 0, $54 = 0, sp = 0;
 sp = STACKTOP; //@line 15338
 $3 = HEAP32[$scsi + 56 >> 2] & 7; //@line 15341
 do {
  if ((HEAP32[$scsi + 76 + ($3 << 5) >> 2] | 0) != 0) {
   $9 = HEAP32[$scsi + 76 + ($3 << 5) + 4 >> 2] | 0; //@line 15349
   if (($9 | 0) == 65535) {
    break;
   }
   $13 = _dsks_get_disk(HEAP32[$scsi + 332 >> 2] | 0, $9) | 0; //@line 15357
   if (($13 | 0) == 0) {
    break;
   }
   $22 = $cnt << 9; //@line 15363
   $23 = $scsi + 48 | 0; //@line 15364
   $26 = $scsi + 52 | 0; //@line 15367
   $27 = HEAP32[$26 >> 2] | 0; //@line 15368
   do {
    if ((HEAP32[$23 >> 2] | 0) >>> 0 < $22 >>> 0) {
     $29 = _realloc($27, $22) | 0; //@line 15372
     if (($29 | 0) != 0) {
      HEAP32[$26 >> 2] = $29; //@line 15376
      HEAP32[$23 >> 2] = $22; //@line 15377
      $39 = $29; //@line 15379
      break;
     }
     _mac_log_deb(31472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $cnt, tempInt) | 0); //@line 15382
     HEAP32[$scsi >> 2] = 7; //@line 15384
     $34 = $scsi + 9 | 0; //@line 15385
     HEAP8[$34] = HEAP8[$34] & -125 | 108; //@line 15389
     HEAP8[$scsi + 5 | 0] = 2; //@line 15391
     STACKTOP = sp; //@line 15393
     return;
    } else {
     $39 = $27; //@line 15396
    }
   } while (0);
   if ((_dsk_read_lba($13, $39, $lba, $cnt) | 0) == 0) {
    HEAP32[$scsi + 40 >> 2] = 0; //@line 15406
    HEAP32[$scsi + 44 >> 2] = $22; //@line 15408
    HEAP32[$scsi >> 2] = 5; //@line 15410
    $54 = $scsi + 9 | 0; //@line 15411
    HEAP8[$54] = HEAP8[$54] & -125 | 100; //@line 15415
    HEAP8[$scsi + 5 | 0] = HEAP8[HEAP32[$scsi + 52 >> 2] | 0] | 0; //@line 15419
    STACKTOP = sp; //@line 15421
    return;
   } else {
    _mac_log_deb(30512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $lba, HEAP32[tempInt + 8 >> 2] = $cnt, tempInt) | 0); //@line 15424
    HEAP32[$scsi >> 2] = 7; //@line 15426
    $44 = $scsi + 9 | 0; //@line 15427
    HEAP8[$44] = HEAP8[$44] & -125 | 108; //@line 15431
    HEAP8[$scsi + 5 | 0] = 2; //@line 15433
    STACKTOP = sp; //@line 15435
    return;
   }
  }
 } while (0);
 HEAP32[$scsi >> 2] = 7; //@line 15441
 $16 = $scsi + 9 | 0; //@line 15442
 HEAP8[$16] = HEAP8[$16] & -125 | 108; //@line 15446
 HEAP8[$scsi + 5 | 0] = 2; //@line 15448
 STACKTOP = sp; //@line 15450
 return;
}
function _mac_scsi_cmd_write6_finish($scsi) {
 $scsi = $scsi | 0;
 var $16 = 0;
 $16 = HEAP8[$scsi + 28 | 0] | 0; //@line 15477
 _mac_scsi_cmd_write_finish($scsi, ((HEAPU8[$scsi + 25 | 0] | 0) << 8 & 7936 | (HEAPU8[$scsi + 26 | 0] | 0)) << 8 | (HEAPU8[$scsi + 27 | 0] | 0), $16 << 24 >> 24 == 0 ? 256 : $16 & 255); //@line 15481
 return;
}
function _mac_ser_init($ser) {
 $ser = $ser | 0;
 HEAP32[$ser + 300 >> 2] = 0; //@line 15493
 HEAP32[$ser + 304 >> 2] = 0; //@line 15495
 HEAP32[$ser + 564 >> 2] = 0; //@line 15497
 _memset($ser | 0, 0, 44); //@line 15499
 return;
}
function _mac_ser_set_driver($ser, $name) {
 $ser = $ser | 0;
 $name = $name | 0;
 var $1 = 0, $2 = 0, $6 = 0;
 $1 = $ser + 564 | 0; //@line 15511
 $2 = HEAP32[$1 >> 2] | 0; //@line 15512
 if (($2 | 0) != 0) {
  _chr_close($2); //@line 15516
 }
 $6 = _chr_open($name) | 0; //@line 15519
 HEAP32[$1 >> 2] = $6; //@line 15520
 return ($6 | 0) == 0 | 0; //@line 15524
}
function _mac_ser_set_file($ser, $fname) {
 $ser = $ser | 0;
 $fname = $fname | 0;
 var $1 = 0, $2 = 0, $3 = 0, $6 = 0;
 $1 = _str_cat_alloc(44248, $fname) | 0; //@line 15534
 $2 = $ser + 564 | 0; //@line 15535
 $3 = HEAP32[$2 >> 2] | 0; //@line 15536
 if (($3 | 0) != 0) {
  _chr_close($3); //@line 15540
 }
 $6 = _chr_open($1) | 0; //@line 15543
 HEAP32[$2 >> 2] = $6; //@line 15544
 _free($1); //@line 15547
 return ($6 | 0) == 0 | 0; //@line 15549
}
function _mac_ser_set_scc($ser, $scc, $chn) {
 $ser = $ser | 0;
 $scc = $scc | 0;
 $chn = $chn | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $ser | 0; //@line 15560
 HEAP32[$1 >> 2] = $scc; //@line 15561
 $2 = $ser + 4 | 0; //@line 15562
 HEAP32[$2 >> 2] = $chn; //@line 15563
 $3 = $ser; //@line 15564
 _e8530_set_inp_fct($scc, $chn, $3, 274); //@line 15565
 _e8530_set_out_fct($scc, $chn, $3, 256); //@line 15566
 _e8530_set_rts_fct($scc, $chn, $3, 310); //@line 15567
 _e8530_set_comm_fct($scc, $chn, $3, 2); //@line 15568
 _e8530_set_cts(HEAP32[$1 >> 2] | 0, HEAP32[$2 >> 2] | 0, 1); //@line 15571
 return;
}
function _mac_ser_set_inp($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 _mac_ser_process_input($ext); //@line 15584
 return;
}
function _mac_ser_set_out($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 _mac_ser_process_output($ext); //@line 15597
 return;
}
function _mac_ser_set_rts($ext, $val) {
 $ext = $ext | 0;
 $val = $val | 0;
 var $2 = 0, $4 = 0;
 $2 = $ext + 32 | 0; //@line 15611
 $4 = $val & 255; //@line 15613
 if ((HEAP32[$2 >> 2] | 0) == ($4 | 0)) {
  return;
 }
 HEAP32[$2 >> 2] = $val << 24 >> 24 != 0; //@line 15622
 _chr_set_ctl(HEAP32[$ext + 564 >> 2] | 0, $4) | 0; //@line 15626
 return;
}
function _mac_ser_set_comm($ext, $bps, $parity, $bpc, $stop) {
 $ext = $ext | 0;
 $bps = $bps | 0;
 $parity = $parity | 0;
 $bpc = $bpc | 0;
 $stop = $stop | 0;
 var $1 = 0;
 $1 = $stop >>> 1; //@line 15643
 HEAP32[$ext + 12 >> 2] = $bps; //@line 15646
 HEAP32[$ext + 16 >> 2] = $parity; //@line 15649
 HEAP32[$ext + 20 >> 2] = $bpc; //@line 15652
 HEAP32[$ext + 24 >> 2] = $1; //@line 15655
 _chr_set_params(HEAP32[$ext + 564 >> 2] | 0, $bps, $bpc, $parity, $1) | 0; //@line 15659
 return;
}
function _mac_ser_clock($ser, $n) {
 $ser = $ser | 0;
 $n = $n | 0;
 var $ser_idx = 0, $2 = 0, $4 = 0;
 _mac_ser_process_output($ser); //@line 15672
 _mac_ser_process_input($ser); //@line 15673
 $ser_idx = $ser | 0; //@line 15674
 _e8530_set_cts(HEAP32[$ser_idx >> 2] | 0, HEAP32[$ser + 4 >> 2] | 0, 1); //@line 15678
 $2 = $ser + 8 | 0; //@line 15680
 $4 = (HEAP32[$2 >> 2] | 0) + ($n * 15 | 0) | 0; //@line 15682
 HEAP32[$2 >> 2] = $4; //@line 15683
 _e8530_clock(HEAP32[$ser_idx >> 2] | 0, $4 >>> 5); //@line 15686
 HEAP32[$2 >> 2] = HEAP32[$2 >> 2] & 31; //@line 15689
 return;
}
function _mac_sony_set_mem($sony, $mem) {
 $sony = $sony | 0;
 $mem = $mem | 0;
 HEAP32[$sony + 4 >> 2] = $mem; //@line 15702
 return;
}
function _mac_sony_set_disks($sony, $dsks) {
 $sony = $sony | 0;
 $dsks = $dsks | 0;
 HEAP32[$sony + 8 >> 2] = $dsks; //@line 15715
 return;
}
function _mac_sony_set_delay($sony, $drive, $delay) {
 $sony = $sony | 0;
 $drive = $drive | 0;
 $delay = $delay | 0;
 if ($drive >>> 0 >= 4) {
  return;
 }
 HEAP32[$sony + 12 + ($drive << 2) >> 2] = $delay; //@line 15735
 HEAP32[$sony + 28 + ($drive << 2) >> 2] = $delay; //@line 15737
 return;
}
function _mac_ser_process_output($ser) {
 $ser = $ser | 0;
 var $1 = 0, $2 = 0, $7 = 0, $10 = 0, $13 = 0, $18 = 0, $20 = 0, $24 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $37 = 0, $44 = 0, $50 = 0, $51 = 0, $62 = 0, $65 = 0;
 $1 = $ser + 304 | 0; //@line 15756
 $2 = HEAP32[$1 >> 2] | 0; //@line 15757
 do {
  if (($2 | 0) != 0) {
   $7 = $ser + 300 | 0; //@line 15764
   $10 = _chr_write(HEAP32[$ser + 564 >> 2] | 0, (HEAP32[$7 >> 2] | 0) + ($ser + 308) | 0, $2) | 0; //@line 15767
   HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + $10; //@line 15770
   $13 = HEAP32[$1 >> 2] | 0; //@line 15771
   HEAP32[$1 >> 2] = $13 - $10; //@line 15773
   if (($13 | 0) == ($10 | 0)) {
    HEAP32[$7 >> 2] = 0; //@line 15777
   }
   if (($13 | 0) == ($10 | 0)) {
    break;
   }
   return;
  }
 } while (0);
 $18 = $ser | 0; //@line 15789
 $20 = $ser + 4 | 0; //@line 15791
 L2491 : do {
  if ((_e8530_out_empty(HEAP32[$18 >> 2] | 0, HEAP32[$20 >> 2] | 0) | 0) == 0) {
   $24 = $ser + 300 | 0; //@line 15798
   $25 = $ser + 564 | 0; //@line 15799
   while (1) {
    $44 = _e8530_send(HEAP32[$18 >> 2] | 0, HEAP32[$20 >> 2] | 0) | 0; //@line 15804
    HEAP8[(HEAP32[$1 >> 2] | 0) + (HEAP32[$24 >> 2] | 0) + ($ser + 308) | 0] = $44; //@line 15809
    $50 = (HEAP32[$1 >> 2] | 0) + 1 | 0; //@line 15811
    HEAP32[$1 >> 2] = $50; //@line 15812
    $51 = HEAP32[$24 >> 2] | 0; //@line 15813
    if (!(($51 + $50 | 0) >>> 0 < 256 | ($50 | 0) == 0)) {
     $62 = _chr_write(HEAP32[$25 >> 2] | 0, $ser + 308 + $51 | 0, $50) | 0; //@line 15822
     HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + $62; //@line 15825
     $65 = HEAP32[$1 >> 2] | 0; //@line 15826
     HEAP32[$1 >> 2] = $65 - $62; //@line 15828
     if (($65 | 0) == ($62 | 0)) {
      HEAP32[$24 >> 2] = 0; //@line 15832
     }
     if (($65 | 0) != ($62 | 0)) {
      break;
     }
    }
    if ((_e8530_out_empty(HEAP32[$18 >> 2] | 0, HEAP32[$20 >> 2] | 0) | 0) != 0) {
     break L2491;
    }
   }
   return;
  }
 } while (0);
 $26 = HEAP32[$1 >> 2] | 0; //@line 15854
 if (($26 | 0) == 0) {
  return;
 }
 $31 = $ser + 300 | 0; //@line 15863
 $34 = _chr_write(HEAP32[$ser + 564 >> 2] | 0, (HEAP32[$31 >> 2] | 0) + ($ser + 308) | 0, $26) | 0; //@line 15866
 HEAP32[$31 >> 2] = (HEAP32[$31 >> 2] | 0) + $34; //@line 15869
 $37 = HEAP32[$1 >> 2] | 0; //@line 15870
 HEAP32[$1 >> 2] = $37 - $34; //@line 15872
 if (($37 | 0) != ($34 | 0)) {
  return;
 }
 HEAP32[$31 >> 2] = 0; //@line 15879
 return;
}
function _mac_ser_process_input($ser) {
 $ser = $ser | 0;
 var $1 = 0, $2 = 0, $4 = 0, $8 = 0, $9 = 0, $16 = 0, $18 = 0, label = 0;
 $1 = $ser + 36 | 0; //@line 15894
 $2 = $ser | 0; //@line 15895
 $4 = $ser + 4 | 0; //@line 15897
 if ((_e8530_inp_full(HEAP32[$2 >> 2] | 0, HEAP32[$4 >> 2] | 0) | 0) != 0) {
  return;
 }
 $8 = $ser + 40 | 0; //@line 15906
 $9 = $ser + 564 | 0; //@line 15907
 while (1) {
  if ((HEAP32[$8 >> 2] | 0) == 0) {
   HEAP32[$1 >> 2] = 0; //@line 15914
   $16 = _chr_read(HEAP32[$9 >> 2] | 0, $ser + 44 | 0, 256) | 0; //@line 15917
   $18 = (HEAP32[$8 >> 2] | 0) + $16 | 0; //@line 15919
   HEAP32[$8 >> 2] = $18; //@line 15920
   if (($18 | 0) == 0) {
    label = 2016; //@line 15924
    break;
   }
  }
  _e8530_receive(HEAP32[$2 >> 2] | 0, HEAP32[$4 >> 2] | 0, HEAP8[(HEAP32[$1 >> 2] | 0) + ($ser + 44) | 0] | 0); //@line 15933
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 1; //@line 15936
  HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) - 1; //@line 15939
  if ((_e8530_inp_full(HEAP32[$2 >> 2] | 0, HEAP32[$4 >> 2] | 0) | 0) != 0) {
   label = 2017; //@line 15946
   break;
  }
 }
 if ((label | 0) == 2017) {
  return;
 } else if ((label | 0) == 2016) {
  return;
 }
}
function _mac_sony_init($sony, $enable) {
 $sony = $sony | 0;
 $enable = $enable | 0;
 HEAP8[$sony | 0] = 0; //@line 15968
 HEAP8[$sony + 1 | 0] = 0; //@line 15970
 HEAP8[$sony + 2 | 0] = ($enable | 0) != 0 | 0; //@line 15974
 HEAP32[$sony + 64 >> 2] = 0; //@line 15977
 _memset($sony + 4 | 0, 0, 57); //@line 15979
 return;
}
function _mac_sony_patch($sony) {
 $sony = $sony | 0;
 var $5 = 0, $9 = 0, $10 = 0, $11 = 0, $33 = 0, $_0112_i = 0, $_0121_i = 0, $38 = 0, $39 = 0, $50 = 0, $57 = 0, $65 = 0, $buf_031_i = 0, $i_030_i = 0, $68 = 0, $71 = 0, $73 = 0, $77 = 0, $78 = 0, $83 = 0, $87 = 0, $91 = 0, $95 = 0, $99 = 0, $103 = 0, $116 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 16002
 if ((HEAP8[$sony + 2 | 0] | 0) == 0) {
  STACKTOP = sp; //@line 16008
  return;
 }
 $5 = $sony + 1 | 0; //@line 16011
 if ((HEAP8[$5] | 0) != 0) {
  STACKTOP = sp; //@line 16016
  return;
 }
 HEAP8[$5] = 1; //@line 16019
 $9 = $sony + 132 | 0; //@line 16020
 HEAP32[$9 >> 2] = 0; //@line 16021
 $10 = $sony + 136 | 0; //@line 16022
 HEAP32[$10 >> 2] = 0; //@line 16023
 $11 = $sony + 4 | 0; //@line 16024
 do {
  if ((_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, 16252928) | 0) == 1346585944) {
   if ((_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, 16252936) | 0) >>> 0 < 4) {
    label = 2023; //@line 16036
    break;
   }
   HEAP32[$sony + 44 >> 2] = (_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, 16252944) | 0) + 16252928; //@line 16043
   HEAP32[$sony + 48 >> 2] = (_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, 16252948) | 0) + 16252928; //@line 16048
   HEAP32[$sony + 52 >> 2] = (_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, 16252952) | 0) + 16252928; //@line 16053
   $33 = (_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, 16252940) | 0) + 16252928 | 0; //@line 16056
   HEAP32[$9 >> 2] = $33; //@line 16057
   if (($33 | 0) == 0) {
    break;
   }
   _pce_log_tag(2, 43912, 48784, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $33, tempInt) | 0); //@line 16063
   $_0121_i = 4194304;
   $_0112_i = 1048576;
   L2534 : while (1) {
    $38 = $_0121_i + 1 | 0; //@line 16069
    $39 = $_0112_i - 1 | 0; //@line 16070
    do {
     if ((_mem_get_uint16_be(HEAP32[$11 >> 2] | 0, $_0121_i) | 0) << 16 >> 16 == 1326) {
      if ((_mem_get_uint32_be(HEAP32[$11 >> 2] | 0, $_0121_i + 2 | 0) | 0) != 1399811705) {
       break;
      }
      $50 = $_0121_i - 18 | 0; //@line 16085
      if ((_mem_get_uint16_be(HEAP32[$11 >> 2] | 0, $50) | 0) << 16 >> 16 == 20224) {
       label = 2032; //@line 16091
       break L2534;
      }
     }
    } while (0);
    if (($39 | 0) == 0) {
     label = 2029; //@line 16099
     break;
    } else {
     $_0121_i = $38;
     $_0112_i = $39;
    }
   }
   do {
    if ((label | 0) == 2032) {
     HEAP32[$10 >> 2] = $50; //@line 16107
     if (($50 | 0) == 0) {
      break;
     }
     _pce_log_tag(2, 43912, 41680, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $50, tempInt) | 0); //@line 16113
     $57 = HEAP32[$10 >> 2] | 0; //@line 16114
     if (($57 | 0) == 0) {
      STACKTOP = sp; //@line 16118
      return;
     }
     if ((HEAP32[$9 >> 2] | 0) == 0) {
      STACKTOP = sp; //@line 16125
      return;
     }
     $i_030_i = 0;
     $buf_031_i = $sony + 140 | 0;
     $65 = $57;
     while (1) {
      $68 = ($i_030_i << 1) + 8 | 0; //@line 16137
      $71 = (_mem_get_uint16_be(HEAP32[$11 >> 2] | 0, $68 + $65 | 0) | 0) & 65535; //@line 16140
      $73 = (HEAP32[$10 >> 2] | 0) + $71 | 0; //@line 16142
      $77 = _mem_get_uint16_be(HEAP32[$11 >> 2] | 0, (HEAP32[$9 >> 2] | 0) + $68 | 0) | 0; //@line 16146
      $78 = HEAP32[$9 >> 2] | 0; //@line 16147
      HEAP8[$buf_031_i] = _mem_get_uint8(HEAP32[$11 >> 2] | 0, $73) | 0; //@line 16151
      $83 = $73 + 1 | 0; //@line 16153
      HEAP8[$buf_031_i + 1 | 0] = _mem_get_uint8(HEAP32[$11 >> 2] | 0, $83) | 0; //@line 16156
      $87 = $73 + 2 | 0; //@line 16158
      HEAP8[$buf_031_i + 2 | 0] = _mem_get_uint8(HEAP32[$11 >> 2] | 0, $87) | 0; //@line 16161
      $91 = $73 + 3 | 0; //@line 16163
      HEAP8[$buf_031_i + 3 | 0] = _mem_get_uint8(HEAP32[$11 >> 2] | 0, $91) | 0; //@line 16166
      $95 = $73 + 4 | 0; //@line 16168
      HEAP8[$buf_031_i + 4 | 0] = _mem_get_uint8(HEAP32[$11 >> 2] | 0, $95) | 0; //@line 16171
      $99 = $73 + 5 | 0; //@line 16173
      HEAP8[$buf_031_i + 5 | 0] = _mem_get_uint8(HEAP32[$11 >> 2] | 0, $99) | 0; //@line 16175
      $103 = $78 + ($77 & 65535) | 0; //@line 16178
      _mem_set_uint8_rw(HEAP32[$11 >> 2] | 0, $73, 78); //@line 16179
      _mem_set_uint8_rw(HEAP32[$11 >> 2] | 0, $83, -7); //@line 16181
      _mem_set_uint8_rw(HEAP32[$11 >> 2] | 0, $87, $103 >>> 24 & 255); //@line 16185
      _mem_set_uint8_rw(HEAP32[$11 >> 2] | 0, $91, $103 >>> 16 & 255); //@line 16189
      _mem_set_uint8_rw(HEAP32[$11 >> 2] | 0, $95, $103 >>> 8 & 255); //@line 16193
      _mem_set_uint8_rw(HEAP32[$11 >> 2] | 0, $99, $103 & 255); //@line 16196
      $116 = $i_030_i + 1 | 0; //@line 16197
      if ($116 >>> 0 >= 5) {
       break;
      }
      $i_030_i = $116;
      $buf_031_i = $buf_031_i + 6 | 0;
      $65 = HEAP32[$10 >> 2] | 0;
     }
     STACKTOP = sp; //@line 16208
     return;
    } else if ((label | 0) == 2029) {
     HEAP32[$10 >> 2] = 0; //@line 16212
    }
   } while (0);
   _pce_log_tag(0, 43912, 45176, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 16216
   STACKTOP = sp; //@line 16218
   return;
  } else {
   label = 2023; //@line 16221
  }
 } while (0);
 if ((label | 0) == 2023) {
  HEAP32[$9 >> 2] = 0; //@line 16225
 }
 _pce_log_tag(0, 43912, 54792, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 16228
 STACKTOP = sp; //@line 16230
 return;
}
function _mac_sony_insert($sony, $drive) {
 $sony = $sony | 0;
 $drive = $drive | 0;
 var $10 = 0, $sony_idx = 0, $13 = 0, $ret_0_i = 0, $20 = 0, $26 = 0, $27 = 0, $28 = 0, $35 = 0, $36 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 16244
 if ((HEAP8[$sony | 0] | 0) == 0) {
  STACKTOP = sp; //@line 16250
  return;
 }
 if (($drive | 0) == 0 | $drive >>> 0 > 4) {
  STACKTOP = sp; //@line 16258
  return;
 }
 $10 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $drive) | 0; //@line 16263
 if (($10 | 0) == 0) {
  STACKTOP = sp; //@line 16267
  return;
 }
 $sony_idx = $sony + 4 | 0; //@line 16270
 $13 = _mem_get_uint32_be(HEAP32[$sony_idx >> 2] | 0, 308) | 0; //@line 16272
 if ($drive >>> 0 < 5) {
  $ret_0_i = ($drive * 66 | 0) + 8 + $13 | 0; //@line 16280
 } else {
  $ret_0_i = $13; //@line 16282
 }
 $20 = $ret_0_i + 3 | 0; //@line 16286
 if ((_mem_get_uint8(HEAP32[$sony_idx >> 2] | 0, $20) | 0) << 24 >> 24 != 0) {
  STACKTOP = sp; //@line 16291
  return;
 }
 _pce_log_tag(2, 43912, 38688, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $drive, tempInt) | 0); //@line 16294
 _mem_set_uint8(HEAP32[$sony_idx >> 2] | 0, $20, 1); //@line 16296
 $26 = (_dsk_get_block_cnt($10) | 0) >>> 0 < 1600; //@line 16298
 $27 = HEAP32[$sony_idx >> 2] | 0; //@line 16299
 $28 = $ret_0_i + 18 | 0; //@line 16300
 if ($26) {
  _mem_set_uint8($27, $28, 0); //@line 16303
 } else {
  _mem_set_uint8($27, $28, -1); //@line 16306
 }
 _mem_set_uint8(HEAP32[$sony_idx >> 2] | 0, $ret_0_i + 19 | 0, -1); //@line 16310
 $35 = (_dsk_get_readonly($10) | 0) == 0; //@line 16312
 $36 = HEAP32[$sony_idx >> 2] | 0; //@line 16313
 $37 = $ret_0_i + 2 | 0; //@line 16314
 if ($35) {
  _mem_set_uint8($36, $37, 0); //@line 16317
  STACKTOP = sp; //@line 16318
  return;
 } else {
  _mem_set_uint8($36, $37, -1); //@line 16321
  STACKTOP = sp; //@line 16323
  return;
 }
}
function _mac_sony_check($sony) {
 $sony = $sony | 0;
 var $4 = 0, $sony_idx = 0, $i_0_ph = 0, $check_0_ph = 0, $i_0 = 0, $8 = 0, $9 = 0, $12 = 0, $22 = 0, $ret_0_i = 0, $_0 = 0;
 if ((HEAP8[$sony | 0] | 0) == 0) {
  $_0 = 0; //@line 16343
  return $_0 | 0; //@line 16346
 }
 $4 = $sony + 8 | 0; //@line 16348
 $sony_idx = $sony + 4 | 0; //@line 16349
 $check_0_ph = 0;
 $i_0_ph = 0;
 L2589 : while (1) {
  $i_0 = $i_0_ph; //@line 16355
  do {
   if ($i_0 >>> 0 >= 4) {
    $_0 = $check_0_ph; //@line 16361
    break L2589;
   }
   $8 = $sony + 28 + ($i_0 << 2) | 0; //@line 16364
   $9 = HEAP32[$8 >> 2] | 0; //@line 16365
   do {
    if (($9 | 0) != 0) {
     $12 = $9 - 1 | 0; //@line 16370
     HEAP32[$8 >> 2] = $12; //@line 16371
     if (($12 | 0) != 0) {
      break;
     }
     _mac_sony_insert($sony, $i_0 + 1 | 0); //@line 16378
    }
   } while (0);
   $i_0 = $i_0 + 1 | 0; //@line 16383
  } while ((_dsks_get_disk(HEAP32[$4 >> 2] | 0, $i_0) | 0) == 0);
  $22 = _mem_get_uint32_be(HEAP32[$sony_idx >> 2] | 0, 308) | 0; //@line 16394
  if (($i_0 | 0) != 0 & $i_0 >>> 0 < 5) {
   $ret_0_i = ($i_0 * 66 | 0) + 8 + $22 | 0; //@line 16404
  } else {
   $ret_0_i = $22; //@line 16406
  }
  $check_0_ph = (_mem_get_uint8(HEAP32[$sony_idx >> 2] | 0, $ret_0_i + 3 | 0) | 0) << 24 >> 24 == 1 ? 1 : $check_0_ph;
  $i_0_ph = $i_0;
 }
 return $_0 | 0; //@line 16419
}
function _mac_sony_hook($sony, $val) {
 $sony = $sony | 0;
 $val = $val | 0;
 var $c_i_i_i = 0, $h_i_i_i = 0, $s_i_i_i = 0, $cnt_i_i_i = 0, $buf_i_i = 0, $tag_i_i = 0, $10 = 0, $12 = 0, $16 = 0, $20 = 0, $21 = 0, $29 = 0, $37 = 0, $45 = 0, $46 = 0, $ret_0_i_i = 0, $52 = 0, $60 = 0, $68 = 0, $77 = 0, $79 = 0, $80 = 0, $86 = 0, $99 = 0, $_0_i_i_i = 0, $106 = 0, $111 = 0, $115 = 0, $118 = 0, $125 = 0, $133 = 0, $148 = 0, $156 = 0, $174 = 0, $182 = 0, $190 = 0, $192 = 0, $197 = 0, $198 = 0, $199 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $i_074_i_i = 0, $211 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $231 = 0, $236 = 0, $244 = 0, $j_064_i_i = 0, $281 = 0, $283 = 0, $333 = 0, $ret_0_i_i_i = 0, $sony_idx43_i_i = 0, $345 = 0, $351 = 0, $359 = 0, $366 = 0, $367 = 0, $373 = 0, $386 = 0, $_0_i_i24_i = 0, $393 = 0, $398 = 0, $401 = 0, $408 = 0, $416 = 0, $431 = 0, $439 = 0, $457 = 0, $465 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $i_0_i_i = 0, $493 = 0, $j_062_i_i = 0, $502 = 0, $504 = 0, $506 = 0, $j_164_i_i = 0, $510 = 0, $514 = 0, $552 = 0, $560 = 0, $sony_idx45_i_i = 0, $573 = 0, $579 = 0, $587 = 0, $598 = 0, $606 = 0, $614 = 0, $616 = 0, $620 = 0, $634 = 0, $642 = 0, $650 = 0, $663 = 0, $668 = 0, $676 = 0, $687 = 0, $695 = 0, $706 = 0, $707 = 0, $715 = 0, $723 = 0, $731 = 0, $ret_0_i_i_i9 = 0, $747 = 0, $755 = 0, $773 = 0, $781 = 0, $793 = 0, $801 = 0, $812 = 0, $813 = 0, $817 = 0, $818 = 0, $826 = 0, $834 = 0, $844 = 0, $851 = 0, $859 = 0, $875 = 0, $883 = 0, $902 = 0, $blk_0_i_i = 0, $915 = 0, $923 = 0, $931 = 0, $ret_0_i_i16_i = 0, $948 = 0, $956 = 0, $969 = 0, $977 = 0, $985 = 0, $994 = 0, $1009 = 0, $1017 = 0, $1025 = 0, $1026 = 0, $1030 = 0, $1034 = 0, $1035 = 0, $1039 = 0, $1043 = 0, $1051 = 0, $1059 = 0, $1070 = 0, $1077 = 0, $1085 = 0, $1101 = 0, $1109 = 0, $1126 = 0, $_0_i_i_i12 = 0, $1141 = 0, $1149 = 0, $1161 = 0, $1169 = 0, $1177 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $1190 = 0, $1191 = 0, $data_060_us_i_i = 0, $idx_059_us_i_i = 0, $tags_057_us_i_i = 0, $1233 = 0, $i_054_us_i_i = 0, $data_060_i_i = 0, $idx_059_i_i = 0, $i_054_i_i = 0, $1256 = 0, $1264 = 0, $1273 = 0, $1279 = 0, $1287 = 0, $1299 = 0, $1307 = 0, $1315 = 0, $1317 = 0, $1321 = 0, $1326 = 0, $1331 = 0, $1335 = 0, $1343 = 0, $1351 = 0, $1362 = 0, $1369 = 0, $1377 = 0, $1385 = 0, $1386 = 0, $1389 = 0, $1391 = 0, $1393 = 0, $1395 = 0, $1397 = 0, $1411 = 0, $__i_i17 = 0, $1414 = 0, $1415 = 0, $i_052_i_i = 0, $1417 = 0, $1418 = 0, $1426 = 0, $1428 = 0, $_lcssa_i_i = 0, $1436 = 0, $1444 = 0, $1455 = 0, $1456 = 0, $1464 = 0, $1472 = 0, $1489 = 0, $1497 = 0, $1505 = 0, $ret_0_i_i_i21 = 0, $i_014_i_i = 0, $1513 = 0, $1515 = 0, $1527 = 0, $1535 = 0, $1547 = 0, $1555 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 16613
 STACKTOP = STACKTOP + 560 | 0; //@line 16613
 $c_i_i_i = sp | 0; //@line 16614
 $h_i_i_i = sp + 8 | 0; //@line 16615
 $s_i_i_i = sp + 16 | 0; //@line 16616
 $cnt_i_i_i = sp + 24 | 0; //@line 16617
 $buf_i_i = sp + 32 | 0; //@line 16618
 $tag_i_i = sp + 544 | 0; //@line 16619
 if (($val | 0) == 17) {
  $10 = $sony + 4 | 0; //@line 16621
  $12 = $sony + 208 | 0; //@line 16623
  $16 = (_mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0) & 65535; //@line 16627
  $20 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 22 | 0) | 0; //@line 16631
  $21 = $20 & 65535; //@line 16632
  if ($20 << 16 >> 16 == 0 | ($20 & 65535) > 4) {
   HEAP32[$sony + 204 >> 2] = -56; //@line 16639
   $29 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 16643
   _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -56); //@line 16647
   if (($29 & 512) != 0) {
    $_0 = 0; //@line 16652
    STACKTOP = sp; //@line 16654
    return $_0 | 0; //@line 16655
   }
   $37 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 16658
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $37) | 0; //@line 16662
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 16666
   $_0 = 0; //@line 16668
   STACKTOP = sp; //@line 16670
   return $_0 | 0; //@line 16671
  }
  $45 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 16674
  $46 = ($20 & 65535) < 5; //@line 16675
  if ($46) {
   $ret_0_i_i = ($21 * 66 | 0) + 8 + $45 | 0; //@line 16682
  } else {
   $ret_0_i_i = $45; //@line 16684
  }
  $52 = $ret_0_i_i + 3 | 0; //@line 16688
  if ((_mem_get_uint8(HEAP32[$10 >> 2] | 0, $52) | 0) << 24 >> 24 == 0) {
   HEAP32[$sony + 204 >> 2] = -65; //@line 16694
   $60 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 16698
   _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -65); //@line 16702
   if (($60 & 512) != 0) {
    $_0 = 0; //@line 16707
    STACKTOP = sp; //@line 16709
    return $_0 | 0; //@line 16710
   }
   $68 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 16713
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $68) | 0; //@line 16717
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 16721
   $_0 = 0; //@line 16723
   STACKTOP = sp; //@line 16725
   return $_0 | 0; //@line 16726
  }
  _mem_set_uint8(HEAP32[$10 >> 2] | 0, $52, 2); //@line 16729
  $77 = $16 & 255; //@line 16730
  if (($77 | 0) == 2) {
   $79 = $buf_i_i | 0; //@line 16732
   $80 = $tag_i_i | 0; //@line 16733
   $86 = (_mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 44 | 0) | 0) & 15; //@line 16739
   if (($86 | 0) == 1) {
    $_0_i_i_i = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 46 | 0) | 0; //@line 16746
   } else if (($86 | 0) == 3) {
    $99 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 46 | 0) | 0; //@line 16751
    $_0_i_i_i = (_mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony + 212 >> 2] | 0) + 16 | 0) | 0) + $99 | 0; //@line 16759
   } else if (($86 | 0) == 0) {
    $_0_i_i_i = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony + 212 >> 2] | 0) + 16 | 0) | 0; //@line 16767
   } else {
    $_0_i_i_i = 0; //@line 16769
   }
   $106 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 36 | 0) | 0; //@line 16775
   $111 = (_mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 32 | 0) | 0) & 16777215; //@line 16780
   $115 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 44 | 0) | 0; //@line 16784
   $118 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $21) | 0; //@line 16787
   if (($118 | 0) == 0) {
    HEAP32[$sony + 204 >> 2] = -65; //@line 16792
    $125 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 16796
    _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -65); //@line 16800
    if (($125 & 512) != 0) {
     $_0 = 0; //@line 16805
     STACKTOP = sp; //@line 16807
     return $_0 | 0; //@line 16808
    }
    $133 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 16811
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $133) | 0; //@line 16815
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 16819
    $_0 = 0; //@line 16821
    STACKTOP = sp; //@line 16823
    return $_0 | 0; //@line 16824
   }
   if (($115 & 64) != 0) {
    HEAP32[$sony + 204 >> 2] = 0; //@line 16831
    $148 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 16835
    _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, 0); //@line 16839
    if (($148 & 512) != 0) {
     $_0 = 0; //@line 16844
     STACKTOP = sp; //@line 16846
     return $_0 | 0; //@line 16847
    }
    $156 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 16850
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $156) | 0; //@line 16854
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 16858
    $_0 = 0; //@line 16860
    STACKTOP = sp; //@line 16862
    return $_0 | 0; //@line 16863
   }
   do {
    if (($_0_i_i_i & 511 | 0) == 0) {
     if (($106 & 511 | 0) != 0) {
      break;
     }
     $190 = $106 >>> 9; //@line 16876
     L2647 : do {
      if (($190 | 0) != 0) {
       $192 = $_0_i_i_i >>> 9; //@line 16881
       $197 = $118 + 64 | 0; //@line 16886
       $198 = $sony + 56 | 0; //@line 16887
       $199 = $tag_i_i + 1 | 0; //@line 16888
       $200 = $tag_i_i + 2 | 0; //@line 16889
       $201 = $tag_i_i + 3 | 0; //@line 16890
       $202 = $tag_i_i + 4 | 0; //@line 16891
       $203 = $tag_i_i + 5 | 0; //@line 16892
       $204 = $tag_i_i + 6 | 0; //@line 16893
       $205 = $tag_i_i + 7 | 0; //@line 16894
       $206 = $tag_i_i + 8 | 0; //@line 16895
       $207 = $tag_i_i + 9 | 0; //@line 16896
       $208 = $tag_i_i + 10 | 0; //@line 16897
       $209 = $tag_i_i + 11 | 0; //@line 16898
       $i_074_i_i = 0; //@line 16900
       while (1) {
        $211 = $i_074_i_i + $192 | 0; //@line 16903
        if ((_dsk_get_type($118) | 0) == 6) {
         if ((_mac_sony_get_chs(_dsk_get_block_cnt($118) | 0, $211, $c_i_i_i, $h_i_i_i, $s_i_i_i) | 0) != 0) {
          break;
         }
         $221 = HEAP32[$197 >> 2] | 0; //@line 16916
         $222 = HEAP32[$c_i_i_i >> 2] | 0; //@line 16917
         $223 = HEAP32[$h_i_i_i >> 2] | 0; //@line 16918
         $224 = HEAP32[$s_i_i_i >> 2] | 0; //@line 16919
         _dsk_psi_read_tags($221, $80, 12, $222, $223, $224, 0) | 0; //@line 16920
         HEAP32[$cnt_i_i_i >> 2] = 512; //@line 16921
         if ((_dsk_psi_read_chs(HEAP32[$197 >> 2] | 0, $79, $cnt_i_i_i, $222, $223, $224, 0) | 0) != 0) {
          label = 2113; //@line 16928
          break;
         }
        } else {
         _memset($80 | 0, 0, 12); //@line 16932
         if ((_dsk_read_lba($118, $79, $211, 1) | 0) != 0) {
          break;
         }
        }
        $231 = ($i_074_i_i << 9) + $111 | 0; //@line 16941
        $j_064_i_i = 0; //@line 16943
        do {
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $231 + $j_064_i_i | 0, HEAP8[$buf_i_i + $j_064_i_i | 0] | 0); //@line 16950
         $j_064_i_i = $j_064_i_i + 1 | 0; //@line 16951
        } while ($j_064_i_i >>> 0 < 512);
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 764, HEAP8[$80] | 0); //@line 16962
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 765, HEAP8[$199] | 0); //@line 16965
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 766, HEAP8[$200] | 0); //@line 16968
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 767, HEAP8[$201] | 0); //@line 16971
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 768, HEAP8[$202] | 0); //@line 16974
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 769, HEAP8[$203] | 0); //@line 16977
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 770, HEAP8[$204] | 0); //@line 16980
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 771, HEAP8[$205] | 0); //@line 16983
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 772, HEAP8[$206] | 0); //@line 16986
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 773, HEAP8[$207] | 0); //@line 16989
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 774, HEAP8[$208] | 0); //@line 16992
        _mem_set_uint8(HEAP32[$10 >> 2] | 0, 775, HEAP8[$209] | 0); //@line 16995
        $281 = HEAP32[$198 >> 2] | 0; //@line 16996
        if (($281 | 0) != 0) {
         $283 = $i_074_i_i * 12 | 0; //@line 17000
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $281 + $283 | 0, HEAP8[$80] | 0); //@line 17004
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, ($283 | 1) + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$199] | 0); //@line 17010
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, ($283 | 2) + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$200] | 0); //@line 17016
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, ($283 | 3) + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$201] | 0); //@line 17022
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 4 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$202] | 0); //@line 17028
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 5 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$203] | 0); //@line 17034
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 6 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$204] | 0); //@line 17040
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 7 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$205] | 0); //@line 17046
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 8 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$206] | 0); //@line 17052
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 9 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$207] | 0); //@line 17058
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 10 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$208] | 0); //@line 17064
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $283 + 11 + (HEAP32[$198 >> 2] | 0) | 0, HEAP8[$209] | 0); //@line 17070
        }
        $i_074_i_i = $i_074_i_i + 1 | 0; //@line 17072
        if ($i_074_i_i >>> 0 >= $190 >>> 0) {
         break L2647;
        }
       }
       if ((label | 0) == 2113) {
        _mac_log_deb(52944, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $222, HEAP32[tempInt + 8 >> 2] = $223, HEAP32[tempInt + 16 >> 2] = $224, tempInt) | 0); //@line 17082
       }
       _mac_log_deb(53664, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 17084
       HEAP32[$sony + 204 >> 2] = -1; //@line 17086
       $236 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17090
       _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -1); //@line 17094
       if (($236 & 512) != 0) {
        $_0 = 0; //@line 17099
        STACKTOP = sp; //@line 17101
        return $_0 | 0; //@line 17102
       }
       $244 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17105
       HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $244) | 0; //@line 17109
       HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17113
       $_0 = 0; //@line 17115
       STACKTOP = sp; //@line 17117
       return $_0 | 0; //@line 17118
      }
     } while (0);
     $333 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17122
     if ($46) {
      $ret_0_i_i_i = ($21 * 66 | 0) + 8 + $333 | 0; //@line 17129
     } else {
      $ret_0_i_i_i = $333; //@line 17131
     }
     _mem_set_uint8(HEAP32[$10 >> 2] | 0, $ret_0_i_i_i + 3 | 0, 2); //@line 17136
     _mem_set_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 40 | 0, $106); //@line 17140
     $sony_idx43_i_i = $sony + 212 | 0; //@line 17142
     $345 = (_mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony_idx43_i_i >> 2] | 0) + 16 | 0) | 0) + $106 | 0; //@line 17146
     _mem_set_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony_idx43_i_i >> 2] | 0) + 16 | 0, $345); //@line 17150
     HEAP32[$sony + 204 >> 2] = 0; //@line 17152
     $351 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17156
     _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, 0); //@line 17160
     if (($351 & 512) != 0) {
      $_0 = 0; //@line 17165
      STACKTOP = sp; //@line 17167
      return $_0 | 0; //@line 17168
     }
     $359 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17171
     HEAP32[$sony_idx43_i_i >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $359) | 0; //@line 17174
     HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17178
     $_0 = 0; //@line 17180
     STACKTOP = sp; //@line 17182
     return $_0 | 0; //@line 17183
    }
   } while (0);
   _mac_log_deb(54272, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 17186
   HEAP32[$sony + 204 >> 2] = -50; //@line 17188
   $174 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17192
   _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -50); //@line 17196
   if (($174 & 512) != 0) {
    $_0 = 0; //@line 17201
    STACKTOP = sp; //@line 17203
    return $_0 | 0; //@line 17204
   }
   $182 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17207
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $182) | 0; //@line 17211
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17215
   $_0 = 0; //@line 17217
   STACKTOP = sp; //@line 17219
   return $_0 | 0; //@line 17220
  } else if (($77 | 0) == 3) {
   $366 = $buf_i_i | 0; //@line 17222
   $367 = $tag_i_i | 0; //@line 17223
   $373 = (_mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 44 | 0) | 0) & 15; //@line 17229
   if (($373 | 0) == 0) {
    $_0_i_i24_i = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony + 212 >> 2] | 0) + 16 | 0) | 0; //@line 17237
   } else if (($373 | 0) == 1) {
    $_0_i_i24_i = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 46 | 0) | 0; //@line 17244
   } else if (($373 | 0) == 3) {
    $386 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 46 | 0) | 0; //@line 17249
    $_0_i_i24_i = (_mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony + 212 >> 2] | 0) + 16 | 0) | 0) + $386 | 0; //@line 17257
   } else {
    $_0_i_i24_i = 0; //@line 17259
   }
   $393 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 36 | 0) | 0; //@line 17265
   $398 = (_mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 32 | 0) | 0) & 16777215; //@line 17270
   $401 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $21) | 0; //@line 17273
   if (($401 | 0) == 0) {
    HEAP32[$sony + 204 >> 2] = -65; //@line 17278
    $408 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17282
    _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -65); //@line 17286
    if (($408 & 512) != 0) {
     $_0 = 0; //@line 17291
     STACKTOP = sp; //@line 17293
     return $_0 | 0; //@line 17294
    }
    $416 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17297
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $416) | 0; //@line 17301
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17305
    $_0 = 0; //@line 17307
    STACKTOP = sp; //@line 17309
    return $_0 | 0; //@line 17310
   }
   if ((_dsk_get_readonly($401) | 0) != 0) {
    HEAP32[$sony + 204 >> 2] = -44; //@line 17317
    $431 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17321
    _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -44); //@line 17325
    if (($431 & 512) != 0) {
     $_0 = 0; //@line 17330
     STACKTOP = sp; //@line 17332
     return $_0 | 0; //@line 17333
    }
    $439 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17336
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $439) | 0; //@line 17340
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17344
    $_0 = 0; //@line 17346
    STACKTOP = sp; //@line 17348
    return $_0 | 0; //@line 17349
   }
   do {
    if (($393 & 511 | 0) == 0) {
     if (($_0_i_i24_i & 511 | 0) != 0) {
      break;
     }
     _memset($367 | 0, 0, 12); //@line 17362
     $475 = (_mem_get_uint16_be(HEAP32[$10 >> 2] | 0, 770) | 0) & 65535; //@line 17365
     $476 = $393 >>> 9; //@line 17366
     $477 = $sony + 56 | 0; //@line 17367
     $478 = $_0_i_i24_i >>> 9; //@line 17368
     $479 = $tag_i_i + 1 | 0; //@line 17369
     $480 = $tag_i_i + 2 | 0; //@line 17370
     $481 = $tag_i_i + 3 | 0; //@line 17371
     $482 = $tag_i_i + 4 | 0; //@line 17372
     $483 = $tag_i_i + 5 | 0; //@line 17373
     $484 = $tag_i_i + 6 | 0; //@line 17374
     $485 = $tag_i_i + 7 | 0; //@line 17375
     $486 = $tag_i_i + 8 | 0; //@line 17376
     $487 = $tag_i_i + 9 | 0; //@line 17377
     $488 = $tag_i_i + 10 | 0; //@line 17378
     $489 = $tag_i_i + 11 | 0; //@line 17379
     $i_0_i_i = 0; //@line 17381
     while (1) {
      if ($i_0_i_i >>> 0 >= $476 >>> 0) {
       label = 2150; //@line 17387
       break;
      }
      $493 = ($i_0_i_i << 9) + $398 | 0; //@line 17391
      $j_062_i_i = 0; //@line 17393
      do {
       HEAP8[$buf_i_i + $j_062_i_i | 0] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, $493 + $j_062_i_i | 0) | 0; //@line 17400
       $j_062_i_i = $j_062_i_i + 1 | 0; //@line 17401
      } while ($j_062_i_i >>> 0 < 512);
      $502 = HEAP32[$477 >> 2] | 0; //@line 17410
      L2711 : do {
       if (($502 | 0) == 0) {
        _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, 770, $i_0_i_i + $475 & 65535); //@line 17418
        HEAP8[$367] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 764) | 0; //@line 17421
        HEAP8[$479] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 765) | 0; //@line 17424
        HEAP8[$480] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 766) | 0; //@line 17427
        HEAP8[$481] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 767) | 0; //@line 17430
        HEAP8[$482] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 768) | 0; //@line 17433
        HEAP8[$483] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 769) | 0; //@line 17436
        HEAP8[$484] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 770) | 0; //@line 17439
        HEAP8[$485] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 771) | 0; //@line 17442
        HEAP8[$486] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 772) | 0; //@line 17445
        HEAP8[$487] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 773) | 0; //@line 17448
        HEAP8[$488] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 774) | 0; //@line 17451
        HEAP8[$489] = _mem_get_uint8(HEAP32[$10 >> 2] | 0, 775) | 0; //@line 17454
       } else {
        $504 = $i_0_i_i * 12 | 0; //@line 17456
        $j_164_i_i = 0;
        $506 = $502;
        while (1) {
         $510 = _mem_get_uint8(HEAP32[$10 >> 2] | 0, $506 + $504 + $j_164_i_i | 0) | 0; //@line 17465
         HEAP8[$tag_i_i + $j_164_i_i | 0] = $510; //@line 17467
         _mem_set_uint8(HEAP32[$10 >> 2] | 0, $j_164_i_i + 764 | 0, $510); //@line 17470
         $514 = $j_164_i_i + 1 | 0; //@line 17471
         if ($514 >>> 0 >= 12) {
          break L2711;
         }
         $j_164_i_i = $514;
         $506 = HEAP32[$477 >> 2] | 0;
        }
       }
      } while (0);
      if ((_mac_sony_write_block($401, $366, $367, $i_0_i_i + $478 | 0) | 0) == 0) {
       $i_0_i_i = $i_0_i_i + 1 | 0; //@line 17489
      } else {
       label = 2148; //@line 17491
       break;
      }
     }
     if ((label | 0) == 2148) {
      _mac_log_deb(55016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 17496
      HEAP32[$sony + 204 >> 2] = -1; //@line 17498
      $552 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17502
      _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -1); //@line 17506
      if (($552 & 512) != 0) {
       $_0 = 0; //@line 17511
       STACKTOP = sp; //@line 17513
       return $_0 | 0; //@line 17514
      }
      $560 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17517
      HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $560) | 0; //@line 17521
      HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17525
      $_0 = 0; //@line 17527
      STACKTOP = sp; //@line 17529
      return $_0 | 0; //@line 17530
     } else if ((label | 0) == 2150) {
      _mem_set_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 40 | 0, $393); //@line 17536
      $sony_idx45_i_i = $sony + 212 | 0; //@line 17538
      $573 = (_mem_get_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony_idx45_i_i >> 2] | 0) + 16 | 0) | 0) + $393 | 0; //@line 17542
      _mem_set_uint32_be(HEAP32[$10 >> 2] | 0, (HEAP32[$sony_idx45_i_i >> 2] | 0) + 16 | 0, $573); //@line 17546
      HEAP32[$sony + 204 >> 2] = 0; //@line 17548
      $579 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17552
      _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, 0); //@line 17556
      if (($579 & 512) != 0) {
       $_0 = 0; //@line 17561
       STACKTOP = sp; //@line 17563
       return $_0 | 0; //@line 17564
      }
      $587 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17567
      HEAP32[$sony_idx45_i_i >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $587) | 0; //@line 17570
      HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17574
      $_0 = 0; //@line 17576
      STACKTOP = sp; //@line 17578
      return $_0 | 0; //@line 17579
     }
    }
   } while (0);
   _mac_log_deb(55672, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 17583
   HEAP32[$sony + 204 >> 2] = -50; //@line 17585
   $457 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17589
   _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -50); //@line 17593
   if (($457 & 512) != 0) {
    $_0 = 0; //@line 17598
    STACKTOP = sp; //@line 17600
    return $_0 | 0; //@line 17601
   }
   $465 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17604
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $465) | 0; //@line 17608
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17612
   $_0 = 0; //@line 17614
   STACKTOP = sp; //@line 17616
   return $_0 | 0; //@line 17617
  } else {
   _mac_log_deb(56808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $16, tempInt) | 0); //@line 17619
   HEAP32[$sony + 204 >> 2] = -17; //@line 17621
   $598 = _mem_get_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 6 | 0) | 0; //@line 17625
   _mem_set_uint16_be(HEAP32[$10 >> 2] | 0, (HEAP32[$12 >> 2] | 0) + 16 | 0, -17); //@line 17629
   if (($598 & 512) != 0) {
    $_0 = 0; //@line 17634
    STACKTOP = sp; //@line 17636
    return $_0 | 0; //@line 17637
   }
   $606 = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 308) | 0; //@line 17640
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, $606) | 0; //@line 17644
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$10 >> 2] | 0, 2300) | 0; //@line 17648
   $_0 = 0; //@line 17650
   STACKTOP = sp; //@line 17652
   return $_0 | 0; //@line 17653
  }
 } else if (($val | 0) == 18) {
  $614 = $sony + 4 | 0; //@line 17656
  $616 = $sony + 208 | 0; //@line 17658
  $620 = (_mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 26 | 0) | 0) & 65535; //@line 17662
  if (($620 | 0) == 21) {
   _mac_sony_ctl_get_icon($sony); //@line 17664
   $_0 = 0; //@line 17666
   STACKTOP = sp; //@line 17668
   return $_0 | 0; //@line 17669
  } else if (($620 | 0) == 22) {
   _mac_sony_ctl_get_icon($sony); //@line 17671
   $_0 = 0; //@line 17673
   STACKTOP = sp; //@line 17675
   return $_0 | 0; //@line 17676
  } else if (($620 | 0) == 23) {
   $969 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 22 | 0) | 0; //@line 17681
   if ($969 << 16 >> 16 == 0 | ($969 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 17688
    $977 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 17692
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -56); //@line 17696
    if (($977 & 512) != 0) {
     $_0 = 0; //@line 17701
     STACKTOP = sp; //@line 17703
     return $_0 | 0; //@line 17704
    }
    $985 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 17707
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $985) | 0; //@line 17711
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 17715
    $_0 = 0; //@line 17717
    STACKTOP = sp; //@line 17719
    return $_0 | 0; //@line 17720
   } else {
    $994 = ($969 & 65535) - 1 | 0; //@line 17723
    _mem_set_uint32_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 28 | 0, ($994 << 3 & 8 | $994 >>> 1 & 1) << 8 | 4); //@line 17734
    HEAP32[$sony + 204 >> 2] = 0; //@line 17736
    $1009 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 17740
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, 0); //@line 17744
    if (($1009 & 512) != 0) {
     $_0 = 0; //@line 17749
     STACKTOP = sp; //@line 17751
     return $_0 | 0; //@line 17752
    }
    $1017 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 17755
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1017) | 0; //@line 17759
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 17763
    $_0 = 0; //@line 17765
    STACKTOP = sp; //@line 17767
    return $_0 | 0; //@line 17768
   }
  } else if (($620 | 0) == 21315) {
   $1025 = $buf_i_i | 0; //@line 17771
   $1026 = $tag_i_i | 0; //@line 17772
   $1030 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 22 | 0) | 0; //@line 17776
   $1034 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 28 | 0) | 0; //@line 17780
   $1035 = $1034 & 65535; //@line 17781
   $1039 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 30 | 0) | 0; //@line 17785
   $1043 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 34 | 0) | 0; //@line 17789
   if ($1030 << 16 >> 16 == 0 | ($1030 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 17796
    $1051 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 17800
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -56); //@line 17804
    if (($1051 & 512) != 0) {
     $_0 = 0; //@line 17809
     STACKTOP = sp; //@line 17811
     return $_0 | 0; //@line 17812
    }
    $1059 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 17815
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1059) | 0; //@line 17819
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 17823
    $_0 = 0; //@line 17825
    STACKTOP = sp; //@line 17827
    return $_0 | 0; //@line 17828
   }
   $1070 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $1030 & 65535) | 0; //@line 17833
   if (($1070 | 0) == 0) {
    HEAP32[$sony + 204 >> 2] = -64; //@line 17838
    $1077 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 17842
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -64); //@line 17846
    if (($1077 & 512) != 0) {
     $_0 = 0; //@line 17851
     STACKTOP = sp; //@line 17853
     return $_0 | 0; //@line 17854
    }
    $1085 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 17857
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1085) | 0; //@line 17861
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 17865
    $_0 = 0; //@line 17867
    STACKTOP = sp; //@line 17869
    return $_0 | 0; //@line 17870
   }
   if ((HEAP8[$1070 + 56 | 0] | 0) != 0) {
    HEAP32[$sony + 204 >> 2] = -44; //@line 17878
    $1101 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 17882
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -44); //@line 17886
    if (($1101 & 512) != 0) {
     $_0 = 0; //@line 17891
     STACKTOP = sp; //@line 17893
     return $_0 | 0; //@line 17894
    }
    $1109 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 17897
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1109) | 0; //@line 17901
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 17905
    $_0 = 0; //@line 17907
    STACKTOP = sp; //@line 17909
    return $_0 | 0; //@line 17910
   }
   do {
    if ($1034 << 16 >> 16 != 0) {
     if ($1035 >>> 0 > (HEAP32[$sony + 64 >> 2] | 0) >>> 0) {
      break;
     }
     $1126 = HEAP32[$sony + 68 + (($1035 << 1) - 2 << 2) >> 2] | 0; //@line 17926
     do {
      if ($1126 >>> 0 < 1120) {
       $_0_i_i_i12 = -2; //@line 17931
      } else {
       if ($1126 >>> 0 < 1520) {
        $_0_i_i_i12 = 0; //@line 17936
        break;
       }
       if ($1126 >>> 0 < 2240) {
        $_0_i_i_i12 = -1; //@line 17942
        break;
       }
       $_0_i_i_i12 = $1126 >>> 0 < 5760 ? 1 : 253; //@line 17948
      }
     } while (0);
     if ((_mac_sony_format($1070, $1126) | 0) != 0) {
      HEAP32[$sony + 204 >> 2] = -50; //@line 17957
      $1161 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 17961
      _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -50); //@line 17965
      if (($1161 & 512) != 0) {
       $_0 = 0; //@line 17970
       STACKTOP = sp; //@line 17972
       return $_0 | 0; //@line 17973
      }
      $1169 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 17976
      HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1169) | 0; //@line 17980
      HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 17984
      $_0 = 0; //@line 17986
      STACKTOP = sp; //@line 17988
      return $_0 | 0; //@line 17989
     }
     $1177 = $1039 & 16777215; //@line 17991
     _memset($1026 | 0, 0, 12); //@line 17992
     L2794 : do {
      if (($1126 | 0) != 0) {
       L2796 : do {
        if ($_0_i_i_i12 >>> 0 > 1) {
         $1181 = $tag_i_i + 1 | 0; //@line 18001
         $1182 = $tag_i_i + 2 | 0; //@line 18002
         $1183 = $tag_i_i + 3 | 0; //@line 18003
         $1184 = $tag_i_i + 4 | 0; //@line 18004
         $1185 = $tag_i_i + 5 | 0; //@line 18005
         $1186 = $tag_i_i + 6 | 0; //@line 18006
         $1187 = $tag_i_i + 7 | 0; //@line 18007
         $1188 = $tag_i_i + 8 | 0; //@line 18008
         $1189 = $tag_i_i + 9 | 0; //@line 18009
         $1190 = $tag_i_i + 10 | 0; //@line 18010
         $1191 = $tag_i_i + 11 | 0; //@line 18011
         $tags_057_us_i_i = $1043 & 16777215;
         $idx_059_us_i_i = 0;
         $data_060_us_i_i = $1177;
         while (1) {
          $i_054_us_i_i = 0; //@line 18019
          do {
           HEAP8[$buf_i_i + $i_054_us_i_i | 0] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $i_054_us_i_i + $data_060_us_i_i | 0) | 0; //@line 18026
           $i_054_us_i_i = $i_054_us_i_i + 1 | 0; //@line 18027
          } while ($i_054_us_i_i >>> 0 < 512);
          HEAP8[$1026] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i) | 0; //@line 18038
          HEAP8[$1181] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 1 | 0) | 0; //@line 18042
          HEAP8[$1182] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 2 | 0) | 0; //@line 18046
          HEAP8[$1183] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 3 | 0) | 0; //@line 18050
          HEAP8[$1184] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 4 | 0) | 0; //@line 18054
          HEAP8[$1185] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 5 | 0) | 0; //@line 18058
          HEAP8[$1186] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 6 | 0) | 0; //@line 18062
          HEAP8[$1187] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 7 | 0) | 0; //@line 18066
          HEAP8[$1188] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 8 | 0) | 0; //@line 18070
          HEAP8[$1189] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 9 | 0) | 0; //@line 18074
          HEAP8[$1190] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 10 | 0) | 0; //@line 18078
          HEAP8[$1191] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $tags_057_us_i_i + 11 | 0) | 0; //@line 18082
          if ((_mac_sony_write_block($1070, $1025, $1026, $idx_059_us_i_i) | 0) != 0) {
           break L2796;
          }
          $1233 = $idx_059_us_i_i + 1 | 0; //@line 18091
          if ($1233 >>> 0 < $1126 >>> 0) {
           $tags_057_us_i_i = $tags_057_us_i_i + 12 | 0;
           $idx_059_us_i_i = $1233;
           $data_060_us_i_i = $data_060_us_i_i + 512 | 0;
          } else {
           break L2794;
          }
         }
        } else {
         $idx_059_i_i = 0;
         $data_060_i_i = $1177;
         while (1) {
          $i_054_i_i = 0; //@line 18106
          do {
           HEAP8[$buf_i_i + $i_054_i_i | 0] = _mem_get_uint8(HEAP32[$614 >> 2] | 0, $i_054_i_i + $data_060_i_i | 0) | 0; //@line 18113
           $i_054_i_i = $i_054_i_i + 1 | 0; //@line 18114
          } while ($i_054_i_i >>> 0 < 512);
          if ((_mac_sony_write_block($1070, $1025, $1026, $idx_059_i_i) | 0) != 0) {
           break L2796;
          }
          $1273 = $idx_059_i_i + 1 | 0; //@line 18130
          if ($1273 >>> 0 < $1126 >>> 0) {
           $idx_059_i_i = $1273;
           $data_060_i_i = $data_060_i_i + 512 | 0;
          } else {
           break L2794;
          }
         }
        }
       } while (0);
       HEAP32[$sony + 204 >> 2] = -1; //@line 18142
       $1256 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18146
       _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -1); //@line 18150
       if (($1256 & 512) != 0) {
        $_0 = 0; //@line 18155
        STACKTOP = sp; //@line 18157
        return $_0 | 0; //@line 18158
       }
       $1264 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18161
       HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1264) | 0; //@line 18165
       HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18169
       $_0 = 0; //@line 18171
       STACKTOP = sp; //@line 18173
       return $_0 | 0; //@line 18174
      }
     } while (0);
     HEAP32[$sony + 204 >> 2] = 0; //@line 18178
     $1279 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18182
     _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, 0); //@line 18186
     if (($1279 & 512) != 0) {
      $_0 = 0; //@line 18191
      STACKTOP = sp; //@line 18193
      return $_0 | 0; //@line 18194
     }
     $1287 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18197
     HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1287) | 0; //@line 18201
     HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18205
     $_0 = 0; //@line 18207
     STACKTOP = sp; //@line 18209
     return $_0 | 0; //@line 18210
    }
   } while (0);
   HEAP32[$sony + 204 >> 2] = -50; //@line 18214
   $1141 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18218
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -50); //@line 18222
   if (($1141 & 512) != 0) {
    $_0 = 0; //@line 18227
    STACKTOP = sp; //@line 18229
    return $_0 | 0; //@line 18230
   }
   $1149 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18233
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1149) | 0; //@line 18237
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18241
   $_0 = 0; //@line 18243
   STACKTOP = sp; //@line 18245
   return $_0 | 0; //@line 18246
  } else if (($620 | 0) == 8) {
   HEAP32[$sony + 56 >> 2] = (_mem_get_uint32_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 28 | 0) | 0) & 16777215; //@line 18254
   HEAP32[$sony + 204 >> 2] = 0; //@line 18256
   $773 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18260
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, 0); //@line 18264
   if (($773 & 512) != 0) {
    $_0 = 0; //@line 18269
    STACKTOP = sp; //@line 18271
    return $_0 | 0; //@line 18272
   }
   $781 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18275
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $781) | 0; //@line 18279
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18283
   $_0 = 0; //@line 18285
   STACKTOP = sp; //@line 18287
   return $_0 | 0; //@line 18288
  } else if (($620 | 0) == 7) {
   $706 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 22 | 0) | 0; //@line 18293
   $707 = $706 & 65535; //@line 18294
   if ($706 << 16 >> 16 == 0 | ($706 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 18301
    $715 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18305
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -56); //@line 18309
    if (($715 & 512) != 0) {
     $_0 = 0; //@line 18314
     STACKTOP = sp; //@line 18316
     return $_0 | 0; //@line 18317
    }
    $723 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18320
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $723) | 0; //@line 18324
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18328
    $_0 = 0; //@line 18330
    STACKTOP = sp; //@line 18332
    return $_0 | 0; //@line 18333
   }
   $731 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18336
   if (($706 & 65535) < 5) {
    $ret_0_i_i_i9 = ($707 * 66 | 0) + 8 + $731 | 0; //@line 18344
   } else {
    $ret_0_i_i_i9 = $731; //@line 18346
   }
   _mem_set_uint8(HEAP32[$614 >> 2] | 0, $ret_0_i_i_i9 + 3 | 0, 0); //@line 18351
   _mem_set_uint8(HEAP32[$614 >> 2] | 0, $ret_0_i_i_i9 + 2 | 0, 0); //@line 18354
   _mem_set_uint8(HEAP32[$614 >> 2] | 0, $ret_0_i_i_i9 + 18 | 0, 0); //@line 18357
   HEAP32[$sony + 204 >> 2] = 0; //@line 18359
   $747 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18363
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, 0); //@line 18367
   if (($747 & 512) != 0) {
    $_0 = 0; //@line 18372
    STACKTOP = sp; //@line 18374
    return $_0 | 0; //@line 18375
   }
   $755 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18378
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $755) | 0; //@line 18382
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18386
   $_0 = 0; //@line 18388
   STACKTOP = sp; //@line 18390
   return $_0 | 0; //@line 18391
  } else if (($620 | 0) == 5) {
   $634 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 22 | 0) | 0; //@line 18396
   if ($634 << 16 >> 16 == 0 | ($634 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 18403
    $642 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18407
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -56); //@line 18411
    if (($642 & 512) != 0) {
     $_0 = 0; //@line 18416
     STACKTOP = sp; //@line 18418
     return $_0 | 0; //@line 18419
    }
    $650 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18422
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $650) | 0; //@line 18426
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18430
    $_0 = 0; //@line 18432
    STACKTOP = sp; //@line 18434
    return $_0 | 0; //@line 18435
   }
   $663 = $sony + 204 | 0; //@line 18442
   if ((_dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $634 & 65535) | 0) == 0) {
    HEAP32[$663 >> 2] = -64; //@line 18445
    $668 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18449
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -64); //@line 18453
    if (($668 & 512) != 0) {
     $_0 = 0; //@line 18458
     STACKTOP = sp; //@line 18460
     return $_0 | 0; //@line 18461
    }
    $676 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18464
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $676) | 0; //@line 18468
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18472
    $_0 = 0; //@line 18474
    STACKTOP = sp; //@line 18476
    return $_0 | 0; //@line 18477
   } else {
    HEAP32[$663 >> 2] = 0; //@line 18479
    $687 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18483
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, 0); //@line 18487
    if (($687 & 512) != 0) {
     $_0 = 0; //@line 18492
     STACKTOP = sp; //@line 18494
     return $_0 | 0; //@line 18495
    }
    $695 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18498
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $695) | 0; //@line 18502
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18506
    $_0 = 0; //@line 18508
    STACKTOP = sp; //@line 18510
    return $_0 | 0; //@line 18511
   }
  } else if (($620 | 0) == 1) {
   HEAP32[$sony + 204 >> 2] = -27; //@line 18515
   _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18519
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -27); //@line 18523
   $_0 = 0; //@line 18525
   STACKTOP = sp; //@line 18527
   return $_0 | 0; //@line 18528
  } else if (($620 | 0) == 9) {
   HEAP32[$sony + 204 >> 2] = -56; //@line 18531
   $793 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18535
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -56); //@line 18539
   if (($793 & 512) != 0) {
    $_0 = 0; //@line 18544
    STACKTOP = sp; //@line 18546
    return $_0 | 0; //@line 18547
   }
   $801 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18550
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $801) | 0; //@line 18554
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18558
   $_0 = 0; //@line 18560
   STACKTOP = sp; //@line 18562
   return $_0 | 0; //@line 18563
  } else if (($620 | 0) == 6) {
   $812 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 22 | 0) | 0; //@line 18568
   $813 = $812 & 65535; //@line 18569
   $817 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 28 | 0) | 0; //@line 18573
   $818 = $817 & 65535; //@line 18574
   if ($812 << 16 >> 16 == 0 | ($812 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 18581
    $826 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18585
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -56); //@line 18589
    if (($826 & 512) != 0) {
     $_0 = 0; //@line 18594
     STACKTOP = sp; //@line 18596
     return $_0 | 0; //@line 18597
    }
    $834 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18600
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $834) | 0; //@line 18604
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18608
    $_0 = 0; //@line 18610
    STACKTOP = sp; //@line 18612
    return $_0 | 0; //@line 18613
   }
   $844 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $813) | 0; //@line 18617
   if (($844 | 0) == 0) {
    HEAP32[$sony + 204 >> 2] = -64; //@line 18622
    $851 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18626
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -64); //@line 18630
    if (($851 & 512) != 0) {
     $_0 = 0; //@line 18635
     STACKTOP = sp; //@line 18637
     return $_0 | 0; //@line 18638
    }
    $859 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18641
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $859) | 0; //@line 18645
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18649
    $_0 = 0; //@line 18651
    STACKTOP = sp; //@line 18653
    return $_0 | 0; //@line 18654
   }
   if ((HEAP8[$844 + 56 | 0] | 0) != 0) {
    HEAP32[$sony + 204 >> 2] = -44; //@line 18662
    $875 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18666
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -44); //@line 18670
    if (($875 & 512) != 0) {
     $_0 = 0; //@line 18675
     STACKTOP = sp; //@line 18677
     return $_0 | 0; //@line 18678
    }
    $883 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18681
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $883) | 0; //@line 18685
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18689
    $_0 = 0; //@line 18691
    STACKTOP = sp; //@line 18693
    return $_0 | 0; //@line 18694
   }
   do {
    if ($817 << 16 >> 16 == 0) {
     label = 2187; //@line 18700
    } else {
     if ($818 >>> 0 > (HEAP32[$sony + 64 >> 2] | 0) >>> 0) {
      label = 2187; //@line 18707
      break;
     }
     $blk_0_i_i = HEAP32[$sony + 68 + (($818 << 1) - 2 << 2) >> 2] | 0; //@line 18715
    }
   } while (0);
   do {
    if ((label | 0) == 2187) {
     $902 = _dsk_get_block_cnt($844) | 0; //@line 18720
     if ((_dsk_get_type($844) | 0) != 6) {
      $blk_0_i_i = $902; //@line 18725
      break;
     }
     $blk_0_i_i = $817 << 16 >> 16 == 1 ? 800 : 1600; //@line 18731
    }
   } while (0);
   if ((_mac_sony_format($844, $blk_0_i_i) | 0) != 0) {
    HEAP32[$sony + 204 >> 2] = -50; //@line 18740
    $915 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18744
    _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -50); //@line 18748
    if (($915 & 512) != 0) {
     $_0 = 0; //@line 18753
     STACKTOP = sp; //@line 18755
     return $_0 | 0; //@line 18756
    }
    $923 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18759
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $923) | 0; //@line 18763
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18767
    $_0 = 0; //@line 18769
    STACKTOP = sp; //@line 18771
    return $_0 | 0; //@line 18772
   }
   $931 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18775
   if (($812 & 65535) < 5) {
    $ret_0_i_i16_i = ($813 * 66 | 0) + 8 + $931 | 0; //@line 18783
   } else {
    $ret_0_i_i16_i = $931; //@line 18785
   }
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, $ret_0_i_i16_i + 18 | 0, $blk_0_i_i & 65535); //@line 18791
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, $ret_0_i_i16_i + 20 | 0, $blk_0_i_i >>> 16 & 65535); //@line 18796
   HEAP32[$sony + 204 >> 2] = 0; //@line 18798
   $948 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18802
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, 0); //@line 18806
   if (($948 & 512) != 0) {
    $_0 = 0; //@line 18811
    STACKTOP = sp; //@line 18813
    return $_0 | 0; //@line 18814
   }
   $956 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18817
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $956) | 0; //@line 18821
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18825
   $_0 = 0; //@line 18827
   STACKTOP = sp; //@line 18829
   return $_0 | 0; //@line 18830
  } else {
   _mac_log_deb(32752, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $620, tempInt) | 0); //@line 18832
   HEAP32[$sony + 204 >> 2] = -17; //@line 18834
   $1299 = _mem_get_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 6 | 0) | 0; //@line 18838
   _mem_set_uint16_be(HEAP32[$614 >> 2] | 0, (HEAP32[$616 >> 2] | 0) + 16 | 0, -17); //@line 18842
   if (($1299 & 512) != 0) {
    $_0 = 0; //@line 18847
    STACKTOP = sp; //@line 18849
    return $_0 | 0; //@line 18850
   }
   $1307 = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 308) | 0; //@line 18853
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, $1307) | 0; //@line 18857
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$614 >> 2] | 0, 2300) | 0; //@line 18861
   $_0 = 0; //@line 18863
   STACKTOP = sp; //@line 18865
   return $_0 | 0; //@line 18866
  }
 } else if (($val | 0) == 16) {
  HEAP8[$sony | 0] = 1; //@line 18870
  if ((_mac_sony_check($sony) | 0) == 0) {
   $_0 = 0; //@line 18875
   STACKTOP = sp; //@line 18877
   return $_0 | 0; //@line 18878
  }
  HEAP32[$sony + 216 >> 2] = HEAP32[$sony + 44 >> 2]; //@line 18883
  $_0 = 0; //@line 18885
  STACKTOP = sp; //@line 18887
  return $_0 | 0; //@line 18888
 } else if (($val | 0) == 19) {
  $1315 = $sony + 4 | 0; //@line 18890
  $1317 = $sony + 208 | 0; //@line 18892
  $1321 = (_mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 26 | 0) | 0) & 65535; //@line 18896
  if (($1321 | 0) == 6) {
   $1326 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 22 | 0) | 0; //@line 18901
   $1331 = (_mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 28 | 0) | 0) & 65535; //@line 18906
   $1335 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 30 | 0) | 0; //@line 18910
   if ($1326 << 16 >> 16 == 0 | ($1326 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 18917
    $1343 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 18921
    _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, -56); //@line 18925
    if (($1343 & 512) != 0) {
     $_0 = 0; //@line 18930
     STACKTOP = sp; //@line 18932
     return $_0 | 0; //@line 18933
    }
    $1351 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 18936
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1351) | 0; //@line 18940
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 18944
    $_0 = 0; //@line 18946
    STACKTOP = sp; //@line 18948
    return $_0 | 0; //@line 18949
   }
   $1362 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $1326 & 65535) | 0; //@line 18954
   if (($1362 | 0) == 0) {
    HEAP32[$sony + 204 >> 2] = -64; //@line 18959
    $1369 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 18963
    _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, -64); //@line 18967
    if (($1369 & 512) != 0) {
     $_0 = 0; //@line 18972
     STACKTOP = sp; //@line 18974
     return $_0 | 0; //@line 18975
    }
    $1377 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 18978
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1377) | 0; //@line 18982
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 18986
    $_0 = 0; //@line 18988
    STACKTOP = sp; //@line 18990
    return $_0 | 0; //@line 18991
   }
   $1385 = _dsk_get_block_cnt($1362) | 0; //@line 18993
   $1386 = $sony + 68 | 0; //@line 18994
   $1389 = $sony + 64 | 0; //@line 18997
   do {
    if ((_dsk_get_type($1362) | 0) == 6) {
     HEAP32[$1389 >> 2] = 4; //@line 19001
     HEAP32[$1386 >> 2] = 800; //@line 19002
     $1391 = $sony + 72 | 0; //@line 19003
     HEAP32[$1391 >> 2] = -2130050992; //@line 19004
     HEAP32[$sony + 76 >> 2] = 1600; //@line 19006
     $1393 = $sony + 80 | 0; //@line 19007
     HEAP32[$1393 >> 2] = -2113273776; //@line 19008
     HEAP32[$sony + 84 >> 2] = 1440; //@line 19010
     $1395 = $sony + 88 | 0; //@line 19011
     HEAP32[$1395 >> 2] = -2113339312; //@line 19012
     HEAP32[$sony + 92 >> 2] = 2880; //@line 19014
     $1397 = $sony + 96 | 0; //@line 19015
     HEAP32[$1397 >> 2] = -1844314032; //@line 19016
     if ($1385 >>> 0 < 1120) {
      HEAP32[$1391 >> 2] = -1056309168; //@line 19020
      $1411 = 4; //@line 19022
      break;
     }
     if ($1385 >>> 0 < 1520) {
      HEAP32[$1395 >> 2] = -1039597488; //@line 19028
      $1411 = 4; //@line 19030
      break;
     }
     if ($1385 >>> 0 < 2240) {
      HEAP32[$1393 >> 2] = -1039531952; //@line 19036
      $1411 = 4; //@line 19038
      break;
     }
     if ((HEAP8[$sony + 60 | 0] | 0) == 0) {
      HEAP32[$1389 >> 2] = 1; //@line 19046
      HEAP32[$1386 >> 2] = 2880; //@line 19047
      HEAP32[$1391 >> 2] = -770572208; //@line 19048
      $1411 = 1; //@line 19049
      break;
     } else {
      HEAP32[$1397 >> 2] = -770572208; //@line 19052
      $1411 = 4; //@line 19054
      break;
     }
    } else {
     HEAP32[$1389 >> 2] = 1; //@line 19058
     HEAP32[$1386 >> 2] = $1385; //@line 19059
     HEAP32[$sony + 72 >> 2] = 0; //@line 19061
     $1411 = 1; //@line 19062
    }
   } while (0);
   $__i_i17 = $1331 >>> 0 > $1411 >>> 0 ? $1411 : $1331; //@line 19067
   $1414 = HEAP32[$1315 >> 2] | 0; //@line 19069
   if (($__i_i17 | 0) == 0) {
    $_lcssa_i_i = $1414; //@line 19072
   } else {
    $i_052_i_i = 0;
    $1415 = $1414;
    while (1) {
     $1417 = ($i_052_i_i << 3) + $1335 | 0; //@line 19079
     $1418 = $i_052_i_i << 1; //@line 19080
     _mem_set_uint32_be($1415, $1417, HEAP32[$sony + 68 + ($1418 << 2) >> 2] | 0); //@line 19083
     _mem_set_uint32_be(HEAP32[$1315 >> 2] | 0, $1417 + 4 | 0, HEAP32[$sony + 68 + (($1418 | 1) << 2) >> 2] | 0); //@line 19089
     $1426 = $i_052_i_i + 1 | 0; //@line 19090
     $1428 = HEAP32[$1315 >> 2] | 0; //@line 19092
     if ($1426 >>> 0 < $__i_i17 >>> 0) {
      $i_052_i_i = $1426;
      $1415 = $1428;
     } else {
      $_lcssa_i_i = $1428; //@line 19097
      break;
     }
    }
   }
   _mem_set_uint16_be($_lcssa_i_i, (HEAP32[$1317 >> 2] | 0) + 28 | 0, $__i_i17 & 65535); //@line 19106
   HEAP32[$sony + 204 >> 2] = 0; //@line 19108
   $1436 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 19112
   _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, 0); //@line 19116
   if (($1436 & 512) != 0) {
    $_0 = 0; //@line 19121
    STACKTOP = sp; //@line 19123
    return $_0 | 0; //@line 19124
   }
   $1444 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 19127
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1444) | 0; //@line 19131
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 19135
   $_0 = 0; //@line 19137
   STACKTOP = sp; //@line 19139
   return $_0 | 0; //@line 19140
  } else if (($1321 | 0) == 8) {
   $1455 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 22 | 0) | 0; //@line 19145
   $1456 = $1455 & 65535; //@line 19146
   if ($1455 << 16 >> 16 == 0 | ($1455 & 65535) > 4) {
    HEAP32[$sony + 204 >> 2] = -56; //@line 19153
    $1464 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 19157
    _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, -56); //@line 19161
    if (($1464 & 512) != 0) {
     $_0 = 0; //@line 19166
     STACKTOP = sp; //@line 19168
     return $_0 | 0; //@line 19169
    }
    $1472 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 19172
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1472) | 0; //@line 19176
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 19180
    $_0 = 0; //@line 19182
    STACKTOP = sp; //@line 19184
    return $_0 | 0; //@line 19185
   }
   if ((_dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $1456) | 0) == 0) {
    HEAP32[$sony + 204 >> 2] = -64; //@line 19194
    $1489 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 19198
    _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, -64); //@line 19202
    if (($1489 & 512) != 0) {
     $_0 = 0; //@line 19207
     STACKTOP = sp; //@line 19209
     return $_0 | 0; //@line 19210
    }
    $1497 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 19213
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1497) | 0; //@line 19217
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 19221
    $_0 = 0; //@line 19223
    STACKTOP = sp; //@line 19225
    return $_0 | 0; //@line 19226
   }
   $1505 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 19229
   if (($1455 & 65535) < 5) {
    $ret_0_i_i_i21 = ($1456 * 66 | 0) + 8 + $1505 | 0; //@line 19237
   } else {
    $ret_0_i_i_i21 = $1505; //@line 19239
   }
   $i_014_i_i = 0; //@line 19243
   do {
    $1513 = $i_014_i_i << 1; //@line 19247
    $1515 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, $1513 + $ret_0_i_i_i21 | 0) | 0; //@line 19249
    _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, $1513 + 28 + (HEAP32[$1317 >> 2] | 0) | 0, $1515); //@line 19254
    $i_014_i_i = $i_014_i_i + 1 | 0; //@line 19255
   } while ($i_014_i_i >>> 0 < 11);
   HEAP32[$sony + 204 >> 2] = 0; //@line 19265
   $1527 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 19269
   _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, 0); //@line 19273
   if (($1527 & 512) != 0) {
    $_0 = 0; //@line 19278
    STACKTOP = sp; //@line 19280
    return $_0 | 0; //@line 19281
   }
   $1535 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 19284
   HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1535) | 0; //@line 19288
   HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 19292
   $_0 = 0; //@line 19294
   STACKTOP = sp; //@line 19296
   return $_0 | 0; //@line 19297
  } else {
   HEAP32[$sony + 204 >> 2] = -18; //@line 19300
   $1547 = _mem_get_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 6 | 0) | 0; //@line 19304
   _mem_set_uint16_be(HEAP32[$1315 >> 2] | 0, (HEAP32[$1317 >> 2] | 0) + 16 | 0, -18); //@line 19308
   if (($1547 & 512) == 0) {
    $1555 = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 308) | 0; //@line 19314
    HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, $1555) | 0; //@line 19318
    HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1315 >> 2] | 0, 2300) | 0; //@line 19322
   }
   _mac_log_deb(35784, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $1321, tempInt) | 0); //@line 19325
   $_0 = 0; //@line 19327
   STACKTOP = sp; //@line 19329
   return $_0 | 0; //@line 19330
  }
 } else if (($val | 0) == 20) {
  $_0 = 0; //@line 19333
  STACKTOP = sp; //@line 19335
  return $_0 | 0; //@line 19336
 } else {
  $_0 = 1; //@line 19339
  STACKTOP = sp; //@line 19341
  return $_0 | 0; //@line 19342
 }
 return 0;
}
function _mac_sound_set_sbuf($ms, $sbuf) {
 $ms = $ms | 0;
 $sbuf = $sbuf | 0;
 HEAP32[$ms + 4 >> 2] = $sbuf; //@line 19354
 return;
}
function _mac_sound_set_volume($ms, $vol) {
 $ms = $ms | 0;
 $vol = $vol | 0;
 HEAP32[$ms + 764 >> 2] = $vol; //@line 19367
 return;
}
function _mac_sound_set_enable($ms, $val) {
 $ms = $ms | 0;
 $val = $val | 0;
 var $2 = 0, $3 = 0;
 $2 = ($val | 0) != 0 | 0; //@line 19380
 $3 = $ms + 760 | 0; //@line 19381
 if ((HEAP32[$3 >> 2] | 0) == ($2 | 0)) {
  return;
 }
 HEAP32[$3 >> 2] = $2; //@line 19389
 return;
}
function _mac_sony_reset($sony) {
 $sony = $sony | 0;
 var $1 = 0, $5 = 0, $6 = 0, $14 = 0, $16 = 0, $buf_015_i = 0, $i_014_i = 0, $22 = 0, $24 = 0, $47 = 0;
 $1 = $sony + 1 | 0; //@line 19408
 do {
  if ((HEAP8[$1] | 0) != 0) {
   $5 = $sony + 136 | 0; //@line 19414
   $6 = HEAP32[$5 >> 2] | 0; //@line 19415
   if (($6 | 0) == 0) {
    break;
   }
   if ((HEAP32[$sony + 132 >> 2] | 0) == 0) {
    break;
   }
   $14 = $sony + 4 | 0; //@line 19429
   $i_014_i = 0;
   $buf_015_i = $sony + 140 | 0;
   $16 = $6;
   while (1) {
    $22 = (_mem_get_uint16_be(HEAP32[$14 >> 2] | 0, $16 + 8 + ($i_014_i << 1) | 0) | 0) & 65535; //@line 19441
    $24 = (HEAP32[$5 >> 2] | 0) + $22 | 0; //@line 19443
    _mem_set_uint8_rw(HEAP32[$14 >> 2] | 0, $24, HEAP8[$buf_015_i] | 0); //@line 19447
    _mem_set_uint8_rw(HEAP32[$14 >> 2] | 0, $24 + 1 | 0, HEAP8[$buf_015_i + 1 | 0] | 0); //@line 19452
    _mem_set_uint8_rw(HEAP32[$14 >> 2] | 0, $24 + 2 | 0, HEAP8[$buf_015_i + 2 | 0] | 0); //@line 19457
    _mem_set_uint8_rw(HEAP32[$14 >> 2] | 0, $24 + 3 | 0, HEAP8[$buf_015_i + 3 | 0] | 0); //@line 19462
    _mem_set_uint8_rw(HEAP32[$14 >> 2] | 0, $24 + 4 | 0, HEAP8[$buf_015_i + 4 | 0] | 0); //@line 19467
    _mem_set_uint8_rw(HEAP32[$14 >> 2] | 0, $24 + 5 | 0, HEAP8[$buf_015_i + 5 | 0] | 0); //@line 19471
    $47 = $i_014_i + 1 | 0; //@line 19472
    if ($47 >>> 0 >= 5) {
     break;
    }
    $i_014_i = $47;
    $buf_015_i = $buf_015_i + 6 | 0;
    $16 = HEAP32[$5 >> 2] | 0;
   }
   HEAP8[$1] = 0; //@line 19483
  }
 } while (0);
 HEAP8[$sony | 0] = 0; //@line 19488
 HEAP32[$sony + 28 >> 2] = HEAP32[$sony + 12 >> 2]; //@line 19492
 HEAP32[$sony + 32 >> 2] = HEAP32[$sony + 16 >> 2]; //@line 19496
 HEAP32[$sony + 36 >> 2] = HEAP32[$sony + 20 >> 2]; //@line 19500
 HEAP32[$sony + 40 >> 2] = HEAP32[$sony + 24 >> 2]; //@line 19504
 return;
}
function _mac_sony_ctl_get_icon($sony) {
 $sony = $sony | 0;
 var $1 = 0, $3 = 0, $6 = 0, $14 = 0, $22 = 0, $32 = 0, $34 = 0, $37 = 0, $40 = 0, $addr_0 = 0, $50 = 0, $58 = 0;
 $1 = $sony + 4 | 0; //@line 19522
 $3 = $sony + 208 | 0; //@line 19524
 $6 = _mem_get_uint16_be(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + 22 | 0) | 0; //@line 19527
 if ($6 << 16 >> 16 == 0 | ($6 & 65535) > 4) {
  HEAP32[$sony + 204 >> 2] = -56; //@line 19534
  $14 = _mem_get_uint16_be(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + 6 | 0) | 0; //@line 19538
  _mem_set_uint16_be(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + 16 | 0, -56); //@line 19542
  if (($14 & 512) != 0) {
   return;
  }
  $22 = _mem_get_uint32_be(HEAP32[$1 >> 2] | 0, 308) | 0; //@line 19551
  HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1 >> 2] | 0, $22) | 0; //@line 19555
  HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1 >> 2] | 0, 2300) | 0; //@line 19559
  return;
 }
 $32 = HEAP32[$sony + 48 >> 2] | 0; //@line 19566
 $34 = HEAP32[$sony + 52 >> 2] | 0; //@line 19568
 $37 = _dsks_get_disk(HEAP32[$sony + 8 >> 2] | 0, $6 & 65535) | 0; //@line 19571
 do {
  if (($37 | 0) == 0) {
   $addr_0 = $32; //@line 19576
  } else {
   $40 = _dsk_get_block_cnt($37) | 0; //@line 19578
   if (($40 | 0) == 800 | ($40 | 0) == 1600 | ($40 | 0) == 1440 | ($40 | 0) == 2880) {
    $addr_0 = $32;
    break;
   }
   $addr_0 = $34; //@line 19584
  }
 } while (0);
 _mem_set_uint32_be(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + 28 | 0, $addr_0); //@line 19591
 HEAP32[$sony + 204 >> 2] = 0; //@line 19593
 $50 = _mem_get_uint16_be(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + 6 | 0) | 0; //@line 19597
 _mem_set_uint16_be(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + 16 | 0, 0); //@line 19601
 if (($50 & 512) != 0) {
  return;
 }
 $58 = _mem_get_uint32_be(HEAP32[$1 >> 2] | 0, 308) | 0; //@line 19610
 HEAP32[$sony + 212 >> 2] = _mem_get_uint32_be(HEAP32[$1 >> 2] | 0, $58) | 0; //@line 19614
 HEAP32[$sony + 216 >> 2] = _mem_get_uint32_be(HEAP32[$1 >> 2] | 0, 2300) | 0; //@line 19618
 return;
}
function _mac_sony_format($dsk, $blk) {
 $dsk = $dsk | 0;
 $blk = $blk | 0;
 var $buf = 0, $7 = 0, $i_067 = 0, $10 = 0, $14 = 0, $15 = 0, $16 = 0, $_0_i_ph = 0, $27 = 0, $c_058 = 0, $sn_057 = 0, $s_055_us = 0, $39 = 0, $h_056_us = 0, $_0_i_ph52 = 0, $50 = 0, $54 = 0, $c_165 = 0, $s_161 = 0, $56 = 0, $59 = 0, $_0 = 0, $s_161_1 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 19637
 STACKTOP = STACKTOP + 512 | 0; //@line 19637
 $buf = sp | 0; //@line 19638
 if ((_dsk_get_type($dsk) | 0) != 6) {
  if ((_dsk_get_block_cnt($dsk) | 0) != ($blk | 0)) {
   $_0 = 1; //@line 19647
   STACKTOP = sp; //@line 19649
   return $_0 | 0; //@line 19650
  }
  $7 = $buf | 0; //@line 19652
  _memset($7 | 0, 0, 512); //@line 19653
  if (($blk | 0) == 0) {
   $_0 = 0; //@line 19657
   STACKTOP = sp; //@line 19659
   return $_0 | 0; //@line 19660
  } else {
   $i_067 = 0; //@line 19662
  }
  while (1) {
   _dsk_write_lba($dsk, $7, $i_067, 1) | 0; //@line 19666
   $10 = $i_067 + 1 | 0; //@line 19667
   if ($10 >>> 0 < $blk >>> 0) {
    $i_067 = $10; //@line 19671
   } else {
    $_0 = 0; //@line 19673
    break;
   }
  }
  STACKTOP = sp; //@line 19678
  return $_0 | 0; //@line 19679
 }
 $14 = HEAP32[$dsk + 64 >> 2] | 0; //@line 19682
 $15 = $14; //@line 19683
 $16 = $buf | 0; //@line 19684
 _memset($16 | 0, 0, 12); //@line 19685
 do {
  if ($blk >>> 0 < 1120) {
   $_0_i_ph = 1; //@line 19690
   label = 2405; //@line 19691
  } else {
   if ($blk >>> 0 < 1520) {
    $_0_i_ph52 = 2; //@line 19696
   } else {
    if ($blk >>> 0 < 2240) {
     $_0_i_ph = 2; //@line 19701
     label = 2405; //@line 19702
     break;
    }
    $_0_i_ph52 = $blk >>> 0 < 5760 ? 3 : 255; //@line 19708
   }
   _dsk_psi_erase_disk($15) | 0; //@line 19711
   $50 = ($_0_i_ph52 | 0) == 2; //@line 19712
   if (($_0_i_ph52 - 2 | 0) >>> 0 >= 2) {
    $_0 = 1; //@line 19717
    STACKTOP = sp; //@line 19719
    return $_0 | 0; //@line 19720
   }
   _dsk_psi_set_encoding($15, $50 ? 2 : 32770); //@line 19723
   $54 = $50 ? 9 : 18; //@line 19724
   $c_165 = 0; //@line 19726
   do {
    $s_161 = 0; //@line 19730
    while (1) {
     $56 = $s_161 + 1 | 0; //@line 19733
     _dsk_psi_format_sector($15, $c_165, 0, $c_165, 0, $56, 512, 0) | 0; //@line 19734
     if ($56 >>> 0 < $54 >>> 0) {
      $s_161 = $56; //@line 19738
     } else {
      $s_161_1 = 0; //@line 19740
      break;
     }
    }
    do {
     $s_161_1 = $s_161_1 + 1 | 0; //@line 19746
     _dsk_psi_format_sector($15, $c_165, 1, $c_165, 1, $s_161_1, 512, 0) | 0; //@line 19747
    } while ($s_161_1 >>> 0 < $54 >>> 0);
    $c_165 = $c_165 + 1 | 0; //@line 19756
   } while ($c_165 >>> 0 < 80);
  }
 } while (0);
 if ((label | 0) == 2405) {
  _dsk_psi_erase_disk($15) | 0; //@line 19769
  _dsk_psi_set_encoding($15, 3); //@line 19770
  $27 = $14 + 68 | 0; //@line 19772
  $sn_057 = 13;
  $c_058 = 0;
  do {
   $sn_057 = ((($c_058 & 15 | 0) == 0) << 31 >> 31) + $sn_057 | 0; //@line 19781
   if (($sn_057 | 0) != 0) {
    $h_056_us = 0; //@line 19784
    do {
     $s_055_us = 0; //@line 19788
     do {
      _dsk_psi_format_sector($15, $c_058, $h_056_us, $c_058, $h_056_us, $s_055_us, 512, 0) | 0; //@line 19791
      $39 = _psi_img_get_sector(HEAP32[$27 >> 2] | 0, $c_058, $h_056_us, $s_055_us, 1) | 0; //@line 19793
      if (($39 | 0) != 0) {
       _psi_sct_set_tags($39, $16, 12) | 0; //@line 19797
      }
      $s_055_us = $s_055_us + 1 | 0; //@line 19800
     } while ($s_055_us >>> 0 < $sn_057 >>> 0);
     $h_056_us = $h_056_us + 1 | 0; //@line 19809
    } while ($h_056_us >>> 0 < $_0_i_ph >>> 0);
   }
   $c_058 = $c_058 + 1 | 0; //@line 19819
  } while ($c_058 >>> 0 < 80);
 }
 $59 = _dsk_get_block_cnt($dsk) | 0; //@line 19829
 _mac_log_deb(57656, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $59, tempInt) | 0); //@line 19830
 $_0 = 0; //@line 19832
 STACKTOP = sp; //@line 19834
 return $_0 | 0; //@line 19835
}
function _mac_sony_write_block($dsk, $buf, $tag, $idx) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $tag = $tag | 0;
 $idx = $idx | 0;
 var $c = 0, $h = 0, $s = 0, $cnt = 0, $10 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $_pre_phi = 0, $21 = 0, $22 = 0, $23 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 19850
 STACKTOP = STACKTOP + 32 | 0; //@line 19850
 $c = sp | 0; //@line 19851
 $h = sp + 8 | 0; //@line 19852
 $s = sp + 16 | 0; //@line 19853
 $cnt = sp + 24 | 0; //@line 19854
 if ((_dsk_get_type($dsk) | 0) != 6) {
  $_0 = (_dsk_write_lba($dsk, $buf, $idx, 1) | 0) != 0 | 0; //@line 19863
  STACKTOP = sp; //@line 19865
  return $_0 | 0; //@line 19866
 }
 if ((_mac_sony_get_chs(_dsk_get_block_cnt($dsk) | 0, $idx, $c, $h, $s) | 0) != 0) {
  $_0 = 1; //@line 19873
  STACKTOP = sp; //@line 19875
  return $_0 | 0; //@line 19876
 }
 $10 = _dsk_get_block_cnt($dsk) | 0; //@line 19878
 if ($10 >>> 0 < 1120 | ($10 - 1520 | 0) >>> 0 < 720) {
  $14 = $dsk + 64 | 0; //@line 19885
  $16 = HEAP32[$14 >> 2] | 0; //@line 19887
  $17 = HEAP32[$c >> 2] | 0; //@line 19888
  $18 = HEAP32[$h >> 2] | 0; //@line 19889
  $19 = HEAP32[$s >> 2] | 0; //@line 19890
  _dsk_psi_write_tags($16, $tag, 12, $17, $18, $19, 0) | 0; //@line 19891
  $23 = $17;
  $22 = $18;
  $21 = $19;
  $_pre_phi = $14;
 } else {
  $23 = HEAP32[$c >> 2] | 0;
  $22 = HEAP32[$h >> 2] | 0;
  $21 = HEAP32[$s >> 2] | 0;
  $_pre_phi = $dsk + 64 | 0;
 }
 HEAP32[$cnt >> 2] = 512; //@line 19906
 if ((_dsk_psi_write_chs(HEAP32[$_pre_phi >> 2] | 0, $buf, $cnt, $23, $22, $21, 0) | 0) == 0) {
  $_0 = 0; //@line 19913
  STACKTOP = sp; //@line 19915
  return $_0 | 0; //@line 19916
 }
 _mac_log_deb(31416, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $23, HEAP32[tempInt + 8 >> 2] = $22, HEAP32[tempInt + 16 >> 2] = $21, tempInt) | 0); //@line 19918
 $_0 = 1; //@line 19920
 STACKTOP = sp; //@line 19922
 return $_0 | 0; //@line 19923
}
function _mac_sony_get_chs($blk, $lba, $c, $h, $s) {
 $blk = $blk | 0;
 $lba = $lba | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 var $_0_i_ph = 0, $7 = 0, $8 = 0, $_03947_lcssa = 0, $sn_049_lcssa = 0, $16 = 0, $20 = 0, $21 = 0, $storemerge = 0, $_0 = 0, $40 = 0, $41 = 0, $44 = 0, $45 = 0, $48 = 0, sp = 0;
 sp = STACKTOP; //@line 19940
 L3092 : do {
  if ($blk >>> 0 < 1120) {
   $_0_i_ph = 1; //@line 19945
  } else {
   do {
    if ($blk >>> 0 < 1520) {
     HEAP32[$s >> 2] = (($lba >>> 0) % 9 | 0) + 1; //@line 19953
     HEAP32[$h >> 2] = (($lba >>> 0) / 9 | 0) & 1; //@line 19956
     $storemerge = ($lba >>> 0) / 18 | 0; //@line 19959
    } else {
     if ($blk >>> 0 < 2240) {
      $_0_i_ph = 0; //@line 19964
      break L3092;
     }
     if ($blk >>> 0 < 5760) {
      HEAP32[$s >> 2] = (($lba >>> 0) % 18 | 0) + 1; //@line 19972
      HEAP32[$h >> 2] = (($lba >>> 0) / 18 | 0) & 1; //@line 19975
      $storemerge = ($lba >>> 0) / 36 | 0; //@line 19977
      break;
     }
     _mac_log_deb(30448, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $blk, HEAP32[tempInt + 8 >> 2] = $lba, tempInt) | 0); //@line 19980
     $_0 = 1; //@line 19982
     STACKTOP = sp; //@line 19984
     return $_0 | 0; //@line 19985
    }
   } while (0);
   HEAP32[$c >> 2] = $storemerge; //@line 19989
   $_0 = 0; //@line 19991
   STACKTOP = sp; //@line 19993
   return $_0 | 0; //@line 19994
  }
 } while (0);
 $7 = $_0_i_ph ? 1 : 2; //@line 19998
 HEAP32[$c >> 2] = 0; //@line 19999
 $8 = $7 * 192 | 0; //@line 20000
 do {
  if ($8 >>> 0 > $lba >>> 0) {
   $sn_049_lcssa = 12;
   $_03947_lcssa = $lba;
  } else {
   $20 = $lba - $8 | 0; //@line 20007
   HEAP32[$c >> 2] = 16; //@line 20008
   $21 = $7 * 176 | 0; //@line 20009
   if ($20 >>> 0 < $21 >>> 0) {
    $sn_049_lcssa = 11;
    $_03947_lcssa = $20;
    break;
   }
   $40 = $20 - $21 | 0; //@line 20016
   HEAP32[$c >> 2] = 32; //@line 20017
   $41 = $7 * 160 | 0; //@line 20018
   if ($40 >>> 0 < $41 >>> 0) {
    $sn_049_lcssa = 10;
    $_03947_lcssa = $40;
    break;
   }
   $44 = $40 - $41 | 0; //@line 20025
   HEAP32[$c >> 2] = 48; //@line 20026
   $45 = $7 * 144 | 0; //@line 20027
   if ($44 >>> 0 < $45 >>> 0) {
    $sn_049_lcssa = 9;
    $_03947_lcssa = $44;
    break;
   }
   $48 = $44 - $45 | 0; //@line 20034
   HEAP32[$c >> 2] = 64; //@line 20035
   if ($48 >>> 0 < $7 << 7 >>> 0) {
    $sn_049_lcssa = 8;
    $_03947_lcssa = $48;
    break;
   }
   HEAP32[$c >> 2] = 80; //@line 20043
   $_0 = 1; //@line 20044
   STACKTOP = sp; //@line 20046
   return $_0 | 0; //@line 20047
  }
 } while (0);
 HEAP32[$s >> 2] = ($_03947_lcssa >>> 0) % ($sn_049_lcssa >>> 0) | 0; //@line 20053
 HEAP32[$h >> 2] = (($_03947_lcssa >>> 0) / ($sn_049_lcssa >>> 0) | 0) & ($_0_i_ph & 1 ^ 1); //@line 20058
 $16 = ($_03947_lcssa >>> 0) / ((Math_imul($sn_049_lcssa, $7) | 0) >>> 0) | 0; //@line 20060
 HEAP32[$c >> 2] = (HEAP32[$c >> 2] | 0) + $16; //@line 20063
 $_0 = 0; //@line 20065
 STACKTOP = sp; //@line 20067
 return $_0 | 0; //@line 20068
}
function _mac_sound_init($ms) {
 $ms = $ms | 0;
 HEAP32[$ms + 756 >> 2] = 0; //@line 20079
 HEAP32[$ms + 760 >> 2] = 0; //@line 20081
 HEAP32[$ms + 764 >> 2] = 0; //@line 20083
 _memset($ms | 0, 0, 16); //@line 20086
 HEAP32[$ms + 768 >> 2] = 8e3; //@line 20087
 _snd_iir2_init($ms + 772 | 0); //@line 20089
 HEAP16[$ms + 820 >> 1] = -32768; //@line 20091
 HEAP32[$ms + 824 >> 2] = 0; //@line 20093
 HEAP32[$ms + 828 >> 2] = 60; //@line 20095
 return;
}
function _mac_sound_set_lowpass($ms, $freq) {
 $ms = $ms | 0;
 $freq = $freq | 0;
 HEAP32[$ms + 768 >> 2] = $freq; //@line 20108
 _snd_iir2_set_lowpass($ms + 772 | 0, $freq, 22255); //@line 20110
 return;
}
function _mac_sound_set_driver($ms, $driver) {
 $ms = $ms | 0;
 $driver = $driver | 0;
 var $1 = 0, $2 = 0, $6 = 0, $_0 = 0;
 $1 = $ms | 0; //@line 20123
 $2 = HEAP32[$1 >> 2] | 0; //@line 20124
 if (($2 | 0) != 0) {
  _snd_close($2); //@line 20128
 }
 $6 = _snd_open($driver) | 0; //@line 20131
 HEAP32[$1 >> 2] = $6; //@line 20132
 if (($6 | 0) == 0) {
  $_0 = 1; //@line 20136
  return $_0 | 0; //@line 20139
 }
 if ((_snd_set_params($6, 1, 22255, 0) | 0) == 0) {
  $_0 = 0; //@line 20145
  return $_0 | 0; //@line 20148
 }
 _snd_close(HEAP32[$1 >> 2] | 0); //@line 20151
 HEAP32[$1 >> 2] = 0; //@line 20152
 $_0 = 1; //@line 20154
 return $_0 | 0; //@line 20157
}
function _mac_sound_vbl($ms) {
 $ms = $ms | 0;
 var $buf_i = 0, $1 = 0, $5 = 0, $9 = 0, $10 = 0, $13 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $24 = 0, $_024_i = 0, $_pre_i = 0, $35 = 0, $val_0_i = 0, $45 = 0, $_pre26_i = 0, $63 = 0, $68 = 0, $70 = 0, $_013_i = 0, $75 = 0, $81 = 0, $84 = 0, $85 = 0, $ms_idx_val = 0, $90 = 0, $94 = 0, $102 = 0, $_pre_phi = 0, $105 = 0, $106 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 20177
 STACKTOP = STACKTOP + 8192 | 0; //@line 20177
 $buf_i = sp | 0; //@line 20178
 $1 = $ms + 4 | 0; //@line 20179
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  STACKTOP = sp; //@line 20184
  return;
 }
 $5 = $ms | 0; //@line 20187
 if ((HEAP32[$5 >> 2] | 0) == 0) {
  STACKTOP = sp; //@line 20192
  return;
 }
 $9 = $ms + 12 | 0; //@line 20195
 $10 = HEAP32[$9 >> 2] | 0; //@line 20196
 L3134 : do {
  if ($10 >>> 0 < 370) {
   $13 = $ms + 760 | 0; //@line 20201
   if ((HEAP32[$13 >> 2] | 0) == 0) {
    if ((HEAP32[$ms + 828 >> 2] | 0) >>> 0 > 59 & ($10 | 0) == 0) {
     break;
    }
    $63 = $ms + 820 | 0; //@line 20216
    if ((HEAP16[$63 >> 1] | 0) != -32768) {
     HEAP32[$ms + 824 >> 2] = 1; //@line 20222
    }
    $68 = $ms + 8 | 0; //@line 20225
    $_013_i = 370 - $10 | 0;
    $70 = $10;
    do {
     if ($70 >>> 0 >= 370) {
      break;
     }
     HEAP16[$ms + 16 + ($70 << 1) >> 1] = -32768; //@line 20236
     $75 = (HEAP32[$68 >> 2] | 0) + 1 | 0; //@line 20238
     HEAP32[$68 >> 2] = $75 >>> 0 > 369 ? 0 : $75; //@line 20241
     $70 = (HEAP32[$9 >> 2] | 0) + 1 | 0; //@line 20243
     HEAP32[$9 >> 2] = $70; //@line 20244
     $_013_i = $_013_i - 1 | 0; //@line 20245
    } while (($_013_i | 0) != 0);
    HEAP16[$63 >> 1] = -32768; //@line 20254
    break;
   }
   $19 = 8 - (HEAP32[$ms + 764 >> 2] | 0) | 0; //@line 20261
   $20 = $ms + 8 | 0; //@line 20262
   $21 = $ms + 820 | 0; //@line 20263
   $22 = $ms + 824 | 0; //@line 20264
   $_024_i = 370 - $10 | 0;
   $24 = $10;
   do {
    if ($24 >>> 0 >= 370) {
     break L3134;
    }
    $_pre_i = HEAP32[$20 >> 2] | 0; //@line 20276
    do {
     if ((HEAP32[$13 >> 2] | 0) == 0) {
      $val_0_i = 32768; //@line 20280
     } else {
      $35 = HEAPU8[(HEAP32[$1 >> 2] | 0) + ($_pre_i << 1) | 0] << 8; //@line 20287
      if ($35 >>> 0 < 32768) {
       $val_0_i = 32768 - (((32768 - $35 | 0) >>> 0) / ($19 >>> 0) | 0) | 0; //@line 20295
       break;
      } else {
       $val_0_i = ((($35 - 32768 | 0) >>> 0) / ($19 >>> 0) | 0) + 32768 | 0; //@line 20301
       break;
      }
     }
    } while (0);
    $45 = $_pre_i + 1 | 0; //@line 20307
    HEAP32[$20 >> 2] = $45 >>> 0 > 369 ? 0 : $45; //@line 20310
    $_pre26_i = $val_0_i & 65535; //@line 20314
    if (($val_0_i | 0) != (HEAPU16[$21 >> 1] | 0)) {
     HEAP16[$21 >> 1] = $_pre26_i; //@line 20317
     HEAP32[$22 >> 2] = 1; //@line 20318
    }
    HEAP16[$ms + 16 + ($24 << 1) >> 1] = $_pre26_i; //@line 20322
    $24 = (HEAP32[$9 >> 2] | 0) + 1 | 0; //@line 20324
    HEAP32[$9 >> 2] = $24; //@line 20325
    $_024_i = $_024_i - 1 | 0; //@line 20326
   } while (($_024_i | 0) != 0);
  }
 } while (0);
 $81 = $ms + 824 | 0; //@line 20337
 $84 = $ms + 828 | 0; //@line 20340
 $85 = HEAP32[$84 >> 2] | 0; //@line 20341
 do {
  if ((HEAP32[$81 >> 2] | 0) == 0) {
   if ($85 >>> 0 >= 60) {
    break;
   }
   $94 = $85 + 1 | 0; //@line 20350
   HEAP32[$84 >> 2] = $94; //@line 20351
   if ($94 >>> 0 < 60) {
    label = 2496; //@line 20355
   }
  } else {
   if ($85 >>> 0 > 59) {
    $ms_idx_val = HEAP32[$5 >> 2] | 0; //@line 20361
    _memset($buf_i | 0, 0, 8192); //@line 20363
    $90 = $buf_i | 0; //@line 20364
    _snd_write($ms_idx_val, $90, 4096) | 0; //@line 20365
   }
   HEAP32[$84 >> 2] = 0; //@line 20368
   label = 2496; //@line 20370
  }
 } while (0);
 if ((label | 0) == 2496) {
  if ((HEAP32[$ms + 768 >> 2] | 0) == 0) {
   $_pre_phi = $ms + 16 | 0; //@line 20381
  } else {
   $102 = $ms + 16 | 0; //@line 20384
   _snd_iir2_filter($ms + 772 | 0, $102, $102, HEAP32[$9 >> 2] | 0, 1, 0); //@line 20386
   $_pre_phi = $102; //@line 20388
  }
  $105 = HEAP32[$5 >> 2] | 0; //@line 20391
  $106 = HEAP32[$9 >> 2] | 0; //@line 20392
  _snd_write($105, $_pre_phi, $106) | 0; //@line 20393
 }
 HEAP32[$81 >> 2] = 0; //@line 20396
 HEAP32[$ms + 8 >> 2] = 16; //@line 20398
 HEAP32[$9 >> 2] = 0; //@line 20399
 HEAP32[$ms + 756 >> 2] = 0; //@line 20401
 STACKTOP = sp; //@line 20403
 return;
}
function _mac_sound_clock($ms, $n) {
 $ms = $ms | 0;
 $n = $n | 0;
 var $1 = 0, $5 = 0, $9 = 0, $10 = 0, $13 = 0, $15 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $26 = 0, $_024_i = 0, $_pre_i = 0, $37 = 0, $val_0_i = 0, $47 = 0, $_pre26_i = 0, $55 = 0, $56 = 0, label = 0;
 $1 = $ms + 760 | 0; //@line 20420
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  return;
 }
 $5 = $ms + 4 | 0; //@line 20428
 if ((HEAP32[$5 >> 2] | 0) == 0) {
  return;
 }
 $9 = $ms + 12 | 0; //@line 20436
 $10 = HEAP32[$9 >> 2] | 0; //@line 20437
 if ($10 >>> 0 > 369) {
  return;
 }
 $13 = $ms + 756 | 0; //@line 20444
 $15 = (HEAP32[$13 >> 2] | 0) + $n | 0; //@line 20446
 HEAP32[$13 >> 2] = $15; //@line 20447
 if ($15 >>> 0 <= 351) {
  return;
 }
 HEAP32[$13 >> 2] = ($15 >>> 0) % 352 | 0; //@line 20456
 $21 = 8 - (HEAP32[$ms + 764 >> 2] | 0) | 0; //@line 20459
 $22 = $ms + 8 | 0; //@line 20460
 $23 = $ms + 820 | 0; //@line 20461
 $24 = $ms + 824 | 0; //@line 20462
 $_024_i = ($15 >>> 0) / 352 | 0;
 $26 = $10;
 while (1) {
  if ($26 >>> 0 >= 370) {
   label = 2521; //@line 20470
   break;
  }
  $_pre_i = HEAP32[$22 >> 2] | 0; //@line 20475
  do {
   if ((HEAP32[$1 >> 2] | 0) == 0) {
    $val_0_i = 32768; //@line 20479
   } else {
    $37 = (HEAPU8[(HEAP32[$5 >> 2] | 0) + ($_pre_i << 1) | 0] | 0) << 8; //@line 20486
    if ($37 >>> 0 < 32768) {
     $val_0_i = 32768 - (((32768 - $37 | 0) >>> 0) / ($21 >>> 0) | 0) | 0; //@line 20494
     break;
    } else {
     $val_0_i = ((($37 - 32768 | 0) >>> 0) / ($21 >>> 0) | 0) + 32768 | 0; //@line 20500
     break;
    }
   }
  } while (0);
  $47 = $_pre_i + 1 | 0; //@line 20506
  HEAP32[$22 >> 2] = $47 >>> 0 > 369 ? 0 : $47; //@line 20509
  $_pre26_i = $val_0_i & 65535; //@line 20513
  if (($val_0_i | 0) != (HEAPU16[$23 >> 1] | 0 | 0)) {
   HEAP16[$23 >> 1] = $_pre26_i; //@line 20516
   HEAP32[$24 >> 2] = 1; //@line 20517
  }
  HEAP16[$ms + 16 + ($26 << 1) >> 1] = $_pre26_i; //@line 20521
  $55 = (HEAP32[$9 >> 2] | 0) + 1 | 0; //@line 20523
  HEAP32[$9 >> 2] = $55; //@line 20524
  $56 = $_024_i - 1 | 0; //@line 20525
  if (($56 | 0) == 0) {
   label = 2519; //@line 20529
   break;
  } else {
   $_024_i = $56;
   $26 = $55;
  }
 }
 if ((label | 0) == 2521) {
  return;
 } else if ((label | 0) == 2519) {
  return;
 }
}
function _mac_get_trap_name($trap) {
 $trap = $trap | 0;
 var $5 = 0, $_ = 0, $_9 = 0, $i_0 = 0, $8 = 0, $_0 = 0, label = 0;
 if (($trap & 61440 | 0) != 40960) {
  $_0 = 0; //@line 20557
  return $_0 | 0; //@line 20560
 }
 $5 = ($trap & 2048 | 0) == 0; //@line 20563
 $_ = $5 ? 63743 : 64511; //@line 20564
 $_9 = $5 ? 5208 : 400; //@line 20565
 $i_0 = 0; //@line 20567
 while (1) {
  $8 = HEAP32[$_9 + ($i_0 << 3) + 4 >> 2] | 0; //@line 20571
  if (($8 | 0) == 0) {
   $_0 = 0; //@line 20575
   label = 2532; //@line 20576
   break;
  }
  if ((((HEAPU16[$_9 + ($i_0 << 3) >> 1] | 0) ^ $trap) & $_ | 0) == 0) {
   $_0 = $8; //@line 20588
   label = 2530; //@line 20589
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 20592
  }
 }
 if ((label | 0) == 2530) {
  return $_0 | 0; //@line 20598
 } else if ((label | 0) == 2532) {
  return $_0 | 0; //@line 20603
 }
 return 0;
}
function _mac_video_set_vbi_fct($mv, $ext, $fct) {
 $mv = $mv | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$mv + 52 >> 2] = $ext; //@line 20616
 HEAP32[$mv + 56 >> 2] = $fct; //@line 20619
 return;
}
function _mac_video_set_vbuf($mv, $vbuf) {
 $mv = $mv | 0;
 $vbuf = $vbuf | 0;
 HEAP32[$mv >> 2] = $vbuf; //@line 20632
 return;
}
function _mac_video_set_color($mv, $col0, $col1) {
 $mv = $mv | 0;
 $col0 = $col0 | 0;
 $col1 = $col1 | 0;
 HEAP8[$mv + 32 | 0] = $col0 >>> 16 & 255; //@line 20650
 HEAP8[$mv + 35 | 0] = $col1 >>> 16 & 255; //@line 20654
 HEAP8[$mv + 33 | 0] = $col0 >>> 8 & 255; //@line 20658
 HEAP8[$mv + 36 | 0] = $col1 >>> 8 & 255; //@line 20662
 HEAP8[$mv + 34 | 0] = $col0 & 255; //@line 20665
 HEAP8[$mv + 37 | 0] = $col1 & 255; //@line 20668
 HEAP8[$mv + 12 | 0] = 1; //@line 20670
 return;
}
function _mac_video_set_brightness($mv, $val) {
 $mv = $mv | 0;
 $val = $val | 0;
 var $_val = 0, $2 = 0;
 $_val = $val >>> 0 > 255 ? 255 : $val; //@line 20683
 $2 = $mv + 28 | 0; //@line 20684
 if ((HEAP32[$2 >> 2] | 0) == ($_val | 0)) {
  return;
 }
 HEAP8[$mv + 12 | 0] = 1; //@line 20693
 HEAP32[$2 >> 2] = $_val; //@line 20694
 return;
}
function _mac_video_new($w, $h) {
 $w = $w | 0;
 $h = $h | 0;
 var $1 = 0, $2 = 0, $18 = 0, $24 = 0, $_0 = 0;
 $1 = _malloc(60) | 0; //@line 20712
 $2 = $1; //@line 20713
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 20717
  return $_0 | 0; //@line 20720
 }
 HEAP32[$1 >> 2] = 0; //@line 20723
 HEAP32[$1 + 44 >> 2] = 0; //@line 20726
 HEAP32[$1 + 4 >> 2] = $w; //@line 20729
 HEAP32[$1 + 8 >> 2] = $h; //@line 20732
 HEAP8[$1 + 12 | 0] = 0; //@line 20734
 HEAP32[$1 + 16 >> 2] = 8; //@line 20737
 $18 = _malloc(Math_imul(($w + 7 | 0) >>> 3, $h) | 0) | 0; //@line 20741
 HEAP32[$1 + 20 >> 2] = $18; //@line 20744
 do {
  if (($18 | 0) != 0) {
   $24 = _malloc($w * 24 | 0) | 0; //@line 20750
   HEAP32[$1 + 24 >> 2] = $24; //@line 20753
   if (($24 | 0) == 0) {
    break;
   }
   HEAP32[$1 + 28 >> 2] = 255; //@line 20761
   HEAP8[$1 + 32 | 0] = 0; //@line 20763
   HEAP8[$1 + 33 | 0] = 0; //@line 20765
   HEAP8[$1 + 34 | 0] = 0; //@line 20767
   HEAP8[$1 + 35 | 0] = -1; //@line 20769
   HEAP8[$1 + 36 | 0] = -1; //@line 20771
   HEAP8[$1 + 37 | 0] = -1; //@line 20773
   HEAP32[$1 + 40 >> 2] = 0; //@line 20776
   HEAP8[$1 + 48 | 0] = 0; //@line 20778
   HEAP32[$1 + 52 >> 2] = 0; //@line 20781
   HEAP32[$1 + 56 >> 2] = 0; //@line 20784
   $_0 = $2; //@line 20786
   return $_0 | 0; //@line 20789
  }
 } while (0);
 _free($1); //@line 20792
 $_0 = 0; //@line 20794
 return $_0 | 0; //@line 20797
}
function _mac_video_set_terminal($mv, $trm) {
 $mv = $mv | 0;
 $trm = $trm | 0;
 HEAP32[$mv + 44 >> 2] = $trm; //@line 20808
 if (($trm | 0) == 0) {
  return;
 }
 _trm_open($trm, HEAP32[$mv + 4 >> 2] | 0, HEAP32[$mv + 8 >> 2] | 0) | 0; //@line 20819
 return;
}
function _mac_video_update($mv) {
 $mv = $mv | 0;
 var $col0 = 0, $col1 = 0, $1 = 0, $2 = 0, $5 = 0, $9 = 0, $16 = 0, $23 = 0, $30 = 0, $37 = 0, $44 = 0, $51 = 0, $52 = 0, $54 = 0, $57 = 0, $58 = 0, $63 = 0, $64 = 0, $66 = 0, $y_059 = 0, $dst_058 = 0, $src_057 = 0, $67 = 0, $68 = 0, $_ = 0, $73 = 0, $80 = 0, $i_156 = 0, $j_055 = 0, $110 = 0, $114 = 0, $115 = 0, $_pre_phi = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 20845
 STACKTOP = STACKTOP + 16 | 0; //@line 20845
 $col0 = sp | 0; //@line 20846
 $col1 = sp + 8 | 0; //@line 20847
 $1 = $mv + 44 | 0; //@line 20848
 $2 = HEAP32[$1 >> 2] | 0; //@line 20849
 if (($2 | 0) == 0) {
  STACKTOP = sp; //@line 20853
  return;
 }
 $5 = $mv | 0; //@line 20856
 if ((HEAP32[$5 >> 2] | 0) == 0) {
  STACKTOP = sp; //@line 20861
  return;
 }
 $9 = HEAP32[$mv + 28 >> 2] | 0; //@line 20865
 $16 = $col0 | 0; //@line 20872
 HEAP8[$16] = (((Math_imul(HEAPU8[$mv + 32 | 0] | 0, $9) | 0) >>> 0) / 255 | 0) & 255; //@line 20873
 $23 = $col1 | 0; //@line 20880
 HEAP8[$23] = (((Math_imul(HEAPU8[$mv + 35 | 0] | 0, $9) | 0) >>> 0) / 255 | 0) & 255; //@line 20881
 $30 = $col0 + 1 | 0; //@line 20888
 HEAP8[$30] = (((Math_imul(HEAPU8[$mv + 33 | 0] | 0, $9) | 0) >>> 0) / 255 | 0) & 255; //@line 20889
 $37 = $col1 + 1 | 0; //@line 20896
 HEAP8[$37] = (((Math_imul(HEAPU8[$mv + 36 | 0] | 0, $9) | 0) >>> 0) / 255 | 0) & 255; //@line 20897
 $44 = $col0 + 2 | 0; //@line 20904
 HEAP8[$44] = (((Math_imul(HEAPU8[$mv + 34 | 0] | 0, $9) | 0) >>> 0) / 255 | 0) & 255; //@line 20905
 $51 = $col1 + 2 | 0; //@line 20912
 HEAP8[$51] = (((Math_imul(HEAPU8[$mv + 37 | 0] | 0, $9) | 0) >>> 0) / 255 | 0) & 255; //@line 20913
 $52 = $mv + 4 | 0; //@line 20914
 $54 = $mv + 8 | 0; //@line 20916
 _trm_set_size($2, HEAP32[$52 >> 2] | 0, HEAP32[$54 >> 2] | 0); //@line 20918
 $57 = HEAP32[$mv + 24 >> 2] | 0; //@line 20920
 $58 = HEAP32[$54 >> 2] | 0; //@line 20921
 L3243 : do {
  if (($58 | 0) == 0) {
   $_pre_phi = $mv + 12 | 0; //@line 20928
  } else {
   $63 = $mv + 16 | 0; //@line 20933
   $64 = $mv + 12 | 0; //@line 20934
   $src_057 = HEAP32[$5 >> 2] | 0;
   $dst_058 = HEAP32[$mv + 20 >> 2] | 0;
   $y_059 = 0;
   $66 = $58;
   while (1) {
    $67 = $66 - $y_059 | 0; //@line 20942
    $68 = HEAP32[$63 >> 2] | 0; //@line 20943
    $_ = $67 >>> 0 > $68 >>> 0 ? $68 : $67; //@line 20945
    $73 = Math_imul(((HEAP32[$52 >> 2] | 0) + 7 | 0) >>> 3, $_) | 0; //@line 20949
    if ((HEAP8[$64] | 0) == 0) {
     if ((_memcmp($dst_058 | 0, $src_057 | 0, $73 | 0) | 0) == 0) {
      $114 = $66; //@line 20958
     } else {
      label = 2562; //@line 20960
     }
    } else {
     label = 2562; //@line 20963
    }
    if ((label | 0) == 2562) {
     label = 0; //@line 20966
     _memcpy($dst_058 | 0, $src_057 | 0, $73) | 0; //@line 20967
     $80 = $73 << 3; //@line 20968
     if (($80 | 0) != 0) {
      $j_055 = 0;
      $i_156 = 0;
      while (1) {
       if ((HEAPU8[$dst_058 + ($i_156 >>> 3) | 0] & 128 >>> (($i_156 & 7) >>> 0) | 0) == 0) {
        HEAP8[$57 + $j_055 | 0] = HEAP8[$23] | 0; //@line 20988
        HEAP8[$57 + ($j_055 + 1) | 0] = HEAP8[$37] | 0; //@line 20992
        HEAP8[$57 + ($j_055 + 2) | 0] = HEAP8[$51] | 0; //@line 20996
       } else {
        HEAP8[$57 + $j_055 | 0] = HEAP8[$16] | 0; //@line 21000
        HEAP8[$57 + ($j_055 + 1) | 0] = HEAP8[$30] | 0; //@line 21004
        HEAP8[$57 + ($j_055 + 2) | 0] = HEAP8[$44] | 0; //@line 21008
       }
       $110 = $i_156 + 1 | 0; //@line 21012
       if ($110 >>> 0 < $80 >>> 0) {
        $j_055 = $j_055 + 3 | 0;
        $i_156 = $110;
       } else {
        break;
       }
      }
     }
     _trm_set_lines(HEAP32[$1 >> 2] | 0, $57, $y_059, $_); //@line 21023
     $114 = HEAP32[$54 >> 2] | 0; //@line 21026
    }
    $115 = $_ + $y_059 | 0; //@line 21029
    if ($115 >>> 0 >= $114 >>> 0) {
     $_pre_phi = $64; //@line 21033
     break L3243;
    }
    $src_057 = $src_057 + $73 | 0;
    $dst_058 = $dst_058 + $73 | 0;
    $y_059 = $115;
    $66 = $114;
   }
  }
 } while (0);
 HEAP8[$_pre_phi] = 0; //@line 21044
 _trm_update(HEAP32[$1 >> 2] | 0); //@line 21046
 STACKTOP = sp; //@line 21048
 return;
}
function _mac_video_clock($mv, $n) {
 $mv = $mv | 0;
 $n = $n | 0;
 var $1 = 0, $2 = 0, $3 = 0, $8 = 0, $13 = 0, $18 = 0, $21 = 0, $26 = 0, $31 = 0;
 $1 = $mv + 40 | 0; //@line 21062
 $2 = HEAP32[$1 >> 2] | 0; //@line 21063
 $3 = $2 + $n | 0; //@line 21064
 HEAP32[$1 >> 2] = $3; //@line 21065
 if ($3 >>> 0 < 120384) {
  return;
 }
 do {
  if ($2 >>> 0 < 120384) {
   _mac_video_update($mv); //@line 21076
   $8 = $mv + 48 | 0; //@line 21077
   if ((HEAP8[$8] | 0) == 1) {
    break;
   }
   HEAP8[$8] = 1; //@line 21084
   $13 = HEAP32[$mv + 56 >> 2] | 0; //@line 21086
   if (($13 | 0) == 0) {
    break;
   }
   FUNCTION_TABLE_vii[$13 & 511](HEAP32[$mv + 52 >> 2] | 0, 1); //@line 21094
  }
 } while (0);
 $18 = HEAP32[$1 >> 2] | 0; //@line 21098
 if ($18 >>> 0 <= 130239) {
  return;
 }
 $21 = $mv + 48 | 0; //@line 21105
 do {
  if ((HEAP8[$21] | 0) == 0) {
   $31 = $18; //@line 21111
  } else {
   HEAP8[$21] = 0; //@line 21113
   $26 = HEAP32[$mv + 56 >> 2] | 0; //@line 21115
   if (($26 | 0) == 0) {
    $31 = $18; //@line 21119
    break;
   }
   FUNCTION_TABLE_vii[$26 & 511](HEAP32[$mv + 52 >> 2] | 0, 0); //@line 21124
   $31 = HEAP32[$1 >> 2] | 0; //@line 21127
  }
 } while (0);
 HEAP32[$1 >> 2] = $31 - 130240; //@line 21132
 return;
}
function _e68_dasm_mem($c, $da, $pc) {
 $c = $c | 0;
 $da = $da | 0;
 $pc = $pc | 0;
 var $src = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $i_07 = 0, $6 = 0, $_0_i = 0, $21 = 0, $25 = 0, $29 = 0, $33 = 0, $i_018_i = 0, $43 = 0, sp = 0;
 sp = STACKTOP; //@line 21152
 STACKTOP = STACKTOP + 16 | 0; //@line 21152
 $src = sp | 0; //@line 21153
 $1 = $c + 36 | 0; //@line 21154
 $2 = $c + 32 | 0; //@line 21155
 $3 = $c + 8 | 0; //@line 21156
 $4 = $c + 4 | 0; //@line 21157
 $i_07 = 0; //@line 21159
 do {
  $6 = $i_07 + $pc & 16777215; //@line 21163
  if ($6 >>> 0 < (HEAP32[$1 >> 2] | 0) >>> 0) {
   $_0_i = HEAP8[(HEAP32[$2 >> 2] | 0) + $6 | 0] | 0; //@line 21172
  } else {
   $_0_i = FUNCTION_TABLE_iii[HEAP32[$3 >> 2] & 63](HEAP32[$4 >> 2] | 0, $6) | 0; //@line 21178
  }
  HEAP8[$src + $i_07 | 0] = $_0_i; //@line 21182
  $i_07 = $i_07 + 1 | 0; //@line 21183
 } while ($i_07 >>> 0 < 16);
 $21 = $src | 0; //@line 21192
 HEAP32[$da >> 2] = 0; //@line 21194
 HEAP32[$da + 4 >> 2] = $pc; //@line 21196
 HEAP8[$da + 288 | 0] = 0; //@line 21198
 $25 = HEAP8[$21] | 0; //@line 21199
 $29 = HEAP8[$src + 1 | 0] | 0; //@line 21203
 HEAP16[$da + 12 >> 1] = ($25 & 255) << 8 | $29 & 255; //@line 21207
 $33 = $da + 8 | 0; //@line 21208
 HEAP32[$33 >> 2] = 1; //@line 21209
 FUNCTION_TABLE_vii[HEAP32[20824 + ((($29 & 255) >>> 6 | ($25 & 255) << 2) << 2) >> 2] & 511]($da, $21); //@line 21217
 if ((HEAP32[$33 >> 2] | 0) == 0) {
  STACKTOP = sp; //@line 21222
  return;
 } else {
  $i_018_i = 0; //@line 21225
 }
 do {
  $43 = $i_018_i << 1; //@line 21229
  HEAP16[$da + 12 + ($i_018_i << 1) >> 1] = (HEAPU8[$src + $43 | 0] | 0) << 8 | (HEAPU8[$src + ($43 | 1) | 0] | 0); //@line 21240
  $i_018_i = $i_018_i + 1 | 0; //@line 21241
 } while ($i_018_i >>> 0 < (HEAP32[$33 >> 2] | 0) >>> 0);
 STACKTOP = sp; //@line 21251
 return;
}
function _d_0000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $5 = 0, $10 = 0, $12 = 0, $15 = 0, $17 = 0, sp = 0;
 sp = STACKTOP; //@line 21263
 $4 = (HEAP16[$da + 12 >> 1] & 63) == 60; //@line 21267
 $5 = $da + 32 | 0; //@line 21268
 HEAP8[$5] = HEAP8[47648] | 0; //@line 21269
 HEAP8[$5 + 1 | 0] = HEAP8[47649 | 0] | 0; //@line 21269
 HEAP8[$5 + 2 | 0] = HEAP8[47650 | 0] | 0; //@line 21269
 HEAP8[$5 + 3 | 0] = HEAP8[47651 | 0] | 0; //@line 21269
 HEAP8[$5 + 4 | 0] = HEAP8[47652 | 0] | 0; //@line 21269
 HEAP8[$5 + 5 | 0] = HEAP8[47653 | 0] | 0; //@line 21269
 HEAP32[$da + 28 >> 2] = 2; //@line 21271
 $10 = HEAPU8[$src + 3 | 0] | 0; //@line 21275
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $10, tempInt) | 0) | 0; //@line 21276
 $12 = $da + 8 | 0; //@line 21277
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 1; //@line 21280
 $15 = $da + 160 | 0; //@line 21281
 if ($4) {
  $17 = $15; //@line 21284
  tempBigInt = 5391171; //@line 21285
  HEAP8[$17] = tempBigInt & 255; //@line 21285
  tempBigInt = tempBigInt >> 8; //@line 21285
  HEAP8[$17 + 1 | 0] = tempBigInt & 255; //@line 21285
  tempBigInt = tempBigInt >> 8; //@line 21285
  HEAP8[$17 + 2 | 0] = tempBigInt & 255; //@line 21285
  tempBigInt = tempBigInt >> 8; //@line 21285
  HEAP8[$17 + 3 | 0] = tempBigInt & 255; //@line 21285
  STACKTOP = sp; //@line 21287
  return;
 } else {
  _dasm_ea($da, $15, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21294
  STACKTOP = sp; //@line 21295
  return;
 }
}
function _d_0040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $5 = 0, $16 = 0, $18 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 21309
 $4 = (HEAP16[$da + 12 >> 1] & 63) == 60; //@line 21313
 $5 = $da + 32 | 0; //@line 21314
 HEAP8[$5] = HEAP8[47680] | 0; //@line 21315
 HEAP8[$5 + 1 | 0] = HEAP8[47681 | 0] | 0; //@line 21315
 HEAP8[$5 + 2 | 0] = HEAP8[47682 | 0] | 0; //@line 21315
 HEAP8[$5 + 3 | 0] = HEAP8[47683 | 0] | 0; //@line 21315
 HEAP8[$5 + 4 | 0] = HEAP8[47684 | 0] | 0; //@line 21315
 HEAP8[$5 + 5 | 0] = HEAP8[47685 | 0] | 0; //@line 21315
 HEAP32[$da + 28 >> 2] = 2; //@line 21317
 $16 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 21327
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $16, tempInt) | 0) | 0; //@line 21328
 $18 = $da + 8 | 0; //@line 21329
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 1; //@line 21332
 $21 = $da + 160 | 0; //@line 21333
 if ($4) {
  HEAP8[$21] = HEAP8[51464] | 0; //@line 21336
  HEAP8[$21 + 1 | 0] = HEAP8[51465 | 0] | 0; //@line 21336
  HEAP8[$21 + 2 | 0] = HEAP8[51466 | 0] | 0; //@line 21336
  $23 = $da | 0; //@line 21337
  HEAP32[$23 >> 2] = HEAP32[$23 >> 2] | 1; //@line 21340
  STACKTOP = sp; //@line 21342
  return;
 } else {
  _dasm_ea($da, $21, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 21349
  STACKTOP = sp; //@line 21350
  return;
 }
}
function _d_0080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 21364
 $1 = $da + 32 | 0; //@line 21365
 HEAP8[$1] = HEAP8[47704] | 0; //@line 21366
 HEAP8[$1 + 1 | 0] = HEAP8[47705 | 0] | 0; //@line 21366
 HEAP8[$1 + 2 | 0] = HEAP8[47706 | 0] | 0; //@line 21366
 HEAP8[$1 + 3 | 0] = HEAP8[47707 | 0] | 0; //@line 21366
 HEAP8[$1 + 4 | 0] = HEAP8[47708 | 0] | 0; //@line 21366
 HEAP8[$1 + 5 | 0] = HEAP8[47709 | 0] | 0; //@line 21366
 HEAP32[$da + 28 >> 2] = 2; //@line 21368
 $21 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 21387
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 21388
 $23 = $da + 8 | 0; //@line 21389
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 21392
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 21398
 STACKTOP = sp; //@line 21399
 return;
}
function _d_00c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $9 = 0, $17 = 0, $20 = 0, $23 = 0, $25 = 0, $34 = 0, $37 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $47 = 0, sp = 0;
 sp = STACKTOP; //@line 21414
 $1 = $da + 8 | 0; //@line 21415
 $2 = HEAP32[$1 >> 2] | 0; //@line 21416
 $5 = HEAP8[$src + ($2 << 1) | 0] | 0; //@line 21419
 HEAP32[$1 >> 2] = $2 + 1; //@line 21421
 $9 = $da + 32 | 0; //@line 21424
 if (($5 & 8) == 0) {
  HEAP8[$9] = HEAP8[47728] | 0; //@line 21427
  HEAP8[$9 + 1 | 0] = HEAP8[47729 | 0] | 0; //@line 21427
  HEAP8[$9 + 2 | 0] = HEAP8[47730 | 0] | 0; //@line 21427
  HEAP8[$9 + 3 | 0] = HEAP8[47731 | 0] | 0; //@line 21427
  HEAP8[$9 + 4 | 0] = HEAP8[47732 | 0] | 0; //@line 21427
  HEAP8[$9 + 5 | 0] = HEAP8[47733 | 0] | 0; //@line 21427
  HEAP8[$9 + 6 | 0] = HEAP8[47734 | 0] | 0; //@line 21427
  HEAP32[$da + 28 >> 2] = 2; //@line 21429
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21435
  $34 = $da + 160 | 0; //@line 21436
  $37 = HEAPU8[$src + 2 | 0] | 0; //@line 21439
  $40 = ($37 & 128 | 0) != 0 ? 34768 : 32184; //@line 21442
  $42 = $37 >>> 4 & 7; //@line 21444
  _sprintf($34 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $40, HEAP32[tempInt + 8 >> 2] = $42, tempInt) | 0) | 0; //@line 21445
  $45 = $da | 0; //@line 21446
  $46 = HEAP32[$45 >> 2] | 0; //@line 21447
  $47 = $46 | 128; //@line 21448
  HEAP32[$45 >> 2] = $47; //@line 21449
  STACKTOP = sp; //@line 21450
  return;
 } else {
  HEAP8[$9] = HEAP8[47760] | 0; //@line 21453
  HEAP8[$9 + 1 | 0] = HEAP8[47761 | 0] | 0; //@line 21453
  HEAP8[$9 + 2 | 0] = HEAP8[47762 | 0] | 0; //@line 21453
  HEAP8[$9 + 3 | 0] = HEAP8[47763 | 0] | 0; //@line 21453
  HEAP8[$9 + 4 | 0] = HEAP8[47764 | 0] | 0; //@line 21453
  HEAP8[$9 + 5 | 0] = HEAP8[47765 | 0] | 0; //@line 21453
  HEAP8[$9 + 6 | 0] = HEAP8[47766 | 0] | 0; //@line 21453
  HEAP32[$da + 28 >> 2] = 2; //@line 21455
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21461
  $17 = $da + 160 | 0; //@line 21462
  $20 = HEAPU8[$src + 2 | 0] | 0; //@line 21465
  $23 = ($20 & 128 | 0) != 0 ? 34768 : 32184; //@line 21468
  $25 = $20 >>> 4 & 7; //@line 21470
  _sprintf($17 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $23, HEAP32[tempInt + 8 >> 2] = $25, tempInt) | 0) | 0; //@line 21471
  $45 = $da | 0; //@line 21473
  $46 = HEAP32[$45 >> 2] | 0; //@line 21474
  $47 = $46 | 128; //@line 21475
  HEAP32[$45 >> 2] = $47; //@line 21476
  STACKTOP = sp; //@line 21477
  return;
 }
}
function _d_0100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $4 = 0, $6 = 0, $st$1$0 = 0, $st$2$1 = 0, $8 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $26 = 0, $29 = 0, $33 = 0, $37 = 0, $41 = 0, sp = 0;
 sp = STACKTOP; //@line 21494
 $2 = HEAP16[$da + 12 >> 1] | 0; //@line 21496
 $4 = $da + 32 | 0; //@line 21499
 if (($2 & 56) == 8) {
  $6 = $4; //@line 21502
  $st$1$0 = $6 | 0; //@line 21505
  tempBigInt = 1163284301; //@line 21506
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 21506
  tempBigInt = tempBigInt >> 8; //@line 21506
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 21506
  tempBigInt = tempBigInt >> 8; //@line 21506
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 21506
  tempBigInt = tempBigInt >> 8; //@line 21506
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 21506
  $st$2$1 = $6 + 4 | 0; //@line 21507
  tempBigInt = 5713488; //@line 21508
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 21508
  tempBigInt = tempBigInt >> 8; //@line 21508
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 21508
  tempBigInt = tempBigInt >> 8; //@line 21508
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 21508
  tempBigInt = tempBigInt >> 8; //@line 21508
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 21508
  HEAP32[$da + 28 >> 2] = 2; //@line 21510
  $8 = $da + 96 | 0; //@line 21511
  $17 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 21520
  $19 = ($17 & 32768 | 0) != 0; //@line 21522
  $20 = $19 ? 56344 : 62888; //@line 21523
  $22 = ($19 ? -$17 | 0 : $17) & 65535; //@line 21526
  $24 = $2 & 7; //@line 21528
  _sprintf($8 | 0, 57472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $20, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $22, HEAP32[tempInt + 24 >> 2] = $24, tempInt) | 0) | 0; //@line 21529
  $26 = $da + 8 | 0; //@line 21530
  HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 1; //@line 21533
  $29 = $da + 160 | 0; //@line 21534
  $33 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21538
  _sprintf($29 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $33, tempInt) | 0) | 0; //@line 21539
  STACKTOP = sp; //@line 21541
  return;
 } else {
  HEAP8[$4] = HEAP8[48320] | 0; //@line 21544
  HEAP8[$4 + 1 | 0] = HEAP8[48321 | 0] | 0; //@line 21544
  HEAP8[$4 + 2 | 0] = HEAP8[48322 | 0] | 0; //@line 21544
  HEAP8[$4 + 3 | 0] = HEAP8[48323 | 0] | 0; //@line 21544
  HEAP8[$4 + 4 | 0] = HEAP8[48324 | 0] | 0; //@line 21544
  HEAP32[$da + 28 >> 2] = 2; //@line 21546
  $37 = $da + 96 | 0; //@line 21547
  $41 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21551
  _sprintf($37 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $41, tempInt) | 0) | 0; //@line 21552
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21558
  STACKTOP = sp; //@line 21560
  return;
 }
}
function _d_0140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $4 = 0, $6 = 0, $st$1$0 = 0, $st$2$1 = 0, $8 = 0, $17 = 0, $19 = 0, $20 = 0, $22 = 0, $24 = 0, $26 = 0, $29 = 0, $33 = 0, $37 = 0, $41 = 0, sp = 0;
 sp = STACKTOP; //@line 21577
 $2 = HEAP16[$da + 12 >> 1] | 0; //@line 21579
 $4 = $da + 32 | 0; //@line 21582
 if (($2 & 56) == 8) {
  $6 = $4; //@line 21585
  $st$1$0 = $6 | 0; //@line 21588
  tempBigInt = 1163284301; //@line 21589
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 21589
  tempBigInt = tempBigInt >> 8; //@line 21589
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 21589
  tempBigInt = tempBigInt >> 8; //@line 21589
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 21589
  tempBigInt = tempBigInt >> 8; //@line 21589
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 21589
  $st$2$1 = $6 + 4 | 0; //@line 21590
  tempBigInt = 4992592; //@line 21591
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 21591
  tempBigInt = tempBigInt >> 8; //@line 21591
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 21591
  tempBigInt = tempBigInt >> 8; //@line 21591
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 21591
  tempBigInt = tempBigInt >> 8; //@line 21591
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 21591
  HEAP32[$da + 28 >> 2] = 2; //@line 21593
  $8 = $da + 96 | 0; //@line 21594
  $17 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 21603
  $19 = ($17 & 32768 | 0) != 0; //@line 21605
  $20 = $19 ? 56344 : 62888; //@line 21606
  $22 = ($19 ? -$17 | 0 : $17) & 65535; //@line 21609
  $24 = $2 & 7; //@line 21611
  _sprintf($8 | 0, 57472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $20, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $22, HEAP32[tempInt + 24 >> 2] = $24, tempInt) | 0) | 0; //@line 21612
  $26 = $da + 8 | 0; //@line 21613
  HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 1; //@line 21616
  $29 = $da + 160 | 0; //@line 21617
  $33 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21621
  _sprintf($29 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $33, tempInt) | 0) | 0; //@line 21622
  STACKTOP = sp; //@line 21624
  return;
 } else {
  HEAP8[$4] = HEAP8[48368] | 0; //@line 21627
  HEAP8[$4 + 1 | 0] = HEAP8[48369 | 0] | 0; //@line 21627
  HEAP8[$4 + 2 | 0] = HEAP8[48370 | 0] | 0; //@line 21627
  HEAP8[$4 + 3 | 0] = HEAP8[48371 | 0] | 0; //@line 21627
  HEAP8[$4 + 4 | 0] = HEAP8[48372 | 0] | 0; //@line 21627
  HEAP32[$da + 28 >> 2] = 2; //@line 21629
  $37 = $da + 96 | 0; //@line 21630
  $41 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21634
  _sprintf($37 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $41, tempInt) | 0) | 0; //@line 21635
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21641
  STACKTOP = sp; //@line 21643
  return;
 }
}
function _d_0180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $4 = 0, $6 = 0, $st$1$0 = 0, $st$2$1 = 0, $8 = 0, $12 = 0, $14 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $31 = 0, $33 = 0, $38 = 0, $42 = 0, sp = 0;
 sp = STACKTOP; //@line 21660
 $1 = $da + 12 | 0; //@line 21661
 $4 = $da + 32 | 0; //@line 21665
 if ((HEAP16[$1 >> 1] & 56) == 8) {
  $6 = $4; //@line 21668
  $st$1$0 = $6 | 0; //@line 21671
  tempBigInt = 1163284301; //@line 21672
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 21672
  tempBigInt = tempBigInt >> 8; //@line 21672
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 21672
  tempBigInt = tempBigInt >> 8; //@line 21672
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 21672
  tempBigInt = tempBigInt >> 8; //@line 21672
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 21672
  $st$2$1 = $6 + 4 | 0; //@line 21673
  tempBigInt = 5713488; //@line 21674
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 21674
  tempBigInt = tempBigInt >> 8; //@line 21674
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 21674
  tempBigInt = tempBigInt >> 8; //@line 21674
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 21674
  tempBigInt = tempBigInt >> 8; //@line 21674
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 21674
  HEAP32[$da + 28 >> 2] = 2; //@line 21676
  $8 = $da + 96 | 0; //@line 21677
  $12 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21681
  _sprintf($8 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $12, tempInt) | 0) | 0; //@line 21682
  $14 = $da + 160 | 0; //@line 21683
  $23 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 21692
  $25 = ($23 & 32768 | 0) != 0; //@line 21694
  $26 = $25 ? 56344 : 62888; //@line 21695
  $28 = ($25 ? -$23 | 0 : $23) & 65535; //@line 21698
  $31 = HEAP16[$1 >> 1] & 7; //@line 21701
  _sprintf($14 | 0, 57472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $26, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $28, HEAP32[tempInt + 24 >> 2] = $31, tempInt) | 0) | 0; //@line 21702
  $33 = $da + 8 | 0; //@line 21703
  HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 1; //@line 21706
  STACKTOP = sp; //@line 21708
  return;
 } else {
  HEAP8[$4] = HEAP8[48392] | 0; //@line 21711
  HEAP8[$4 + 1 | 0] = HEAP8[48393 | 0] | 0; //@line 21711
  HEAP8[$4 + 2 | 0] = HEAP8[48394 | 0] | 0; //@line 21711
  HEAP8[$4 + 3 | 0] = HEAP8[48395 | 0] | 0; //@line 21711
  HEAP8[$4 + 4 | 0] = HEAP8[48396 | 0] | 0; //@line 21711
  HEAP32[$da + 28 >> 2] = 2; //@line 21713
  $38 = $da + 96 | 0; //@line 21714
  $42 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21718
  _sprintf($38 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $42, tempInt) | 0) | 0; //@line 21719
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21725
  STACKTOP = sp; //@line 21727
  return;
 }
}
function _d_01c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $4 = 0, $6 = 0, $st$1$0 = 0, $st$2$1 = 0, $8 = 0, $12 = 0, $14 = 0, $23 = 0, $25 = 0, $26 = 0, $28 = 0, $31 = 0, $33 = 0, $38 = 0, $42 = 0, sp = 0;
 sp = STACKTOP; //@line 21744
 $1 = $da + 12 | 0; //@line 21745
 $4 = $da + 32 | 0; //@line 21749
 if ((HEAP16[$1 >> 1] & 56) == 8) {
  $6 = $4; //@line 21752
  $st$1$0 = $6 | 0; //@line 21755
  tempBigInt = 1163284301; //@line 21756
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 21756
  tempBigInt = tempBigInt >> 8; //@line 21756
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 21756
  tempBigInt = tempBigInt >> 8; //@line 21756
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 21756
  tempBigInt = tempBigInt >> 8; //@line 21756
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 21756
  $st$2$1 = $6 + 4 | 0; //@line 21757
  tempBigInt = 4992592; //@line 21758
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 21758
  tempBigInt = tempBigInt >> 8; //@line 21758
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 21758
  tempBigInt = tempBigInt >> 8; //@line 21758
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 21758
  tempBigInt = tempBigInt >> 8; //@line 21758
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 21758
  HEAP32[$da + 28 >> 2] = 2; //@line 21760
  $8 = $da + 96 | 0; //@line 21761
  $12 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21765
  _sprintf($8 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $12, tempInt) | 0) | 0; //@line 21766
  $14 = $da + 160 | 0; //@line 21767
  $23 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 21776
  $25 = ($23 & 32768 | 0) != 0; //@line 21778
  $26 = $25 ? 56344 : 62888; //@line 21779
  $28 = ($25 ? -$23 | 0 : $23) & 65535; //@line 21782
  $31 = HEAP16[$1 >> 1] & 7; //@line 21785
  _sprintf($14 | 0, 57472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $26, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $28, HEAP32[tempInt + 24 >> 2] = $31, tempInt) | 0) | 0; //@line 21786
  $33 = $da + 8 | 0; //@line 21787
  HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 1; //@line 21790
  STACKTOP = sp; //@line 21792
  return;
 } else {
  HEAP8[$4] = HEAP8[48416] | 0; //@line 21795
  HEAP8[$4 + 1 | 0] = HEAP8[48417 | 0] | 0; //@line 21795
  HEAP8[$4 + 2 | 0] = HEAP8[48418 | 0] | 0; //@line 21795
  HEAP8[$4 + 3 | 0] = HEAP8[48419 | 0] | 0; //@line 21795
  HEAP8[$4 + 4 | 0] = HEAP8[48420 | 0] | 0; //@line 21795
  HEAP32[$da + 28 >> 2] = 2; //@line 21797
  $38 = $da + 96 | 0; //@line 21798
  $42 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 21802
  _sprintf($38 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $42, tempInt) | 0) | 0; //@line 21803
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21809
  STACKTOP = sp; //@line 21811
  return;
 }
}
function _d_0200($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $5 = 0, $10 = 0, $12 = 0, $15 = 0, $17 = 0, sp = 0;
 sp = STACKTOP; //@line 21824
 $4 = (HEAP16[$da + 12 >> 1] & 63) == 60; //@line 21828
 $5 = $da + 32 | 0; //@line 21829
 HEAP8[$5] = HEAP8[47800] | 0; //@line 21830
 HEAP8[$5 + 1 | 0] = HEAP8[47801 | 0] | 0; //@line 21830
 HEAP8[$5 + 2 | 0] = HEAP8[47802 | 0] | 0; //@line 21830
 HEAP8[$5 + 3 | 0] = HEAP8[47803 | 0] | 0; //@line 21830
 HEAP8[$5 + 4 | 0] = HEAP8[47804 | 0] | 0; //@line 21830
 HEAP8[$5 + 5 | 0] = HEAP8[47805 | 0] | 0; //@line 21830
 HEAP8[$5 + 6 | 0] = HEAP8[47806 | 0] | 0; //@line 21830
 HEAP32[$da + 28 >> 2] = 2; //@line 21832
 $10 = HEAPU8[$src + 3 | 0] | 0; //@line 21836
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $10, tempInt) | 0) | 0; //@line 21837
 $12 = $da + 8 | 0; //@line 21838
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 1; //@line 21841
 $15 = $da + 160 | 0; //@line 21842
 if ($4) {
  $17 = $15; //@line 21845
  tempBigInt = 5391171; //@line 21846
  HEAP8[$17] = tempBigInt & 255; //@line 21846
  tempBigInt = tempBigInt >> 8; //@line 21846
  HEAP8[$17 + 1 | 0] = tempBigInt & 255; //@line 21846
  tempBigInt = tempBigInt >> 8; //@line 21846
  HEAP8[$17 + 2 | 0] = tempBigInt & 255; //@line 21846
  tempBigInt = tempBigInt >> 8; //@line 21846
  HEAP8[$17 + 3 | 0] = tempBigInt & 255; //@line 21846
  STACKTOP = sp; //@line 21848
  return;
 } else {
  _dasm_ea($da, $15, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 21855
  STACKTOP = sp; //@line 21856
  return;
 }
}
function _d_0240($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $5 = 0, $16 = 0, $18 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 21870
 $4 = (HEAP16[$da + 12 >> 1] & 63) == 60; //@line 21874
 $5 = $da + 32 | 0; //@line 21875
 HEAP8[$5] = HEAP8[47816] | 0; //@line 21876
 HEAP8[$5 + 1 | 0] = HEAP8[47817 | 0] | 0; //@line 21876
 HEAP8[$5 + 2 | 0] = HEAP8[47818 | 0] | 0; //@line 21876
 HEAP8[$5 + 3 | 0] = HEAP8[47819 | 0] | 0; //@line 21876
 HEAP8[$5 + 4 | 0] = HEAP8[47820 | 0] | 0; //@line 21876
 HEAP8[$5 + 5 | 0] = HEAP8[47821 | 0] | 0; //@line 21876
 HEAP8[$5 + 6 | 0] = HEAP8[47822 | 0] | 0; //@line 21876
 HEAP32[$da + 28 >> 2] = 2; //@line 21878
 $16 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 21888
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $16, tempInt) | 0) | 0; //@line 21889
 $18 = $da + 8 | 0; //@line 21890
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 1; //@line 21893
 $21 = $da + 160 | 0; //@line 21894
 if ($4) {
  HEAP8[$21] = HEAP8[51464] | 0; //@line 21897
  HEAP8[$21 + 1 | 0] = HEAP8[51465 | 0] | 0; //@line 21897
  HEAP8[$21 + 2 | 0] = HEAP8[51466 | 0] | 0; //@line 21897
  $23 = $da | 0; //@line 21898
  HEAP32[$23 >> 2] = HEAP32[$23 >> 2] | 1; //@line 21901
  STACKTOP = sp; //@line 21903
  return;
 } else {
  _dasm_ea($da, $21, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 21910
  STACKTOP = sp; //@line 21911
  return;
 }
}
function _d_0280($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 21925
 $1 = $da + 32 | 0; //@line 21926
 HEAP8[$1] = HEAP8[47880] | 0; //@line 21927
 HEAP8[$1 + 1 | 0] = HEAP8[47881 | 0] | 0; //@line 21927
 HEAP8[$1 + 2 | 0] = HEAP8[47882 | 0] | 0; //@line 21927
 HEAP8[$1 + 3 | 0] = HEAP8[47883 | 0] | 0; //@line 21927
 HEAP8[$1 + 4 | 0] = HEAP8[47884 | 0] | 0; //@line 21927
 HEAP8[$1 + 5 | 0] = HEAP8[47885 | 0] | 0; //@line 21927
 HEAP8[$1 + 6 | 0] = HEAP8[47886 | 0] | 0; //@line 21927
 HEAP32[$da + 28 >> 2] = 2; //@line 21929
 $21 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 21948
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 21949
 $23 = $da + 8 | 0; //@line 21950
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 21953
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 21959
 STACKTOP = sp; //@line 21960
 return;
}
function _d_02c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $9 = 0, $17 = 0, $20 = 0, $23 = 0, $25 = 0, $34 = 0, $37 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $47 = 0, sp = 0;
 sp = STACKTOP; //@line 21975
 $1 = $da + 8 | 0; //@line 21976
 $2 = HEAP32[$1 >> 2] | 0; //@line 21977
 $5 = HEAP8[$src + ($2 << 1) | 0] | 0; //@line 21980
 HEAP32[$1 >> 2] = $2 + 1; //@line 21982
 $9 = $da + 32 | 0; //@line 21985
 if (($5 & 8) == 0) {
  HEAP8[$9] = HEAP8[47952] | 0; //@line 21988
  HEAP8[$9 + 1 | 0] = HEAP8[47953 | 0] | 0; //@line 21988
  HEAP8[$9 + 2 | 0] = HEAP8[47954 | 0] | 0; //@line 21988
  HEAP8[$9 + 3 | 0] = HEAP8[47955 | 0] | 0; //@line 21988
  HEAP8[$9 + 4 | 0] = HEAP8[47956 | 0] | 0; //@line 21988
  HEAP8[$9 + 5 | 0] = HEAP8[47957 | 0] | 0; //@line 21988
  HEAP8[$9 + 6 | 0] = HEAP8[47958 | 0] | 0; //@line 21988
  HEAP32[$da + 28 >> 2] = 2; //@line 21990
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 21996
  $34 = $da + 160 | 0; //@line 21997
  $37 = HEAPU8[$src + 2 | 0] | 0; //@line 22000
  $40 = ($37 & 128 | 0) != 0 ? 34768 : 32184; //@line 22003
  $42 = $37 >>> 4 & 7; //@line 22005
  _sprintf($34 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $40, HEAP32[tempInt + 8 >> 2] = $42, tempInt) | 0) | 0; //@line 22006
  $45 = $da | 0; //@line 22007
  $46 = HEAP32[$45 >> 2] | 0; //@line 22008
  $47 = $46 | 128; //@line 22009
  HEAP32[$45 >> 2] = $47; //@line 22010
  STACKTOP = sp; //@line 22011
  return;
 } else {
  HEAP8[$9] = HEAP8[47984] | 0; //@line 22014
  HEAP8[$9 + 1 | 0] = HEAP8[47985 | 0] | 0; //@line 22014
  HEAP8[$9 + 2 | 0] = HEAP8[47986 | 0] | 0; //@line 22014
  HEAP8[$9 + 3 | 0] = HEAP8[47987 | 0] | 0; //@line 22014
  HEAP8[$9 + 4 | 0] = HEAP8[47988 | 0] | 0; //@line 22014
  HEAP8[$9 + 5 | 0] = HEAP8[47989 | 0] | 0; //@line 22014
  HEAP8[$9 + 6 | 0] = HEAP8[47990 | 0] | 0; //@line 22014
  HEAP32[$da + 28 >> 2] = 2; //@line 22016
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22022
  $17 = $da + 160 | 0; //@line 22023
  $20 = HEAPU8[$src + 2 | 0] | 0; //@line 22026
  $23 = ($20 & 128 | 0) != 0 ? 34768 : 32184; //@line 22029
  $25 = $20 >>> 4 & 7; //@line 22031
  _sprintf($17 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $23, HEAP32[tempInt + 8 >> 2] = $25, tempInt) | 0) | 0; //@line 22032
  $45 = $da | 0; //@line 22034
  $46 = HEAP32[$45 >> 2] | 0; //@line 22035
  $47 = $46 | 128; //@line 22036
  HEAP32[$45 >> 2] = $47; //@line 22037
  STACKTOP = sp; //@line 22038
  return;
 }
}
function _d_0400($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22050
 $1 = $da + 32 | 0; //@line 22051
 HEAP8[$1] = HEAP8[48e3] | 0; //@line 22052
 HEAP8[$1 + 1 | 0] = HEAP8[48001 | 0] | 0; //@line 22052
 HEAP8[$1 + 2 | 0] = HEAP8[48002 | 0] | 0; //@line 22052
 HEAP8[$1 + 3 | 0] = HEAP8[48003 | 0] | 0; //@line 22052
 HEAP8[$1 + 4 | 0] = HEAP8[48004 | 0] | 0; //@line 22052
 HEAP8[$1 + 5 | 0] = HEAP8[48005 | 0] | 0; //@line 22052
 HEAP8[$1 + 6 | 0] = HEAP8[48006 | 0] | 0; //@line 22052
 HEAP32[$da + 28 >> 2] = 2; //@line 22054
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22058
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22059
 $8 = $da + 8 | 0; //@line 22060
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22063
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22069
 STACKTOP = sp; //@line 22070
 return;
}
function _d_0440($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $12 = 0, $14 = 0, sp = 0;
 sp = STACKTOP; //@line 22082
 $1 = $da + 32 | 0; //@line 22083
 HEAP8[$1] = HEAP8[48024] | 0; //@line 22084
 HEAP8[$1 + 1 | 0] = HEAP8[48025 | 0] | 0; //@line 22084
 HEAP8[$1 + 2 | 0] = HEAP8[48026 | 0] | 0; //@line 22084
 HEAP8[$1 + 3 | 0] = HEAP8[48027 | 0] | 0; //@line 22084
 HEAP8[$1 + 4 | 0] = HEAP8[48028 | 0] | 0; //@line 22084
 HEAP8[$1 + 5 | 0] = HEAP8[48029 | 0] | 0; //@line 22084
 HEAP8[$1 + 6 | 0] = HEAP8[48030 | 0] | 0; //@line 22084
 HEAP32[$da + 28 >> 2] = 2; //@line 22086
 $12 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 22096
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $12, tempInt) | 0) | 0; //@line 22097
 $14 = $da + 8 | 0; //@line 22098
 HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 1; //@line 22101
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22107
 STACKTOP = sp; //@line 22108
 return;
}
function _d_0480($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 22121
 $1 = $da + 32 | 0; //@line 22122
 HEAP8[$1] = HEAP8[48048] | 0; //@line 22123
 HEAP8[$1 + 1 | 0] = HEAP8[48049 | 0] | 0; //@line 22123
 HEAP8[$1 + 2 | 0] = HEAP8[48050 | 0] | 0; //@line 22123
 HEAP8[$1 + 3 | 0] = HEAP8[48051 | 0] | 0; //@line 22123
 HEAP8[$1 + 4 | 0] = HEAP8[48052 | 0] | 0; //@line 22123
 HEAP8[$1 + 5 | 0] = HEAP8[48053 | 0] | 0; //@line 22123
 HEAP8[$1 + 6 | 0] = HEAP8[48054 | 0] | 0; //@line 22123
 HEAP32[$da + 28 >> 2] = 2; //@line 22125
 $21 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 22144
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 22145
 $23 = $da + 8 | 0; //@line 22146
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 22149
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22155
 STACKTOP = sp; //@line 22156
 return;
}
function _d_04c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $9 = 0, $17 = 0, $20 = 0, $23 = 0, $25 = 0, $34 = 0, $37 = 0, $40 = 0, $42 = 0, $45 = 0, $46 = 0, $47 = 0, sp = 0;
 sp = STACKTOP; //@line 22171
 $1 = $da + 8 | 0; //@line 22172
 $2 = HEAP32[$1 >> 2] | 0; //@line 22173
 $5 = HEAP8[$src + ($2 << 1) | 0] | 0; //@line 22176
 HEAP32[$1 >> 2] = $2 + 1; //@line 22178
 $9 = $da + 32 | 0; //@line 22181
 if (($5 & 8) == 0) {
  HEAP8[$9] = HEAP8[48064] | 0; //@line 22184
  HEAP8[$9 + 1 | 0] = HEAP8[48065 | 0] | 0; //@line 22184
  HEAP8[$9 + 2 | 0] = HEAP8[48066 | 0] | 0; //@line 22184
  HEAP8[$9 + 3 | 0] = HEAP8[48067 | 0] | 0; //@line 22184
  HEAP8[$9 + 4 | 0] = HEAP8[48068 | 0] | 0; //@line 22184
  HEAP8[$9 + 5 | 0] = HEAP8[48069 | 0] | 0; //@line 22184
  HEAP8[$9 + 6 | 0] = HEAP8[48070 | 0] | 0; //@line 22184
  HEAP32[$da + 28 >> 2] = 2; //@line 22186
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22192
  $34 = $da + 160 | 0; //@line 22193
  $37 = HEAPU8[$src + 2 | 0] | 0; //@line 22196
  $40 = ($37 & 128 | 0) != 0 ? 34768 : 32184; //@line 22199
  $42 = $37 >>> 4 & 7; //@line 22201
  _sprintf($34 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $40, HEAP32[tempInt + 8 >> 2] = $42, tempInt) | 0) | 0; //@line 22202
  $45 = $da | 0; //@line 22203
  $46 = HEAP32[$45 >> 2] | 0; //@line 22204
  $47 = $46 | 128; //@line 22205
  HEAP32[$45 >> 2] = $47; //@line 22206
  STACKTOP = sp; //@line 22207
  return;
 } else {
  HEAP8[$9] = HEAP8[48096] | 0; //@line 22210
  HEAP8[$9 + 1 | 0] = HEAP8[48097 | 0] | 0; //@line 22210
  HEAP8[$9 + 2 | 0] = HEAP8[48098 | 0] | 0; //@line 22210
  HEAP8[$9 + 3 | 0] = HEAP8[48099 | 0] | 0; //@line 22210
  HEAP8[$9 + 4 | 0] = HEAP8[48100 | 0] | 0; //@line 22210
  HEAP8[$9 + 5 | 0] = HEAP8[48101 | 0] | 0; //@line 22210
  HEAP8[$9 + 6 | 0] = HEAP8[48102 | 0] | 0; //@line 22210
  HEAP32[$da + 28 >> 2] = 2; //@line 22212
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22218
  $17 = $da + 160 | 0; //@line 22219
  $20 = HEAPU8[$src + 2 | 0] | 0; //@line 22222
  $23 = ($20 & 128 | 0) != 0 ? 34768 : 32184; //@line 22225
  $25 = $20 >>> 4 & 7; //@line 22227
  _sprintf($17 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $23, HEAP32[tempInt + 8 >> 2] = $25, tempInt) | 0) | 0; //@line 22228
  $45 = $da | 0; //@line 22230
  $46 = HEAP32[$45 >> 2] | 0; //@line 22231
  $47 = $46 | 128; //@line 22232
  HEAP32[$45 >> 2] = $47; //@line 22233
  STACKTOP = sp; //@line 22234
  return;
 }
}
function _d_0600($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22246
 $1 = $da + 32 | 0; //@line 22247
 HEAP8[$1] = HEAP8[48136] | 0; //@line 22248
 HEAP8[$1 + 1 | 0] = HEAP8[48137 | 0] | 0; //@line 22248
 HEAP8[$1 + 2 | 0] = HEAP8[48138 | 0] | 0; //@line 22248
 HEAP8[$1 + 3 | 0] = HEAP8[48139 | 0] | 0; //@line 22248
 HEAP8[$1 + 4 | 0] = HEAP8[48140 | 0] | 0; //@line 22248
 HEAP8[$1 + 5 | 0] = HEAP8[48141 | 0] | 0; //@line 22248
 HEAP8[$1 + 6 | 0] = HEAP8[48142 | 0] | 0; //@line 22248
 HEAP32[$da + 28 >> 2] = 2; //@line 22250
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22254
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22255
 $8 = $da + 8 | 0; //@line 22256
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22259
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22265
 STACKTOP = sp; //@line 22266
 return;
}
function _d_0640($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $12 = 0, $14 = 0, sp = 0;
 sp = STACKTOP; //@line 22278
 $1 = $da + 32 | 0; //@line 22279
 HEAP8[$1] = HEAP8[48160] | 0; //@line 22280
 HEAP8[$1 + 1 | 0] = HEAP8[48161 | 0] | 0; //@line 22280
 HEAP8[$1 + 2 | 0] = HEAP8[48162 | 0] | 0; //@line 22280
 HEAP8[$1 + 3 | 0] = HEAP8[48163 | 0] | 0; //@line 22280
 HEAP8[$1 + 4 | 0] = HEAP8[48164 | 0] | 0; //@line 22280
 HEAP8[$1 + 5 | 0] = HEAP8[48165 | 0] | 0; //@line 22280
 HEAP8[$1 + 6 | 0] = HEAP8[48166 | 0] | 0; //@line 22280
 HEAP32[$da + 28 >> 2] = 2; //@line 22282
 $12 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 22292
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $12, tempInt) | 0) | 0; //@line 22293
 $14 = $da + 8 | 0; //@line 22294
 HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 1; //@line 22297
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22303
 STACKTOP = sp; //@line 22304
 return;
}
function _d_0680($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 22317
 $1 = $da + 32 | 0; //@line 22318
 HEAP8[$1] = HEAP8[48256] | 0; //@line 22319
 HEAP8[$1 + 1 | 0] = HEAP8[48257 | 0] | 0; //@line 22319
 HEAP8[$1 + 2 | 0] = HEAP8[48258 | 0] | 0; //@line 22319
 HEAP8[$1 + 3 | 0] = HEAP8[48259 | 0] | 0; //@line 22319
 HEAP8[$1 + 4 | 0] = HEAP8[48260 | 0] | 0; //@line 22319
 HEAP8[$1 + 5 | 0] = HEAP8[48261 | 0] | 0; //@line 22319
 HEAP8[$1 + 6 | 0] = HEAP8[48262 | 0] | 0; //@line 22319
 HEAP32[$da + 28 >> 2] = 2; //@line 22321
 $21 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 22340
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 22341
 $23 = $da + 8 | 0; //@line 22342
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 22345
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22351
 STACKTOP = sp; //@line 22352
 return;
}
function _di_und($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $11 = 0, sp = 0;
 sp = STACKTOP; //@line 22363
 $1 = $da + 32 | 0; //@line 22364
 HEAP8[$1] = HEAP8[36120] | 0; //@line 22365
 HEAP8[$1 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 22365
 HEAP8[$1 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 22365
 HEAP32[$da + 28 >> 2] = 1; //@line 22367
 $11 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 22376
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $11, tempInt) | 0) | 0; //@line 22377
 STACKTOP = sp; //@line 22378
 return;
}
function _d_0800($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22389
 $1 = $da + 32 | 0; //@line 22390
 HEAP8[$1] = HEAP8[48320] | 0; //@line 22391
 HEAP8[$1 + 1 | 0] = HEAP8[48321 | 0] | 0; //@line 22391
 HEAP8[$1 + 2 | 0] = HEAP8[48322 | 0] | 0; //@line 22391
 HEAP8[$1 + 3 | 0] = HEAP8[48323 | 0] | 0; //@line 22391
 HEAP8[$1 + 4 | 0] = HEAP8[48324 | 0] | 0; //@line 22391
 HEAP32[$da + 28 >> 2] = 2; //@line 22393
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22397
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22398
 $8 = $da + 8 | 0; //@line 22399
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22402
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22408
 STACKTOP = sp; //@line 22409
 return;
}
function _d_0840($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22420
 $1 = $da + 32 | 0; //@line 22421
 HEAP8[$1] = HEAP8[48368] | 0; //@line 22422
 HEAP8[$1 + 1 | 0] = HEAP8[48369 | 0] | 0; //@line 22422
 HEAP8[$1 + 2 | 0] = HEAP8[48370 | 0] | 0; //@line 22422
 HEAP8[$1 + 3 | 0] = HEAP8[48371 | 0] | 0; //@line 22422
 HEAP8[$1 + 4 | 0] = HEAP8[48372 | 0] | 0; //@line 22422
 HEAP32[$da + 28 >> 2] = 2; //@line 22424
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22428
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22429
 $8 = $da + 8 | 0; //@line 22430
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22433
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22439
 STACKTOP = sp; //@line 22440
 return;
}
function _d_0880($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22451
 $1 = $da + 32 | 0; //@line 22452
 HEAP8[$1] = HEAP8[48392] | 0; //@line 22453
 HEAP8[$1 + 1 | 0] = HEAP8[48393 | 0] | 0; //@line 22453
 HEAP8[$1 + 2 | 0] = HEAP8[48394 | 0] | 0; //@line 22453
 HEAP8[$1 + 3 | 0] = HEAP8[48395 | 0] | 0; //@line 22453
 HEAP8[$1 + 4 | 0] = HEAP8[48396 | 0] | 0; //@line 22453
 HEAP32[$da + 28 >> 2] = 2; //@line 22455
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22459
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22460
 $8 = $da + 8 | 0; //@line 22461
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22464
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22470
 STACKTOP = sp; //@line 22471
 return;
}
function _d_08c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22482
 $1 = $da + 32 | 0; //@line 22483
 HEAP8[$1] = HEAP8[48416] | 0; //@line 22484
 HEAP8[$1 + 1 | 0] = HEAP8[48417 | 0] | 0; //@line 22484
 HEAP8[$1 + 2 | 0] = HEAP8[48418 | 0] | 0; //@line 22484
 HEAP8[$1 + 3 | 0] = HEAP8[48419 | 0] | 0; //@line 22484
 HEAP8[$1 + 4 | 0] = HEAP8[48420 | 0] | 0; //@line 22484
 HEAP32[$da + 28 >> 2] = 2; //@line 22486
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22490
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22491
 $8 = $da + 8 | 0; //@line 22492
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22495
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22501
 STACKTOP = sp; //@line 22502
 return;
}
function _d_0a00($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $5 = 0, $10 = 0, $12 = 0, $15 = 0, $17 = 0, sp = 0;
 sp = STACKTOP; //@line 22514
 $4 = (HEAP16[$da + 12 >> 1] & 63) == 60; //@line 22518
 $5 = $da + 32 | 0; //@line 22519
 HEAP8[$5] = HEAP8[48464] | 0; //@line 22520
 HEAP8[$5 + 1 | 0] = HEAP8[48465 | 0] | 0; //@line 22520
 HEAP8[$5 + 2 | 0] = HEAP8[48466 | 0] | 0; //@line 22520
 HEAP8[$5 + 3 | 0] = HEAP8[48467 | 0] | 0; //@line 22520
 HEAP8[$5 + 4 | 0] = HEAP8[48468 | 0] | 0; //@line 22520
 HEAP8[$5 + 5 | 0] = HEAP8[48469 | 0] | 0; //@line 22520
 HEAP8[$5 + 6 | 0] = HEAP8[48470 | 0] | 0; //@line 22520
 HEAP32[$da + 28 >> 2] = 2; //@line 22522
 $10 = HEAPU8[$src + 3 | 0] | 0; //@line 22526
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $10, tempInt) | 0) | 0; //@line 22527
 $12 = $da + 8 | 0; //@line 22528
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 1; //@line 22531
 $15 = $da + 160 | 0; //@line 22532
 if ($4) {
  $17 = $15; //@line 22535
  tempBigInt = 5391171; //@line 22536
  HEAP8[$17] = tempBigInt & 255; //@line 22536
  tempBigInt = tempBigInt >> 8; //@line 22536
  HEAP8[$17 + 1 | 0] = tempBigInt & 255; //@line 22536
  tempBigInt = tempBigInt >> 8; //@line 22536
  HEAP8[$17 + 2 | 0] = tempBigInt & 255; //@line 22536
  tempBigInt = tempBigInt >> 8; //@line 22536
  HEAP8[$17 + 3 | 0] = tempBigInt & 255; //@line 22536
  STACKTOP = sp; //@line 22538
  return;
 } else {
  _dasm_ea($da, $15, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22545
  STACKTOP = sp; //@line 22546
  return;
 }
}
function _d_0a40($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $5 = 0, $16 = 0, $18 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 22560
 $4 = (HEAP16[$da + 12 >> 1] & 63) == 60; //@line 22564
 $5 = $da + 32 | 0; //@line 22565
 HEAP8[$5] = HEAP8[48488] | 0; //@line 22566
 HEAP8[$5 + 1 | 0] = HEAP8[48489 | 0] | 0; //@line 22566
 HEAP8[$5 + 2 | 0] = HEAP8[48490 | 0] | 0; //@line 22566
 HEAP8[$5 + 3 | 0] = HEAP8[48491 | 0] | 0; //@line 22566
 HEAP8[$5 + 4 | 0] = HEAP8[48492 | 0] | 0; //@line 22566
 HEAP8[$5 + 5 | 0] = HEAP8[48493 | 0] | 0; //@line 22566
 HEAP8[$5 + 6 | 0] = HEAP8[48494 | 0] | 0; //@line 22566
 HEAP32[$da + 28 >> 2] = 2; //@line 22568
 $16 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 22578
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $16, tempInt) | 0) | 0; //@line 22579
 $18 = $da + 8 | 0; //@line 22580
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 1; //@line 22583
 $21 = $da + 160 | 0; //@line 22584
 if ($4) {
  HEAP8[$21] = HEAP8[51464] | 0; //@line 22587
  HEAP8[$21 + 1 | 0] = HEAP8[51465 | 0] | 0; //@line 22587
  HEAP8[$21 + 2 | 0] = HEAP8[51466 | 0] | 0; //@line 22587
  $23 = $da | 0; //@line 22588
  HEAP32[$23 >> 2] = HEAP32[$23 >> 2] | 1; //@line 22591
  STACKTOP = sp; //@line 22593
  return;
 } else {
  _dasm_ea($da, $21, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22600
  STACKTOP = sp; //@line 22601
  return;
 }
}
function _d_0a80($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 22615
 $1 = $da + 32 | 0; //@line 22616
 HEAP8[$1] = HEAP8[48528] | 0; //@line 22617
 HEAP8[$1 + 1 | 0] = HEAP8[48529 | 0] | 0; //@line 22617
 HEAP8[$1 + 2 | 0] = HEAP8[48530 | 0] | 0; //@line 22617
 HEAP8[$1 + 3 | 0] = HEAP8[48531 | 0] | 0; //@line 22617
 HEAP8[$1 + 4 | 0] = HEAP8[48532 | 0] | 0; //@line 22617
 HEAP8[$1 + 5 | 0] = HEAP8[48533 | 0] | 0; //@line 22617
 HEAP8[$1 + 6 | 0] = HEAP8[48534 | 0] | 0; //@line 22617
 HEAP32[$da + 28 >> 2] = 2; //@line 22619
 $21 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 22638
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 22639
 $23 = $da + 8 | 0; //@line 22640
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 22643
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22649
 STACKTOP = sp; //@line 22650
 return;
}
function _d_0c00($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 22661
 $1 = $da + 32 | 0; //@line 22662
 HEAP8[$1] = HEAP8[48560] | 0; //@line 22663
 HEAP8[$1 + 1 | 0] = HEAP8[48561 | 0] | 0; //@line 22663
 HEAP8[$1 + 2 | 0] = HEAP8[48562 | 0] | 0; //@line 22663
 HEAP8[$1 + 3 | 0] = HEAP8[48563 | 0] | 0; //@line 22663
 HEAP8[$1 + 4 | 0] = HEAP8[48564 | 0] | 0; //@line 22663
 HEAP8[$1 + 5 | 0] = HEAP8[48565 | 0] | 0; //@line 22663
 HEAP8[$1 + 6 | 0] = HEAP8[48566 | 0] | 0; //@line 22663
 HEAP32[$da + 28 >> 2] = 2; //@line 22665
 $6 = HEAPU8[$src + 3 | 0] | 0; //@line 22669
 _sprintf($da + 96 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $6, tempInt) | 0) | 0; //@line 22670
 $8 = $da + 8 | 0; //@line 22671
 HEAP32[$8 >> 2] = (HEAP32[$8 >> 2] | 0) + 1; //@line 22674
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22680
 STACKTOP = sp; //@line 22681
 return;
}
function _d_0c40($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $12 = 0, $14 = 0, sp = 0;
 sp = STACKTOP; //@line 22693
 $1 = $da + 32 | 0; //@line 22694
 HEAP8[$1] = HEAP8[48592] | 0; //@line 22695
 HEAP8[$1 + 1 | 0] = HEAP8[48593 | 0] | 0; //@line 22695
 HEAP8[$1 + 2 | 0] = HEAP8[48594 | 0] | 0; //@line 22695
 HEAP8[$1 + 3 | 0] = HEAP8[48595 | 0] | 0; //@line 22695
 HEAP8[$1 + 4 | 0] = HEAP8[48596 | 0] | 0; //@line 22695
 HEAP8[$1 + 5 | 0] = HEAP8[48597 | 0] | 0; //@line 22695
 HEAP8[$1 + 6 | 0] = HEAP8[48598 | 0] | 0; //@line 22695
 HEAP32[$da + 28 >> 2] = 2; //@line 22697
 $12 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 22707
 _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $12, tempInt) | 0) | 0; //@line 22708
 $14 = $da + 8 | 0; //@line 22709
 HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 1; //@line 22712
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22718
 STACKTOP = sp; //@line 22719
 return;
}
function _d_0c80($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $21 = 0, $23 = 0, sp = 0;
 sp = STACKTOP; //@line 22732
 $1 = $da + 32 | 0; //@line 22733
 HEAP8[$1] = HEAP8[48656] | 0; //@line 22734
 HEAP8[$1 + 1 | 0] = HEAP8[48657 | 0] | 0; //@line 22734
 HEAP8[$1 + 2 | 0] = HEAP8[48658 | 0] | 0; //@line 22734
 HEAP8[$1 + 3 | 0] = HEAP8[48659 | 0] | 0; //@line 22734
 HEAP8[$1 + 4 | 0] = HEAP8[48660 | 0] | 0; //@line 22734
 HEAP8[$1 + 5 | 0] = HEAP8[48661 | 0] | 0; //@line 22734
 HEAP8[$1 + 6 | 0] = HEAP8[48662 | 0] | 0; //@line 22734
 HEAP32[$da + 28 >> 2] = 2; //@line 22736
 $21 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 22755
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 22756
 $23 = $da + 8 | 0; //@line 22757
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 22760
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22766
 STACKTOP = sp; //@line 22767
 return;
}
function _d_0e00($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $9 = 0, $11 = 0, $15 = 0, $18 = 0, $20 = 0, $32 = 0, $35 = 0, $38 = 0, $40 = 0, $43 = 0, $44 = 0, $45 = 0, sp = 0;
 sp = STACKTOP; //@line 22782
 $1 = $da + 8 | 0; //@line 22783
 $2 = HEAP32[$1 >> 2] | 0; //@line 22784
 $5 = HEAP8[$src + ($2 << 1) | 0] | 0; //@line 22787
 HEAP32[$1 >> 2] = $2 + 1; //@line 22789
 $9 = $da + 32 | 0; //@line 22792
 HEAP8[$9] = HEAP8[48728] | 0; //@line 22793
 HEAP8[$9 + 1 | 0] = HEAP8[48729 | 0] | 0; //@line 22793
 HEAP8[$9 + 2 | 0] = HEAP8[48730 | 0] | 0; //@line 22793
 HEAP8[$9 + 3 | 0] = HEAP8[48731 | 0] | 0; //@line 22793
 HEAP8[$9 + 4 | 0] = HEAP8[48732 | 0] | 0; //@line 22793
 HEAP8[$9 + 5 | 0] = HEAP8[48733 | 0] | 0; //@line 22793
 HEAP8[$9 + 6 | 0] = HEAP8[48734 | 0] | 0; //@line 22793
 HEAP32[$da + 28 >> 2] = 2; //@line 22795
 $11 = $da + 96 | 0; //@line 22796
 if (($5 & 8) == 0) {
  _dasm_ea($da, $11, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22803
  $32 = $da + 160 | 0; //@line 22804
  $35 = HEAPU8[$src + 2 | 0] | 0; //@line 22807
  $38 = ($35 & 128 | 0) != 0 ? 34768 : 32184; //@line 22810
  $40 = $35 >>> 4 & 7; //@line 22812
  _sprintf($32 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $38, HEAP32[tempInt + 8 >> 2] = $40, tempInt) | 0) | 0; //@line 22813
  $43 = $da | 0; //@line 22814
  $44 = HEAP32[$43 >> 2] | 0; //@line 22815
  $45 = $44 | 64; //@line 22816
  HEAP32[$43 >> 2] = $45; //@line 22817
  STACKTOP = sp; //@line 22818
  return;
 } else {
  $15 = HEAPU8[$src + 2 | 0] | 0; //@line 22823
  $18 = ($15 & 128 | 0) != 0 ? 34768 : 32184; //@line 22826
  $20 = $15 >>> 4 & 7; //@line 22828
  _sprintf($11 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $18, HEAP32[tempInt + 8 >> 2] = $20, tempInt) | 0) | 0; //@line 22829
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 22835
  $43 = $da | 0; //@line 22837
  $44 = HEAP32[$43 >> 2] | 0; //@line 22838
  $45 = $44 | 64; //@line 22839
  HEAP32[$43 >> 2] = $45; //@line 22840
  STACKTOP = sp; //@line 22841
  return;
 }
}
function _d_0e40($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $9 = 0, $11 = 0, $15 = 0, $18 = 0, $20 = 0, $32 = 0, $35 = 0, $38 = 0, $40 = 0, $43 = 0, $44 = 0, $45 = 0, sp = 0;
 sp = STACKTOP; //@line 22857
 $1 = $da + 8 | 0; //@line 22858
 $2 = HEAP32[$1 >> 2] | 0; //@line 22859
 $5 = HEAP8[$src + ($2 << 1) | 0] | 0; //@line 22862
 HEAP32[$1 >> 2] = $2 + 1; //@line 22864
 $9 = $da + 32 | 0; //@line 22867
 HEAP8[$9] = HEAP8[48760] | 0; //@line 22868
 HEAP8[$9 + 1 | 0] = HEAP8[48761 | 0] | 0; //@line 22868
 HEAP8[$9 + 2 | 0] = HEAP8[48762 | 0] | 0; //@line 22868
 HEAP8[$9 + 3 | 0] = HEAP8[48763 | 0] | 0; //@line 22868
 HEAP8[$9 + 4 | 0] = HEAP8[48764 | 0] | 0; //@line 22868
 HEAP8[$9 + 5 | 0] = HEAP8[48765 | 0] | 0; //@line 22868
 HEAP8[$9 + 6 | 0] = HEAP8[48766 | 0] | 0; //@line 22868
 HEAP32[$da + 28 >> 2] = 2; //@line 22870
 $11 = $da + 96 | 0; //@line 22871
 if (($5 & 8) == 0) {
  _dasm_ea($da, $11, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22878
  $32 = $da + 160 | 0; //@line 22879
  $35 = HEAPU8[$src + 2 | 0] | 0; //@line 22882
  $38 = ($35 & 128 | 0) != 0 ? 34768 : 32184; //@line 22885
  $40 = $35 >>> 4 & 7; //@line 22887
  _sprintf($32 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $38, HEAP32[tempInt + 8 >> 2] = $40, tempInt) | 0) | 0; //@line 22888
  $43 = $da | 0; //@line 22889
  $44 = HEAP32[$43 >> 2] | 0; //@line 22890
  $45 = $44 | 64; //@line 22891
  HEAP32[$43 >> 2] = $45; //@line 22892
  STACKTOP = sp; //@line 22893
  return;
 } else {
  $15 = HEAPU8[$src + 2 | 0] | 0; //@line 22898
  $18 = ($15 & 128 | 0) != 0 ? 34768 : 32184; //@line 22901
  $20 = $15 >>> 4 & 7; //@line 22903
  _sprintf($11 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $18, HEAP32[tempInt + 8 >> 2] = $20, tempInt) | 0) | 0; //@line 22904
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 22910
  $43 = $da | 0; //@line 22912
  $44 = HEAP32[$43 >> 2] | 0; //@line 22913
  $45 = $44 | 64; //@line 22914
  HEAP32[$43 >> 2] = $45; //@line 22915
  STACKTOP = sp; //@line 22916
  return;
 }
}
function _d_0e80($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $9 = 0, $11 = 0, $15 = 0, $18 = 0, $20 = 0, $32 = 0, $35 = 0, $38 = 0, $40 = 0, $43 = 0, $44 = 0, $45 = 0, sp = 0;
 sp = STACKTOP; //@line 22932
 $1 = $da + 8 | 0; //@line 22933
 $2 = HEAP32[$1 >> 2] | 0; //@line 22934
 $5 = HEAP8[$src + ($2 << 1) | 0] | 0; //@line 22937
 HEAP32[$1 >> 2] = $2 + 1; //@line 22939
 $9 = $da + 32 | 0; //@line 22942
 HEAP8[$9] = HEAP8[48776] | 0; //@line 22943
 HEAP8[$9 + 1 | 0] = HEAP8[48777 | 0] | 0; //@line 22943
 HEAP8[$9 + 2 | 0] = HEAP8[48778 | 0] | 0; //@line 22943
 HEAP8[$9 + 3 | 0] = HEAP8[48779 | 0] | 0; //@line 22943
 HEAP8[$9 + 4 | 0] = HEAP8[48780 | 0] | 0; //@line 22943
 HEAP8[$9 + 5 | 0] = HEAP8[48781 | 0] | 0; //@line 22943
 HEAP8[$9 + 6 | 0] = HEAP8[48782 | 0] | 0; //@line 22943
 HEAP32[$da + 28 >> 2] = 2; //@line 22945
 $11 = $da + 96 | 0; //@line 22946
 if (($5 & 8) == 0) {
  _dasm_ea($da, $11, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22953
  $32 = $da + 160 | 0; //@line 22954
  $35 = HEAPU8[$src + 2 | 0] | 0; //@line 22957
  $38 = ($35 & 128 | 0) != 0 ? 34768 : 32184; //@line 22960
  $40 = $35 >>> 4 & 7; //@line 22962
  _sprintf($32 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $38, HEAP32[tempInt + 8 >> 2] = $40, tempInt) | 0) | 0; //@line 22963
  $43 = $da | 0; //@line 22964
  $44 = HEAP32[$43 >> 2] | 0; //@line 22965
  $45 = $44 | 64; //@line 22966
  HEAP32[$43 >> 2] = $45; //@line 22967
  STACKTOP = sp; //@line 22968
  return;
 } else {
  $15 = HEAPU8[$src + 2 | 0] | 0; //@line 22973
  $18 = ($15 & 128 | 0) != 0 ? 34768 : 32184; //@line 22976
  $20 = $15 >>> 4 & 7; //@line 22978
  _sprintf($11 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $18, HEAP32[tempInt + 8 >> 2] = $20, tempInt) | 0) | 0; //@line 22979
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 22985
  $43 = $da | 0; //@line 22987
  $44 = HEAP32[$43 >> 2] | 0; //@line 22988
  $45 = $44 | 64; //@line 22989
  HEAP32[$43 >> 2] = $45; //@line 22990
  STACKTOP = sp; //@line 22991
  return;
 }
}
function _d_4ec0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $9 = 0;
 $2 = $da + 32 | 0; //@line 23005
 tempBigInt = 5262666; //@line 23006
 HEAP8[$2] = tempBigInt & 255; //@line 23006
 tempBigInt = tempBigInt >> 8; //@line 23006
 HEAP8[$2 + 1 | 0] = tempBigInt & 255; //@line 23006
 tempBigInt = tempBigInt >> 8; //@line 23006
 HEAP8[$2 + 2 | 0] = tempBigInt & 255; //@line 23006
 tempBigInt = tempBigInt >> 8; //@line 23006
 HEAP8[$2 + 3 | 0] = tempBigInt & 255; //@line 23006
 HEAP32[$da + 28 >> 2] = 1; //@line 23008
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 0); //@line 23014
 $9 = $da | 0; //@line 23015
 HEAP32[$9 >> 2] = HEAP32[$9 >> 2] | 2; //@line 23018
 return;
}
function _d_1000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $4 = 0, $15 = 0;
 $1 = $da + 32 | 0; //@line 23032
 HEAP8[$1] = HEAP8[48848] | 0; //@line 23033
 HEAP8[$1 + 1 | 0] = HEAP8[48849 | 0] | 0; //@line 23033
 HEAP8[$1 + 2 | 0] = HEAP8[48850 | 0] | 0; //@line 23033
 HEAP8[$1 + 3 | 0] = HEAP8[48851 | 0] | 0; //@line 23033
 HEAP8[$1 + 4 | 0] = HEAP8[48852 | 0] | 0; //@line 23033
 HEAP8[$1 + 5 | 0] = HEAP8[48853 | 0] | 0; //@line 23033
 HEAP8[$1 + 6 | 0] = HEAP8[48854 | 0] | 0; //@line 23033
 HEAP32[$da + 28 >> 2] = 2; //@line 23035
 $4 = $src + 1 | 0; //@line 23037
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$4] & 63, 8); //@line 23041
 $15 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$4] | 0)) & 65535; //@line 23049
 _dasm_ea($da, $da + 160 | 0, $src, $15 >>> 3 & 56 | $15 >>> 9 & 7, 8); //@line 23055
 return;
}
function _d_2000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $4 = 0, $15 = 0;
 $1 = $da + 32 | 0; //@line 23069
 HEAP8[$1] = HEAP8[48872] | 0; //@line 23070
 HEAP8[$1 + 1 | 0] = HEAP8[48873 | 0] | 0; //@line 23070
 HEAP8[$1 + 2 | 0] = HEAP8[48874 | 0] | 0; //@line 23070
 HEAP8[$1 + 3 | 0] = HEAP8[48875 | 0] | 0; //@line 23070
 HEAP8[$1 + 4 | 0] = HEAP8[48876 | 0] | 0; //@line 23070
 HEAP8[$1 + 5 | 0] = HEAP8[48877 | 0] | 0; //@line 23070
 HEAP8[$1 + 6 | 0] = HEAP8[48878 | 0] | 0; //@line 23070
 HEAP32[$da + 28 >> 2] = 2; //@line 23072
 $4 = $src + 1 | 0; //@line 23074
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$4] & 63, 32); //@line 23078
 $15 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$4] | 0)) & 65535; //@line 23086
 _dasm_ea($da, $da + 160 | 0, $src, $15 >>> 3 & 56 | $15 >>> 9 & 7, 32); //@line 23092
 return;
}
function _d_2040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $st$1$0 = 0, $st$2$1 = 0, sp = 0;
 sp = STACKTOP; //@line 23105
 $2 = $da + 32 | 0; //@line 23107
 $st$1$0 = $2 | 0; //@line 23110
 tempBigInt = 1163284301; //@line 23111
 HEAP8[$st$1$0] = tempBigInt & 255; //@line 23111
 tempBigInt = tempBigInt >> 8; //@line 23111
 HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 23111
 tempBigInt = tempBigInt >> 8; //@line 23111
 HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 23111
 tempBigInt = tempBigInt >> 8; //@line 23111
 HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 23111
 $st$2$1 = $2 + 4 | 0; //@line 23112
 tempBigInt = 4992577; //@line 23113
 HEAP8[$st$2$1] = tempBigInt & 255; //@line 23113
 tempBigInt = tempBigInt >> 8; //@line 23113
 HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 23113
 tempBigInt = tempBigInt >> 8; //@line 23113
 HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 23113
 tempBigInt = tempBigInt >> 8; //@line 23113
 HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 23113
 HEAP32[$da + 28 >> 2] = 2; //@line 23115
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23121
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 23127
 STACKTOP = sp; //@line 23128
 return;
}
function _d_3000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $4 = 0, $15 = 0;
 $1 = $da + 32 | 0; //@line 23141
 HEAP8[$1] = HEAP8[49704] | 0; //@line 23142
 HEAP8[$1 + 1 | 0] = HEAP8[49705 | 0] | 0; //@line 23142
 HEAP8[$1 + 2 | 0] = HEAP8[49706 | 0] | 0; //@line 23142
 HEAP8[$1 + 3 | 0] = HEAP8[49707 | 0] | 0; //@line 23142
 HEAP8[$1 + 4 | 0] = HEAP8[49708 | 0] | 0; //@line 23142
 HEAP8[$1 + 5 | 0] = HEAP8[49709 | 0] | 0; //@line 23142
 HEAP8[$1 + 6 | 0] = HEAP8[49710 | 0] | 0; //@line 23142
 HEAP32[$da + 28 >> 2] = 2; //@line 23144
 $4 = $src + 1 | 0; //@line 23146
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$4] & 63, 16); //@line 23150
 $15 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$4] | 0)) & 65535; //@line 23158
 _dasm_ea($da, $da + 160 | 0, $src, $15 >>> 3 & 56 | $15 >>> 9 & 7, 16); //@line 23164
 return;
}
function _d_3040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $st$1$0 = 0, $st$2$1 = 0, sp = 0;
 sp = STACKTOP; //@line 23177
 $2 = $da + 32 | 0; //@line 23179
 $st$1$0 = $2 | 0; //@line 23182
 tempBigInt = 1163284301; //@line 23183
 HEAP8[$st$1$0] = tempBigInt & 255; //@line 23183
 tempBigInt = tempBigInt >> 8; //@line 23183
 HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 23183
 tempBigInt = tempBigInt >> 8; //@line 23183
 HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 23183
 tempBigInt = tempBigInt >> 8; //@line 23183
 HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 23183
 $st$2$1 = $2 + 4 | 0; //@line 23184
 tempBigInt = 5713473; //@line 23185
 HEAP8[$st$2$1] = tempBigInt & 255; //@line 23185
 tempBigInt = tempBigInt >> 8; //@line 23185
 HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 23185
 tempBigInt = tempBigInt >> 8; //@line 23185
 HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 23185
 tempBigInt = tempBigInt >> 8; //@line 23185
 HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 23185
 HEAP32[$da + 28 >> 2] = 2; //@line 23187
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23193
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 23199
 STACKTOP = sp; //@line 23200
 return;
}
function _d_4000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0;
 $1 = $da + 32 | 0; //@line 23212
 HEAP8[$1] = HEAP8[48936] | 0; //@line 23213
 HEAP8[$1 + 1 | 0] = HEAP8[48937 | 0] | 0; //@line 23213
 HEAP8[$1 + 2 | 0] = HEAP8[48938 | 0] | 0; //@line 23213
 HEAP8[$1 + 3 | 0] = HEAP8[48939 | 0] | 0; //@line 23213
 HEAP8[$1 + 4 | 0] = HEAP8[48940 | 0] | 0; //@line 23213
 HEAP8[$1 + 5 | 0] = HEAP8[48941 | 0] | 0; //@line 23213
 HEAP8[$1 + 6 | 0] = HEAP8[48942 | 0] | 0; //@line 23213
 HEAP32[$da + 28 >> 2] = 1; //@line 23215
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 23221
 $8 = $da | 0; //@line 23222
 HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 32; //@line 23225
 return;
}
function _d_4040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0;
 $1 = $da + 32 | 0; //@line 23238
 HEAP8[$1] = HEAP8[49048] | 0; //@line 23239
 HEAP8[$1 + 1 | 0] = HEAP8[49049 | 0] | 0; //@line 23239
 HEAP8[$1 + 2 | 0] = HEAP8[49050 | 0] | 0; //@line 23239
 HEAP8[$1 + 3 | 0] = HEAP8[49051 | 0] | 0; //@line 23239
 HEAP8[$1 + 4 | 0] = HEAP8[49052 | 0] | 0; //@line 23239
 HEAP8[$1 + 5 | 0] = HEAP8[49053 | 0] | 0; //@line 23239
 HEAP8[$1 + 6 | 0] = HEAP8[49054 | 0] | 0; //@line 23239
 HEAP32[$da + 28 >> 2] = 1; //@line 23241
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23247
 $8 = $da | 0; //@line 23248
 HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 32; //@line 23251
 return;
}
function _d_4080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0;
 $1 = $da + 32 | 0; //@line 23264
 HEAP8[$1] = HEAP8[49128] | 0; //@line 23265
 HEAP8[$1 + 1 | 0] = HEAP8[49129 | 0] | 0; //@line 23265
 HEAP8[$1 + 2 | 0] = HEAP8[49130 | 0] | 0; //@line 23265
 HEAP8[$1 + 3 | 0] = HEAP8[49131 | 0] | 0; //@line 23265
 HEAP8[$1 + 4 | 0] = HEAP8[49132 | 0] | 0; //@line 23265
 HEAP8[$1 + 5 | 0] = HEAP8[49133 | 0] | 0; //@line 23265
 HEAP8[$1 + 6 | 0] = HEAP8[49134 | 0] | 0; //@line 23265
 HEAP32[$da + 28 >> 2] = 1; //@line 23267
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23273
 $8 = $da | 0; //@line 23274
 HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 32; //@line 23277
 return;
}
function _d_40c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0;
 $1 = $da + 32 | 0; //@line 23289
 HEAP8[$1] = HEAP8[49704] | 0; //@line 23290
 HEAP8[$1 + 1 | 0] = HEAP8[49705 | 0] | 0; //@line 23290
 HEAP8[$1 + 2 | 0] = HEAP8[49706 | 0] | 0; //@line 23290
 HEAP8[$1 + 3 | 0] = HEAP8[49707 | 0] | 0; //@line 23290
 HEAP8[$1 + 4 | 0] = HEAP8[49708 | 0] | 0; //@line 23290
 HEAP8[$1 + 5 | 0] = HEAP8[49709 | 0] | 0; //@line 23290
 HEAP8[$1 + 6 | 0] = HEAP8[49710 | 0] | 0; //@line 23290
 HEAP32[$da + 28 >> 2] = 2; //@line 23292
 $3 = $da + 96 | 0; //@line 23293
 HEAP8[$3] = HEAP8[51464] | 0; //@line 23294
 HEAP8[$3 + 1 | 0] = HEAP8[51465 | 0] | 0; //@line 23294
 HEAP8[$3 + 2 | 0] = HEAP8[51466 | 0] | 0; //@line 23294
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23300
 return;
}
function _d_4180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, sp = 0;
 sp = STACKTOP; //@line 23312
 $2 = $da + 32 | 0; //@line 23314
 tempBigInt = 4933699; //@line 23315
 HEAP8[$2] = tempBigInt & 255; //@line 23315
 tempBigInt = tempBigInt >> 8; //@line 23315
 HEAP8[$2 + 1 | 0] = tempBigInt & 255; //@line 23315
 tempBigInt = tempBigInt >> 8; //@line 23315
 HEAP8[$2 + 2 | 0] = tempBigInt & 255; //@line 23315
 tempBigInt = tempBigInt >> 8; //@line 23315
 HEAP8[$2 + 3 | 0] = tempBigInt & 255; //@line 23315
 HEAP32[$da + 28 >> 2] = 2; //@line 23317
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23323
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 23329
 STACKTOP = sp; //@line 23330
 return;
}
function _d_41c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, sp = 0;
 sp = STACKTOP; //@line 23341
 $2 = $da + 32 | 0; //@line 23343
 tempBigInt = 4277580; //@line 23344
 HEAP8[$2] = tempBigInt & 255; //@line 23344
 tempBigInt = tempBigInt >> 8; //@line 23344
 HEAP8[$2 + 1 | 0] = tempBigInt & 255; //@line 23344
 tempBigInt = tempBigInt >> 8; //@line 23344
 HEAP8[$2 + 2 | 0] = tempBigInt & 255; //@line 23344
 tempBigInt = tempBigInt >> 8; //@line 23344
 HEAP8[$2 + 3 | 0] = tempBigInt & 255; //@line 23344
 HEAP32[$da + 28 >> 2] = 2; //@line 23346
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23352
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 23358
 STACKTOP = sp; //@line 23359
 return;
}
function _d_4200($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23370
 HEAP8[$1] = HEAP8[49200] | 0; //@line 23371
 HEAP8[$1 + 1 | 0] = HEAP8[49201 | 0] | 0; //@line 23371
 HEAP8[$1 + 2 | 0] = HEAP8[49202 | 0] | 0; //@line 23371
 HEAP8[$1 + 3 | 0] = HEAP8[49203 | 0] | 0; //@line 23371
 HEAP8[$1 + 4 | 0] = HEAP8[49204 | 0] | 0; //@line 23371
 HEAP8[$1 + 5 | 0] = HEAP8[49205 | 0] | 0; //@line 23371
 HEAP32[$da + 28 >> 2] = 1; //@line 23373
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 23379
 return;
}
function _d_4240($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23391
 HEAP8[$1] = HEAP8[49224] | 0; //@line 23392
 HEAP8[$1 + 1 | 0] = HEAP8[49225 | 0] | 0; //@line 23392
 HEAP8[$1 + 2 | 0] = HEAP8[49226 | 0] | 0; //@line 23392
 HEAP8[$1 + 3 | 0] = HEAP8[49227 | 0] | 0; //@line 23392
 HEAP8[$1 + 4 | 0] = HEAP8[49228 | 0] | 0; //@line 23392
 HEAP8[$1 + 5 | 0] = HEAP8[49229 | 0] | 0; //@line 23392
 HEAP32[$da + 28 >> 2] = 1; //@line 23394
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23400
 return;
}
function _d_4280($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23412
 HEAP8[$1] = HEAP8[49240] | 0; //@line 23413
 HEAP8[$1 + 1 | 0] = HEAP8[49241 | 0] | 0; //@line 23413
 HEAP8[$1 + 2 | 0] = HEAP8[49242 | 0] | 0; //@line 23413
 HEAP8[$1 + 3 | 0] = HEAP8[49243 | 0] | 0; //@line 23413
 HEAP8[$1 + 4 | 0] = HEAP8[49244 | 0] | 0; //@line 23413
 HEAP8[$1 + 5 | 0] = HEAP8[49245 | 0] | 0; //@line 23413
 HEAP32[$da + 28 >> 2] = 1; //@line 23415
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23421
 return;
}
function _d_42c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $4 = 0, $10 = 0;
 $1 = $da + 32 | 0; //@line 23434
 HEAP8[$1] = HEAP8[49704] | 0; //@line 23435
 HEAP8[$1 + 1 | 0] = HEAP8[49705 | 0] | 0; //@line 23435
 HEAP8[$1 + 2 | 0] = HEAP8[49706 | 0] | 0; //@line 23435
 HEAP8[$1 + 3 | 0] = HEAP8[49707 | 0] | 0; //@line 23435
 HEAP8[$1 + 4 | 0] = HEAP8[49708 | 0] | 0; //@line 23435
 HEAP8[$1 + 5 | 0] = HEAP8[49709 | 0] | 0; //@line 23435
 HEAP8[$1 + 6 | 0] = HEAP8[49710 | 0] | 0; //@line 23435
 HEAP32[$da + 28 >> 2] = 2; //@line 23437
 $4 = $da + 96 | 0; //@line 23439
 tempBigInt = 5391171; //@line 23440
 HEAP8[$4] = tempBigInt & 255; //@line 23440
 tempBigInt = tempBigInt >> 8; //@line 23440
 HEAP8[$4 + 1 | 0] = tempBigInt & 255; //@line 23440
 tempBigInt = tempBigInt >> 8; //@line 23440
 HEAP8[$4 + 2 | 0] = tempBigInt & 255; //@line 23440
 tempBigInt = tempBigInt >> 8; //@line 23440
 HEAP8[$4 + 3 | 0] = tempBigInt & 255; //@line 23440
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23446
 $10 = $da | 0; //@line 23447
 HEAP32[$10 >> 2] = HEAP32[$10 >> 2] | 64; //@line 23450
 return;
}
function _d_4400($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23462
 HEAP8[$1] = HEAP8[49296] | 0; //@line 23463
 HEAP8[$1 + 1 | 0] = HEAP8[49297 | 0] | 0; //@line 23463
 HEAP8[$1 + 2 | 0] = HEAP8[49298 | 0] | 0; //@line 23463
 HEAP8[$1 + 3 | 0] = HEAP8[49299 | 0] | 0; //@line 23463
 HEAP8[$1 + 4 | 0] = HEAP8[49300 | 0] | 0; //@line 23463
 HEAP8[$1 + 5 | 0] = HEAP8[49301 | 0] | 0; //@line 23463
 HEAP32[$da + 28 >> 2] = 1; //@line 23465
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 23471
 return;
}
function _d_4440($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23483
 HEAP8[$1] = HEAP8[49344] | 0; //@line 23484
 HEAP8[$1 + 1 | 0] = HEAP8[49345 | 0] | 0; //@line 23484
 HEAP8[$1 + 2 | 0] = HEAP8[49346 | 0] | 0; //@line 23484
 HEAP8[$1 + 3 | 0] = HEAP8[49347 | 0] | 0; //@line 23484
 HEAP8[$1 + 4 | 0] = HEAP8[49348 | 0] | 0; //@line 23484
 HEAP8[$1 + 5 | 0] = HEAP8[49349 | 0] | 0; //@line 23484
 HEAP32[$da + 28 >> 2] = 1; //@line 23486
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23492
 return;
}
function _d_4480($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23504
 HEAP8[$1] = HEAP8[49368] | 0; //@line 23505
 HEAP8[$1 + 1 | 0] = HEAP8[49369 | 0] | 0; //@line 23505
 HEAP8[$1 + 2 | 0] = HEAP8[49370 | 0] | 0; //@line 23505
 HEAP8[$1 + 3 | 0] = HEAP8[49371 | 0] | 0; //@line 23505
 HEAP8[$1 + 4 | 0] = HEAP8[49372 | 0] | 0; //@line 23505
 HEAP8[$1 + 5 | 0] = HEAP8[49373 | 0] | 0; //@line 23505
 HEAP32[$da + 28 >> 2] = 1; //@line 23507
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23513
 return;
}
function _d_44c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $9 = 0;
 $1 = $da + 32 | 0; //@line 23526
 HEAP8[$1] = HEAP8[49704] | 0; //@line 23527
 HEAP8[$1 + 1 | 0] = HEAP8[49705 | 0] | 0; //@line 23527
 HEAP8[$1 + 2 | 0] = HEAP8[49706 | 0] | 0; //@line 23527
 HEAP8[$1 + 3 | 0] = HEAP8[49707 | 0] | 0; //@line 23527
 HEAP8[$1 + 4 | 0] = HEAP8[49708 | 0] | 0; //@line 23527
 HEAP8[$1 + 5 | 0] = HEAP8[49709 | 0] | 0; //@line 23527
 HEAP8[$1 + 6 | 0] = HEAP8[49710 | 0] | 0; //@line 23527
 HEAP32[$da + 28 >> 2] = 2; //@line 23529
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23535
 $9 = $da + 160 | 0; //@line 23537
 tempBigInt = 5391171; //@line 23538
 HEAP8[$9] = tempBigInt & 255; //@line 23538
 tempBigInt = tempBigInt >> 8; //@line 23538
 HEAP8[$9 + 1 | 0] = tempBigInt & 255; //@line 23538
 tempBigInt = tempBigInt >> 8; //@line 23538
 HEAP8[$9 + 2 | 0] = tempBigInt & 255; //@line 23538
 tempBigInt = tempBigInt >> 8; //@line 23538
 HEAP8[$9 + 3 | 0] = tempBigInt & 255; //@line 23538
 return;
}
function _d_4600($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23550
 HEAP8[$1] = HEAP8[49512] | 0; //@line 23551
 HEAP8[$1 + 1 | 0] = HEAP8[49513 | 0] | 0; //@line 23551
 HEAP8[$1 + 2 | 0] = HEAP8[49514 | 0] | 0; //@line 23551
 HEAP8[$1 + 3 | 0] = HEAP8[49515 | 0] | 0; //@line 23551
 HEAP8[$1 + 4 | 0] = HEAP8[49516 | 0] | 0; //@line 23551
 HEAP8[$1 + 5 | 0] = HEAP8[49517 | 0] | 0; //@line 23551
 HEAP32[$da + 28 >> 2] = 1; //@line 23553
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 23559
 return;
}
function _d_4640($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23571
 HEAP8[$1] = HEAP8[49584] | 0; //@line 23572
 HEAP8[$1 + 1 | 0] = HEAP8[49585 | 0] | 0; //@line 23572
 HEAP8[$1 + 2 | 0] = HEAP8[49586 | 0] | 0; //@line 23572
 HEAP8[$1 + 3 | 0] = HEAP8[49587 | 0] | 0; //@line 23572
 HEAP8[$1 + 4 | 0] = HEAP8[49588 | 0] | 0; //@line 23572
 HEAP8[$1 + 5 | 0] = HEAP8[49589 | 0] | 0; //@line 23572
 HEAP32[$da + 28 >> 2] = 1; //@line 23574
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23580
 return;
}
function _d_4680($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23592
 HEAP8[$1] = HEAP8[49640] | 0; //@line 23593
 HEAP8[$1 + 1 | 0] = HEAP8[49641 | 0] | 0; //@line 23593
 HEAP8[$1 + 2 | 0] = HEAP8[49642 | 0] | 0; //@line 23593
 HEAP8[$1 + 3 | 0] = HEAP8[49643 | 0] | 0; //@line 23593
 HEAP8[$1 + 4 | 0] = HEAP8[49644 | 0] | 0; //@line 23593
 HEAP8[$1 + 5 | 0] = HEAP8[49645 | 0] | 0; //@line 23593
 HEAP32[$da + 28 >> 2] = 1; //@line 23595
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23601
 return;
}
function _d_46c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0, $9 = 0;
 $1 = $da + 32 | 0; //@line 23614
 HEAP8[$1] = HEAP8[49704] | 0; //@line 23615
 HEAP8[$1 + 1 | 0] = HEAP8[49705 | 0] | 0; //@line 23615
 HEAP8[$1 + 2 | 0] = HEAP8[49706 | 0] | 0; //@line 23615
 HEAP8[$1 + 3 | 0] = HEAP8[49707 | 0] | 0; //@line 23615
 HEAP8[$1 + 4 | 0] = HEAP8[49708 | 0] | 0; //@line 23615
 HEAP8[$1 + 5 | 0] = HEAP8[49709 | 0] | 0; //@line 23615
 HEAP8[$1 + 6 | 0] = HEAP8[49710 | 0] | 0; //@line 23615
 HEAP32[$da + 28 >> 2] = 2; //@line 23617
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23623
 $8 = $da + 160 | 0; //@line 23624
 HEAP8[$8] = HEAP8[51464] | 0; //@line 23625
 HEAP8[$8 + 1 | 0] = HEAP8[51465 | 0] | 0; //@line 23625
 HEAP8[$8 + 2 | 0] = HEAP8[51466 | 0] | 0; //@line 23625
 $9 = $da | 0; //@line 23626
 HEAP32[$9 >> 2] = HEAP32[$9 >> 2] | 1; //@line 23629
 return;
}
function _d_4800($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0;
 $1 = $da + 32 | 0; //@line 23642
 HEAP8[$1] = HEAP8[49832] | 0; //@line 23643
 HEAP8[$1 + 1 | 0] = HEAP8[49833 | 0] | 0; //@line 23643
 HEAP8[$1 + 2 | 0] = HEAP8[49834 | 0] | 0; //@line 23643
 HEAP8[$1 + 3 | 0] = HEAP8[49835 | 0] | 0; //@line 23643
 HEAP8[$1 + 4 | 0] = HEAP8[49836 | 0] | 0; //@line 23643
 HEAP8[$1 + 5 | 0] = HEAP8[49837 | 0] | 0; //@line 23643
 HEAP8[$1 + 6 | 0] = HEAP8[49838 | 0] | 0; //@line 23643
 HEAP32[$da + 28 >> 2] = 1; //@line 23645
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 23651
 $8 = $da | 0; //@line 23652
 HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 32; //@line 23655
 return;
}
function _d_4840($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $4 = 0, $7 = 0, $9 = 0, $12 = 0, sp = 0;
 sp = STACKTOP; //@line 23668
 $2 = HEAP16[$da + 12 >> 1] | 0; //@line 23670
 $4 = $da + 32 | 0; //@line 23673
 if (($2 & 56) == 0) {
  HEAP8[$4] = HEAP8[50072] | 0; //@line 23676
  HEAP8[$4 + 1 | 0] = HEAP8[50073 | 0] | 0; //@line 23676
  HEAP8[$4 + 2 | 0] = HEAP8[50074 | 0] | 0; //@line 23676
  HEAP8[$4 + 3 | 0] = HEAP8[50075 | 0] | 0; //@line 23676
  HEAP8[$4 + 4 | 0] = HEAP8[50076 | 0] | 0; //@line 23676
  HEAP32[$da + 28 >> 2] = 1; //@line 23678
  $7 = $da + 96 | 0; //@line 23679
  $9 = $2 & 7; //@line 23681
  _sprintf($7 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $9, tempInt) | 0) | 0; //@line 23682
  STACKTOP = sp; //@line 23684
  return;
 } else {
  $12 = $4; //@line 23687
  tempBigInt = 4277584; //@line 23688
  HEAP8[$12] = tempBigInt & 255; //@line 23688
  tempBigInt = tempBigInt >> 8; //@line 23688
  HEAP8[$12 + 1 | 0] = tempBigInt & 255; //@line 23688
  tempBigInt = tempBigInt >> 8; //@line 23688
  HEAP8[$12 + 2 | 0] = tempBigInt & 255; //@line 23688
  tempBigInt = tempBigInt >> 8; //@line 23688
  HEAP8[$12 + 3 | 0] = tempBigInt & 255; //@line 23688
  HEAP32[$da + 28 >> 2] = 1; //@line 23690
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23696
  STACKTOP = sp; //@line 23698
  return;
 }
}
function _d_4880($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $3 = 0, $5 = 0, $7 = 0, $14 = 0, $st$1$0 = 0, $st$2$1 = 0, $24 = 0, $st$4$0 = 0, $st$5$1 = 0, sp = 0;
 sp = STACKTOP; //@line 23713
 $3 = HEAPU16[$da + 12 >> 1] | 0; //@line 23716
 $5 = $3 >>> 3 & 7; //@line 23718
 if (($5 | 0) == 4) {
  $14 = $da + 32 | 0; //@line 23721
  $st$1$0 = $14 | 0; //@line 23724
  tempBigInt = 1163284301; //@line 23725
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 23725
  tempBigInt = tempBigInt >> 8; //@line 23725
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 23725
  tempBigInt = tempBigInt >> 8; //@line 23725
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 23725
  tempBigInt = tempBigInt >> 8; //@line 23725
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 23725
  $st$2$1 = $14 + 4 | 0; //@line 23726
  tempBigInt = 5713485; //@line 23727
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 23727
  tempBigInt = tempBigInt >> 8; //@line 23727
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 23727
  tempBigInt = tempBigInt >> 8; //@line 23727
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 23727
  tempBigInt = tempBigInt >> 8; //@line 23727
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 23727
  HEAP32[$da + 28 >> 2] = 2; //@line 23729
  _dasm_arg($da, $da + 96 | 0, $src, 25, 16); //@line 23731
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23737
  STACKTOP = sp; //@line 23739
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 23742
  HEAP8[$7] = HEAP8[50216] | 0; //@line 23743
  HEAP8[$7 + 1 | 0] = HEAP8[50217 | 0] | 0; //@line 23743
  HEAP8[$7 + 2 | 0] = HEAP8[50218 | 0] | 0; //@line 23743
  HEAP8[$7 + 3 | 0] = HEAP8[50219 | 0] | 0; //@line 23743
  HEAP8[$7 + 4 | 0] = HEAP8[50220 | 0] | 0; //@line 23743
  HEAP8[$7 + 5 | 0] = HEAP8[50221 | 0] | 0; //@line 23743
  HEAP32[$da + 28 >> 2] = 1; //@line 23745
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 23748
  STACKTOP = sp; //@line 23750
  return;
 } else {
  $24 = $da + 32 | 0; //@line 23754
  $st$4$0 = $24 | 0; //@line 23757
  tempBigInt = 1163284301; //@line 23758
  HEAP8[$st$4$0] = tempBigInt & 255; //@line 23758
  tempBigInt = tempBigInt >> 8; //@line 23758
  HEAP8[$st$4$0 + 1 | 0] = tempBigInt & 255; //@line 23758
  tempBigInt = tempBigInt >> 8; //@line 23758
  HEAP8[$st$4$0 + 2 | 0] = tempBigInt & 255; //@line 23758
  tempBigInt = tempBigInt >> 8; //@line 23758
  HEAP8[$st$4$0 + 3 | 0] = tempBigInt & 255; //@line 23758
  $st$5$1 = $24 + 4 | 0; //@line 23759
  tempBigInt = 5713485; //@line 23760
  HEAP8[$st$5$1] = tempBigInt & 255; //@line 23760
  tempBigInt = tempBigInt >> 8; //@line 23760
  HEAP8[$st$5$1 + 1 | 0] = tempBigInt & 255; //@line 23760
  tempBigInt = tempBigInt >> 8; //@line 23760
  HEAP8[$st$5$1 + 2 | 0] = tempBigInt & 255; //@line 23760
  tempBigInt = tempBigInt >> 8; //@line 23760
  HEAP8[$st$5$1 + 3 | 0] = tempBigInt & 255; //@line 23760
  HEAP32[$da + 28 >> 2] = 2; //@line 23762
  _dasm_arg($da, $da + 96 | 0, $src, 24, 16); //@line 23764
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23770
  STACKTOP = sp; //@line 23772
  return;
 }
}
function _d_48c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $3 = 0, $5 = 0, $7 = 0, $14 = 0, $st$1$0 = 0, $st$2$1 = 0, $24 = 0, $st$4$0 = 0, $st$5$1 = 0, sp = 0;
 sp = STACKTOP; //@line 23787
 $3 = HEAPU16[$da + 12 >> 1] | 0; //@line 23790
 $5 = $3 >>> 3 & 7; //@line 23792
 if (($5 | 0) == 4) {
  $14 = $da + 32 | 0; //@line 23795
  $st$1$0 = $14 | 0; //@line 23798
  tempBigInt = 1163284301; //@line 23799
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 23799
  tempBigInt = tempBigInt >> 8; //@line 23799
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 23799
  tempBigInt = tempBigInt >> 8; //@line 23799
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 23799
  tempBigInt = tempBigInt >> 8; //@line 23799
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 23799
  $st$2$1 = $14 + 4 | 0; //@line 23800
  tempBigInt = 4992589; //@line 23801
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 23801
  tempBigInt = tempBigInt >> 8; //@line 23801
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 23801
  tempBigInt = tempBigInt >> 8; //@line 23801
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 23801
  tempBigInt = tempBigInt >> 8; //@line 23801
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 23801
  HEAP32[$da + 28 >> 2] = 2; //@line 23803
  _dasm_arg($da, $da + 96 | 0, $src, 25, 32); //@line 23805
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23811
  STACKTOP = sp; //@line 23813
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 23816
  HEAP8[$7] = HEAP8[50296] | 0; //@line 23817
  HEAP8[$7 + 1 | 0] = HEAP8[50297 | 0] | 0; //@line 23817
  HEAP8[$7 + 2 | 0] = HEAP8[50298 | 0] | 0; //@line 23817
  HEAP8[$7 + 3 | 0] = HEAP8[50299 | 0] | 0; //@line 23817
  HEAP8[$7 + 4 | 0] = HEAP8[50300 | 0] | 0; //@line 23817
  HEAP8[$7 + 5 | 0] = HEAP8[50301 | 0] | 0; //@line 23817
  HEAP32[$da + 28 >> 2] = 1; //@line 23819
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 23822
  STACKTOP = sp; //@line 23824
  return;
 } else {
  $24 = $da + 32 | 0; //@line 23828
  $st$4$0 = $24 | 0; //@line 23831
  tempBigInt = 1163284301; //@line 23832
  HEAP8[$st$4$0] = tempBigInt & 255; //@line 23832
  tempBigInt = tempBigInt >> 8; //@line 23832
  HEAP8[$st$4$0 + 1 | 0] = tempBigInt & 255; //@line 23832
  tempBigInt = tempBigInt >> 8; //@line 23832
  HEAP8[$st$4$0 + 2 | 0] = tempBigInt & 255; //@line 23832
  tempBigInt = tempBigInt >> 8; //@line 23832
  HEAP8[$st$4$0 + 3 | 0] = tempBigInt & 255; //@line 23832
  $st$5$1 = $24 + 4 | 0; //@line 23833
  tempBigInt = 4992589; //@line 23834
  HEAP8[$st$5$1] = tempBigInt & 255; //@line 23834
  tempBigInt = tempBigInt >> 8; //@line 23834
  HEAP8[$st$5$1 + 1 | 0] = tempBigInt & 255; //@line 23834
  tempBigInt = tempBigInt >> 8; //@line 23834
  HEAP8[$st$5$1 + 2 | 0] = tempBigInt & 255; //@line 23834
  tempBigInt = tempBigInt >> 8; //@line 23834
  HEAP8[$st$5$1 + 3 | 0] = tempBigInt & 255; //@line 23834
  HEAP32[$da + 28 >> 2] = 2; //@line 23836
  _dasm_arg($da, $da + 96 | 0, $src, 24, 32); //@line 23838
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23844
  STACKTOP = sp; //@line 23846
  return;
 }
}
function _d_49c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $4 = 0, $7 = 0, $9 = 0, $11 = 0, $15 = 0, $22 = 0, $26 = 0, sp = 0;
 sp = STACKTOP; //@line 23860
 $2 = HEAP16[$da + 12 >> 1] | 0; //@line 23862
 $4 = $da + 32 | 0; //@line 23865
 if (($2 & 56) == 0) {
  HEAP8[$4] = HEAP8[50328] | 0; //@line 23868
  HEAP8[$4 + 1 | 0] = HEAP8[50329 | 0] | 0; //@line 23868
  HEAP8[$4 + 2 | 0] = HEAP8[50330 | 0] | 0; //@line 23868
  HEAP8[$4 + 3 | 0] = HEAP8[50331 | 0] | 0; //@line 23868
  HEAP8[$4 + 4 | 0] = HEAP8[50332 | 0] | 0; //@line 23868
  HEAP8[$4 + 5 | 0] = HEAP8[50333 | 0] | 0; //@line 23868
  HEAP8[$4 + 6 | 0] = HEAP8[50334 | 0] | 0; //@line 23868
  HEAP32[$da + 28 >> 2] = 1; //@line 23870
  $7 = $da + 96 | 0; //@line 23871
  $9 = $2 & 7; //@line 23873
  _sprintf($7 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $9, tempInt) | 0) | 0; //@line 23874
  $11 = $da | 0; //@line 23875
  HEAP32[$11 >> 2] = HEAP32[$11 >> 2] | 128; //@line 23878
  STACKTOP = sp; //@line 23880
  return;
 } else {
  $15 = $4; //@line 23883
  tempBigInt = 4277580; //@line 23884
  HEAP8[$15] = tempBigInt & 255; //@line 23884
  tempBigInt = tempBigInt >> 8; //@line 23884
  HEAP8[$15 + 1 | 0] = tempBigInt & 255; //@line 23884
  tempBigInt = tempBigInt >> 8; //@line 23884
  HEAP8[$15 + 2 | 0] = tempBigInt & 255; //@line 23884
  tempBigInt = tempBigInt >> 8; //@line 23884
  HEAP8[$15 + 3 | 0] = tempBigInt & 255; //@line 23884
  HEAP32[$da + 28 >> 2] = 2; //@line 23886
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23892
  $22 = $da + 160 | 0; //@line 23893
  $26 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 23897
  _sprintf($22 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $26, tempInt) | 0) | 0; //@line 23898
  STACKTOP = sp; //@line 23900
  return;
 }
}
function _d_4a00($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23912
 HEAP8[$1] = HEAP8[50464] | 0; //@line 23913
 HEAP8[$1 + 1 | 0] = HEAP8[50465 | 0] | 0; //@line 23913
 HEAP8[$1 + 2 | 0] = HEAP8[50466 | 0] | 0; //@line 23913
 HEAP8[$1 + 3 | 0] = HEAP8[50467 | 0] | 0; //@line 23913
 HEAP8[$1 + 4 | 0] = HEAP8[50468 | 0] | 0; //@line 23913
 HEAP8[$1 + 5 | 0] = HEAP8[50469 | 0] | 0; //@line 23913
 HEAP32[$da + 28 >> 2] = 1; //@line 23915
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 23921
 return;
}
function _d_4a40($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23933
 HEAP8[$1] = HEAP8[50520] | 0; //@line 23934
 HEAP8[$1 + 1 | 0] = HEAP8[50521 | 0] | 0; //@line 23934
 HEAP8[$1 + 2 | 0] = HEAP8[50522 | 0] | 0; //@line 23934
 HEAP8[$1 + 3 | 0] = HEAP8[50523 | 0] | 0; //@line 23934
 HEAP8[$1 + 4 | 0] = HEAP8[50524 | 0] | 0; //@line 23934
 HEAP8[$1 + 5 | 0] = HEAP8[50525 | 0] | 0; //@line 23934
 HEAP32[$da + 28 >> 2] = 1; //@line 23936
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 23942
 return;
}
function _d_4a80($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 23954
 HEAP8[$1] = HEAP8[50552] | 0; //@line 23955
 HEAP8[$1 + 1 | 0] = HEAP8[50553 | 0] | 0; //@line 23955
 HEAP8[$1 + 2 | 0] = HEAP8[50554 | 0] | 0; //@line 23955
 HEAP8[$1 + 3 | 0] = HEAP8[50555 | 0] | 0; //@line 23955
 HEAP8[$1 + 4 | 0] = HEAP8[50556 | 0] | 0; //@line 23955
 HEAP8[$1 + 5 | 0] = HEAP8[50557 | 0] | 0; //@line 23955
 HEAP32[$da + 28 >> 2] = 1; //@line 23957
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 23963
 return;
}
function _d_4ac0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $6 = 0, $st$1$0 = 0, $st$2$1 = 0, $8 = 0, $12 = 0;
 $4 = $da + 32 | 0; //@line 23980
 if ((HEAP16[$da + 12 >> 1] | 0) == 19196) {
  $6 = $4; //@line 23983
  $st$1$0 = $6 | 0; //@line 23986
  tempBigInt = 1162628169; //@line 23987
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 23987
  tempBigInt = tempBigInt >> 8; //@line 23987
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 23987
  tempBigInt = tempBigInt >> 8; //@line 23987
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 23987
  tempBigInt = tempBigInt >> 8; //@line 23987
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 23987
  $st$2$1 = $6 + 4 | 0; //@line 23988
  tempBigInt = 4997447; //@line 23989
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 23989
  tempBigInt = tempBigInt >> 8; //@line 23989
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 23989
  tempBigInt = tempBigInt >> 8; //@line 23989
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 23989
  tempBigInt = tempBigInt >> 8; //@line 23989
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 23989
  HEAP32[$da + 28 >> 2] = 0; //@line 23991
  $8 = $da | 0; //@line 23992
  HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 4; //@line 23995
  return;
 } else {
  $12 = $4; //@line 24000
  tempBigInt = 5456212; //@line 24001
  HEAP8[$12] = tempBigInt & 255; //@line 24001
  tempBigInt = tempBigInt >> 8; //@line 24001
  HEAP8[$12 + 1 | 0] = tempBigInt & 255; //@line 24001
  tempBigInt = tempBigInt >> 8; //@line 24001
  HEAP8[$12 + 2 | 0] = tempBigInt & 255; //@line 24001
  tempBigInt = tempBigInt >> 8; //@line 24001
  HEAP8[$12 + 3 | 0] = tempBigInt & 255; //@line 24001
  HEAP32[$da + 28 >> 2] = 1; //@line 24003
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 24009
  return;
 }
}
function _d_4c00($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $3 = 0, $7 = 0, $11 = 0, $13 = 0, $16 = 0, $23 = 0, $25 = 0, $27 = 0, $29 = 0, $33 = 0, $36 = 0, $37 = 0, $38 = 0, sp = 0;
 sp = STACKTOP; //@line 24025
 $1 = $da + 8 | 0; //@line 24026
 $2 = HEAP32[$1 >> 2] | 0; //@line 24027
 $3 = $2 << 1; //@line 24028
 $7 = (HEAPU8[$src + $3 | 0] | 0) << 8; //@line 24032
 $11 = $7 | (HEAPU8[$src + ($3 | 1) | 0] | 0); //@line 24037
 HEAP32[$1 >> 2] = $2 + 1; //@line 24039
 $13 = $da + 14 | 0; //@line 24040
 HEAP16[$13 >> 1] = $11; //@line 24041
 $16 = $da + 32 | 0; //@line 24044
 HEAP8[$16] = HEAP8[50600] | 0; //@line 24045
 HEAP8[$16 + 1 | 0] = HEAP8[50601 | 0] | 0; //@line 24045
 HEAP8[$16 + 2 | 0] = HEAP8[50602 | 0] | 0; //@line 24045
 HEAP8[$16 + 3 | 0] = HEAP8[50603 | 0] | 0; //@line 24045
 HEAP8[$16 + 4 | 0] = HEAP8[50604 | 0] | 0; //@line 24045
 HEAP8[$16 + 5 | 0] = HEAP8[50605 | 0] | 0; //@line 24045
 HEAP8[$16 + 6 | 0] = HEAP8[50606 | 0] | 0; //@line 24045
 HEAP32[$da + 28 >> 2] = 2; //@line 24047
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 24053
 $23 = $da + 160 | 0; //@line 24054
 $25 = HEAPU16[$13 >> 1] | 0; //@line 24056
 if (($7 & 1024) == 0) {
  $33 = $25 >>> 12 & 7; //@line 24060
  _sprintf($23 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $33, tempInt) | 0) | 0; //@line 24061
  $36 = $da | 0; //@line 24062
  $37 = HEAP32[$36 >> 2] | 0; //@line 24063
  $38 = $37 | 128; //@line 24064
  HEAP32[$36 >> 2] = $38; //@line 24065
  STACKTOP = sp; //@line 24066
  return;
 } else {
  $27 = $25 & 7; //@line 24069
  $29 = $25 >>> 12 & 7; //@line 24071
  _sprintf($23 | 0, 50584, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $27, HEAP32[tempInt + 8 >> 2] = $29, tempInt) | 0) | 0; //@line 24072
  $36 = $da | 0; //@line 24074
  $37 = HEAP32[$36 >> 2] | 0; //@line 24075
  $38 = $37 | 128; //@line 24076
  HEAP32[$36 >> 2] = $38; //@line 24077
  STACKTOP = sp; //@line 24078
  return;
 }
}
function _d_4c40($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $3 = 0, $7 = 0, $11 = 0, $13 = 0, $16 = 0, $18 = 0, $st$1$0 = 0, $st$2$1 = 0, $25 = 0, $27 = 0, $28 = 0, $30 = 0, $39 = 0, $41 = 0, $42 = 0, $44 = 0, $47 = 0, $48 = 0, $49 = 0, sp = 0;
 sp = STACKTOP; //@line 24095
 $1 = $da + 8 | 0; //@line 24096
 $2 = HEAP32[$1 >> 2] | 0; //@line 24097
 $3 = $2 << 1; //@line 24098
 $7 = (HEAPU8[$src + $3 | 0] | 0) << 8; //@line 24102
 $11 = $7 | (HEAPU8[$src + ($3 | 1) | 0] | 0); //@line 24107
 HEAP32[$1 >> 2] = $2 + 1; //@line 24109
 $13 = $da + 14 | 0; //@line 24110
 HEAP16[$13 >> 1] = $11; //@line 24111
 $16 = $da + 32 | 0; //@line 24114
 if (($7 & 1024) == 0) {
  HEAP8[$16] = HEAP8[50616] | 0; //@line 24117
  HEAP8[$16 + 1 | 0] = HEAP8[50617 | 0] | 0; //@line 24117
  HEAP8[$16 + 2 | 0] = HEAP8[50618 | 0] | 0; //@line 24117
  HEAP8[$16 + 3 | 0] = HEAP8[50619 | 0] | 0; //@line 24117
  HEAP8[$16 + 4 | 0] = HEAP8[50620 | 0] | 0; //@line 24117
  HEAP8[$16 + 5 | 0] = HEAP8[50621 | 0] | 0; //@line 24117
  HEAP8[$16 + 6 | 0] = HEAP8[50622 | 0] | 0; //@line 24117
  HEAP32[$da + 28 >> 2] = 2; //@line 24119
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 24125
  $39 = $da + 160 | 0; //@line 24126
  $41 = HEAPU16[$13 >> 1] | 0; //@line 24128
  $42 = $41 & 7; //@line 24129
  $44 = $41 >>> 12 & 7; //@line 24131
  _sprintf($39 | 0, 50584, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $42, HEAP32[tempInt + 8 >> 2] = $44, tempInt) | 0) | 0; //@line 24132
  $47 = $da | 0; //@line 24133
  $48 = HEAP32[$47 >> 2] | 0; //@line 24134
  $49 = $48 | 128; //@line 24135
  HEAP32[$47 >> 2] = $49; //@line 24136
  STACKTOP = sp; //@line 24137
  return;
 } else {
  $18 = $16; //@line 24140
  $st$1$0 = $18 | 0; //@line 24143
  tempBigInt = 1431718212; //@line 24144
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 24144
  tempBigInt = tempBigInt >> 8; //@line 24144
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 24144
  tempBigInt = tempBigInt >> 8; //@line 24144
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 24144
  tempBigInt = tempBigInt >> 8; //@line 24144
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 24144
  $st$2$1 = $18 + 4 | 0; //@line 24145
  tempBigInt = 4992588; //@line 24146
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 24146
  tempBigInt = tempBigInt >> 8; //@line 24146
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 24146
  tempBigInt = tempBigInt >> 8; //@line 24146
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 24146
  tempBigInt = tempBigInt >> 8; //@line 24146
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 24146
  HEAP32[$da + 28 >> 2] = 2; //@line 24148
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 24154
  $25 = $da + 160 | 0; //@line 24155
  $27 = HEAPU16[$13 >> 1] | 0; //@line 24157
  $28 = $27 & 7; //@line 24158
  $30 = $27 >>> 12 & 7; //@line 24160
  _sprintf($25 | 0, 50584, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $28, HEAP32[tempInt + 8 >> 2] = $30, tempInt) | 0) | 0; //@line 24161
  $47 = $da | 0; //@line 24163
  $48 = HEAP32[$47 >> 2] | 0; //@line 24164
  $49 = $48 | 128; //@line 24165
  HEAP32[$47 >> 2] = $49; //@line 24166
  STACKTOP = sp; //@line 24167
  return;
 }
}
function _d_4c80($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $7 = 0, $15 = 0, $18 = 0, $st$1$0 = 0, $st$2$1 = 0, sp = 0;
 sp = STACKTOP; //@line 24181
 $4 = $da + 32 | 0; //@line 24186
 if ((HEAP16[$da + 12 >> 1] & 56) == 0) {
  HEAP8[$4] = HEAP8[36120] | 0; //@line 24189
  HEAP8[$4 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 24189
  HEAP8[$4 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 24189
  HEAP32[$da + 28 >> 2] = 1; //@line 24191
  $7 = $da + 96 | 0; //@line 24192
  $15 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 24200
  _sprintf($7 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $15, tempInt) | 0) | 0; //@line 24201
  STACKTOP = sp; //@line 24203
  return;
 } else {
  $18 = $4; //@line 24206
  $st$1$0 = $18 | 0; //@line 24209
  tempBigInt = 1163284301; //@line 24210
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 24210
  tempBigInt = tempBigInt >> 8; //@line 24210
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 24210
  tempBigInt = tempBigInt >> 8; //@line 24210
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 24210
  tempBigInt = tempBigInt >> 8; //@line 24210
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 24210
  $st$2$1 = $18 + 4 | 0; //@line 24211
  tempBigInt = 5713485; //@line 24212
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 24212
  tempBigInt = tempBigInt >> 8; //@line 24212
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 24212
  tempBigInt = tempBigInt >> 8; //@line 24212
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 24212
  tempBigInt = tempBigInt >> 8; //@line 24212
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 24212
  HEAP32[$da + 28 >> 2] = 2; //@line 24214
  _dasm_arg($da, $da + 160 | 0, $src, 24, 16); //@line 24216
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 24222
  STACKTOP = sp; //@line 24224
  return;
 }
}
function _d_4cc0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $4 = 0, $7 = 0, $15 = 0, $18 = 0, $st$1$0 = 0, $st$2$1 = 0, sp = 0;
 sp = STACKTOP; //@line 24238
 $4 = $da + 32 | 0; //@line 24243
 if ((HEAP16[$da + 12 >> 1] & 56) == 0) {
  HEAP8[$4] = HEAP8[36120] | 0; //@line 24246
  HEAP8[$4 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 24246
  HEAP8[$4 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 24246
  HEAP32[$da + 28 >> 2] = 1; //@line 24248
  $7 = $da + 96 | 0; //@line 24249
  $15 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 24257
  _sprintf($7 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $15, tempInt) | 0) | 0; //@line 24258
  STACKTOP = sp; //@line 24260
  return;
 } else {
  $18 = $4; //@line 24263
  $st$1$0 = $18 | 0; //@line 24266
  tempBigInt = 1163284301; //@line 24267
  HEAP8[$st$1$0] = tempBigInt & 255; //@line 24267
  tempBigInt = tempBigInt >> 8; //@line 24267
  HEAP8[$st$1$0 + 1 | 0] = tempBigInt & 255; //@line 24267
  tempBigInt = tempBigInt >> 8; //@line 24267
  HEAP8[$st$1$0 + 2 | 0] = tempBigInt & 255; //@line 24267
  tempBigInt = tempBigInt >> 8; //@line 24267
  HEAP8[$st$1$0 + 3 | 0] = tempBigInt & 255; //@line 24267
  $st$2$1 = $18 + 4 | 0; //@line 24268
  tempBigInt = 4992589; //@line 24269
  HEAP8[$st$2$1] = tempBigInt & 255; //@line 24269
  tempBigInt = tempBigInt >> 8; //@line 24269
  HEAP8[$st$2$1 + 1 | 0] = tempBigInt & 255; //@line 24269
  tempBigInt = tempBigInt >> 8; //@line 24269
  HEAP8[$st$2$1 + 2 | 0] = tempBigInt & 255; //@line 24269
  tempBigInt = tempBigInt >> 8; //@line 24269
  HEAP8[$st$2$1 + 3 | 0] = tempBigInt & 255; //@line 24269
  HEAP32[$da + 28 >> 2] = 2; //@line 24271
  _dasm_arg($da, $da + 160 | 0, $src, 24, 32); //@line 24273
  _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 24279
  STACKTOP = sp; //@line 24281
  return;
 }
}
function _d_4e40($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $3 = 0, $5 = 0, $7 = 0, $12 = 0, $15 = 0, $26 = 0, $28 = 0, $31 = 0, $36 = 0, $38 = 0, $43 = 0, $54 = 0, $56 = 0, $59 = 0, $64 = 0, $66 = 0, $70 = 0, $72 = 0, $77 = 0, $80 = 0, $83 = 0, $85 = 0, $86 = 0, $95 = 0, $97 = 0, $101 = 0, $105 = 0, $109 = 0, $114 = 0, $str_0_i_i = 0, $118 = 0, $119 = 0, $_pre_phi = 0, $123 = 0, $133 = 0, $136 = 0, $139 = 0, $141 = 0, $148 = 0, $157 = 0, $159 = 0, $161 = 0, $163 = 0, $165 = 0, $167 = 0, $169 = 0, $171 = 0, $173 = 0, $176 = 0, $178 = 0, $180 = 0, $str_0_i_i42 = 0, $181 = 0, $182 = 0, $_pre_phi45 = 0, $184 = 0, $190 = 0, $192 = 0, $193 = 0, $196 = 0, $198 = 0, $200 = 0, $201 = 0, $203 = 0, $212 = 0, $214 = 0, $218 = 0, $224 = 0, $230 = 0, $231 = 0, $235 = 0, $238 = 0, $242 = 0, $246 = 0, $256 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 24321
 $2 = HEAP16[$da + 12 >> 1] | 0; //@line 24323
 $3 = $2 & 65535; //@line 24324
 if (($2 << 16 >> 16 | 0) == 20085) {
  $64 = $da + 32 | 0; //@line 24327
  tempBigInt = 5461074; //@line 24328
  HEAP8[$64] = tempBigInt & 255; //@line 24328
  tempBigInt = tempBigInt >> 8; //@line 24328
  HEAP8[$64 + 1 | 0] = tempBigInt & 255; //@line 24328
  tempBigInt = tempBigInt >> 8; //@line 24328
  HEAP8[$64 + 2 | 0] = tempBigInt & 255; //@line 24328
  tempBigInt = tempBigInt >> 8; //@line 24328
  HEAP8[$64 + 3 | 0] = tempBigInt & 255; //@line 24328
  HEAP32[$da + 28 >> 2] = 0; //@line 24330
  $66 = $da | 0; //@line 24331
  HEAP32[$66 >> 2] = HEAP32[$66 >> 2] | 16; //@line 24334
  STACKTOP = sp; //@line 24336
  return;
 } else if (($2 << 16 >> 16 | 0) == 20082) {
  $15 = $da + 32 | 0; //@line 24339
  HEAP8[$15] = HEAP8[51296] | 0; //@line 24340
  HEAP8[$15 + 1 | 0] = HEAP8[51297 | 0] | 0; //@line 24340
  HEAP8[$15 + 2 | 0] = HEAP8[51298 | 0] | 0; //@line 24340
  HEAP8[$15 + 3 | 0] = HEAP8[51299 | 0] | 0; //@line 24340
  HEAP8[$15 + 4 | 0] = HEAP8[51300 | 0] | 0; //@line 24340
  HEAP32[$da + 28 >> 2] = 1; //@line 24342
  $26 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 24352
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $26, tempInt) | 0) | 0; //@line 24353
  $28 = $da + 8 | 0; //@line 24354
  HEAP32[$28 >> 2] = (HEAP32[$28 >> 2] | 0) + 1; //@line 24357
  $31 = $da | 0; //@line 24358
  HEAP32[$31 >> 2] = HEAP32[$31 >> 2] | 1; //@line 24361
  STACKTOP = sp; //@line 24363
  return;
 } else if (($2 << 16 >> 16 | 0) == 20087) {
  $77 = $da + 32 | 0; //@line 24367
  tempBigInt = 5395538; //@line 24368
  HEAP8[$77] = tempBigInt & 255; //@line 24368
  tempBigInt = tempBigInt >> 8; //@line 24368
  HEAP8[$77 + 1 | 0] = tempBigInt & 255; //@line 24368
  tempBigInt = tempBigInt >> 8; //@line 24368
  HEAP8[$77 + 2 | 0] = tempBigInt & 255; //@line 24368
  tempBigInt = tempBigInt >> 8; //@line 24368
  HEAP8[$77 + 3 | 0] = tempBigInt & 255; //@line 24368
  HEAP32[$da + 28 >> 2] = 0; //@line 24370
  STACKTOP = sp; //@line 24372
  return;
 } else if (($2 << 16 >> 16 | 0) == 20081) {
  $12 = $da + 32 | 0; //@line 24376
  tempBigInt = 5263182; //@line 24377
  HEAP8[$12] = tempBigInt & 255; //@line 24377
  tempBigInt = tempBigInt >> 8; //@line 24377
  HEAP8[$12 + 1 | 0] = tempBigInt & 255; //@line 24377
  tempBigInt = tempBigInt >> 8; //@line 24377
  HEAP8[$12 + 2 | 0] = tempBigInt & 255; //@line 24377
  tempBigInt = tempBigInt >> 8; //@line 24377
  HEAP8[$12 + 3 | 0] = tempBigInt & 255; //@line 24377
  HEAP32[$da + 28 >> 2] = 0; //@line 24379
  STACKTOP = sp; //@line 24381
  return;
 } else if (($2 << 16 >> 16 | 0) == 20086) {
  $70 = $da + 32 | 0; //@line 24384
  HEAP8[$70] = HEAP8[51024] | 0; //@line 24385
  HEAP8[$70 + 1 | 0] = HEAP8[51025 | 0] | 0; //@line 24385
  HEAP8[$70 + 2 | 0] = HEAP8[51026 | 0] | 0; //@line 24385
  HEAP8[$70 + 3 | 0] = HEAP8[51027 | 0] | 0; //@line 24385
  HEAP8[$70 + 4 | 0] = HEAP8[51028 | 0] | 0; //@line 24385
  HEAP8[$70 + 5 | 0] = HEAP8[51029 | 0] | 0; //@line 24385
  HEAP32[$da + 28 >> 2] = 0; //@line 24387
  $72 = $da | 0; //@line 24388
  HEAP32[$72 >> 2] = HEAP32[$72 >> 2] | 32; //@line 24391
  STACKTOP = sp; //@line 24393
  return;
 } else if (($2 << 16 >> 16 | 0) == 20084) {
  $43 = $da + 32 | 0; //@line 24397
  tempBigInt = 4478034; //@line 24398
  HEAP8[$43] = tempBigInt & 255; //@line 24398
  tempBigInt = tempBigInt >> 8; //@line 24398
  HEAP8[$43 + 1 | 0] = tempBigInt & 255; //@line 24398
  tempBigInt = tempBigInt >> 8; //@line 24398
  HEAP8[$43 + 2 | 0] = tempBigInt & 255; //@line 24398
  tempBigInt = tempBigInt >> 8; //@line 24398
  HEAP8[$43 + 3 | 0] = tempBigInt & 255; //@line 24398
  HEAP32[$da + 28 >> 2] = 1; //@line 24400
  $54 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 24410
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $54, tempInt) | 0) | 0; //@line 24411
  $56 = $da + 8 | 0; //@line 24412
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 1; //@line 24415
  $59 = $da | 0; //@line 24416
  HEAP32[$59 >> 2] = HEAP32[$59 >> 2] | 80; //@line 24419
  STACKTOP = sp; //@line 24421
  return;
 } else if (($2 << 16 >> 16 | 0) == 20090) {
  $80 = $da + 8 | 0; //@line 24424
  HEAP32[$80 >> 2] = (HEAP32[$80 >> 2] | 0) + 1; //@line 24427
  $83 = $da + 32 | 0; //@line 24428
  HEAP8[$83] = HEAP8[50968] | 0; //@line 24429
  HEAP8[$83 + 1 | 0] = HEAP8[50969 | 0] | 0; //@line 24429
  HEAP8[$83 + 2 | 0] = HEAP8[50970 | 0] | 0; //@line 24429
  HEAP8[$83 + 3 | 0] = HEAP8[50971 | 0] | 0; //@line 24429
  HEAP8[$83 + 4 | 0] = HEAP8[50972 | 0] | 0; //@line 24429
  HEAP8[$83 + 5 | 0] = HEAP8[50973 | 0] | 0; //@line 24429
  HEAP32[$da + 28 >> 2] = 2; //@line 24431
  $85 = $da + 96 | 0; //@line 24432
  $86 = $src + 2 | 0; //@line 24433
  $95 = ((HEAPU8[$86] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 4095; //@line 24442
  if (($95 | 0) == 2048) {
   $105 = $da | 0; //@line 24444
   HEAP32[$105 >> 2] = HEAP32[$105 >> 2] | 64; //@line 24447
   $str_0_i_i = 50984; //@line 24449
   label = 2813; //@line 24450
  } else if (($95 | 0) == 0) {
   $97 = $da | 0; //@line 24452
   HEAP32[$97 >> 2] = HEAP32[$97 >> 2] | 64; //@line 24455
   $str_0_i_i = 48824; //@line 24457
   label = 2813; //@line 24458
  } else if (($95 | 0) == 2049) {
   $109 = $da | 0; //@line 24460
   HEAP32[$109 >> 2] = HEAP32[$109 >> 2] | 64; //@line 24463
   $str_0_i_i = 48032; //@line 24465
   label = 2813; //@line 24466
  } else if (($95 | 0) == 1) {
   $101 = $da | 0; //@line 24468
   HEAP32[$101 >> 2] = HEAP32[$101 >> 2] | 64; //@line 24471
   $str_0_i_i = 48424; //@line 24473
   label = 2813; //@line 24474
  } else {
   _sprintf($85 | 0, 47736, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $95, tempInt) | 0) | 0; //@line 24476
   $114 = $da | 0; //@line 24477
   HEAP32[$114 >> 2] = HEAP32[$114 >> 2] | 64; //@line 24480
   $_pre_phi = $114; //@line 24482
  }
  if ((label | 0) == 2813) {
   $118 = $str_0_i_i; //@line 24486
   $119 = $85; //@line 24487
   tempBigInt = HEAPU8[$118] | HEAPU8[$118 + 1 | 0] << 8 | HEAPU8[$118 + 2 | 0] << 16 | HEAPU8[$118 + 3 | 0] << 24 | 0; //@line 24489
   HEAP8[$119] = tempBigInt & 255; //@line 24489
   tempBigInt = tempBigInt >> 8; //@line 24489
   HEAP8[$119 + 1 | 0] = tempBigInt & 255; //@line 24489
   tempBigInt = tempBigInt >> 8; //@line 24489
   HEAP8[$119 + 2 | 0] = tempBigInt & 255; //@line 24489
   tempBigInt = tempBigInt >> 8; //@line 24489
   HEAP8[$119 + 3 | 0] = tempBigInt & 255; //@line 24489
   $_pre_phi = $da | 0; //@line 24492
  }
  $123 = HEAPU8[$86] | 0; //@line 24497
  _sprintf($da + 160 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = ($123 & 128 | 0) != 0 ? 34768 : 32184, HEAP32[tempInt + 8 >> 2] = $123 >>> 4 & 7, tempInt) | 0) | 0; //@line 24503
  HEAP32[$_pre_phi >> 2] = HEAP32[$_pre_phi >> 2] | 64; //@line 24506
  STACKTOP = sp; //@line 24508
  return;
 } else if (($2 << 16 >> 16 | 0) == 20080) {
  $5 = $da + 32 | 0; //@line 24511
  HEAP8[$5] = HEAP8[51400] | 0; //@line 24512
  HEAP8[$5 + 1 | 0] = HEAP8[51401 | 0] | 0; //@line 24512
  HEAP8[$5 + 2 | 0] = HEAP8[51402 | 0] | 0; //@line 24512
  HEAP8[$5 + 3 | 0] = HEAP8[51403 | 0] | 0; //@line 24512
  HEAP8[$5 + 4 | 0] = HEAP8[51404 | 0] | 0; //@line 24512
  HEAP8[$5 + 5 | 0] = HEAP8[51405 | 0] | 0; //@line 24512
  HEAP32[$da + 28 >> 2] = 0; //@line 24514
  $7 = $da | 0; //@line 24515
  HEAP32[$7 >> 2] = HEAP32[$7 >> 2] | 1; //@line 24518
  STACKTOP = sp; //@line 24520
  return;
 } else if (($2 << 16 >> 16 | 0) == 20083) {
  $36 = $da + 32 | 0; //@line 24524
  tempBigInt = 4543570; //@line 24525
  HEAP8[$36] = tempBigInt & 255; //@line 24525
  tempBigInt = tempBigInt >> 8; //@line 24525
  HEAP8[$36 + 1 | 0] = tempBigInt & 255; //@line 24525
  tempBigInt = tempBigInt >> 8; //@line 24525
  HEAP8[$36 + 2 | 0] = tempBigInt & 255; //@line 24525
  tempBigInt = tempBigInt >> 8; //@line 24525
  HEAP8[$36 + 3 | 0] = tempBigInt & 255; //@line 24525
  HEAP32[$da + 28 >> 2] = 0; //@line 24527
  $38 = $da | 0; //@line 24528
  HEAP32[$38 >> 2] = HEAP32[$38 >> 2] | 9; //@line 24531
  STACKTOP = sp; //@line 24533
  return;
 } else if (($2 << 16 >> 16 | 0) == 20091) {
  $133 = $da + 8 | 0; //@line 24536
  HEAP32[$133 >> 2] = (HEAP32[$133 >> 2] | 0) + 1; //@line 24539
  $136 = $da + 32 | 0; //@line 24540
  HEAP8[$136] = HEAP8[50968] | 0; //@line 24541
  HEAP8[$136 + 1 | 0] = HEAP8[50969 | 0] | 0; //@line 24541
  HEAP8[$136 + 2 | 0] = HEAP8[50970 | 0] | 0; //@line 24541
  HEAP8[$136 + 3 | 0] = HEAP8[50971 | 0] | 0; //@line 24541
  HEAP8[$136 + 4 | 0] = HEAP8[50972 | 0] | 0; //@line 24541
  HEAP8[$136 + 5 | 0] = HEAP8[50973 | 0] | 0; //@line 24541
  HEAP32[$da + 28 >> 2] = 2; //@line 24543
  $139 = $src + 2 | 0; //@line 24545
  $141 = HEAPU8[$139] | 0; //@line 24547
  _sprintf($da + 96 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = ($141 & 128 | 0) != 0 ? 34768 : 32184, HEAP32[tempInt + 8 >> 2] = $141 >>> 4 & 7, tempInt) | 0) | 0; //@line 24553
  $148 = $da + 160 | 0; //@line 24554
  $157 = ((HEAPU8[$139] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 4095; //@line 24563
  if (($157 | 0) == 1) {
   $163 = $da | 0; //@line 24565
   $165 = HEAP32[$163 >> 2] | 64; //@line 24567
   HEAP32[$163 >> 2] = $165; //@line 24568
   $str_0_i_i42 = 48424;
   $180 = $165;
   label = 2821; //@line 24571
  } else if (($157 | 0) == 2048) {
   $167 = $da | 0; //@line 24573
   $169 = HEAP32[$167 >> 2] | 64; //@line 24575
   HEAP32[$167 >> 2] = $169; //@line 24576
   $str_0_i_i42 = 50984;
   $180 = $169;
   label = 2821; //@line 24579
  } else if (($157 | 0) == 0) {
   $159 = $da | 0; //@line 24581
   $161 = HEAP32[$159 >> 2] | 64; //@line 24583
   HEAP32[$159 >> 2] = $161; //@line 24584
   $str_0_i_i42 = 48824;
   $180 = $161;
   label = 2821; //@line 24587
  } else if (($157 | 0) == 2049) {
   $171 = $da | 0; //@line 24589
   $173 = HEAP32[$171 >> 2] | 64; //@line 24591
   HEAP32[$171 >> 2] = $173; //@line 24592
   $str_0_i_i42 = 48032;
   $180 = $173;
   label = 2821; //@line 24595
  } else {
   _sprintf($148 | 0, 47736, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $157, tempInt) | 0) | 0; //@line 24597
   $176 = $da | 0; //@line 24598
   $178 = HEAP32[$176 >> 2] | 64; //@line 24600
   HEAP32[$176 >> 2] = $178; //@line 24601
   $184 = $178;
   $_pre_phi45 = $176;
  }
  if ((label | 0) == 2821) {
   $181 = $str_0_i_i42; //@line 24608
   $182 = $148; //@line 24609
   tempBigInt = HEAPU8[$181] | HEAPU8[$181 + 1 | 0] << 8 | HEAPU8[$181 + 2 | 0] << 16 | HEAPU8[$181 + 3 | 0] << 24 | 0; //@line 24611
   HEAP8[$182] = tempBigInt & 255; //@line 24611
   tempBigInt = tempBigInt >> 8; //@line 24611
   HEAP8[$182 + 1 | 0] = tempBigInt & 255; //@line 24611
   tempBigInt = tempBigInt >> 8; //@line 24611
   HEAP8[$182 + 2 | 0] = tempBigInt & 255; //@line 24611
   tempBigInt = tempBigInt >> 8; //@line 24611
   HEAP8[$182 + 3 | 0] = tempBigInt & 255; //@line 24611
   $184 = $180;
   $_pre_phi45 = $da | 0;
  }
  HEAP32[$_pre_phi45 >> 2] = $184 | 64; //@line 24619
  STACKTOP = sp; //@line 24621
  return;
 } else {
  if (($3 & 48 | 0) == 0) {
   $190 = $da + 32 | 0; //@line 24628
   HEAP8[$190] = HEAP8[50944] | 0; //@line 24629
   HEAP8[$190 + 1 | 0] = HEAP8[50945 | 0] | 0; //@line 24629
   HEAP8[$190 + 2 | 0] = HEAP8[50946 | 0] | 0; //@line 24629
   HEAP8[$190 + 3 | 0] = HEAP8[50947 | 0] | 0; //@line 24629
   HEAP8[$190 + 4 | 0] = HEAP8[50948 | 0] | 0; //@line 24629
   HEAP32[$da + 28 >> 2] = 1; //@line 24631
   $192 = $da + 96 | 0; //@line 24632
   $193 = $3 & 15; //@line 24633
   _sprintf($192 | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $193, tempInt) | 0) | 0; //@line 24634
   STACKTOP = sp; //@line 24636
   return;
  }
  $196 = $3 & 56; //@line 24639
  if (($196 | 0) == 16) {
   $198 = $da + 32 | 0; //@line 24641
   HEAP8[$198] = HEAP8[50904] | 0; //@line 24642
   HEAP8[$198 + 1 | 0] = HEAP8[50905 | 0] | 0; //@line 24642
   HEAP8[$198 + 2 | 0] = HEAP8[50906 | 0] | 0; //@line 24642
   HEAP8[$198 + 3 | 0] = HEAP8[50907 | 0] | 0; //@line 24642
   HEAP8[$198 + 4 | 0] = HEAP8[50908 | 0] | 0; //@line 24642
   HEAP32[$da + 28 >> 2] = 2; //@line 24644
   $200 = $da + 96 | 0; //@line 24645
   $201 = $3 & 7; //@line 24646
   _sprintf($200 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $201, tempInt) | 0) | 0; //@line 24647
   $203 = $da + 160 | 0; //@line 24648
   $212 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 24657
   _sprintf($203 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $212, tempInt) | 0) | 0; //@line 24658
   $214 = $da + 8 | 0; //@line 24659
   HEAP32[$214 >> 2] = (HEAP32[$214 >> 2] | 0) + 1; //@line 24662
   STACKTOP = sp; //@line 24664
   return;
  } else if (($196 | 0) == 24) {
   $218 = $da + 32 | 0; //@line 24667
   HEAP8[$218] = HEAP8[50848] | 0; //@line 24668
   HEAP8[$218 + 1 | 0] = HEAP8[50849 | 0] | 0; //@line 24668
   HEAP8[$218 + 2 | 0] = HEAP8[50850 | 0] | 0; //@line 24668
   HEAP8[$218 + 3 | 0] = HEAP8[50851 | 0] | 0; //@line 24668
   HEAP8[$218 + 4 | 0] = HEAP8[50852 | 0] | 0; //@line 24668
   HEAP32[$da + 28 >> 2] = 1; //@line 24670
   _sprintf($da + 96 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 24673
   STACKTOP = sp; //@line 24675
   return;
  } else if (($196 | 0) == 32) {
   $224 = $da + 32 | 0; //@line 24678
   HEAP8[$224] = HEAP8[50792] | 0; //@line 24679
   HEAP8[$224 + 1 | 0] = HEAP8[50793 | 0] | 0; //@line 24679
   HEAP8[$224 + 2 | 0] = HEAP8[50794 | 0] | 0; //@line 24679
   HEAP8[$224 + 3 | 0] = HEAP8[50795 | 0] | 0; //@line 24679
   HEAP8[$224 + 4 | 0] = HEAP8[50796 | 0] | 0; //@line 24679
   HEAP32[$da + 28 >> 2] = 2; //@line 24681
   _sprintf($da + 96 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 24684
   $230 = $da + 160 | 0; //@line 24686
   tempBigInt = 5264213; //@line 24687
   HEAP8[$230] = tempBigInt & 255; //@line 24687
   tempBigInt = tempBigInt >> 8; //@line 24687
   HEAP8[$230 + 1 | 0] = tempBigInt & 255; //@line 24687
   tempBigInt = tempBigInt >> 8; //@line 24687
   HEAP8[$230 + 2 | 0] = tempBigInt & 255; //@line 24687
   tempBigInt = tempBigInt >> 8; //@line 24687
   HEAP8[$230 + 3 | 0] = tempBigInt & 255; //@line 24687
   $231 = $da | 0; //@line 24688
   HEAP32[$231 >> 2] = HEAP32[$231 >> 2] | 1; //@line 24691
   STACKTOP = sp; //@line 24693
   return;
  } else if (($196 | 0) == 40) {
   $235 = $da + 32 | 0; //@line 24696
   HEAP8[$235] = HEAP8[50792] | 0; //@line 24697
   HEAP8[$235 + 1 | 0] = HEAP8[50793 | 0] | 0; //@line 24697
   HEAP8[$235 + 2 | 0] = HEAP8[50794 | 0] | 0; //@line 24697
   HEAP8[$235 + 3 | 0] = HEAP8[50795 | 0] | 0; //@line 24697
   HEAP8[$235 + 4 | 0] = HEAP8[50796 | 0] | 0; //@line 24697
   HEAP32[$da + 28 >> 2] = 2; //@line 24699
   $238 = $da + 96 | 0; //@line 24701
   tempBigInt = 5264213; //@line 24702
   HEAP8[$238] = tempBigInt & 255; //@line 24702
   tempBigInt = tempBigInt >> 8; //@line 24702
   HEAP8[$238 + 1 | 0] = tempBigInt & 255; //@line 24702
   tempBigInt = tempBigInt >> 8; //@line 24702
   HEAP8[$238 + 2 | 0] = tempBigInt & 255; //@line 24702
   tempBigInt = tempBigInt >> 8; //@line 24702
   HEAP8[$238 + 3 | 0] = tempBigInt & 255; //@line 24702
   _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 24705
   $242 = $da | 0; //@line 24706
   HEAP32[$242 >> 2] = HEAP32[$242 >> 2] | 1; //@line 24709
   STACKTOP = sp; //@line 24711
   return;
  } else {
   $246 = $da + 32 | 0; //@line 24714
   HEAP8[$246] = HEAP8[36120] | 0; //@line 24715
   HEAP8[$246 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 24715
   HEAP8[$246 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 24715
   HEAP32[$da + 28 >> 2] = 1; //@line 24717
   $256 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 24726
   _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $256, tempInt) | 0) | 0; //@line 24727
   STACKTOP = sp; //@line 24728
   return;
  }
 }
}
function _d_4e80($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $2 = 0, $9 = 0;
 $2 = $da + 32 | 0; //@line 24743
 tempBigInt = 5395274; //@line 24744
 HEAP8[$2] = tempBigInt & 255; //@line 24744
 tempBigInt = tempBigInt >> 8; //@line 24744
 HEAP8[$2 + 1 | 0] = tempBigInt & 255; //@line 24744
 tempBigInt = tempBigInt >> 8; //@line 24744
 HEAP8[$2 + 2 | 0] = tempBigInt & 255; //@line 24744
 tempBigInt = tempBigInt >> 8; //@line 24744
 HEAP8[$2 + 3 | 0] = tempBigInt & 255; //@line 24744
 HEAP32[$da + 28 >> 2] = 1; //@line 24746
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 0); //@line 24752
 $9 = $da | 0; //@line 24753
 HEAP32[$9 >> 2] = HEAP32[$9 >> 2] | 4; //@line 24756
 return;
}
function _d_5000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 24768
 $1 = $da + 32 | 0; //@line 24769
 HEAP8[$1] = HEAP8[51448] | 0; //@line 24770
 HEAP8[$1 + 1 | 0] = HEAP8[51449 | 0] | 0; //@line 24770
 HEAP8[$1 + 2 | 0] = HEAP8[51450 | 0] | 0; //@line 24770
 HEAP8[$1 + 3 | 0] = HEAP8[51451 | 0] | 0; //@line 24770
 HEAP8[$1 + 4 | 0] = HEAP8[51452 | 0] | 0; //@line 24770
 HEAP8[$1 + 5 | 0] = HEAP8[51453 | 0] | 0; //@line 24770
 HEAP8[$1 + 6 | 0] = HEAP8[51454 | 0] | 0; //@line 24770
 HEAP32[$da + 28 >> 2] = 2; //@line 24772
 $7 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 24777
 _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $7 << 16 >> 16 == 0 ? 8 : $7 & 65535, tempInt) | 0) | 0; //@line 24781
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 24787
 STACKTOP = sp; //@line 24788
 return;
}
function _d_5040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 24799
 $1 = $da + 32 | 0; //@line 24800
 HEAP8[$1] = HEAP8[51496] | 0; //@line 24801
 HEAP8[$1 + 1 | 0] = HEAP8[51497 | 0] | 0; //@line 24801
 HEAP8[$1 + 2 | 0] = HEAP8[51498 | 0] | 0; //@line 24801
 HEAP8[$1 + 3 | 0] = HEAP8[51499 | 0] | 0; //@line 24801
 HEAP8[$1 + 4 | 0] = HEAP8[51500 | 0] | 0; //@line 24801
 HEAP8[$1 + 5 | 0] = HEAP8[51501 | 0] | 0; //@line 24801
 HEAP8[$1 + 6 | 0] = HEAP8[51502 | 0] | 0; //@line 24801
 HEAP32[$da + 28 >> 2] = 2; //@line 24803
 $7 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 24808
 _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $7 << 16 >> 16 == 0 ? 8 : $7 & 65535, tempInt) | 0) | 0; //@line 24812
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 24818
 STACKTOP = sp; //@line 24819
 return;
}
function _d_5080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 24830
 $1 = $da + 32 | 0; //@line 24831
 HEAP8[$1] = HEAP8[51520] | 0; //@line 24832
 HEAP8[$1 + 1 | 0] = HEAP8[51521 | 0] | 0; //@line 24832
 HEAP8[$1 + 2 | 0] = HEAP8[51522 | 0] | 0; //@line 24832
 HEAP8[$1 + 3 | 0] = HEAP8[51523 | 0] | 0; //@line 24832
 HEAP8[$1 + 4 | 0] = HEAP8[51524 | 0] | 0; //@line 24832
 HEAP8[$1 + 5 | 0] = HEAP8[51525 | 0] | 0; //@line 24832
 HEAP8[$1 + 6 | 0] = HEAP8[51526 | 0] | 0; //@line 24832
 HEAP32[$da + 28 >> 2] = 2; //@line 24834
 $7 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 24839
 _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $7 << 16 >> 16 == 0 ? 8 : $7 & 65535, tempInt) | 0) | 0; //@line 24843
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 24849
 STACKTOP = sp; //@line 24850
 return;
}
function _d_50c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $9 = 0, $28 = 0, $30 = 0, $33 = 0, $38 = 0, $39 = 0, $42 = 0, $60 = 0, $62 = 0, $65 = 0, $74 = 0, $82 = 0, $83 = 0, $86 = 0, $89 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $102 = 0, $107 = 0, $112 = 0, $114 = 0, $119 = 0, $120 = 0, sp = 0;
 sp = STACKTOP; //@line 24874
 $1 = $da + 12 | 0; //@line 24875
 $3 = HEAPU16[$1 >> 1] | 0; //@line 24877
 $5 = $3 >>> 8 & 15; //@line 24879
 $6 = $3 & 63; //@line 24880
 if ($5 >>> 0 > 1) {
  $9 = $da | 0; //@line 24884
  HEAP32[$9 >> 2] = HEAP32[$9 >> 2] | 32; //@line 24887
 }
 if (($6 | 0) == 59) {
  $38 = HEAP32[7400 + ($5 << 2) >> 2] | 0; //@line 24892
  $39 = $da + 32 | 0; //@line 24893
  _strcpy($39 | 0, $38 | 0) | 0; //@line 24894
  HEAP32[$da + 28 >> 2] = 1; //@line 24896
  $42 = $da + 96 | 0; //@line 24897
  $60 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 24915
  _sprintf($42 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $60, tempInt) | 0) | 0; //@line 24916
  $62 = $da + 8 | 0; //@line 24917
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 24920
  $65 = $da | 0; //@line 24921
  HEAP32[$65 >> 2] = HEAP32[$65 >> 2] | 128; //@line 24924
  STACKTOP = sp; //@line 24926
  return;
 } else if (($6 | 0) == 60) {
  _strcpy($da + 32 | 0, HEAP32[7400 + ($5 << 2) >> 2] | 0) | 0; //@line 24932
  HEAP32[$da + 28 >> 2] = 0; //@line 24934
  $74 = $da | 0; //@line 24935
  HEAP32[$74 >> 2] = HEAP32[$74 >> 2] | 128; //@line 24938
  STACKTOP = sp; //@line 24940
  return;
 } else if (($6 | 0) == 58) {
  _strcpy($da + 32 | 0, HEAP32[7400 + ($5 << 2) >> 2] | 0) | 0; //@line 24946
  HEAP32[$da + 28 >> 2] = 1; //@line 24948
  $28 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 24958
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28, tempInt) | 0) | 0; //@line 24959
  $30 = $da + 8 | 0; //@line 24960
  HEAP32[$30 >> 2] = (HEAP32[$30 >> 2] | 0) + 1; //@line 24963
  $33 = $da | 0; //@line 24964
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 128; //@line 24967
  STACKTOP = sp; //@line 24969
  return;
 } else {
  if (($3 & 56 | 0) == 8) {
   $82 = HEAP32[7528 + ($5 << 2) >> 2] | 0; //@line 24977
   $83 = $da + 32 | 0; //@line 24978
   _strcpy($83 | 0, $82 | 0) | 0; //@line 24979
   HEAP32[$da + 28 >> 2] = 2; //@line 24981
   $86 = $da + 96 | 0; //@line 24982
   $89 = HEAP16[$1 >> 1] & 7; //@line 24985
   _sprintf($86 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $89, tempInt) | 0) | 0; //@line 24986
   $91 = $da + 160 | 0; //@line 24987
   $92 = $da + 8 | 0; //@line 24988
   $93 = HEAP32[$92 >> 2] | 0; //@line 24989
   $94 = $93 << 1; //@line 24990
   $102 = (HEAPU8[$src + $94 | 0] | 0) << 8 | (HEAPU8[$src + ($94 | 1) | 0] | 0); //@line 24999
   HEAP32[$92 >> 2] = $93 + 1; //@line 25001
   $107 = $102 & 65535; //@line 25005
   $112 = (HEAP32[$da + 4 >> 2] | 0) + 2 + (($107 & 32768 | 0) != 0 ? $107 | -65536 : $107) | 0; //@line 25010
   _sprintf($91 | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $112, tempInt) | 0) | 0; //@line 25011
   $114 = $da | 0; //@line 25012
   HEAP32[$114 >> 2] = HEAP32[$114 >> 2] | 2; //@line 25015
   STACKTOP = sp; //@line 25017
   return;
  } else {
   $119 = HEAP32[7464 + ($5 << 2) >> 2] | 0; //@line 25021
   $120 = $da + 32 | 0; //@line 25022
   _strcpy($120 | 0, $119 | 0) | 0; //@line 25023
   HEAP32[$da + 28 >> 2] = 1; //@line 25025
   _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 25031
   STACKTOP = sp; //@line 25032
   return;
  }
 }
}
function _d_5100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 25045
 $1 = $da + 32 | 0; //@line 25046
 HEAP8[$1] = HEAP8[54896] | 0; //@line 25047
 HEAP8[$1 + 1 | 0] = HEAP8[54897 | 0] | 0; //@line 25047
 HEAP8[$1 + 2 | 0] = HEAP8[54898 | 0] | 0; //@line 25047
 HEAP8[$1 + 3 | 0] = HEAP8[54899 | 0] | 0; //@line 25047
 HEAP8[$1 + 4 | 0] = HEAP8[54900 | 0] | 0; //@line 25047
 HEAP8[$1 + 5 | 0] = HEAP8[54901 | 0] | 0; //@line 25047
 HEAP8[$1 + 6 | 0] = HEAP8[54902 | 0] | 0; //@line 25047
 HEAP32[$da + 28 >> 2] = 2; //@line 25049
 $7 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 25054
 _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $7 << 16 >> 16 == 0 ? 8 : $7 & 65535, tempInt) | 0) | 0; //@line 25058
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 25064
 STACKTOP = sp; //@line 25065
 return;
}
function _d_5140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 25076
 $1 = $da + 32 | 0; //@line 25077
 HEAP8[$1] = HEAP8[54936] | 0; //@line 25078
 HEAP8[$1 + 1 | 0] = HEAP8[54937 | 0] | 0; //@line 25078
 HEAP8[$1 + 2 | 0] = HEAP8[54938 | 0] | 0; //@line 25078
 HEAP8[$1 + 3 | 0] = HEAP8[54939 | 0] | 0; //@line 25078
 HEAP8[$1 + 4 | 0] = HEAP8[54940 | 0] | 0; //@line 25078
 HEAP8[$1 + 5 | 0] = HEAP8[54941 | 0] | 0; //@line 25078
 HEAP8[$1 + 6 | 0] = HEAP8[54942 | 0] | 0; //@line 25078
 HEAP32[$da + 28 >> 2] = 2; //@line 25080
 $7 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 25085
 _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $7 << 16 >> 16 == 0 ? 8 : $7 & 65535, tempInt) | 0) | 0; //@line 25089
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25095
 STACKTOP = sp; //@line 25096
 return;
}
function _d_5180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $7 = 0, sp = 0;
 sp = STACKTOP; //@line 25107
 $1 = $da + 32 | 0; //@line 25108
 HEAP8[$1] = HEAP8[54968] | 0; //@line 25109
 HEAP8[$1 + 1 | 0] = HEAP8[54969 | 0] | 0; //@line 25109
 HEAP8[$1 + 2 | 0] = HEAP8[54970 | 0] | 0; //@line 25109
 HEAP8[$1 + 3 | 0] = HEAP8[54971 | 0] | 0; //@line 25109
 HEAP8[$1 + 4 | 0] = HEAP8[54972 | 0] | 0; //@line 25109
 HEAP8[$1 + 5 | 0] = HEAP8[54973 | 0] | 0; //@line 25109
 HEAP8[$1 + 6 | 0] = HEAP8[54974 | 0] | 0; //@line 25109
 HEAP32[$da + 28 >> 2] = 2; //@line 25111
 $7 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 25116
 _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $7 << 16 >> 16 == 0 ? 8 : $7 & 65535, tempInt) | 0) | 0; //@line 25120
 _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 25126
 STACKTOP = sp; //@line 25127
 return;
}
function _d_6000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $5 = 0, $6 = 0, $7 = 0, $11 = 0, $12 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $26 = 0, $31 = 0, $36 = 0, $endptr19 = 0, $42 = 0, $45 = 0, $47 = 0, $48 = 0, $49 = 0, $67 = 0, $72 = 0, $endptr17 = 0, $74 = 0, $82 = 0, $87 = 0, $endptr = 0, $90 = 0, $91 = 0, $92 = 0, $storemerge_v = 0, $storemerge = 0, $93 = 0, $94 = 0, $storemerge20 = 0, sp = 0;
 sp = STACKTOP; //@line 25149
 $5 = (HEAPU16[$da + 12 >> 1] | 0) >>> 8 & 15; //@line 25154
 $6 = $src + 1 | 0; //@line 25155
 $7 = HEAP8[$6] | 0; //@line 25156
 if ($7 << 24 >> 24 == 0) {
  $11 = HEAP32[7592 + ($5 << 2) >> 2] | 0; //@line 25161
  $12 = $da + 32 | 0; //@line 25162
  _strcpy($12 | 0, $11 | 0) | 0; //@line 25163
  HEAP32[$da + 28 >> 2] = 1; //@line 25165
  $15 = $da + 96 | 0; //@line 25166
  $16 = $da + 8 | 0; //@line 25167
  $17 = HEAP32[$16 >> 2] | 0; //@line 25168
  $18 = $17 << 1; //@line 25169
  $26 = (HEAPU8[$src + $18 | 0] | 0) << 8 | (HEAPU8[$src + ($18 | 1) | 0] | 0); //@line 25178
  HEAP32[$16 >> 2] = $17 + 1; //@line 25180
  $31 = $26 & 65535; //@line 25184
  $36 = (HEAP32[$da + 4 >> 2] | 0) + 2 + (($31 & 32768 | 0) != 0 ? $31 | -65536 : $31) | 0; //@line 25189
  _sprintf($15 | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $36, tempInt) | 0) | 0; //@line 25190
  $endptr19 = (_strlen($12 | 0) | 0) + ($da + 32) | 0; //@line 25192
  HEAP8[$endptr19] = HEAP8[45216] | 0; //@line 25193
  HEAP8[$endptr19 + 1 | 0] = HEAP8[45217 | 0] | 0; //@line 25193
  HEAP8[$endptr19 + 2 | 0] = HEAP8[45218 | 0] | 0; //@line 25193
  $90 = ($5 | 0) == 1; //@line 25195
  $91 = $da | 0; //@line 25196
  $92 = HEAP32[$91 >> 2] | 0; //@line 25197
  $storemerge_v = $90 ? 4 : 2; //@line 25198
  $storemerge = $92 | $storemerge_v; //@line 25199
  $93 = $5 >>> 0 > 1; //@line 25200
  $94 = $storemerge | 32; //@line 25201
  $storemerge20 = $93 ? $94 : $storemerge; //@line 25202
  HEAP32[$91 >> 2] = $storemerge20; //@line 25203
  STACKTOP = sp; //@line 25204
  return;
 }
 $42 = $da + 32 | 0; //@line 25210
 _strcpy($42 | 0, HEAP32[7592 + ($5 << 2) >> 2] | 0) | 0; //@line 25211
 HEAP32[$da + 28 >> 2] = 1; //@line 25213
 $45 = $da + 96 | 0; //@line 25214
 if ($7 << 24 >> 24 == -1) {
  $47 = $da + 8 | 0; //@line 25217
  $48 = HEAP32[$47 >> 2] | 0; //@line 25218
  $49 = $48 << 1; //@line 25219
  $67 = (((HEAPU8[$src + $49 | 0] | 0) << 8 | (HEAPU8[$src + ($49 | 1) | 0] | 0)) << 8 | (HEAPU8[$src + ($49 + 2) | 0] | 0)) << 8 | (HEAPU8[$src + ($49 + 3) | 0] | 0); //@line 25240
  HEAP32[$47 >> 2] = $48 + 2; //@line 25242
  $72 = (HEAP32[$da + 4 >> 2] | 0) + 2 + $67 | 0; //@line 25246
  _sprintf($45 | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $72, tempInt) | 0) | 0; //@line 25247
  $endptr17 = (_strlen($42 | 0) | 0) + ($da + 32) | 0; //@line 25249
  HEAP8[$endptr17] = HEAP8[45520] | 0; //@line 25250
  HEAP8[$endptr17 + 1 | 0] = HEAP8[45521 | 0] | 0; //@line 25250
  HEAP8[$endptr17 + 2 | 0] = HEAP8[45522 | 0] | 0; //@line 25250
  $74 = $da | 0; //@line 25251
  HEAP32[$74 >> 2] = HEAP32[$74 >> 2] | 128; //@line 25254
  $90 = ($5 | 0) == 1; //@line 25256
  $91 = $da | 0; //@line 25257
  $92 = HEAP32[$91 >> 2] | 0; //@line 25258
  $storemerge_v = $90 ? 4 : 2; //@line 25259
  $storemerge = $92 | $storemerge_v; //@line 25260
  $93 = $5 >>> 0 > 1; //@line 25261
  $94 = $storemerge | 32; //@line 25262
  $storemerge20 = $93 ? $94 : $storemerge; //@line 25263
  HEAP32[$91 >> 2] = $storemerge20; //@line 25264
  STACKTOP = sp; //@line 25265
  return;
 } else {
  $82 = HEAPU8[$6] | 0; //@line 25272
  $87 = (HEAP32[$da + 4 >> 2] | 0) + 2 + (($82 & 128 | 0) != 0 ? $82 | -256 : $82) | 0; //@line 25277
  _sprintf($45 | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $87, tempInt) | 0) | 0; //@line 25278
  $endptr = (_strlen($42 | 0) | 0) + ($da + 32) | 0; //@line 25280
  HEAP8[$endptr] = HEAP8[56272] | 0; //@line 25281
  HEAP8[$endptr + 1 | 0] = HEAP8[56273 | 0] | 0; //@line 25281
  HEAP8[$endptr + 2 | 0] = HEAP8[56274 | 0] | 0; //@line 25281
  $90 = ($5 | 0) == 1; //@line 25282
  $91 = $da | 0; //@line 25283
  $92 = HEAP32[$91 >> 2] | 0; //@line 25284
  $storemerge_v = $90 ? 4 : 2; //@line 25285
  $storemerge = $92 | $storemerge_v; //@line 25286
  $93 = $5 >>> 0 > 1; //@line 25287
  $94 = $storemerge | 32; //@line 25288
  $storemerge20 = $93 ? $94 : $storemerge; //@line 25289
  HEAP32[$91 >> 2] = $storemerge20; //@line 25290
  STACKTOP = sp; //@line 25291
  return;
 }
}
function _d_7000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $6 = 0, sp = 0;
 sp = STACKTOP; //@line 25304
 $1 = $da + 32 | 0; //@line 25305
 HEAP8[$1] = HEAP8[56440] | 0; //@line 25306
 HEAP8[$1 + 1 | 0] = HEAP8[56441 | 0] | 0; //@line 25306
 HEAP8[$1 + 2 | 0] = HEAP8[56442 | 0] | 0; //@line 25306
 HEAP8[$1 + 3 | 0] = HEAP8[56443 | 0] | 0; //@line 25306
 HEAP8[$1 + 4 | 0] = HEAP8[56444 | 0] | 0; //@line 25306
 HEAP8[$1 + 5 | 0] = HEAP8[56445 | 0] | 0; //@line 25306
 HEAP32[$da + 28 >> 2] = 2; //@line 25308
 $6 = HEAPU16[$da + 12 >> 1] | 0; //@line 25312
 _sprintf($da + 96 | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = ($6 & 128 | 0) != 0 ? $6 | -256 : $6 & 255, tempInt) | 0) | 0; //@line 25318
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25324
 STACKTOP = sp; //@line 25325
 return;
}
function _d_8000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25336
 $1 = $da + 32 | 0; //@line 25337
 HEAP8[$1] = HEAP8[56680] | 0; //@line 25338
 HEAP8[$1 + 1 | 0] = HEAP8[56681 | 0] | 0; //@line 25338
 HEAP8[$1 + 2 | 0] = HEAP8[56682 | 0] | 0; //@line 25338
 HEAP8[$1 + 3 | 0] = HEAP8[56683 | 0] | 0; //@line 25338
 HEAP8[$1 + 4 | 0] = HEAP8[56684 | 0] | 0; //@line 25338
 HEAP32[$da + 28 >> 2] = 2; //@line 25340
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 25346
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25352
 STACKTOP = sp; //@line 25353
 return;
}
function _d_8040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25364
 $1 = $da + 32 | 0; //@line 25365
 HEAP8[$1] = HEAP8[56936] | 0; //@line 25366
 HEAP8[$1 + 1 | 0] = HEAP8[56937 | 0] | 0; //@line 25366
 HEAP8[$1 + 2 | 0] = HEAP8[56938 | 0] | 0; //@line 25366
 HEAP8[$1 + 3 | 0] = HEAP8[56939 | 0] | 0; //@line 25366
 HEAP8[$1 + 4 | 0] = HEAP8[56940 | 0] | 0; //@line 25366
 HEAP32[$da + 28 >> 2] = 2; //@line 25368
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25374
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25380
 STACKTOP = sp; //@line 25381
 return;
}
function _d_8080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25392
 $1 = $da + 32 | 0; //@line 25393
 HEAP8[$1] = HEAP8[57152] | 0; //@line 25394
 HEAP8[$1 + 1 | 0] = HEAP8[57153 | 0] | 0; //@line 25394
 HEAP8[$1 + 2 | 0] = HEAP8[57154 | 0] | 0; //@line 25394
 HEAP8[$1 + 3 | 0] = HEAP8[57155 | 0] | 0; //@line 25394
 HEAP8[$1 + 4 | 0] = HEAP8[57156 | 0] | 0; //@line 25394
 HEAP32[$da + 28 >> 2] = 2; //@line 25396
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 25402
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25408
 STACKTOP = sp; //@line 25409
 return;
}
function _d_80c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25420
 $1 = $da + 32 | 0; //@line 25421
 HEAP8[$1] = HEAP8[56608] | 0; //@line 25422
 HEAP8[$1 + 1 | 0] = HEAP8[56609 | 0] | 0; //@line 25422
 HEAP8[$1 + 2 | 0] = HEAP8[56610 | 0] | 0; //@line 25422
 HEAP8[$1 + 3 | 0] = HEAP8[56611 | 0] | 0; //@line 25422
 HEAP8[$1 + 4 | 0] = HEAP8[56612 | 0] | 0; //@line 25422
 HEAP8[$1 + 5 | 0] = HEAP8[56613 | 0] | 0; //@line 25422
 HEAP8[$1 + 6 | 0] = HEAP8[56614 | 0] | 0; //@line 25422
 HEAP32[$da + 28 >> 2] = 2; //@line 25424
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25430
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25436
 STACKTOP = sp; //@line 25437
 return;
}
function _d_8100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $18 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 25452
 $1 = $da + 12 | 0; //@line 25453
 $3 = HEAPU16[$1 >> 1] | 0; //@line 25455
 $5 = $3 >>> 3 & 7; //@line 25457
 if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 25459
  HEAP8[$22] = HEAP8[56856] | 0; //@line 25460
  HEAP8[$22 + 1 | 0] = HEAP8[56857 | 0] | 0; //@line 25460
  HEAP8[$22 + 2 | 0] = HEAP8[56858 | 0] | 0; //@line 25460
  HEAP8[$22 + 3 | 0] = HEAP8[56859 | 0] | 0; //@line 25460
  HEAP8[$22 + 4 | 0] = HEAP8[56860 | 0] | 0; //@line 25460
  HEAP8[$22 + 5 | 0] = HEAP8[56861 | 0] | 0; //@line 25460
  HEAP8[$22 + 6 | 0] = HEAP8[56862 | 0] | 0; //@line 25460
  HEAP32[$da + 28 >> 2] = 2; //@line 25462
  $24 = $da + 96 | 0; //@line 25463
  $25 = $3 & 7; //@line 25464
  _sprintf($24 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $25, tempInt) | 0) | 0; //@line 25465
  $27 = $da + 160 | 0; //@line 25466
  $31 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 25470
  _sprintf($27 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 25471
  $33 = $da | 0; //@line 25472
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 25475
  STACKTOP = sp; //@line 25477
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 25480
  HEAP8[$7] = HEAP8[56856] | 0; //@line 25481
  HEAP8[$7 + 1 | 0] = HEAP8[56857 | 0] | 0; //@line 25481
  HEAP8[$7 + 2 | 0] = HEAP8[56858 | 0] | 0; //@line 25481
  HEAP8[$7 + 3 | 0] = HEAP8[56859 | 0] | 0; //@line 25481
  HEAP8[$7 + 4 | 0] = HEAP8[56860 | 0] | 0; //@line 25481
  HEAP8[$7 + 5 | 0] = HEAP8[56861 | 0] | 0; //@line 25481
  HEAP8[$7 + 6 | 0] = HEAP8[56862 | 0] | 0; //@line 25481
  HEAP32[$da + 28 >> 2] = 2; //@line 25483
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 25486
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25492
  $18 = $da | 0; //@line 25493
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 25496
  STACKTOP = sp; //@line 25498
  return;
 } else {
  $37 = $da + 32 | 0; //@line 25501
  HEAP8[$37] = HEAP8[56680] | 0; //@line 25502
  HEAP8[$37 + 1 | 0] = HEAP8[56681 | 0] | 0; //@line 25502
  HEAP8[$37 + 2 | 0] = HEAP8[56682 | 0] | 0; //@line 25502
  HEAP8[$37 + 3 | 0] = HEAP8[56683 | 0] | 0; //@line 25502
  HEAP8[$37 + 4 | 0] = HEAP8[56684 | 0] | 0; //@line 25502
  HEAP32[$da + 28 >> 2] = 2; //@line 25504
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25510
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 25516
  STACKTOP = sp; //@line 25518
  return;
 }
}
function _d_8140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $5 = 0, $8 = 0, $16 = 0, $20 = 0, $24 = 0, sp = 0;
 sp = STACKTOP; //@line 25532
 $5 = $da + 32 | 0; //@line 25538
 if ((HEAP16[$da + 12 >> 1] & 48) >>> 0 < 16) {
  HEAP8[$5] = HEAP8[36120] | 0; //@line 25541
  HEAP8[$5 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 25541
  HEAP8[$5 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 25541
  HEAP32[$da + 28 >> 2] = 1; //@line 25543
  $8 = $da + 96 | 0; //@line 25544
  $16 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 25552
  _sprintf($8 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $16, tempInt) | 0) | 0; //@line 25553
  STACKTOP = sp; //@line 25555
  return;
 } else {
  HEAP8[$5] = HEAP8[56936] | 0; //@line 25558
  HEAP8[$5 + 1 | 0] = HEAP8[56937 | 0] | 0; //@line 25558
  HEAP8[$5 + 2 | 0] = HEAP8[56938 | 0] | 0; //@line 25558
  HEAP8[$5 + 3 | 0] = HEAP8[56939 | 0] | 0; //@line 25558
  HEAP8[$5 + 4 | 0] = HEAP8[56940 | 0] | 0; //@line 25558
  HEAP32[$da + 28 >> 2] = 2; //@line 25560
  $20 = $da + 96 | 0; //@line 25561
  $24 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 25565
  _sprintf($20 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $24, tempInt) | 0) | 0; //@line 25566
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25572
  STACKTOP = sp; //@line 25574
  return;
 }
}
function _d_8180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $5 = 0, $8 = 0, $16 = 0, $20 = 0, $24 = 0, sp = 0;
 sp = STACKTOP; //@line 25588
 $5 = $da + 32 | 0; //@line 25594
 if ((HEAP16[$da + 12 >> 1] & 48) >>> 0 < 16) {
  HEAP8[$5] = HEAP8[36120] | 0; //@line 25597
  HEAP8[$5 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 25597
  HEAP8[$5 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 25597
  HEAP32[$da + 28 >> 2] = 1; //@line 25599
  $8 = $da + 96 | 0; //@line 25600
  $16 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 25608
  _sprintf($8 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $16, tempInt) | 0) | 0; //@line 25609
  STACKTOP = sp; //@line 25611
  return;
 } else {
  HEAP8[$5] = HEAP8[57152] | 0; //@line 25614
  HEAP8[$5 + 1 | 0] = HEAP8[57153 | 0] | 0; //@line 25614
  HEAP8[$5 + 2 | 0] = HEAP8[57154 | 0] | 0; //@line 25614
  HEAP8[$5 + 3 | 0] = HEAP8[57155 | 0] | 0; //@line 25614
  HEAP8[$5 + 4 | 0] = HEAP8[57156 | 0] | 0; //@line 25614
  HEAP32[$da + 28 >> 2] = 2; //@line 25616
  $20 = $da + 96 | 0; //@line 25617
  $24 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 25621
  _sprintf($20 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $24, tempInt) | 0) | 0; //@line 25622
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 25628
  STACKTOP = sp; //@line 25630
  return;
 }
}
function _d_81c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25642
 $1 = $da + 32 | 0; //@line 25643
 HEAP8[$1] = HEAP8[57296] | 0; //@line 25644
 HEAP8[$1 + 1 | 0] = HEAP8[57297 | 0] | 0; //@line 25644
 HEAP8[$1 + 2 | 0] = HEAP8[57298 | 0] | 0; //@line 25644
 HEAP8[$1 + 3 | 0] = HEAP8[57299 | 0] | 0; //@line 25644
 HEAP8[$1 + 4 | 0] = HEAP8[57300 | 0] | 0; //@line 25644
 HEAP8[$1 + 5 | 0] = HEAP8[57301 | 0] | 0; //@line 25644
 HEAP8[$1 + 6 | 0] = HEAP8[57302 | 0] | 0; //@line 25644
 HEAP32[$da + 28 >> 2] = 2; //@line 25646
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25652
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25658
 STACKTOP = sp; //@line 25659
 return;
}
function _d_9000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25670
 $1 = $da + 32 | 0; //@line 25671
 HEAP8[$1] = HEAP8[57408] | 0; //@line 25672
 HEAP8[$1 + 1 | 0] = HEAP8[57409 | 0] | 0; //@line 25672
 HEAP8[$1 + 2 | 0] = HEAP8[57410 | 0] | 0; //@line 25672
 HEAP8[$1 + 3 | 0] = HEAP8[57411 | 0] | 0; //@line 25672
 HEAP8[$1 + 4 | 0] = HEAP8[57412 | 0] | 0; //@line 25672
 HEAP8[$1 + 5 | 0] = HEAP8[57413 | 0] | 0; //@line 25672
 HEAP32[$da + 28 >> 2] = 2; //@line 25674
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 25680
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25686
 STACKTOP = sp; //@line 25687
 return;
}
function _d_9040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25698
 $1 = $da + 32 | 0; //@line 25699
 HEAP8[$1] = HEAP8[57512] | 0; //@line 25700
 HEAP8[$1 + 1 | 0] = HEAP8[57513 | 0] | 0; //@line 25700
 HEAP8[$1 + 2 | 0] = HEAP8[57514 | 0] | 0; //@line 25700
 HEAP8[$1 + 3 | 0] = HEAP8[57515 | 0] | 0; //@line 25700
 HEAP8[$1 + 4 | 0] = HEAP8[57516 | 0] | 0; //@line 25700
 HEAP8[$1 + 5 | 0] = HEAP8[57517 | 0] | 0; //@line 25700
 HEAP32[$da + 28 >> 2] = 2; //@line 25702
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25708
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25714
 STACKTOP = sp; //@line 25715
 return;
}
function _d_9080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25726
 $1 = $da + 32 | 0; //@line 25727
 HEAP8[$1] = HEAP8[57600] | 0; //@line 25728
 HEAP8[$1 + 1 | 0] = HEAP8[57601 | 0] | 0; //@line 25728
 HEAP8[$1 + 2 | 0] = HEAP8[57602 | 0] | 0; //@line 25728
 HEAP8[$1 + 3 | 0] = HEAP8[57603 | 0] | 0; //@line 25728
 HEAP8[$1 + 4 | 0] = HEAP8[57604 | 0] | 0; //@line 25728
 HEAP8[$1 + 5 | 0] = HEAP8[57605 | 0] | 0; //@line 25728
 HEAP32[$da + 28 >> 2] = 2; //@line 25730
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 25736
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25742
 STACKTOP = sp; //@line 25743
 return;
}
function _d_90c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 25754
 $1 = $da + 32 | 0; //@line 25755
 HEAP8[$1] = HEAP8[57360] | 0; //@line 25756
 HEAP8[$1 + 1 | 0] = HEAP8[57361 | 0] | 0; //@line 25756
 HEAP8[$1 + 2 | 0] = HEAP8[57362 | 0] | 0; //@line 25756
 HEAP8[$1 + 3 | 0] = HEAP8[57363 | 0] | 0; //@line 25756
 HEAP8[$1 + 4 | 0] = HEAP8[57364 | 0] | 0; //@line 25756
 HEAP8[$1 + 5 | 0] = HEAP8[57365 | 0] | 0; //@line 25756
 HEAP8[$1 + 6 | 0] = HEAP8[57366 | 0] | 0; //@line 25756
 HEAP32[$da + 28 >> 2] = 2; //@line 25758
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25764
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25770
 STACKTOP = sp; //@line 25771
 return;
}
function _d_9100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $16 = 0, $18 = 0, $22 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 25786
 $1 = $da + 12 | 0; //@line 25787
 $3 = HEAPU16[$1 >> 1] | 0; //@line 25789
 $5 = $3 >>> 3 & 7; //@line 25791
 if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 25793
  HEAP8[$7] = HEAP8[57448] | 0; //@line 25794
  HEAP8[$7 + 1 | 0] = HEAP8[57449 | 0] | 0; //@line 25794
  HEAP8[$7 + 2 | 0] = HEAP8[57450 | 0] | 0; //@line 25794
  HEAP8[$7 + 3 | 0] = HEAP8[57451 | 0] | 0; //@line 25794
  HEAP8[$7 + 4 | 0] = HEAP8[57452 | 0] | 0; //@line 25794
  HEAP8[$7 + 5 | 0] = HEAP8[57453 | 0] | 0; //@line 25794
  HEAP8[$7 + 6 | 0] = HEAP8[57454 | 0] | 0; //@line 25794
  HEAP32[$da + 28 >> 2] = 2; //@line 25796
  $9 = $da + 96 | 0; //@line 25797
  $10 = $3 & 7; //@line 25798
  _sprintf($9 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $10, tempInt) | 0) | 0; //@line 25799
  $12 = $da + 160 | 0; //@line 25800
  $16 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 25804
  _sprintf($12 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $16, tempInt) | 0) | 0; //@line 25805
  $18 = $da | 0; //@line 25806
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 25809
  STACKTOP = sp; //@line 25811
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 25814
  HEAP8[$22] = HEAP8[57448] | 0; //@line 25815
  HEAP8[$22 + 1 | 0] = HEAP8[57449 | 0] | 0; //@line 25815
  HEAP8[$22 + 2 | 0] = HEAP8[57450 | 0] | 0; //@line 25815
  HEAP8[$22 + 3 | 0] = HEAP8[57451 | 0] | 0; //@line 25815
  HEAP8[$22 + 4 | 0] = HEAP8[57452 | 0] | 0; //@line 25815
  HEAP8[$22 + 5 | 0] = HEAP8[57453 | 0] | 0; //@line 25815
  HEAP8[$22 + 6 | 0] = HEAP8[57454 | 0] | 0; //@line 25815
  HEAP32[$da + 28 >> 2] = 2; //@line 25817
  _sprintf($da + 96 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 25820
  _sprintf($da + 160 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7, tempInt) | 0) | 0; //@line 25826
  $33 = $da | 0; //@line 25827
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 25830
  STACKTOP = sp; //@line 25832
  return;
 } else {
  $37 = $da + 32 | 0; //@line 25835
  HEAP8[$37] = HEAP8[57408] | 0; //@line 25836
  HEAP8[$37 + 1 | 0] = HEAP8[57409 | 0] | 0; //@line 25836
  HEAP8[$37 + 2 | 0] = HEAP8[57410 | 0] | 0; //@line 25836
  HEAP8[$37 + 3 | 0] = HEAP8[57411 | 0] | 0; //@line 25836
  HEAP8[$37 + 4 | 0] = HEAP8[57412 | 0] | 0; //@line 25836
  HEAP8[$37 + 5 | 0] = HEAP8[57413 | 0] | 0; //@line 25836
  HEAP32[$da + 28 >> 2] = 2; //@line 25838
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25844
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 25850
  STACKTOP = sp; //@line 25852
  return;
 }
}
function _d_9140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $18 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 25868
 $1 = $da + 12 | 0; //@line 25869
 $3 = HEAPU16[$1 >> 1] | 0; //@line 25871
 $5 = $3 >>> 3 & 7; //@line 25873
 if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 25875
  HEAP8[$22] = HEAP8[57560] | 0; //@line 25876
  HEAP8[$22 + 1 | 0] = HEAP8[57561 | 0] | 0; //@line 25876
  HEAP8[$22 + 2 | 0] = HEAP8[57562 | 0] | 0; //@line 25876
  HEAP8[$22 + 3 | 0] = HEAP8[57563 | 0] | 0; //@line 25876
  HEAP8[$22 + 4 | 0] = HEAP8[57564 | 0] | 0; //@line 25876
  HEAP8[$22 + 5 | 0] = HEAP8[57565 | 0] | 0; //@line 25876
  HEAP8[$22 + 6 | 0] = HEAP8[57566 | 0] | 0; //@line 25876
  HEAP32[$da + 28 >> 2] = 2; //@line 25878
  $24 = $da + 96 | 0; //@line 25879
  $25 = $3 & 7; //@line 25880
  _sprintf($24 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $25, tempInt) | 0) | 0; //@line 25881
  $27 = $da + 160 | 0; //@line 25882
  $31 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 25886
  _sprintf($27 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 25887
  $33 = $da | 0; //@line 25888
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 25891
  STACKTOP = sp; //@line 25893
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 25896
  HEAP8[$7] = HEAP8[57560] | 0; //@line 25897
  HEAP8[$7 + 1 | 0] = HEAP8[57561 | 0] | 0; //@line 25897
  HEAP8[$7 + 2 | 0] = HEAP8[57562 | 0] | 0; //@line 25897
  HEAP8[$7 + 3 | 0] = HEAP8[57563 | 0] | 0; //@line 25897
  HEAP8[$7 + 4 | 0] = HEAP8[57564 | 0] | 0; //@line 25897
  HEAP8[$7 + 5 | 0] = HEAP8[57565 | 0] | 0; //@line 25897
  HEAP8[$7 + 6 | 0] = HEAP8[57566 | 0] | 0; //@line 25897
  HEAP32[$da + 28 >> 2] = 2; //@line 25899
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 25902
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25908
  $18 = $da | 0; //@line 25909
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 25912
  STACKTOP = sp; //@line 25914
  return;
 } else {
  $37 = $da + 32 | 0; //@line 25917
  HEAP8[$37] = HEAP8[57512] | 0; //@line 25918
  HEAP8[$37 + 1 | 0] = HEAP8[57513 | 0] | 0; //@line 25918
  HEAP8[$37 + 2 | 0] = HEAP8[57514 | 0] | 0; //@line 25918
  HEAP8[$37 + 3 | 0] = HEAP8[57515 | 0] | 0; //@line 25918
  HEAP8[$37 + 4 | 0] = HEAP8[57516 | 0] | 0; //@line 25918
  HEAP8[$37 + 5 | 0] = HEAP8[57517 | 0] | 0; //@line 25918
  HEAP32[$da + 28 >> 2] = 2; //@line 25920
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25926
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 25932
  STACKTOP = sp; //@line 25934
  return;
 }
}
function _d_9180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $18 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 25950
 $1 = $da + 12 | 0; //@line 25951
 $3 = HEAPU16[$1 >> 1] | 0; //@line 25953
 $5 = $3 >>> 3 & 7; //@line 25955
 if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 25957
  HEAP8[$22] = HEAP8[57696] | 0; //@line 25958
  HEAP8[$22 + 1 | 0] = HEAP8[57697 | 0] | 0; //@line 25958
  HEAP8[$22 + 2 | 0] = HEAP8[57698 | 0] | 0; //@line 25958
  HEAP8[$22 + 3 | 0] = HEAP8[57699 | 0] | 0; //@line 25958
  HEAP8[$22 + 4 | 0] = HEAP8[57700 | 0] | 0; //@line 25958
  HEAP8[$22 + 5 | 0] = HEAP8[57701 | 0] | 0; //@line 25958
  HEAP8[$22 + 6 | 0] = HEAP8[57702 | 0] | 0; //@line 25958
  HEAP32[$da + 28 >> 2] = 2; //@line 25960
  $24 = $da + 96 | 0; //@line 25961
  $25 = $3 & 7; //@line 25962
  _sprintf($24 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $25, tempInt) | 0) | 0; //@line 25963
  $27 = $da + 160 | 0; //@line 25964
  $31 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 25968
  _sprintf($27 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 25969
  $33 = $da | 0; //@line 25970
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 25973
  STACKTOP = sp; //@line 25975
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 25978
  HEAP8[$7] = HEAP8[57696] | 0; //@line 25979
  HEAP8[$7 + 1 | 0] = HEAP8[57697 | 0] | 0; //@line 25979
  HEAP8[$7 + 2 | 0] = HEAP8[57698 | 0] | 0; //@line 25979
  HEAP8[$7 + 3 | 0] = HEAP8[57699 | 0] | 0; //@line 25979
  HEAP8[$7 + 4 | 0] = HEAP8[57700 | 0] | 0; //@line 25979
  HEAP8[$7 + 5 | 0] = HEAP8[57701 | 0] | 0; //@line 25979
  HEAP8[$7 + 6 | 0] = HEAP8[57702 | 0] | 0; //@line 25979
  HEAP32[$da + 28 >> 2] = 2; //@line 25981
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 25984
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 25990
  $18 = $da | 0; //@line 25991
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 25994
  STACKTOP = sp; //@line 25996
  return;
 } else {
  $37 = $da + 32 | 0; //@line 25999
  HEAP8[$37] = HEAP8[57600] | 0; //@line 26000
  HEAP8[$37 + 1 | 0] = HEAP8[57601 | 0] | 0; //@line 26000
  HEAP8[$37 + 2 | 0] = HEAP8[57602 | 0] | 0; //@line 26000
  HEAP8[$37 + 3 | 0] = HEAP8[57603 | 0] | 0; //@line 26000
  HEAP8[$37 + 4 | 0] = HEAP8[57604 | 0] | 0; //@line 26000
  HEAP8[$37 + 5 | 0] = HEAP8[57605 | 0] | 0; //@line 26000
  HEAP32[$da + 28 >> 2] = 2; //@line 26002
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26008
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26014
  STACKTOP = sp; //@line 26016
  return;
 }
}
function _d_91c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26028
 $1 = $da + 32 | 0; //@line 26029
 HEAP8[$1] = HEAP8[57768] | 0; //@line 26030
 HEAP8[$1 + 1 | 0] = HEAP8[57769 | 0] | 0; //@line 26030
 HEAP8[$1 + 2 | 0] = HEAP8[57770 | 0] | 0; //@line 26030
 HEAP8[$1 + 3 | 0] = HEAP8[57771 | 0] | 0; //@line 26030
 HEAP8[$1 + 4 | 0] = HEAP8[57772 | 0] | 0; //@line 26030
 HEAP8[$1 + 5 | 0] = HEAP8[57773 | 0] | 0; //@line 26030
 HEAP8[$1 + 6 | 0] = HEAP8[57774 | 0] | 0; //@line 26030
 HEAP32[$da + 28 >> 2] = 2; //@line 26032
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26038
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26044
 STACKTOP = sp; //@line 26045
 return;
}
function _d_a000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 26056
 STACKTOP = STACKTOP + 16 | 0; //@line 26056
 $1 = sp | 0; //@line 26058
 _sprintf($1 | 0, 32672, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAPU16[$da + 12 >> 1] | 0, tempInt) | 0) | 0; //@line 26062
 _strcpy($da + 32 | 0, $1 | 0) | 0; //@line 26064
 HEAP32[$da + 28 >> 2] = 0; //@line 26066
 $9 = $da | 0; //@line 26067
 HEAP32[$9 >> 2] = HEAP32[$9 >> 2] | 4; //@line 26070
 STACKTOP = sp; //@line 26071
 return;
}
function _d_b000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26082
 $1 = $da + 32 | 0; //@line 26083
 HEAP8[$1] = HEAP8[57952] | 0; //@line 26084
 HEAP8[$1 + 1 | 0] = HEAP8[57953 | 0] | 0; //@line 26084
 HEAP8[$1 + 2 | 0] = HEAP8[57954 | 0] | 0; //@line 26084
 HEAP8[$1 + 3 | 0] = HEAP8[57955 | 0] | 0; //@line 26084
 HEAP8[$1 + 4 | 0] = HEAP8[57956 | 0] | 0; //@line 26084
 HEAP8[$1 + 5 | 0] = HEAP8[57957 | 0] | 0; //@line 26084
 HEAP32[$da + 28 >> 2] = 2; //@line 26086
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 26092
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26098
 STACKTOP = sp; //@line 26099
 return;
}
function _d_b040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26110
 $1 = $da + 32 | 0; //@line 26111
 HEAP8[$1] = HEAP8[58080] | 0; //@line 26112
 HEAP8[$1 + 1 | 0] = HEAP8[58081 | 0] | 0; //@line 26112
 HEAP8[$1 + 2 | 0] = HEAP8[58082 | 0] | 0; //@line 26112
 HEAP8[$1 + 3 | 0] = HEAP8[58083 | 0] | 0; //@line 26112
 HEAP8[$1 + 4 | 0] = HEAP8[58084 | 0] | 0; //@line 26112
 HEAP8[$1 + 5 | 0] = HEAP8[58085 | 0] | 0; //@line 26112
 HEAP32[$da + 28 >> 2] = 2; //@line 26114
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26120
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26126
 STACKTOP = sp; //@line 26127
 return;
}
function _d_b080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26138
 $1 = $da + 32 | 0; //@line 26139
 HEAP8[$1] = HEAP8[30096] | 0; //@line 26140
 HEAP8[$1 + 1 | 0] = HEAP8[30097 | 0] | 0; //@line 26140
 HEAP8[$1 + 2 | 0] = HEAP8[30098 | 0] | 0; //@line 26140
 HEAP8[$1 + 3 | 0] = HEAP8[30099 | 0] | 0; //@line 26140
 HEAP8[$1 + 4 | 0] = HEAP8[30100 | 0] | 0; //@line 26140
 HEAP8[$1 + 5 | 0] = HEAP8[30101 | 0] | 0; //@line 26140
 HEAP32[$da + 28 >> 2] = 2; //@line 26142
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26148
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26154
 STACKTOP = sp; //@line 26155
 return;
}
function _d_b0c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26166
 $1 = $da + 32 | 0; //@line 26167
 HEAP8[$1] = HEAP8[30176] | 0; //@line 26168
 HEAP8[$1 + 1 | 0] = HEAP8[30177 | 0] | 0; //@line 26168
 HEAP8[$1 + 2 | 0] = HEAP8[30178 | 0] | 0; //@line 26168
 HEAP8[$1 + 3 | 0] = HEAP8[30179 | 0] | 0; //@line 26168
 HEAP8[$1 + 4 | 0] = HEAP8[30180 | 0] | 0; //@line 26168
 HEAP8[$1 + 5 | 0] = HEAP8[30181 | 0] | 0; //@line 26168
 HEAP8[$1 + 6 | 0] = HEAP8[30182 | 0] | 0; //@line 26168
 HEAP32[$da + 28 >> 2] = 2; //@line 26170
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26176
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26182
 STACKTOP = sp; //@line 26183
 return;
}
function _d_b100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $8 = 0, $10 = 0, $12 = 0, $16 = 0, $20 = 0, $24 = 0, sp = 0;
 sp = STACKTOP; //@line 26196
 $1 = $da + 12 | 0; //@line 26197
 $2 = HEAP16[$1 >> 1] | 0; //@line 26198
 $5 = $da + 32 | 0; //@line 26201
 if (($2 & 56) == 8) {
  HEAP8[$5] = HEAP8[30312] | 0; //@line 26204
  HEAP8[$5 + 1 | 0] = HEAP8[30313 | 0] | 0; //@line 26204
  HEAP8[$5 + 2 | 0] = HEAP8[30314 | 0] | 0; //@line 26204
  HEAP8[$5 + 3 | 0] = HEAP8[30315 | 0] | 0; //@line 26204
  HEAP8[$5 + 4 | 0] = HEAP8[30316 | 0] | 0; //@line 26204
  HEAP8[$5 + 5 | 0] = HEAP8[30317 | 0] | 0; //@line 26204
  HEAP8[$5 + 6 | 0] = HEAP8[30318 | 0] | 0; //@line 26204
  HEAP32[$da + 28 >> 2] = 2; //@line 26206
  $8 = $da + 96 | 0; //@line 26207
  $10 = $2 & 7; //@line 26209
  _sprintf($8 | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $10, tempInt) | 0) | 0; //@line 26210
  $12 = $da + 160 | 0; //@line 26211
  $16 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 26215
  _sprintf($12 | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $16, tempInt) | 0) | 0; //@line 26216
  STACKTOP = sp; //@line 26218
  return;
 } else {
  HEAP8[$5] = HEAP8[30240] | 0; //@line 26221
  HEAP8[$5 + 1 | 0] = HEAP8[30241 | 0] | 0; //@line 26221
  HEAP8[$5 + 2 | 0] = HEAP8[30242 | 0] | 0; //@line 26221
  HEAP8[$5 + 3 | 0] = HEAP8[30243 | 0] | 0; //@line 26221
  HEAP8[$5 + 4 | 0] = HEAP8[30244 | 0] | 0; //@line 26221
  HEAP8[$5 + 5 | 0] = HEAP8[30245 | 0] | 0; //@line 26221
  HEAP32[$da + 28 >> 2] = 2; //@line 26223
  $20 = $da + 96 | 0; //@line 26224
  $24 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 26228
  _sprintf($20 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $24, tempInt) | 0) | 0; //@line 26229
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 26235
  STACKTOP = sp; //@line 26236
  return;
 }
}
function _d_b140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $8 = 0, $10 = 0, $12 = 0, $16 = 0, $20 = 0, $24 = 0, sp = 0;
 sp = STACKTOP; //@line 26250
 $1 = $da + 12 | 0; //@line 26251
 $2 = HEAP16[$1 >> 1] | 0; //@line 26252
 $5 = $da + 32 | 0; //@line 26255
 if (($2 & 56) == 8) {
  HEAP8[$5] = HEAP8[30400] | 0; //@line 26258
  HEAP8[$5 + 1 | 0] = HEAP8[30401 | 0] | 0; //@line 26258
  HEAP8[$5 + 2 | 0] = HEAP8[30402 | 0] | 0; //@line 26258
  HEAP8[$5 + 3 | 0] = HEAP8[30403 | 0] | 0; //@line 26258
  HEAP8[$5 + 4 | 0] = HEAP8[30404 | 0] | 0; //@line 26258
  HEAP8[$5 + 5 | 0] = HEAP8[30405 | 0] | 0; //@line 26258
  HEAP8[$5 + 6 | 0] = HEAP8[30406 | 0] | 0; //@line 26258
  HEAP32[$da + 28 >> 2] = 2; //@line 26260
  $8 = $da + 96 | 0; //@line 26261
  $10 = $2 & 7; //@line 26263
  _sprintf($8 | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $10, tempInt) | 0) | 0; //@line 26264
  $12 = $da + 160 | 0; //@line 26265
  $16 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 26269
  _sprintf($12 | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $16, tempInt) | 0) | 0; //@line 26270
  STACKTOP = sp; //@line 26272
  return;
 } else {
  HEAP8[$5] = HEAP8[30360] | 0; //@line 26275
  HEAP8[$5 + 1 | 0] = HEAP8[30361 | 0] | 0; //@line 26275
  HEAP8[$5 + 2 | 0] = HEAP8[30362 | 0] | 0; //@line 26275
  HEAP8[$5 + 3 | 0] = HEAP8[30363 | 0] | 0; //@line 26275
  HEAP8[$5 + 4 | 0] = HEAP8[30364 | 0] | 0; //@line 26275
  HEAP8[$5 + 5 | 0] = HEAP8[30365 | 0] | 0; //@line 26275
  HEAP32[$da + 28 >> 2] = 2; //@line 26277
  $20 = $da + 96 | 0; //@line 26278
  $24 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 26282
  _sprintf($20 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $24, tempInt) | 0) | 0; //@line 26283
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26289
  STACKTOP = sp; //@line 26290
  return;
 }
}
function _d_b180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $2 = 0, $5 = 0, $8 = 0, $10 = 0, $12 = 0, $16 = 0, $20 = 0, $24 = 0, sp = 0;
 sp = STACKTOP; //@line 26304
 $1 = $da + 12 | 0; //@line 26305
 $2 = HEAP16[$1 >> 1] | 0; //@line 26306
 $5 = $da + 32 | 0; //@line 26309
 if (($2 & 56) == 8) {
  HEAP8[$5] = HEAP8[30576] | 0; //@line 26312
  HEAP8[$5 + 1 | 0] = HEAP8[30577 | 0] | 0; //@line 26312
  HEAP8[$5 + 2 | 0] = HEAP8[30578 | 0] | 0; //@line 26312
  HEAP8[$5 + 3 | 0] = HEAP8[30579 | 0] | 0; //@line 26312
  HEAP8[$5 + 4 | 0] = HEAP8[30580 | 0] | 0; //@line 26312
  HEAP8[$5 + 5 | 0] = HEAP8[30581 | 0] | 0; //@line 26312
  HEAP8[$5 + 6 | 0] = HEAP8[30582 | 0] | 0; //@line 26312
  HEAP32[$da + 28 >> 2] = 2; //@line 26314
  $8 = $da + 96 | 0; //@line 26315
  $10 = $2 & 7; //@line 26317
  _sprintf($8 | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $10, tempInt) | 0) | 0; //@line 26318
  $12 = $da + 160 | 0; //@line 26319
  $16 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 26323
  _sprintf($12 | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $16, tempInt) | 0) | 0; //@line 26324
  STACKTOP = sp; //@line 26326
  return;
 } else {
  HEAP8[$5] = HEAP8[30488] | 0; //@line 26329
  HEAP8[$5 + 1 | 0] = HEAP8[30489 | 0] | 0; //@line 26329
  HEAP8[$5 + 2 | 0] = HEAP8[30490 | 0] | 0; //@line 26329
  HEAP8[$5 + 3 | 0] = HEAP8[30491 | 0] | 0; //@line 26329
  HEAP8[$5 + 4 | 0] = HEAP8[30492 | 0] | 0; //@line 26329
  HEAP8[$5 + 5 | 0] = HEAP8[30493 | 0] | 0; //@line 26329
  HEAP32[$da + 28 >> 2] = 2; //@line 26331
  $20 = $da + 96 | 0; //@line 26332
  $24 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 26336
  _sprintf($20 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $24, tempInt) | 0) | 0; //@line 26337
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26343
  STACKTOP = sp; //@line 26344
  return;
 }
}
function _d_b1c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26356
 $1 = $da + 32 | 0; //@line 26357
 HEAP8[$1] = HEAP8[30776] | 0; //@line 26358
 HEAP8[$1 + 1 | 0] = HEAP8[30777 | 0] | 0; //@line 26358
 HEAP8[$1 + 2 | 0] = HEAP8[30778 | 0] | 0; //@line 26358
 HEAP8[$1 + 3 | 0] = HEAP8[30779 | 0] | 0; //@line 26358
 HEAP8[$1 + 4 | 0] = HEAP8[30780 | 0] | 0; //@line 26358
 HEAP8[$1 + 5 | 0] = HEAP8[30781 | 0] | 0; //@line 26358
 HEAP8[$1 + 6 | 0] = HEAP8[30782 | 0] | 0; //@line 26358
 HEAP32[$da + 28 >> 2] = 2; //@line 26360
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26366
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26372
 STACKTOP = sp; //@line 26373
 return;
}
function _d_c000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26384
 $1 = $da + 32 | 0; //@line 26385
 HEAP8[$1] = HEAP8[31056] | 0; //@line 26386
 HEAP8[$1 + 1 | 0] = HEAP8[31057 | 0] | 0; //@line 26386
 HEAP8[$1 + 2 | 0] = HEAP8[31058 | 0] | 0; //@line 26386
 HEAP8[$1 + 3 | 0] = HEAP8[31059 | 0] | 0; //@line 26386
 HEAP8[$1 + 4 | 0] = HEAP8[31060 | 0] | 0; //@line 26386
 HEAP8[$1 + 5 | 0] = HEAP8[31061 | 0] | 0; //@line 26386
 HEAP32[$da + 28 >> 2] = 2; //@line 26388
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 26394
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26400
 STACKTOP = sp; //@line 26401
 return;
}
function _d_c040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26412
 $1 = $da + 32 | 0; //@line 26413
 HEAP8[$1] = HEAP8[31144] | 0; //@line 26414
 HEAP8[$1 + 1 | 0] = HEAP8[31145 | 0] | 0; //@line 26414
 HEAP8[$1 + 2 | 0] = HEAP8[31146 | 0] | 0; //@line 26414
 HEAP8[$1 + 3 | 0] = HEAP8[31147 | 0] | 0; //@line 26414
 HEAP8[$1 + 4 | 0] = HEAP8[31148 | 0] | 0; //@line 26414
 HEAP8[$1 + 5 | 0] = HEAP8[31149 | 0] | 0; //@line 26414
 HEAP32[$da + 28 >> 2] = 2; //@line 26416
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26422
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26428
 STACKTOP = sp; //@line 26429
 return;
}
function _d_c080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26440
 $1 = $da + 32 | 0; //@line 26441
 HEAP8[$1] = HEAP8[31192] | 0; //@line 26442
 HEAP8[$1 + 1 | 0] = HEAP8[31193 | 0] | 0; //@line 26442
 HEAP8[$1 + 2 | 0] = HEAP8[31194 | 0] | 0; //@line 26442
 HEAP8[$1 + 3 | 0] = HEAP8[31195 | 0] | 0; //@line 26442
 HEAP8[$1 + 4 | 0] = HEAP8[31196 | 0] | 0; //@line 26442
 HEAP8[$1 + 5 | 0] = HEAP8[31197 | 0] | 0; //@line 26442
 HEAP32[$da + 28 >> 2] = 2; //@line 26444
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26450
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26456
 STACKTOP = sp; //@line 26457
 return;
}
function _d_c0c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26468
 $1 = $da + 32 | 0; //@line 26469
 HEAP8[$1] = HEAP8[30960] | 0; //@line 26470
 HEAP8[$1 + 1 | 0] = HEAP8[30961 | 0] | 0; //@line 26470
 HEAP8[$1 + 2 | 0] = HEAP8[30962 | 0] | 0; //@line 26470
 HEAP8[$1 + 3 | 0] = HEAP8[30963 | 0] | 0; //@line 26470
 HEAP8[$1 + 4 | 0] = HEAP8[30964 | 0] | 0; //@line 26470
 HEAP8[$1 + 5 | 0] = HEAP8[30965 | 0] | 0; //@line 26470
 HEAP8[$1 + 6 | 0] = HEAP8[30966 | 0] | 0; //@line 26470
 HEAP32[$da + 28 >> 2] = 2; //@line 26472
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26478
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26484
 STACKTOP = sp; //@line 26485
 return;
}
function _d_c100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $18 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 26500
 $1 = $da + 12 | 0; //@line 26501
 $3 = HEAPU16[$1 >> 1] | 0; //@line 26503
 $5 = $3 >>> 3 & 7; //@line 26505
 if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 26507
  HEAP8[$22] = HEAP8[31104] | 0; //@line 26508
  HEAP8[$22 + 1 | 0] = HEAP8[31105 | 0] | 0; //@line 26508
  HEAP8[$22 + 2 | 0] = HEAP8[31106 | 0] | 0; //@line 26508
  HEAP8[$22 + 3 | 0] = HEAP8[31107 | 0] | 0; //@line 26508
  HEAP8[$22 + 4 | 0] = HEAP8[31108 | 0] | 0; //@line 26508
  HEAP8[$22 + 5 | 0] = HEAP8[31109 | 0] | 0; //@line 26508
  HEAP8[$22 + 6 | 0] = HEAP8[31110 | 0] | 0; //@line 26508
  HEAP32[$da + 28 >> 2] = 2; //@line 26510
  $24 = $da + 96 | 0; //@line 26511
  $25 = $3 & 7; //@line 26512
  _sprintf($24 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $25, tempInt) | 0) | 0; //@line 26513
  $27 = $da + 160 | 0; //@line 26514
  $31 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 26518
  _sprintf($27 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 26519
  $33 = $da | 0; //@line 26520
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 26523
  STACKTOP = sp; //@line 26525
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 26528
  HEAP8[$7] = HEAP8[31104] | 0; //@line 26529
  HEAP8[$7 + 1 | 0] = HEAP8[31105 | 0] | 0; //@line 26529
  HEAP8[$7 + 2 | 0] = HEAP8[31106 | 0] | 0; //@line 26529
  HEAP8[$7 + 3 | 0] = HEAP8[31107 | 0] | 0; //@line 26529
  HEAP8[$7 + 4 | 0] = HEAP8[31108 | 0] | 0; //@line 26529
  HEAP8[$7 + 5 | 0] = HEAP8[31109 | 0] | 0; //@line 26529
  HEAP8[$7 + 6 | 0] = HEAP8[31110 | 0] | 0; //@line 26529
  HEAP32[$da + 28 >> 2] = 2; //@line 26531
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 26534
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26540
  $18 = $da | 0; //@line 26541
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 26544
  STACKTOP = sp; //@line 26546
  return;
 } else {
  $37 = $da + 32 | 0; //@line 26549
  HEAP8[$37] = HEAP8[31056] | 0; //@line 26550
  HEAP8[$37 + 1 | 0] = HEAP8[31057 | 0] | 0; //@line 26550
  HEAP8[$37 + 2 | 0] = HEAP8[31058 | 0] | 0; //@line 26550
  HEAP8[$37 + 3 | 0] = HEAP8[31059 | 0] | 0; //@line 26550
  HEAP8[$37 + 4 | 0] = HEAP8[31060 | 0] | 0; //@line 26550
  HEAP8[$37 + 5 | 0] = HEAP8[31061 | 0] | 0; //@line 26550
  HEAP32[$da + 28 >> 2] = 2; //@line 26552
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26558
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 26564
  STACKTOP = sp; //@line 26566
  return;
 }
}
function _d_c140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $8 = 0, $23 = 0, $25 = 0, $29 = 0, $31 = 0, $34 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 26582
 $1 = $da + 12 | 0; //@line 26583
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 26587
 if (($5 | 0) == 1) {
  $23 = $da + 32 | 0; //@line 26590
  tempBigInt = 4675653; //@line 26591
  HEAP8[$23] = tempBigInt & 255; //@line 26591
  tempBigInt = tempBigInt >> 8; //@line 26591
  HEAP8[$23 + 1 | 0] = tempBigInt & 255; //@line 26591
  tempBigInt = tempBigInt >> 8; //@line 26591
  HEAP8[$23 + 2 | 0] = tempBigInt & 255; //@line 26591
  tempBigInt = tempBigInt >> 8; //@line 26591
  HEAP8[$23 + 3 | 0] = tempBigInt & 255; //@line 26591
  HEAP32[$da + 28 >> 2] = 2; //@line 26593
  $25 = $da + 96 | 0; //@line 26594
  $29 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 26598
  _sprintf($25 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $29, tempInt) | 0) | 0; //@line 26599
  $31 = $da + 160 | 0; //@line 26600
  $34 = HEAP16[$1 >> 1] & 7; //@line 26603
  _sprintf($31 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $34, tempInt) | 0) | 0; //@line 26604
  STACKTOP = sp; //@line 26606
  return;
 } else if (($5 | 0) == 0) {
  $8 = $da + 32 | 0; //@line 26610
  tempBigInt = 4675653; //@line 26611
  HEAP8[$8] = tempBigInt & 255; //@line 26611
  tempBigInt = tempBigInt >> 8; //@line 26611
  HEAP8[$8 + 1 | 0] = tempBigInt & 255; //@line 26611
  tempBigInt = tempBigInt >> 8; //@line 26611
  HEAP8[$8 + 2 | 0] = tempBigInt & 255; //@line 26611
  tempBigInt = tempBigInt >> 8; //@line 26611
  HEAP8[$8 + 3 | 0] = tempBigInt & 255; //@line 26611
  HEAP32[$da + 28 >> 2] = 2; //@line 26613
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26619
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 26624
  STACKTOP = sp; //@line 26626
  return;
 } else {
  $37 = $da + 32 | 0; //@line 26629
  HEAP8[$37] = HEAP8[31144] | 0; //@line 26630
  HEAP8[$37 + 1 | 0] = HEAP8[31145 | 0] | 0; //@line 26630
  HEAP8[$37 + 2 | 0] = HEAP8[31146 | 0] | 0; //@line 26630
  HEAP8[$37 + 3 | 0] = HEAP8[31147 | 0] | 0; //@line 26630
  HEAP8[$37 + 4 | 0] = HEAP8[31148 | 0] | 0; //@line 26630
  HEAP8[$37 + 5 | 0] = HEAP8[31149 | 0] | 0; //@line 26630
  HEAP32[$da + 28 >> 2] = 2; //@line 26632
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26638
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26644
  STACKTOP = sp; //@line 26646
  return;
 }
}
function _d_c180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $9 = 0, $17 = 0, $21 = 0, $35 = 0, sp = 0;
 sp = STACKTOP; //@line 26662
 $1 = $da + 12 | 0; //@line 26663
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 26667
 if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 26669
  HEAP8[$7] = HEAP8[36120] | 0; //@line 26670
  HEAP8[$7 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 26670
  HEAP8[$7 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 26670
  HEAP32[$da + 28 >> 2] = 1; //@line 26672
  $9 = $da + 96 | 0; //@line 26673
  $17 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 26681
  _sprintf($9 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $17, tempInt) | 0) | 0; //@line 26682
  STACKTOP = sp; //@line 26684
  return;
 } else if (($5 | 0) == 1) {
  $21 = $da + 32 | 0; //@line 26688
  tempBigInt = 4675653; //@line 26689
  HEAP8[$21] = tempBigInt & 255; //@line 26689
  tempBigInt = tempBigInt >> 8; //@line 26689
  HEAP8[$21 + 1 | 0] = tempBigInt & 255; //@line 26689
  tempBigInt = tempBigInt >> 8; //@line 26689
  HEAP8[$21 + 2 | 0] = tempBigInt & 255; //@line 26689
  tempBigInt = tempBigInt >> 8; //@line 26689
  HEAP8[$21 + 3 | 0] = tempBigInt & 255; //@line 26689
  HEAP32[$da + 28 >> 2] = 2; //@line 26691
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26697
  _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 26702
  STACKTOP = sp; //@line 26704
  return;
 } else {
  $35 = $da + 32 | 0; //@line 26707
  HEAP8[$35] = HEAP8[31192] | 0; //@line 26708
  HEAP8[$35 + 1 | 0] = HEAP8[31193 | 0] | 0; //@line 26708
  HEAP8[$35 + 2 | 0] = HEAP8[31194 | 0] | 0; //@line 26708
  HEAP8[$35 + 3 | 0] = HEAP8[31195 | 0] | 0; //@line 26708
  HEAP8[$35 + 4 | 0] = HEAP8[31196 | 0] | 0; //@line 26708
  HEAP8[$35 + 5 | 0] = HEAP8[31197 | 0] | 0; //@line 26708
  HEAP32[$da + 28 >> 2] = 2; //@line 26710
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26716
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26722
  STACKTOP = sp; //@line 26724
  return;
 }
}
function _d_c1c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26736
 $1 = $da + 32 | 0; //@line 26737
 HEAP8[$1] = HEAP8[31320] | 0; //@line 26738
 HEAP8[$1 + 1 | 0] = HEAP8[31321 | 0] | 0; //@line 26738
 HEAP8[$1 + 2 | 0] = HEAP8[31322 | 0] | 0; //@line 26738
 HEAP8[$1 + 3 | 0] = HEAP8[31323 | 0] | 0; //@line 26738
 HEAP8[$1 + 4 | 0] = HEAP8[31324 | 0] | 0; //@line 26738
 HEAP8[$1 + 5 | 0] = HEAP8[31325 | 0] | 0; //@line 26738
 HEAP8[$1 + 6 | 0] = HEAP8[31326 | 0] | 0; //@line 26738
 HEAP32[$da + 28 >> 2] = 2; //@line 26740
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26746
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26752
 STACKTOP = sp; //@line 26753
 return;
}
function _d_d000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26764
 $1 = $da + 32 | 0; //@line 26765
 HEAP8[$1] = HEAP8[31544] | 0; //@line 26766
 HEAP8[$1 + 1 | 0] = HEAP8[31545 | 0] | 0; //@line 26766
 HEAP8[$1 + 2 | 0] = HEAP8[31546 | 0] | 0; //@line 26766
 HEAP8[$1 + 3 | 0] = HEAP8[31547 | 0] | 0; //@line 26766
 HEAP8[$1 + 4 | 0] = HEAP8[31548 | 0] | 0; //@line 26766
 HEAP8[$1 + 5 | 0] = HEAP8[31549 | 0] | 0; //@line 26766
 HEAP32[$da + 28 >> 2] = 2; //@line 26768
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 26774
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26780
 STACKTOP = sp; //@line 26781
 return;
}
function _d_d040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26792
 $1 = $da + 32 | 0; //@line 26793
 HEAP8[$1] = HEAP8[31880] | 0; //@line 26794
 HEAP8[$1 + 1 | 0] = HEAP8[31881 | 0] | 0; //@line 26794
 HEAP8[$1 + 2 | 0] = HEAP8[31882 | 0] | 0; //@line 26794
 HEAP8[$1 + 3 | 0] = HEAP8[31883 | 0] | 0; //@line 26794
 HEAP8[$1 + 4 | 0] = HEAP8[31884 | 0] | 0; //@line 26794
 HEAP8[$1 + 5 | 0] = HEAP8[31885 | 0] | 0; //@line 26794
 HEAP32[$da + 28 >> 2] = 2; //@line 26796
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26802
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26808
 STACKTOP = sp; //@line 26809
 return;
}
function _d_d080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26820
 $1 = $da + 32 | 0; //@line 26821
 HEAP8[$1] = HEAP8[32048] | 0; //@line 26822
 HEAP8[$1 + 1 | 0] = HEAP8[32049 | 0] | 0; //@line 26822
 HEAP8[$1 + 2 | 0] = HEAP8[32050 | 0] | 0; //@line 26822
 HEAP8[$1 + 3 | 0] = HEAP8[32051 | 0] | 0; //@line 26822
 HEAP8[$1 + 4 | 0] = HEAP8[32052 | 0] | 0; //@line 26822
 HEAP8[$1 + 5 | 0] = HEAP8[32053 | 0] | 0; //@line 26822
 HEAP32[$da + 28 >> 2] = 2; //@line 26824
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 26830
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26836
 STACKTOP = sp; //@line 26837
 return;
}
function _d_d0c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 26848
 $1 = $da + 32 | 0; //@line 26849
 HEAP8[$1] = HEAP8[31448] | 0; //@line 26850
 HEAP8[$1 + 1 | 0] = HEAP8[31449 | 0] | 0; //@line 26850
 HEAP8[$1 + 2 | 0] = HEAP8[31450 | 0] | 0; //@line 26850
 HEAP8[$1 + 3 | 0] = HEAP8[31451 | 0] | 0; //@line 26850
 HEAP8[$1 + 4 | 0] = HEAP8[31452 | 0] | 0; //@line 26850
 HEAP8[$1 + 5 | 0] = HEAP8[31453 | 0] | 0; //@line 26850
 HEAP8[$1 + 6 | 0] = HEAP8[31454 | 0] | 0; //@line 26850
 HEAP32[$da + 28 >> 2] = 2; //@line 26852
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 26858
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26864
 STACKTOP = sp; //@line 26865
 return;
}
function _d_d100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $18 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 26880
 $1 = $da + 12 | 0; //@line 26881
 $3 = HEAPU16[$1 >> 1] | 0; //@line 26883
 $5 = $3 >>> 3 & 7; //@line 26885
 if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 26887
  HEAP8[$22] = HEAP8[31720] | 0; //@line 26888
  HEAP8[$22 + 1 | 0] = HEAP8[31721 | 0] | 0; //@line 26888
  HEAP8[$22 + 2 | 0] = HEAP8[31722 | 0] | 0; //@line 26888
  HEAP8[$22 + 3 | 0] = HEAP8[31723 | 0] | 0; //@line 26888
  HEAP8[$22 + 4 | 0] = HEAP8[31724 | 0] | 0; //@line 26888
  HEAP8[$22 + 5 | 0] = HEAP8[31725 | 0] | 0; //@line 26888
  HEAP8[$22 + 6 | 0] = HEAP8[31726 | 0] | 0; //@line 26888
  HEAP32[$da + 28 >> 2] = 2; //@line 26890
  $24 = $da + 96 | 0; //@line 26891
  $25 = $3 & 7; //@line 26892
  _sprintf($24 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $25, tempInt) | 0) | 0; //@line 26893
  $27 = $da + 160 | 0; //@line 26894
  $31 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 26898
  _sprintf($27 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 26899
  $33 = $da | 0; //@line 26900
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 26903
  STACKTOP = sp; //@line 26905
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 26908
  HEAP8[$7] = HEAP8[31720] | 0; //@line 26909
  HEAP8[$7 + 1 | 0] = HEAP8[31721 | 0] | 0; //@line 26909
  HEAP8[$7 + 2 | 0] = HEAP8[31722 | 0] | 0; //@line 26909
  HEAP8[$7 + 3 | 0] = HEAP8[31723 | 0] | 0; //@line 26909
  HEAP8[$7 + 4 | 0] = HEAP8[31724 | 0] | 0; //@line 26909
  HEAP8[$7 + 5 | 0] = HEAP8[31725 | 0] | 0; //@line 26909
  HEAP8[$7 + 6 | 0] = HEAP8[31726 | 0] | 0; //@line 26909
  HEAP32[$da + 28 >> 2] = 2; //@line 26911
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 26914
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26920
  $18 = $da | 0; //@line 26921
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 26924
  STACKTOP = sp; //@line 26926
  return;
 } else {
  $37 = $da + 32 | 0; //@line 26929
  HEAP8[$37] = HEAP8[31544] | 0; //@line 26930
  HEAP8[$37 + 1 | 0] = HEAP8[31545 | 0] | 0; //@line 26930
  HEAP8[$37 + 2 | 0] = HEAP8[31546 | 0] | 0; //@line 26930
  HEAP8[$37 + 3 | 0] = HEAP8[31547 | 0] | 0; //@line 26930
  HEAP8[$37 + 4 | 0] = HEAP8[31548 | 0] | 0; //@line 26930
  HEAP8[$37 + 5 | 0] = HEAP8[31549 | 0] | 0; //@line 26930
  HEAP32[$da + 28 >> 2] = 2; //@line 26932
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 26938
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 26944
  STACKTOP = sp; //@line 26946
  return;
 }
}
function _d_d140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $9 = 0, $10 = 0, $12 = 0, $16 = 0, $18 = 0, $22 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 26962
 $1 = $da + 12 | 0; //@line 26963
 $3 = HEAPU16[$1 >> 1] | 0; //@line 26965
 $5 = $3 >>> 3 & 7; //@line 26967
 if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 26969
  HEAP8[$7] = HEAP8[31952] | 0; //@line 26970
  HEAP8[$7 + 1 | 0] = HEAP8[31953 | 0] | 0; //@line 26970
  HEAP8[$7 + 2 | 0] = HEAP8[31954 | 0] | 0; //@line 26970
  HEAP8[$7 + 3 | 0] = HEAP8[31955 | 0] | 0; //@line 26970
  HEAP8[$7 + 4 | 0] = HEAP8[31956 | 0] | 0; //@line 26970
  HEAP8[$7 + 5 | 0] = HEAP8[31957 | 0] | 0; //@line 26970
  HEAP8[$7 + 6 | 0] = HEAP8[31958 | 0] | 0; //@line 26970
  HEAP32[$da + 28 >> 2] = 2; //@line 26972
  $9 = $da + 96 | 0; //@line 26973
  $10 = $3 & 7; //@line 26974
  _sprintf($9 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $10, tempInt) | 0) | 0; //@line 26975
  $12 = $da + 160 | 0; //@line 26976
  $16 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 26980
  _sprintf($12 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $16, tempInt) | 0) | 0; //@line 26981
  $18 = $da | 0; //@line 26982
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 26985
  STACKTOP = sp; //@line 26987
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 26990
  HEAP8[$22] = HEAP8[31952] | 0; //@line 26991
  HEAP8[$22 + 1 | 0] = HEAP8[31953 | 0] | 0; //@line 26991
  HEAP8[$22 + 2 | 0] = HEAP8[31954 | 0] | 0; //@line 26991
  HEAP8[$22 + 3 | 0] = HEAP8[31955 | 0] | 0; //@line 26991
  HEAP8[$22 + 4 | 0] = HEAP8[31956 | 0] | 0; //@line 26991
  HEAP8[$22 + 5 | 0] = HEAP8[31957 | 0] | 0; //@line 26991
  HEAP8[$22 + 6 | 0] = HEAP8[31958 | 0] | 0; //@line 26991
  HEAP32[$da + 28 >> 2] = 2; //@line 26993
  _sprintf($da + 96 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 26996
  _sprintf($da + 160 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7, tempInt) | 0) | 0; //@line 27002
  $33 = $da | 0; //@line 27003
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 27006
  STACKTOP = sp; //@line 27008
  return;
 } else {
  $37 = $da + 32 | 0; //@line 27011
  HEAP8[$37] = HEAP8[31880] | 0; //@line 27012
  HEAP8[$37 + 1 | 0] = HEAP8[31881 | 0] | 0; //@line 27012
  HEAP8[$37 + 2 | 0] = HEAP8[31882 | 0] | 0; //@line 27012
  HEAP8[$37 + 3 | 0] = HEAP8[31883 | 0] | 0; //@line 27012
  HEAP8[$37 + 4 | 0] = HEAP8[31884 | 0] | 0; //@line 27012
  HEAP8[$37 + 5 | 0] = HEAP8[31885 | 0] | 0; //@line 27012
  HEAP32[$da + 28 >> 2] = 2; //@line 27014
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27020
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 27026
  STACKTOP = sp; //@line 27028
  return;
 }
}
function _d_d180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $18 = 0, $22 = 0, $24 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, sp = 0;
 sp = STACKTOP; //@line 27044
 $1 = $da + 12 | 0; //@line 27045
 $3 = HEAPU16[$1 >> 1] | 0; //@line 27047
 $5 = $3 >>> 3 & 7; //@line 27049
 if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 27051
  HEAP8[$22] = HEAP8[32160] | 0; //@line 27052
  HEAP8[$22 + 1 | 0] = HEAP8[32161 | 0] | 0; //@line 27052
  HEAP8[$22 + 2 | 0] = HEAP8[32162 | 0] | 0; //@line 27052
  HEAP8[$22 + 3 | 0] = HEAP8[32163 | 0] | 0; //@line 27052
  HEAP8[$22 + 4 | 0] = HEAP8[32164 | 0] | 0; //@line 27052
  HEAP8[$22 + 5 | 0] = HEAP8[32165 | 0] | 0; //@line 27052
  HEAP8[$22 + 6 | 0] = HEAP8[32166 | 0] | 0; //@line 27052
  HEAP32[$da + 28 >> 2] = 2; //@line 27054
  $24 = $da + 96 | 0; //@line 27055
  $25 = $3 & 7; //@line 27056
  _sprintf($24 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $25, tempInt) | 0) | 0; //@line 27057
  $27 = $da + 160 | 0; //@line 27058
  $31 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7; //@line 27062
  _sprintf($27 | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 27063
  $33 = $da | 0; //@line 27064
  HEAP32[$33 >> 2] = HEAP32[$33 >> 2] | 32; //@line 27067
  STACKTOP = sp; //@line 27069
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 27072
  HEAP8[$7] = HEAP8[32160] | 0; //@line 27073
  HEAP8[$7 + 1 | 0] = HEAP8[32161 | 0] | 0; //@line 27073
  HEAP8[$7 + 2 | 0] = HEAP8[32162 | 0] | 0; //@line 27073
  HEAP8[$7 + 3 | 0] = HEAP8[32163 | 0] | 0; //@line 27073
  HEAP8[$7 + 4 | 0] = HEAP8[32164 | 0] | 0; //@line 27073
  HEAP8[$7 + 5 | 0] = HEAP8[32165 | 0] | 0; //@line 27073
  HEAP8[$7 + 6 | 0] = HEAP8[32166 | 0] | 0; //@line 27073
  HEAP32[$da + 28 >> 2] = 2; //@line 27075
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $3 & 7, tempInt) | 0) | 0; //@line 27078
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27084
  $18 = $da | 0; //@line 27085
  HEAP32[$18 >> 2] = HEAP32[$18 >> 2] | 32; //@line 27088
  STACKTOP = sp; //@line 27090
  return;
 } else {
  $37 = $da + 32 | 0; //@line 27093
  HEAP8[$37] = HEAP8[32048] | 0; //@line 27094
  HEAP8[$37 + 1 | 0] = HEAP8[32049 | 0] | 0; //@line 27094
  HEAP8[$37 + 2 | 0] = HEAP8[32050 | 0] | 0; //@line 27094
  HEAP8[$37 + 3 | 0] = HEAP8[32051 | 0] | 0; //@line 27094
  HEAP8[$37 + 4 | 0] = HEAP8[32052 | 0] | 0; //@line 27094
  HEAP8[$37 + 5 | 0] = HEAP8[32053 | 0] | 0; //@line 27094
  HEAP32[$da + 28 >> 2] = 2; //@line 27096
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27102
  _dasm_ea($da, $da + 160 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 27108
  STACKTOP = sp; //@line 27110
  return;
 }
}
function _d_d1c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 27122
 $1 = $da + 32 | 0; //@line 27123
 HEAP8[$1] = HEAP8[32288] | 0; //@line 27124
 HEAP8[$1 + 1 | 0] = HEAP8[32289 | 0] | 0; //@line 27124
 HEAP8[$1 + 2 | 0] = HEAP8[32290 | 0] | 0; //@line 27124
 HEAP8[$1 + 3 | 0] = HEAP8[32291 | 0] | 0; //@line 27124
 HEAP8[$1 + 4 | 0] = HEAP8[32292 | 0] | 0; //@line 27124
 HEAP8[$1 + 5 | 0] = HEAP8[32293 | 0] | 0; //@line 27124
 HEAP8[$1 + 6 | 0] = HEAP8[32294 | 0] | 0; //@line 27124
 HEAP32[$da + 28 >> 2] = 2; //@line 27126
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 32); //@line 27132
 _sprintf($da + 160 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27138
 STACKTOP = sp; //@line 27139
 return;
}
function _d_e000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $13 = 0, $22 = 0, $28 = 0, $37 = 0, $43 = 0, $51 = 0, $55 = 0, $61 = 0, $70 = 0, $84 = 0, $98 = 0, $100 = 0, $104 = 0, $106 = 0, $109 = 0, $111 = 0, $115 = 0, $129 = 0, $139 = 0, sp = 0;
 sp = STACKTOP; //@line 27166
 $1 = $da + 12 | 0; //@line 27167
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 27171
 if (($5 | 0) == 6) {
  $98 = $da + 32 | 0; //@line 27173
  HEAP8[$98] = HEAP8[32592] | 0; //@line 27174
  HEAP8[$98 + 1 | 0] = HEAP8[32593 | 0] | 0; //@line 27174
  HEAP8[$98 + 2 | 0] = HEAP8[32594 | 0] | 0; //@line 27174
  HEAP8[$98 + 3 | 0] = HEAP8[32595 | 0] | 0; //@line 27174
  HEAP8[$98 + 4 | 0] = HEAP8[32596 | 0] | 0; //@line 27174
  HEAP8[$98 + 5 | 0] = HEAP8[32597 | 0] | 0; //@line 27174
  HEAP8[$98 + 6 | 0] = HEAP8[32598 | 0] | 0; //@line 27174
  HEAP32[$da + 28 >> 2] = 2; //@line 27176
  $100 = $da + 96 | 0; //@line 27177
  $104 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 27181
  _sprintf($100 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $104, tempInt) | 0) | 0; //@line 27182
  $106 = $da + 160 | 0; //@line 27183
  $109 = HEAP16[$1 >> 1] & 7; //@line 27186
  _sprintf($106 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $109, tempInt) | 0) | 0; //@line 27187
  $111 = $da | 0; //@line 27188
  HEAP32[$111 >> 2] = HEAP32[$111 >> 2] | 32; //@line 27191
  STACKTOP = sp; //@line 27193
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 27196
  HEAP8[$22] = HEAP8[32792] | 0; //@line 27197
  HEAP8[$22 + 1 | 0] = HEAP8[32793 | 0] | 0; //@line 27197
  HEAP8[$22 + 2 | 0] = HEAP8[32794 | 0] | 0; //@line 27197
  HEAP8[$22 + 3 | 0] = HEAP8[32795 | 0] | 0; //@line 27197
  HEAP8[$22 + 4 | 0] = HEAP8[32796 | 0] | 0; //@line 27197
  HEAP8[$22 + 5 | 0] = HEAP8[32797 | 0] | 0; //@line 27197
  HEAP32[$da + 28 >> 2] = 2; //@line 27199
  $28 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27204
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28 << 16 >> 16 == 0 ? 8 : $28 & 65535, tempInt) | 0) | 0; //@line 27208
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27213
  STACKTOP = sp; //@line 27215
  return;
 } else if (($5 | 0) == 2) {
  $37 = $da + 32 | 0; //@line 27218
  HEAP8[$37] = HEAP8[32592] | 0; //@line 27219
  HEAP8[$37 + 1 | 0] = HEAP8[32593 | 0] | 0; //@line 27219
  HEAP8[$37 + 2 | 0] = HEAP8[32594 | 0] | 0; //@line 27219
  HEAP8[$37 + 3 | 0] = HEAP8[32595 | 0] | 0; //@line 27219
  HEAP8[$37 + 4 | 0] = HEAP8[32596 | 0] | 0; //@line 27219
  HEAP8[$37 + 5 | 0] = HEAP8[32597 | 0] | 0; //@line 27219
  HEAP8[$37 + 6 | 0] = HEAP8[32598 | 0] | 0; //@line 27219
  HEAP32[$da + 28 >> 2] = 2; //@line 27221
  $43 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27226
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $43 << 16 >> 16 == 0 ? 8 : $43 & 65535, tempInt) | 0) | 0; //@line 27230
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27235
  $51 = $da | 0; //@line 27236
  HEAP32[$51 >> 2] = HEAP32[$51 >> 2] | 32; //@line 27239
  STACKTOP = sp; //@line 27241
  return;
 } else if (($5 | 0) == 4) {
  $70 = $da + 32 | 0; //@line 27244
  HEAP8[$70] = HEAP8[33120] | 0; //@line 27245
  HEAP8[$70 + 1 | 0] = HEAP8[33121 | 0] | 0; //@line 27245
  HEAP8[$70 + 2 | 0] = HEAP8[33122 | 0] | 0; //@line 27245
  HEAP8[$70 + 3 | 0] = HEAP8[33123 | 0] | 0; //@line 27245
  HEAP8[$70 + 4 | 0] = HEAP8[33124 | 0] | 0; //@line 27245
  HEAP8[$70 + 5 | 0] = HEAP8[33125 | 0] | 0; //@line 27245
  HEAP32[$da + 28 >> 2] = 2; //@line 27247
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27253
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27258
  STACKTOP = sp; //@line 27260
  return;
 } else if (($5 | 0) == 3) {
  $55 = $da + 32 | 0; //@line 27263
  HEAP8[$55] = HEAP8[32472] | 0; //@line 27264
  HEAP8[$55 + 1 | 0] = HEAP8[32473 | 0] | 0; //@line 27264
  HEAP8[$55 + 2 | 0] = HEAP8[32474 | 0] | 0; //@line 27264
  HEAP8[$55 + 3 | 0] = HEAP8[32475 | 0] | 0; //@line 27264
  HEAP8[$55 + 4 | 0] = HEAP8[32476 | 0] | 0; //@line 27264
  HEAP8[$55 + 5 | 0] = HEAP8[32477 | 0] | 0; //@line 27264
  HEAP32[$da + 28 >> 2] = 2; //@line 27266
  $61 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27271
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $61 << 16 >> 16 == 0 ? 8 : $61 & 65535, tempInt) | 0) | 0; //@line 27275
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27280
  STACKTOP = sp; //@line 27282
  return;
 } else if (($5 | 0) == 5) {
  $84 = $da + 32 | 0; //@line 27285
  HEAP8[$84] = HEAP8[32792] | 0; //@line 27286
  HEAP8[$84 + 1 | 0] = HEAP8[32793 | 0] | 0; //@line 27286
  HEAP8[$84 + 2 | 0] = HEAP8[32794 | 0] | 0; //@line 27286
  HEAP8[$84 + 3 | 0] = HEAP8[32795 | 0] | 0; //@line 27286
  HEAP8[$84 + 4 | 0] = HEAP8[32796 | 0] | 0; //@line 27286
  HEAP8[$84 + 5 | 0] = HEAP8[32797 | 0] | 0; //@line 27286
  HEAP32[$da + 28 >> 2] = 2; //@line 27288
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27294
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27299
  STACKTOP = sp; //@line 27301
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 27304
  HEAP8[$7] = HEAP8[33120] | 0; //@line 27305
  HEAP8[$7 + 1 | 0] = HEAP8[33121 | 0] | 0; //@line 27305
  HEAP8[$7 + 2 | 0] = HEAP8[33122 | 0] | 0; //@line 27305
  HEAP8[$7 + 3 | 0] = HEAP8[33123 | 0] | 0; //@line 27305
  HEAP8[$7 + 4 | 0] = HEAP8[33124 | 0] | 0; //@line 27305
  HEAP8[$7 + 5 | 0] = HEAP8[33125 | 0] | 0; //@line 27305
  HEAP32[$da + 28 >> 2] = 2; //@line 27307
  $13 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27312
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $13 << 16 >> 16 == 0 ? 8 : $13 & 65535, tempInt) | 0) | 0; //@line 27316
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27321
  STACKTOP = sp; //@line 27323
  return;
 } else if (($5 | 0) == 7) {
  $115 = $da + 32 | 0; //@line 27326
  HEAP8[$115] = HEAP8[32472] | 0; //@line 27327
  HEAP8[$115 + 1 | 0] = HEAP8[32473 | 0] | 0; //@line 27327
  HEAP8[$115 + 2 | 0] = HEAP8[32474 | 0] | 0; //@line 27327
  HEAP8[$115 + 3 | 0] = HEAP8[32475 | 0] | 0; //@line 27327
  HEAP8[$115 + 4 | 0] = HEAP8[32476 | 0] | 0; //@line 27327
  HEAP8[$115 + 5 | 0] = HEAP8[32477 | 0] | 0; //@line 27327
  HEAP32[$da + 28 >> 2] = 2; //@line 27329
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27335
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27340
  STACKTOP = sp; //@line 27342
  return;
 } else {
  $129 = $da + 32 | 0; //@line 27345
  HEAP8[$129] = HEAP8[36120] | 0; //@line 27346
  HEAP8[$129 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 27346
  HEAP8[$129 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 27346
  HEAP32[$da + 28 >> 2] = 1; //@line 27348
  $139 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 27357
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $139, tempInt) | 0) | 0; //@line 27358
  STACKTOP = sp; //@line 27360
  return;
 }
}
function _d_e040($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $13 = 0, $22 = 0, $28 = 0, $37 = 0, $43 = 0, $51 = 0, $55 = 0, $57 = 0, $61 = 0, $_off0_i26 = 0, $64 = 0, $67 = 0, $70 = 0, $84 = 0, $98 = 0, $111 = 0, $115 = 0, $129 = 0, $139 = 0, sp = 0;
 sp = STACKTOP; //@line 27388
 $1 = $da + 12 | 0; //@line 27389
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 27393
 if (($5 | 0) == 3) {
  $55 = $da + 32 | 0; //@line 27395
  HEAP8[$55] = HEAP8[39040] | 0; //@line 27396
  HEAP8[$55 + 1 | 0] = HEAP8[39041 | 0] | 0; //@line 27396
  HEAP8[$55 + 2 | 0] = HEAP8[39042 | 0] | 0; //@line 27396
  HEAP8[$55 + 3 | 0] = HEAP8[39043 | 0] | 0; //@line 27396
  HEAP8[$55 + 4 | 0] = HEAP8[39044 | 0] | 0; //@line 27396
  HEAP8[$55 + 5 | 0] = HEAP8[39045 | 0] | 0; //@line 27396
  HEAP32[$da + 28 >> 2] = 2; //@line 27398
  $57 = $da + 96 | 0; //@line 27399
  $61 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27403
  $_off0_i26 = $61 << 16 >> 16 == 0 ? 8 : $61 & 65535; //@line 27406
  _sprintf($57 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $_off0_i26, tempInt) | 0) | 0; //@line 27407
  $64 = $da + 160 | 0; //@line 27408
  $67 = HEAP16[$1 >> 1] & 7; //@line 27411
  _sprintf($64 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $67, tempInt) | 0) | 0; //@line 27412
  STACKTOP = sp; //@line 27414
  return;
 } else if (($5 | 0) == 7) {
  $115 = $da + 32 | 0; //@line 27417
  HEAP8[$115] = HEAP8[39040] | 0; //@line 27418
  HEAP8[$115 + 1 | 0] = HEAP8[39041 | 0] | 0; //@line 27418
  HEAP8[$115 + 2 | 0] = HEAP8[39042 | 0] | 0; //@line 27418
  HEAP8[$115 + 3 | 0] = HEAP8[39043 | 0] | 0; //@line 27418
  HEAP8[$115 + 4 | 0] = HEAP8[39044 | 0] | 0; //@line 27418
  HEAP8[$115 + 5 | 0] = HEAP8[39045 | 0] | 0; //@line 27418
  HEAP32[$da + 28 >> 2] = 2; //@line 27420
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27426
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27431
  STACKTOP = sp; //@line 27433
  return;
 } else if (($5 | 0) == 5) {
  $84 = $da + 32 | 0; //@line 27436
  HEAP8[$84] = HEAP8[37880] | 0; //@line 27437
  HEAP8[$84 + 1 | 0] = HEAP8[37881 | 0] | 0; //@line 27437
  HEAP8[$84 + 2 | 0] = HEAP8[37882 | 0] | 0; //@line 27437
  HEAP8[$84 + 3 | 0] = HEAP8[37883 | 0] | 0; //@line 27437
  HEAP8[$84 + 4 | 0] = HEAP8[37884 | 0] | 0; //@line 27437
  HEAP8[$84 + 5 | 0] = HEAP8[37885 | 0] | 0; //@line 27437
  HEAP32[$da + 28 >> 2] = 2; //@line 27439
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27445
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27450
  STACKTOP = sp; //@line 27452
  return;
 } else if (($5 | 0) == 6) {
  $98 = $da + 32 | 0; //@line 27455
  HEAP8[$98] = HEAP8[38424] | 0; //@line 27456
  HEAP8[$98 + 1 | 0] = HEAP8[38425 | 0] | 0; //@line 27456
  HEAP8[$98 + 2 | 0] = HEAP8[38426 | 0] | 0; //@line 27456
  HEAP8[$98 + 3 | 0] = HEAP8[38427 | 0] | 0; //@line 27456
  HEAP8[$98 + 4 | 0] = HEAP8[38428 | 0] | 0; //@line 27456
  HEAP8[$98 + 5 | 0] = HEAP8[38429 | 0] | 0; //@line 27456
  HEAP8[$98 + 6 | 0] = HEAP8[38430 | 0] | 0; //@line 27456
  HEAP32[$da + 28 >> 2] = 2; //@line 27458
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27464
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27469
  $111 = $da | 0; //@line 27470
  HEAP32[$111 >> 2] = HEAP32[$111 >> 2] | 32; //@line 27473
  STACKTOP = sp; //@line 27475
  return;
 } else if (($5 | 0) == 4) {
  $70 = $da + 32 | 0; //@line 27478
  HEAP8[$70] = HEAP8[34688] | 0; //@line 27479
  HEAP8[$70 + 1 | 0] = HEAP8[34689 | 0] | 0; //@line 27479
  HEAP8[$70 + 2 | 0] = HEAP8[34690 | 0] | 0; //@line 27479
  HEAP8[$70 + 3 | 0] = HEAP8[34691 | 0] | 0; //@line 27479
  HEAP8[$70 + 4 | 0] = HEAP8[34692 | 0] | 0; //@line 27479
  HEAP8[$70 + 5 | 0] = HEAP8[34693 | 0] | 0; //@line 27479
  HEAP32[$da + 28 >> 2] = 2; //@line 27481
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27487
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27492
  STACKTOP = sp; //@line 27494
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 27497
  HEAP8[$22] = HEAP8[37880] | 0; //@line 27498
  HEAP8[$22 + 1 | 0] = HEAP8[37881 | 0] | 0; //@line 27498
  HEAP8[$22 + 2 | 0] = HEAP8[37882 | 0] | 0; //@line 27498
  HEAP8[$22 + 3 | 0] = HEAP8[37883 | 0] | 0; //@line 27498
  HEAP8[$22 + 4 | 0] = HEAP8[37884 | 0] | 0; //@line 27498
  HEAP8[$22 + 5 | 0] = HEAP8[37885 | 0] | 0; //@line 27498
  HEAP32[$da + 28 >> 2] = 2; //@line 27500
  $28 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27505
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28 << 16 >> 16 == 0 ? 8 : $28 & 65535, tempInt) | 0) | 0; //@line 27509
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27514
  STACKTOP = sp; //@line 27516
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 27519
  HEAP8[$7] = HEAP8[34688] | 0; //@line 27520
  HEAP8[$7 + 1 | 0] = HEAP8[34689 | 0] | 0; //@line 27520
  HEAP8[$7 + 2 | 0] = HEAP8[34690 | 0] | 0; //@line 27520
  HEAP8[$7 + 3 | 0] = HEAP8[34691 | 0] | 0; //@line 27520
  HEAP8[$7 + 4 | 0] = HEAP8[34692 | 0] | 0; //@line 27520
  HEAP8[$7 + 5 | 0] = HEAP8[34693 | 0] | 0; //@line 27520
  HEAP32[$da + 28 >> 2] = 2; //@line 27522
  $13 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27527
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $13 << 16 >> 16 == 0 ? 8 : $13 & 65535, tempInt) | 0) | 0; //@line 27531
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27536
  STACKTOP = sp; //@line 27538
  return;
 } else if (($5 | 0) == 2) {
  $37 = $da + 32 | 0; //@line 27541
  HEAP8[$37] = HEAP8[38424] | 0; //@line 27542
  HEAP8[$37 + 1 | 0] = HEAP8[38425 | 0] | 0; //@line 27542
  HEAP8[$37 + 2 | 0] = HEAP8[38426 | 0] | 0; //@line 27542
  HEAP8[$37 + 3 | 0] = HEAP8[38427 | 0] | 0; //@line 27542
  HEAP8[$37 + 4 | 0] = HEAP8[38428 | 0] | 0; //@line 27542
  HEAP8[$37 + 5 | 0] = HEAP8[38429 | 0] | 0; //@line 27542
  HEAP8[$37 + 6 | 0] = HEAP8[38430 | 0] | 0; //@line 27542
  HEAP32[$da + 28 >> 2] = 2; //@line 27544
  $43 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27549
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $43 << 16 >> 16 == 0 ? 8 : $43 & 65535, tempInt) | 0) | 0; //@line 27553
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27558
  $51 = $da | 0; //@line 27559
  HEAP32[$51 >> 2] = HEAP32[$51 >> 2] | 32; //@line 27562
  STACKTOP = sp; //@line 27564
  return;
 } else {
  $129 = $da + 32 | 0; //@line 27567
  HEAP8[$129] = HEAP8[36120] | 0; //@line 27568
  HEAP8[$129 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 27568
  HEAP8[$129 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 27568
  HEAP32[$da + 28 >> 2] = 1; //@line 27570
  $139 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 27579
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $139, tempInt) | 0) | 0; //@line 27580
  STACKTOP = sp; //@line 27582
  return;
 }
}
function _d_e080($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $13 = 0, $22 = 0, $28 = 0, $37 = 0, $43 = 0, $51 = 0, $55 = 0, $61 = 0, $70 = 0, $84 = 0, $98 = 0, $100 = 0, $104 = 0, $106 = 0, $109 = 0, $111 = 0, $115 = 0, $129 = 0, $139 = 0, sp = 0;
 sp = STACKTOP; //@line 27610
 $1 = $da + 12 | 0; //@line 27611
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 27615
 if (($5 | 0) == 6) {
  $98 = $da + 32 | 0; //@line 27617
  HEAP8[$98] = HEAP8[33856] | 0; //@line 27618
  HEAP8[$98 + 1 | 0] = HEAP8[33857 | 0] | 0; //@line 27618
  HEAP8[$98 + 2 | 0] = HEAP8[33858 | 0] | 0; //@line 27618
  HEAP8[$98 + 3 | 0] = HEAP8[33859 | 0] | 0; //@line 27618
  HEAP8[$98 + 4 | 0] = HEAP8[33860 | 0] | 0; //@line 27618
  HEAP8[$98 + 5 | 0] = HEAP8[33861 | 0] | 0; //@line 27618
  HEAP8[$98 + 6 | 0] = HEAP8[33862 | 0] | 0; //@line 27618
  HEAP32[$da + 28 >> 2] = 2; //@line 27620
  $100 = $da + 96 | 0; //@line 27621
  $104 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 27625
  _sprintf($100 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $104, tempInt) | 0) | 0; //@line 27626
  $106 = $da + 160 | 0; //@line 27627
  $109 = HEAP16[$1 >> 1] & 7; //@line 27630
  _sprintf($106 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $109, tempInt) | 0) | 0; //@line 27631
  $111 = $da | 0; //@line 27632
  HEAP32[$111 >> 2] = HEAP32[$111 >> 2] | 32; //@line 27635
  STACKTOP = sp; //@line 27637
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 27640
  HEAP8[$22] = HEAP8[34104] | 0; //@line 27641
  HEAP8[$22 + 1 | 0] = HEAP8[34105 | 0] | 0; //@line 27641
  HEAP8[$22 + 2 | 0] = HEAP8[34106 | 0] | 0; //@line 27641
  HEAP8[$22 + 3 | 0] = HEAP8[34107 | 0] | 0; //@line 27641
  HEAP8[$22 + 4 | 0] = HEAP8[34108 | 0] | 0; //@line 27641
  HEAP8[$22 + 5 | 0] = HEAP8[34109 | 0] | 0; //@line 27641
  HEAP32[$da + 28 >> 2] = 2; //@line 27643
  $28 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27648
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28 << 16 >> 16 == 0 ? 8 : $28 & 65535, tempInt) | 0) | 0; //@line 27652
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27657
  STACKTOP = sp; //@line 27659
  return;
 } else if (($5 | 0) == 2) {
  $37 = $da + 32 | 0; //@line 27662
  HEAP8[$37] = HEAP8[33856] | 0; //@line 27663
  HEAP8[$37 + 1 | 0] = HEAP8[33857 | 0] | 0; //@line 27663
  HEAP8[$37 + 2 | 0] = HEAP8[33858 | 0] | 0; //@line 27663
  HEAP8[$37 + 3 | 0] = HEAP8[33859 | 0] | 0; //@line 27663
  HEAP8[$37 + 4 | 0] = HEAP8[33860 | 0] | 0; //@line 27663
  HEAP8[$37 + 5 | 0] = HEAP8[33861 | 0] | 0; //@line 27663
  HEAP8[$37 + 6 | 0] = HEAP8[33862 | 0] | 0; //@line 27663
  HEAP32[$da + 28 >> 2] = 2; //@line 27665
  $43 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27670
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $43 << 16 >> 16 == 0 ? 8 : $43 & 65535, tempInt) | 0) | 0; //@line 27674
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27679
  $51 = $da | 0; //@line 27680
  HEAP32[$51 >> 2] = HEAP32[$51 >> 2] | 32; //@line 27683
  STACKTOP = sp; //@line 27685
  return;
 } else if (($5 | 0) == 4) {
  $70 = $da + 32 | 0; //@line 27688
  HEAP8[$70] = HEAP8[34448] | 0; //@line 27689
  HEAP8[$70 + 1 | 0] = HEAP8[34449 | 0] | 0; //@line 27689
  HEAP8[$70 + 2 | 0] = HEAP8[34450 | 0] | 0; //@line 27689
  HEAP8[$70 + 3 | 0] = HEAP8[34451 | 0] | 0; //@line 27689
  HEAP8[$70 + 4 | 0] = HEAP8[34452 | 0] | 0; //@line 27689
  HEAP8[$70 + 5 | 0] = HEAP8[34453 | 0] | 0; //@line 27689
  HEAP32[$da + 28 >> 2] = 2; //@line 27691
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27697
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27702
  STACKTOP = sp; //@line 27704
  return;
 } else if (($5 | 0) == 3) {
  $55 = $da + 32 | 0; //@line 27707
  HEAP8[$55] = HEAP8[33536] | 0; //@line 27708
  HEAP8[$55 + 1 | 0] = HEAP8[33537 | 0] | 0; //@line 27708
  HEAP8[$55 + 2 | 0] = HEAP8[33538 | 0] | 0; //@line 27708
  HEAP8[$55 + 3 | 0] = HEAP8[33539 | 0] | 0; //@line 27708
  HEAP8[$55 + 4 | 0] = HEAP8[33540 | 0] | 0; //@line 27708
  HEAP8[$55 + 5 | 0] = HEAP8[33541 | 0] | 0; //@line 27708
  HEAP32[$da + 28 >> 2] = 2; //@line 27710
  $61 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27715
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $61 << 16 >> 16 == 0 ? 8 : $61 & 65535, tempInt) | 0) | 0; //@line 27719
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27724
  STACKTOP = sp; //@line 27726
  return;
 } else if (($5 | 0) == 5) {
  $84 = $da + 32 | 0; //@line 27729
  HEAP8[$84] = HEAP8[34104] | 0; //@line 27730
  HEAP8[$84 + 1 | 0] = HEAP8[34105 | 0] | 0; //@line 27730
  HEAP8[$84 + 2 | 0] = HEAP8[34106 | 0] | 0; //@line 27730
  HEAP8[$84 + 3 | 0] = HEAP8[34107 | 0] | 0; //@line 27730
  HEAP8[$84 + 4 | 0] = HEAP8[34108 | 0] | 0; //@line 27730
  HEAP8[$84 + 5 | 0] = HEAP8[34109 | 0] | 0; //@line 27730
  HEAP32[$da + 28 >> 2] = 2; //@line 27732
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27738
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27743
  STACKTOP = sp; //@line 27745
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 27748
  HEAP8[$7] = HEAP8[34448] | 0; //@line 27749
  HEAP8[$7 + 1 | 0] = HEAP8[34449 | 0] | 0; //@line 27749
  HEAP8[$7 + 2 | 0] = HEAP8[34450 | 0] | 0; //@line 27749
  HEAP8[$7 + 3 | 0] = HEAP8[34451 | 0] | 0; //@line 27749
  HEAP8[$7 + 4 | 0] = HEAP8[34452 | 0] | 0; //@line 27749
  HEAP8[$7 + 5 | 0] = HEAP8[34453 | 0] | 0; //@line 27749
  HEAP32[$da + 28 >> 2] = 2; //@line 27751
  $13 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27756
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $13 << 16 >> 16 == 0 ? 8 : $13 & 65535, tempInt) | 0) | 0; //@line 27760
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27765
  STACKTOP = sp; //@line 27767
  return;
 } else if (($5 | 0) == 7) {
  $115 = $da + 32 | 0; //@line 27770
  HEAP8[$115] = HEAP8[33536] | 0; //@line 27771
  HEAP8[$115 + 1 | 0] = HEAP8[33537 | 0] | 0; //@line 27771
  HEAP8[$115 + 2 | 0] = HEAP8[33538 | 0] | 0; //@line 27771
  HEAP8[$115 + 3 | 0] = HEAP8[33539 | 0] | 0; //@line 27771
  HEAP8[$115 + 4 | 0] = HEAP8[33540 | 0] | 0; //@line 27771
  HEAP8[$115 + 5 | 0] = HEAP8[33541 | 0] | 0; //@line 27771
  HEAP32[$da + 28 >> 2] = 2; //@line 27773
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27779
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27784
  STACKTOP = sp; //@line 27786
  return;
 } else {
  $129 = $da + 32 | 0; //@line 27789
  HEAP8[$129] = HEAP8[36120] | 0; //@line 27790
  HEAP8[$129 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 27790
  HEAP8[$129 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 27790
  HEAP32[$da + 28 >> 2] = 1; //@line 27792
  $139 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 27801
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $139, tempInt) | 0) | 0; //@line 27802
  STACKTOP = sp; //@line 27804
  return;
 }
}
function _d_e0c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 27816
 HEAP8[$1] = HEAP8[34688] | 0; //@line 27817
 HEAP8[$1 + 1 | 0] = HEAP8[34689 | 0] | 0; //@line 27817
 HEAP8[$1 + 2 | 0] = HEAP8[34690 | 0] | 0; //@line 27817
 HEAP8[$1 + 3 | 0] = HEAP8[34691 | 0] | 0; //@line 27817
 HEAP8[$1 + 4 | 0] = HEAP8[34692 | 0] | 0; //@line 27817
 HEAP8[$1 + 5 | 0] = HEAP8[34693 | 0] | 0; //@line 27817
 HEAP32[$da + 28 >> 2] = 1; //@line 27819
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 27825
 return;
}
function _d_e100($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $13 = 0, $22 = 0, $28 = 0, $37 = 0, $43 = 0, $51 = 0, $55 = 0, $57 = 0, $61 = 0, $_off0_i26 = 0, $64 = 0, $67 = 0, $70 = 0, $84 = 0, $98 = 0, $111 = 0, $115 = 0, $129 = 0, $139 = 0, sp = 0;
 sp = STACKTOP; //@line 27853
 $1 = $da + 12 | 0; //@line 27854
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 27858
 if (($5 | 0) == 3) {
  $55 = $da + 32 | 0; //@line 27860
  HEAP8[$55] = HEAP8[34928] | 0; //@line 27861
  HEAP8[$55 + 1 | 0] = HEAP8[34929 | 0] | 0; //@line 27861
  HEAP8[$55 + 2 | 0] = HEAP8[34930 | 0] | 0; //@line 27861
  HEAP8[$55 + 3 | 0] = HEAP8[34931 | 0] | 0; //@line 27861
  HEAP8[$55 + 4 | 0] = HEAP8[34932 | 0] | 0; //@line 27861
  HEAP8[$55 + 5 | 0] = HEAP8[34933 | 0] | 0; //@line 27861
  HEAP32[$da + 28 >> 2] = 2; //@line 27863
  $57 = $da + 96 | 0; //@line 27864
  $61 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27868
  $_off0_i26 = $61 << 16 >> 16 == 0 ? 8 : $61 & 65535; //@line 27871
  _sprintf($57 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $_off0_i26, tempInt) | 0) | 0; //@line 27872
  $64 = $da + 160 | 0; //@line 27873
  $67 = HEAP16[$1 >> 1] & 7; //@line 27876
  _sprintf($64 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $67, tempInt) | 0) | 0; //@line 27877
  STACKTOP = sp; //@line 27879
  return;
 } else if (($5 | 0) == 7) {
  $115 = $da + 32 | 0; //@line 27882
  HEAP8[$115] = HEAP8[34928] | 0; //@line 27883
  HEAP8[$115 + 1 | 0] = HEAP8[34929 | 0] | 0; //@line 27883
  HEAP8[$115 + 2 | 0] = HEAP8[34930 | 0] | 0; //@line 27883
  HEAP8[$115 + 3 | 0] = HEAP8[34931 | 0] | 0; //@line 27883
  HEAP8[$115 + 4 | 0] = HEAP8[34932 | 0] | 0; //@line 27883
  HEAP8[$115 + 5 | 0] = HEAP8[34933 | 0] | 0; //@line 27883
  HEAP32[$da + 28 >> 2] = 2; //@line 27885
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27891
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27896
  STACKTOP = sp; //@line 27898
  return;
 } else if (($5 | 0) == 5) {
  $84 = $da + 32 | 0; //@line 27901
  HEAP8[$84] = HEAP8[35496] | 0; //@line 27902
  HEAP8[$84 + 1 | 0] = HEAP8[35497 | 0] | 0; //@line 27902
  HEAP8[$84 + 2 | 0] = HEAP8[35498 | 0] | 0; //@line 27902
  HEAP8[$84 + 3 | 0] = HEAP8[35499 | 0] | 0; //@line 27902
  HEAP8[$84 + 4 | 0] = HEAP8[35500 | 0] | 0; //@line 27902
  HEAP8[$84 + 5 | 0] = HEAP8[35501 | 0] | 0; //@line 27902
  HEAP32[$da + 28 >> 2] = 2; //@line 27904
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27910
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27915
  STACKTOP = sp; //@line 27917
  return;
 } else if (($5 | 0) == 6) {
  $98 = $da + 32 | 0; //@line 27920
  HEAP8[$98] = HEAP8[35232] | 0; //@line 27921
  HEAP8[$98 + 1 | 0] = HEAP8[35233 | 0] | 0; //@line 27921
  HEAP8[$98 + 2 | 0] = HEAP8[35234 | 0] | 0; //@line 27921
  HEAP8[$98 + 3 | 0] = HEAP8[35235 | 0] | 0; //@line 27921
  HEAP8[$98 + 4 | 0] = HEAP8[35236 | 0] | 0; //@line 27921
  HEAP8[$98 + 5 | 0] = HEAP8[35237 | 0] | 0; //@line 27921
  HEAP8[$98 + 6 | 0] = HEAP8[35238 | 0] | 0; //@line 27921
  HEAP32[$da + 28 >> 2] = 2; //@line 27923
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27929
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27934
  $111 = $da | 0; //@line 27935
  HEAP32[$111 >> 2] = HEAP32[$111 >> 2] | 32; //@line 27938
  STACKTOP = sp; //@line 27940
  return;
 } else if (($5 | 0) == 4) {
  $70 = $da + 32 | 0; //@line 27943
  HEAP8[$70] = HEAP8[35824] | 0; //@line 27944
  HEAP8[$70 + 1 | 0] = HEAP8[35825 | 0] | 0; //@line 27944
  HEAP8[$70 + 2 | 0] = HEAP8[35826 | 0] | 0; //@line 27944
  HEAP8[$70 + 3 | 0] = HEAP8[35827 | 0] | 0; //@line 27944
  HEAP8[$70 + 4 | 0] = HEAP8[35828 | 0] | 0; //@line 27944
  HEAP8[$70 + 5 | 0] = HEAP8[35829 | 0] | 0; //@line 27944
  HEAP32[$da + 28 >> 2] = 2; //@line 27946
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 27952
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27957
  STACKTOP = sp; //@line 27959
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 27962
  HEAP8[$22] = HEAP8[35496] | 0; //@line 27963
  HEAP8[$22 + 1 | 0] = HEAP8[35497 | 0] | 0; //@line 27963
  HEAP8[$22 + 2 | 0] = HEAP8[35498 | 0] | 0; //@line 27963
  HEAP8[$22 + 3 | 0] = HEAP8[35499 | 0] | 0; //@line 27963
  HEAP8[$22 + 4 | 0] = HEAP8[35500 | 0] | 0; //@line 27963
  HEAP8[$22 + 5 | 0] = HEAP8[35501 | 0] | 0; //@line 27963
  HEAP32[$da + 28 >> 2] = 2; //@line 27965
  $28 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27970
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28 << 16 >> 16 == 0 ? 8 : $28 & 65535, tempInt) | 0) | 0; //@line 27974
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 27979
  STACKTOP = sp; //@line 27981
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 27984
  HEAP8[$7] = HEAP8[35824] | 0; //@line 27985
  HEAP8[$7 + 1 | 0] = HEAP8[35825 | 0] | 0; //@line 27985
  HEAP8[$7 + 2 | 0] = HEAP8[35826 | 0] | 0; //@line 27985
  HEAP8[$7 + 3 | 0] = HEAP8[35827 | 0] | 0; //@line 27985
  HEAP8[$7 + 4 | 0] = HEAP8[35828 | 0] | 0; //@line 27985
  HEAP8[$7 + 5 | 0] = HEAP8[35829 | 0] | 0; //@line 27985
  HEAP32[$da + 28 >> 2] = 2; //@line 27987
  $13 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 27992
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $13 << 16 >> 16 == 0 ? 8 : $13 & 65535, tempInt) | 0) | 0; //@line 27996
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28001
  STACKTOP = sp; //@line 28003
  return;
 } else if (($5 | 0) == 2) {
  $37 = $da + 32 | 0; //@line 28006
  HEAP8[$37] = HEAP8[35232] | 0; //@line 28007
  HEAP8[$37 + 1 | 0] = HEAP8[35233 | 0] | 0; //@line 28007
  HEAP8[$37 + 2 | 0] = HEAP8[35234 | 0] | 0; //@line 28007
  HEAP8[$37 + 3 | 0] = HEAP8[35235 | 0] | 0; //@line 28007
  HEAP8[$37 + 4 | 0] = HEAP8[35236 | 0] | 0; //@line 28007
  HEAP8[$37 + 5 | 0] = HEAP8[35237 | 0] | 0; //@line 28007
  HEAP8[$37 + 6 | 0] = HEAP8[35238 | 0] | 0; //@line 28007
  HEAP32[$da + 28 >> 2] = 2; //@line 28009
  $43 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28014
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $43 << 16 >> 16 == 0 ? 8 : $43 & 65535, tempInt) | 0) | 0; //@line 28018
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28023
  $51 = $da | 0; //@line 28024
  HEAP32[$51 >> 2] = HEAP32[$51 >> 2] | 32; //@line 28027
  STACKTOP = sp; //@line 28029
  return;
 } else {
  $129 = $da + 32 | 0; //@line 28032
  HEAP8[$129] = HEAP8[36120] | 0; //@line 28033
  HEAP8[$129 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 28033
  HEAP8[$129 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 28033
  HEAP32[$da + 28 >> 2] = 1; //@line 28035
  $139 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 28044
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $139, tempInt) | 0) | 0; //@line 28045
  STACKTOP = sp; //@line 28047
  return;
 }
}
function _d_e140($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $13 = 0, $22 = 0, $28 = 0, $37 = 0, $43 = 0, $51 = 0, $55 = 0, $61 = 0, $70 = 0, $84 = 0, $98 = 0, $100 = 0, $104 = 0, $106 = 0, $109 = 0, $111 = 0, $115 = 0, $129 = 0, $139 = 0, sp = 0;
 sp = STACKTOP; //@line 28075
 $1 = $da + 12 | 0; //@line 28076
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 28080
 if (($5 | 0) == 6) {
  $98 = $da + 32 | 0; //@line 28082
  HEAP8[$98] = HEAP8[38728] | 0; //@line 28083
  HEAP8[$98 + 1 | 0] = HEAP8[38729 | 0] | 0; //@line 28083
  HEAP8[$98 + 2 | 0] = HEAP8[38730 | 0] | 0; //@line 28083
  HEAP8[$98 + 3 | 0] = HEAP8[38731 | 0] | 0; //@line 28083
  HEAP8[$98 + 4 | 0] = HEAP8[38732 | 0] | 0; //@line 28083
  HEAP8[$98 + 5 | 0] = HEAP8[38733 | 0] | 0; //@line 28083
  HEAP8[$98 + 6 | 0] = HEAP8[38734 | 0] | 0; //@line 28083
  HEAP32[$da + 28 >> 2] = 2; //@line 28085
  $100 = $da + 96 | 0; //@line 28086
  $104 = (HEAPU8[$src] | 0) >>> 1 & 7; //@line 28090
  _sprintf($100 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $104, tempInt) | 0) | 0; //@line 28091
  $106 = $da + 160 | 0; //@line 28092
  $109 = HEAP16[$1 >> 1] & 7; //@line 28095
  _sprintf($106 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $109, tempInt) | 0) | 0; //@line 28096
  $111 = $da | 0; //@line 28097
  HEAP32[$111 >> 2] = HEAP32[$111 >> 2] | 32; //@line 28100
  STACKTOP = sp; //@line 28102
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 28105
  HEAP8[$22] = HEAP8[38136] | 0; //@line 28106
  HEAP8[$22 + 1 | 0] = HEAP8[38137 | 0] | 0; //@line 28106
  HEAP8[$22 + 2 | 0] = HEAP8[38138 | 0] | 0; //@line 28106
  HEAP8[$22 + 3 | 0] = HEAP8[38139 | 0] | 0; //@line 28106
  HEAP8[$22 + 4 | 0] = HEAP8[38140 | 0] | 0; //@line 28106
  HEAP8[$22 + 5 | 0] = HEAP8[38141 | 0] | 0; //@line 28106
  HEAP32[$da + 28 >> 2] = 2; //@line 28108
  $28 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28113
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28 << 16 >> 16 == 0 ? 8 : $28 & 65535, tempInt) | 0) | 0; //@line 28117
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28122
  STACKTOP = sp; //@line 28124
  return;
 } else if (($5 | 0) == 2) {
  $37 = $da + 32 | 0; //@line 28127
  HEAP8[$37] = HEAP8[38728] | 0; //@line 28128
  HEAP8[$37 + 1 | 0] = HEAP8[38729 | 0] | 0; //@line 28128
  HEAP8[$37 + 2 | 0] = HEAP8[38730 | 0] | 0; //@line 28128
  HEAP8[$37 + 3 | 0] = HEAP8[38731 | 0] | 0; //@line 28128
  HEAP8[$37 + 4 | 0] = HEAP8[38732 | 0] | 0; //@line 28128
  HEAP8[$37 + 5 | 0] = HEAP8[38733 | 0] | 0; //@line 28128
  HEAP8[$37 + 6 | 0] = HEAP8[38734 | 0] | 0; //@line 28128
  HEAP32[$da + 28 >> 2] = 2; //@line 28130
  $43 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28135
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $43 << 16 >> 16 == 0 ? 8 : $43 & 65535, tempInt) | 0) | 0; //@line 28139
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28144
  $51 = $da | 0; //@line 28145
  HEAP32[$51 >> 2] = HEAP32[$51 >> 2] | 32; //@line 28148
  STACKTOP = sp; //@line 28150
  return;
 } else if (($5 | 0) == 4) {
  $70 = $da + 32 | 0; //@line 28153
  HEAP8[$70] = HEAP8[37632] | 0; //@line 28154
  HEAP8[$70 + 1 | 0] = HEAP8[37633 | 0] | 0; //@line 28154
  HEAP8[$70 + 2 | 0] = HEAP8[37634 | 0] | 0; //@line 28154
  HEAP8[$70 + 3 | 0] = HEAP8[37635 | 0] | 0; //@line 28154
  HEAP8[$70 + 4 | 0] = HEAP8[37636 | 0] | 0; //@line 28154
  HEAP8[$70 + 5 | 0] = HEAP8[37637 | 0] | 0; //@line 28154
  HEAP32[$da + 28 >> 2] = 2; //@line 28156
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28162
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28167
  STACKTOP = sp; //@line 28169
  return;
 } else if (($5 | 0) == 3) {
  $55 = $da + 32 | 0; //@line 28172
  HEAP8[$55] = HEAP8[39480] | 0; //@line 28173
  HEAP8[$55 + 1 | 0] = HEAP8[39481 | 0] | 0; //@line 28173
  HEAP8[$55 + 2 | 0] = HEAP8[39482 | 0] | 0; //@line 28173
  HEAP8[$55 + 3 | 0] = HEAP8[39483 | 0] | 0; //@line 28173
  HEAP8[$55 + 4 | 0] = HEAP8[39484 | 0] | 0; //@line 28173
  HEAP8[$55 + 5 | 0] = HEAP8[39485 | 0] | 0; //@line 28173
  HEAP32[$da + 28 >> 2] = 2; //@line 28175
  $61 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28180
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $61 << 16 >> 16 == 0 ? 8 : $61 & 65535, tempInt) | 0) | 0; //@line 28184
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28189
  STACKTOP = sp; //@line 28191
  return;
 } else if (($5 | 0) == 5) {
  $84 = $da + 32 | 0; //@line 28194
  HEAP8[$84] = HEAP8[38136] | 0; //@line 28195
  HEAP8[$84 + 1 | 0] = HEAP8[38137 | 0] | 0; //@line 28195
  HEAP8[$84 + 2 | 0] = HEAP8[38138 | 0] | 0; //@line 28195
  HEAP8[$84 + 3 | 0] = HEAP8[38139 | 0] | 0; //@line 28195
  HEAP8[$84 + 4 | 0] = HEAP8[38140 | 0] | 0; //@line 28195
  HEAP8[$84 + 5 | 0] = HEAP8[38141 | 0] | 0; //@line 28195
  HEAP32[$da + 28 >> 2] = 2; //@line 28197
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28203
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28208
  STACKTOP = sp; //@line 28210
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 28213
  HEAP8[$7] = HEAP8[37632] | 0; //@line 28214
  HEAP8[$7 + 1 | 0] = HEAP8[37633 | 0] | 0; //@line 28214
  HEAP8[$7 + 2 | 0] = HEAP8[37634 | 0] | 0; //@line 28214
  HEAP8[$7 + 3 | 0] = HEAP8[37635 | 0] | 0; //@line 28214
  HEAP8[$7 + 4 | 0] = HEAP8[37636 | 0] | 0; //@line 28214
  HEAP8[$7 + 5 | 0] = HEAP8[37637 | 0] | 0; //@line 28214
  HEAP32[$da + 28 >> 2] = 2; //@line 28216
  $13 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28221
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $13 << 16 >> 16 == 0 ? 8 : $13 & 65535, tempInt) | 0) | 0; //@line 28225
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28230
  STACKTOP = sp; //@line 28232
  return;
 } else if (($5 | 0) == 7) {
  $115 = $da + 32 | 0; //@line 28235
  HEAP8[$115] = HEAP8[39480] | 0; //@line 28236
  HEAP8[$115 + 1 | 0] = HEAP8[39481 | 0] | 0; //@line 28236
  HEAP8[$115 + 2 | 0] = HEAP8[39482 | 0] | 0; //@line 28236
  HEAP8[$115 + 3 | 0] = HEAP8[39483 | 0] | 0; //@line 28236
  HEAP8[$115 + 4 | 0] = HEAP8[39484 | 0] | 0; //@line 28236
  HEAP8[$115 + 5 | 0] = HEAP8[39485 | 0] | 0; //@line 28236
  HEAP32[$da + 28 >> 2] = 2; //@line 28238
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28244
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28249
  STACKTOP = sp; //@line 28251
  return;
 } else {
  $129 = $da + 32 | 0; //@line 28254
  HEAP8[$129] = HEAP8[36120] | 0; //@line 28255
  HEAP8[$129 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 28255
  HEAP8[$129 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 28255
  HEAP32[$da + 28 >> 2] = 1; //@line 28257
  $139 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 28266
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $139, tempInt) | 0) | 0; //@line 28267
  STACKTOP = sp; //@line 28269
  return;
 }
}
function _d_e180($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $5 = 0, $7 = 0, $13 = 0, $22 = 0, $28 = 0, $37 = 0, $43 = 0, $51 = 0, $55 = 0, $57 = 0, $61 = 0, $_off0_i26 = 0, $64 = 0, $67 = 0, $70 = 0, $84 = 0, $98 = 0, $111 = 0, $115 = 0, $129 = 0, $139 = 0, sp = 0;
 sp = STACKTOP; //@line 28297
 $1 = $da + 12 | 0; //@line 28298
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 28302
 if (($5 | 0) == 3) {
  $55 = $da + 32 | 0; //@line 28304
  HEAP8[$55] = HEAP8[36536] | 0; //@line 28305
  HEAP8[$55 + 1 | 0] = HEAP8[36537 | 0] | 0; //@line 28305
  HEAP8[$55 + 2 | 0] = HEAP8[36538 | 0] | 0; //@line 28305
  HEAP8[$55 + 3 | 0] = HEAP8[36539 | 0] | 0; //@line 28305
  HEAP8[$55 + 4 | 0] = HEAP8[36540 | 0] | 0; //@line 28305
  HEAP8[$55 + 5 | 0] = HEAP8[36541 | 0] | 0; //@line 28305
  HEAP32[$da + 28 >> 2] = 2; //@line 28307
  $57 = $da + 96 | 0; //@line 28308
  $61 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28312
  $_off0_i26 = $61 << 16 >> 16 == 0 ? 8 : $61 & 65535; //@line 28315
  _sprintf($57 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $_off0_i26, tempInt) | 0) | 0; //@line 28316
  $64 = $da + 160 | 0; //@line 28317
  $67 = HEAP16[$1 >> 1] & 7; //@line 28320
  _sprintf($64 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $67, tempInt) | 0) | 0; //@line 28321
  STACKTOP = sp; //@line 28323
  return;
 } else if (($5 | 0) == 7) {
  $115 = $da + 32 | 0; //@line 28326
  HEAP8[$115] = HEAP8[36536] | 0; //@line 28327
  HEAP8[$115 + 1 | 0] = HEAP8[36537 | 0] | 0; //@line 28327
  HEAP8[$115 + 2 | 0] = HEAP8[36538 | 0] | 0; //@line 28327
  HEAP8[$115 + 3 | 0] = HEAP8[36539 | 0] | 0; //@line 28327
  HEAP8[$115 + 4 | 0] = HEAP8[36540 | 0] | 0; //@line 28327
  HEAP8[$115 + 5 | 0] = HEAP8[36541 | 0] | 0; //@line 28327
  HEAP32[$da + 28 >> 2] = 2; //@line 28329
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28335
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28340
  STACKTOP = sp; //@line 28342
  return;
 } else if (($5 | 0) == 5) {
  $84 = $da + 32 | 0; //@line 28345
  HEAP8[$84] = HEAP8[37144] | 0; //@line 28346
  HEAP8[$84 + 1 | 0] = HEAP8[37145 | 0] | 0; //@line 28346
  HEAP8[$84 + 2 | 0] = HEAP8[37146 | 0] | 0; //@line 28346
  HEAP8[$84 + 3 | 0] = HEAP8[37147 | 0] | 0; //@line 28346
  HEAP8[$84 + 4 | 0] = HEAP8[37148 | 0] | 0; //@line 28346
  HEAP8[$84 + 5 | 0] = HEAP8[37149 | 0] | 0; //@line 28346
  HEAP32[$da + 28 >> 2] = 2; //@line 28348
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28354
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28359
  STACKTOP = sp; //@line 28361
  return;
 } else if (($5 | 0) == 6) {
  $98 = $da + 32 | 0; //@line 28364
  HEAP8[$98] = HEAP8[36912] | 0; //@line 28365
  HEAP8[$98 + 1 | 0] = HEAP8[36913 | 0] | 0; //@line 28365
  HEAP8[$98 + 2 | 0] = HEAP8[36914 | 0] | 0; //@line 28365
  HEAP8[$98 + 3 | 0] = HEAP8[36915 | 0] | 0; //@line 28365
  HEAP8[$98 + 4 | 0] = HEAP8[36916 | 0] | 0; //@line 28365
  HEAP8[$98 + 5 | 0] = HEAP8[36917 | 0] | 0; //@line 28365
  HEAP8[$98 + 6 | 0] = HEAP8[36918 | 0] | 0; //@line 28365
  HEAP32[$da + 28 >> 2] = 2; //@line 28367
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28373
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28378
  $111 = $da | 0; //@line 28379
  HEAP32[$111 >> 2] = HEAP32[$111 >> 2] | 32; //@line 28382
  STACKTOP = sp; //@line 28384
  return;
 } else if (($5 | 0) == 4) {
  $70 = $da + 32 | 0; //@line 28387
  HEAP8[$70] = HEAP8[37344] | 0; //@line 28388
  HEAP8[$70 + 1 | 0] = HEAP8[37345 | 0] | 0; //@line 28388
  HEAP8[$70 + 2 | 0] = HEAP8[37346 | 0] | 0; //@line 28388
  HEAP8[$70 + 3 | 0] = HEAP8[37347 | 0] | 0; //@line 28388
  HEAP8[$70 + 4 | 0] = HEAP8[37348 | 0] | 0; //@line 28388
  HEAP8[$70 + 5 | 0] = HEAP8[37349 | 0] | 0; //@line 28388
  HEAP32[$da + 28 >> 2] = 2; //@line 28390
  _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28396
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28401
  STACKTOP = sp; //@line 28403
  return;
 } else if (($5 | 0) == 1) {
  $22 = $da + 32 | 0; //@line 28406
  HEAP8[$22] = HEAP8[37144] | 0; //@line 28407
  HEAP8[$22 + 1 | 0] = HEAP8[37145 | 0] | 0; //@line 28407
  HEAP8[$22 + 2 | 0] = HEAP8[37146 | 0] | 0; //@line 28407
  HEAP8[$22 + 3 | 0] = HEAP8[37147 | 0] | 0; //@line 28407
  HEAP8[$22 + 4 | 0] = HEAP8[37148 | 0] | 0; //@line 28407
  HEAP8[$22 + 5 | 0] = HEAP8[37149 | 0] | 0; //@line 28407
  HEAP32[$da + 28 >> 2] = 2; //@line 28409
  $28 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28414
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $28 << 16 >> 16 == 0 ? 8 : $28 & 65535, tempInt) | 0) | 0; //@line 28418
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28423
  STACKTOP = sp; //@line 28425
  return;
 } else if (($5 | 0) == 0) {
  $7 = $da + 32 | 0; //@line 28428
  HEAP8[$7] = HEAP8[37344] | 0; //@line 28429
  HEAP8[$7 + 1 | 0] = HEAP8[37345 | 0] | 0; //@line 28429
  HEAP8[$7 + 2 | 0] = HEAP8[37346 | 0] | 0; //@line 28429
  HEAP8[$7 + 3 | 0] = HEAP8[37347 | 0] | 0; //@line 28429
  HEAP8[$7 + 4 | 0] = HEAP8[37348 | 0] | 0; //@line 28429
  HEAP8[$7 + 5 | 0] = HEAP8[37349 | 0] | 0; //@line 28429
  HEAP32[$da + 28 >> 2] = 2; //@line 28431
  $13 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28436
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $13 << 16 >> 16 == 0 ? 8 : $13 & 65535, tempInt) | 0) | 0; //@line 28440
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28445
  STACKTOP = sp; //@line 28447
  return;
 } else if (($5 | 0) == 2) {
  $37 = $da + 32 | 0; //@line 28450
  HEAP8[$37] = HEAP8[36912] | 0; //@line 28451
  HEAP8[$37 + 1 | 0] = HEAP8[36913 | 0] | 0; //@line 28451
  HEAP8[$37 + 2 | 0] = HEAP8[36914 | 0] | 0; //@line 28451
  HEAP8[$37 + 3 | 0] = HEAP8[36915 | 0] | 0; //@line 28451
  HEAP8[$37 + 4 | 0] = HEAP8[36916 | 0] | 0; //@line 28451
  HEAP8[$37 + 5 | 0] = HEAP8[36917 | 0] | 0; //@line 28451
  HEAP8[$37 + 6 | 0] = HEAP8[36918 | 0] | 0; //@line 28451
  HEAP32[$da + 28 >> 2] = 2; //@line 28453
  $43 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 28458
  _sprintf($da + 96 | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $43 << 16 >> 16 == 0 ? 8 : $43 & 65535, tempInt) | 0) | 0; //@line 28462
  _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$1 >> 1] & 7, tempInt) | 0) | 0; //@line 28467
  $51 = $da | 0; //@line 28468
  HEAP32[$51 >> 2] = HEAP32[$51 >> 2] | 32; //@line 28471
  STACKTOP = sp; //@line 28473
  return;
 } else {
  $129 = $da + 32 | 0; //@line 28476
  HEAP8[$129] = HEAP8[36120] | 0; //@line 28477
  HEAP8[$129 + 1 | 0] = HEAP8[36121 | 0] | 0; //@line 28477
  HEAP8[$129 + 2 | 0] = HEAP8[36122 | 0] | 0; //@line 28477
  HEAP32[$da + 28 >> 2] = 1; //@line 28479
  $139 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 28488
  _sprintf($da + 96 | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $139, tempInt) | 0) | 0; //@line 28489
  STACKTOP = sp; //@line 28491
  return;
 }
}
function _d_e1c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28503
 HEAP8[$1] = HEAP8[37632] | 0; //@line 28504
 HEAP8[$1 + 1 | 0] = HEAP8[37633 | 0] | 0; //@line 28504
 HEAP8[$1 + 2 | 0] = HEAP8[37634 | 0] | 0; //@line 28504
 HEAP8[$1 + 3 | 0] = HEAP8[37635 | 0] | 0; //@line 28504
 HEAP8[$1 + 4 | 0] = HEAP8[37636 | 0] | 0; //@line 28504
 HEAP8[$1 + 5 | 0] = HEAP8[37637 | 0] | 0; //@line 28504
 HEAP32[$da + 28 >> 2] = 1; //@line 28506
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28512
 return;
}
function _d_e2c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28524
 HEAP8[$1] = HEAP8[37880] | 0; //@line 28525
 HEAP8[$1 + 1 | 0] = HEAP8[37881 | 0] | 0; //@line 28525
 HEAP8[$1 + 2 | 0] = HEAP8[37882 | 0] | 0; //@line 28525
 HEAP8[$1 + 3 | 0] = HEAP8[37883 | 0] | 0; //@line 28525
 HEAP8[$1 + 4 | 0] = HEAP8[37884 | 0] | 0; //@line 28525
 HEAP8[$1 + 5 | 0] = HEAP8[37885 | 0] | 0; //@line 28525
 HEAP32[$da + 28 >> 2] = 1; //@line 28527
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28533
 return;
}
function _d_e3c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28545
 HEAP8[$1] = HEAP8[38136] | 0; //@line 28546
 HEAP8[$1 + 1 | 0] = HEAP8[38137 | 0] | 0; //@line 28546
 HEAP8[$1 + 2 | 0] = HEAP8[38138 | 0] | 0; //@line 28546
 HEAP8[$1 + 3 | 0] = HEAP8[38139 | 0] | 0; //@line 28546
 HEAP8[$1 + 4 | 0] = HEAP8[38140 | 0] | 0; //@line 28546
 HEAP8[$1 + 5 | 0] = HEAP8[38141 | 0] | 0; //@line 28546
 HEAP32[$da + 28 >> 2] = 1; //@line 28548
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28554
 return;
}
function _d_e4c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0;
 $1 = $da + 32 | 0; //@line 28567
 HEAP8[$1] = HEAP8[38424] | 0; //@line 28568
 HEAP8[$1 + 1 | 0] = HEAP8[38425 | 0] | 0; //@line 28568
 HEAP8[$1 + 2 | 0] = HEAP8[38426 | 0] | 0; //@line 28568
 HEAP8[$1 + 3 | 0] = HEAP8[38427 | 0] | 0; //@line 28568
 HEAP8[$1 + 4 | 0] = HEAP8[38428 | 0] | 0; //@line 28568
 HEAP8[$1 + 5 | 0] = HEAP8[38429 | 0] | 0; //@line 28568
 HEAP8[$1 + 6 | 0] = HEAP8[38430 | 0] | 0; //@line 28568
 HEAP32[$da + 28 >> 2] = 1; //@line 28570
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28576
 $8 = $da | 0; //@line 28577
 HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 32; //@line 28580
 return;
}
function _d_e5c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $8 = 0;
 $1 = $da + 32 | 0; //@line 28593
 HEAP8[$1] = HEAP8[38728] | 0; //@line 28594
 HEAP8[$1 + 1 | 0] = HEAP8[38729 | 0] | 0; //@line 28594
 HEAP8[$1 + 2 | 0] = HEAP8[38730 | 0] | 0; //@line 28594
 HEAP8[$1 + 3 | 0] = HEAP8[38731 | 0] | 0; //@line 28594
 HEAP8[$1 + 4 | 0] = HEAP8[38732 | 0] | 0; //@line 28594
 HEAP8[$1 + 5 | 0] = HEAP8[38733 | 0] | 0; //@line 28594
 HEAP8[$1 + 6 | 0] = HEAP8[38734 | 0] | 0; //@line 28594
 HEAP32[$da + 28 >> 2] = 1; //@line 28596
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28602
 $8 = $da | 0; //@line 28603
 HEAP32[$8 >> 2] = HEAP32[$8 >> 2] | 32; //@line 28606
 return;
}
function _d_e6c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28618
 HEAP8[$1] = HEAP8[39040] | 0; //@line 28619
 HEAP8[$1 + 1 | 0] = HEAP8[39041 | 0] | 0; //@line 28619
 HEAP8[$1 + 2 | 0] = HEAP8[39042 | 0] | 0; //@line 28619
 HEAP8[$1 + 3 | 0] = HEAP8[39043 | 0] | 0; //@line 28619
 HEAP8[$1 + 4 | 0] = HEAP8[39044 | 0] | 0; //@line 28619
 HEAP8[$1 + 5 | 0] = HEAP8[39045 | 0] | 0; //@line 28619
 HEAP32[$da + 28 >> 2] = 1; //@line 28621
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28627
 return;
}
function _d_e7c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28639
 HEAP8[$1] = HEAP8[39480] | 0; //@line 28640
 HEAP8[$1 + 1 | 0] = HEAP8[39481 | 0] | 0; //@line 28640
 HEAP8[$1 + 2 | 0] = HEAP8[39482 | 0] | 0; //@line 28640
 HEAP8[$1 + 3 | 0] = HEAP8[39483 | 0] | 0; //@line 28640
 HEAP8[$1 + 4 | 0] = HEAP8[39484 | 0] | 0; //@line 28640
 HEAP8[$1 + 5 | 0] = HEAP8[39485 | 0] | 0; //@line 28640
 HEAP32[$da + 28 >> 2] = 1; //@line 28642
 _dasm_ea($da, $da + 96 | 0, $src, HEAP8[$src + 1 | 0] & 63, 16); //@line 28648
 return;
}
function _d_e8c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28660
 HEAP8[$1] = HEAP8[39888] | 0; //@line 28661
 HEAP8[$1 + 1 | 0] = HEAP8[39889 | 0] | 0; //@line 28661
 HEAP8[$1 + 2 | 0] = HEAP8[39890 | 0] | 0; //@line 28661
 HEAP8[$1 + 3 | 0] = HEAP8[39891 | 0] | 0; //@line 28661
 HEAP8[$1 + 4 | 0] = HEAP8[39892 | 0] | 0; //@line 28661
 HEAP8[$1 + 5 | 0] = HEAP8[39893 | 0] | 0; //@line 28661
 HEAP32[$da + 28 >> 2] = 1; //@line 28663
 _dasm_arg($da, $da + 96 | 0, $src, 33, 8); //@line 28665
 return;
}
function _d_e9c0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 28677
 $1 = $da + 32 | 0; //@line 28678
 HEAP8[$1] = HEAP8[40120] | 0; //@line 28679
 HEAP8[$1 + 1 | 0] = HEAP8[40121 | 0] | 0; //@line 28679
 HEAP8[$1 + 2 | 0] = HEAP8[40122 | 0] | 0; //@line 28679
 HEAP8[$1 + 3 | 0] = HEAP8[40123 | 0] | 0; //@line 28679
 HEAP8[$1 + 4 | 0] = HEAP8[40124 | 0] | 0; //@line 28679
 HEAP8[$1 + 5 | 0] = HEAP8[40125 | 0] | 0; //@line 28679
 HEAP8[$1 + 6 | 0] = HEAP8[40126 | 0] | 0; //@line 28679
 HEAP32[$da + 28 >> 2] = 2; //@line 28681
 _dasm_arg($da, $da + 96 | 0, $src, 33, 8); //@line 28683
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$da + 14 >> 1] | 0) >>> 12 & 7, tempInt) | 0) | 0; //@line 28690
 STACKTOP = sp; //@line 28691
 return;
}
function _d_eac0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28702
 HEAP8[$1] = HEAP8[40368] | 0; //@line 28703
 HEAP8[$1 + 1 | 0] = HEAP8[40369 | 0] | 0; //@line 28703
 HEAP8[$1 + 2 | 0] = HEAP8[40370 | 0] | 0; //@line 28703
 HEAP8[$1 + 3 | 0] = HEAP8[40371 | 0] | 0; //@line 28703
 HEAP8[$1 + 4 | 0] = HEAP8[40372 | 0] | 0; //@line 28703
 HEAP8[$1 + 5 | 0] = HEAP8[40373 | 0] | 0; //@line 28703
 HEAP32[$da + 28 >> 2] = 1; //@line 28705
 _dasm_arg($da, $da + 96 | 0, $src, 33, 8); //@line 28707
 return;
}
function _d_ebc0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 28719
 $1 = $da + 32 | 0; //@line 28720
 HEAP8[$1] = HEAP8[40624] | 0; //@line 28721
 HEAP8[$1 + 1 | 0] = HEAP8[40625 | 0] | 0; //@line 28721
 HEAP8[$1 + 2 | 0] = HEAP8[40626 | 0] | 0; //@line 28721
 HEAP8[$1 + 3 | 0] = HEAP8[40627 | 0] | 0; //@line 28721
 HEAP8[$1 + 4 | 0] = HEAP8[40628 | 0] | 0; //@line 28721
 HEAP8[$1 + 5 | 0] = HEAP8[40629 | 0] | 0; //@line 28721
 HEAP8[$1 + 6 | 0] = HEAP8[40630 | 0] | 0; //@line 28721
 HEAP32[$da + 28 >> 2] = 2; //@line 28723
 _dasm_arg($da, $da + 96 | 0, $src, 33, 8); //@line 28725
 _sprintf($da + 160 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$da + 14 >> 1] | 0) >>> 12 & 7, tempInt) | 0) | 0; //@line 28732
 STACKTOP = sp; //@line 28733
 return;
}
function _d_ecc0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28744
 HEAP8[$1] = HEAP8[40856] | 0; //@line 28745
 HEAP8[$1 + 1 | 0] = HEAP8[40857 | 0] | 0; //@line 28745
 HEAP8[$1 + 2 | 0] = HEAP8[40858 | 0] | 0; //@line 28745
 HEAP8[$1 + 3 | 0] = HEAP8[40859 | 0] | 0; //@line 28745
 HEAP8[$1 + 4 | 0] = HEAP8[40860 | 0] | 0; //@line 28745
 HEAP8[$1 + 5 | 0] = HEAP8[40861 | 0] | 0; //@line 28745
 HEAP32[$da + 28 >> 2] = 1; //@line 28747
 _dasm_arg($da, $da + 96 | 0, $src, 33, 8); //@line 28749
 return;
}
function _d_eec0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0;
 $1 = $da + 32 | 0; //@line 28761
 HEAP8[$1] = HEAP8[41088] | 0; //@line 28762
 HEAP8[$1 + 1 | 0] = HEAP8[41089 | 0] | 0; //@line 28762
 HEAP8[$1 + 2 | 0] = HEAP8[41090 | 0] | 0; //@line 28762
 HEAP8[$1 + 3 | 0] = HEAP8[41091 | 0] | 0; //@line 28762
 HEAP8[$1 + 4 | 0] = HEAP8[41092 | 0] | 0; //@line 28762
 HEAP8[$1 + 5 | 0] = HEAP8[41093 | 0] | 0; //@line 28762
 HEAP32[$da + 28 >> 2] = 1; //@line 28764
 _dasm_arg($da, $da + 96 | 0, $src, 33, 8); //@line 28766
 return;
}
function _d_efc0($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, sp = 0;
 sp = STACKTOP; //@line 28778
 $1 = $da + 32 | 0; //@line 28779
 HEAP8[$1] = HEAP8[52176] | 0; //@line 28780
 HEAP8[$1 + 1 | 0] = HEAP8[52177 | 0] | 0; //@line 28780
 HEAP8[$1 + 2 | 0] = HEAP8[52178 | 0] | 0; //@line 28780
 HEAP8[$1 + 3 | 0] = HEAP8[52179 | 0] | 0; //@line 28780
 HEAP8[$1 + 4 | 0] = HEAP8[52180 | 0] | 0; //@line 28780
 HEAP8[$1 + 5 | 0] = HEAP8[52181 | 0] | 0; //@line 28780
 HEAP32[$da + 28 >> 2] = 2; //@line 28782
 _sprintf($da + 96 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$da + 14 >> 1] | 0) >>> 12 & 7, tempInt) | 0) | 0; //@line 28789
 _dasm_arg($da, $da + 160 | 0, $src, 33, 8); //@line 28791
 STACKTOP = sp; //@line 28792
 return;
}
function _d_f000($da, $src) {
 $da = $da | 0;
 $src = $src | 0;
 var $1 = 0, $9 = 0, sp = 0;
 sp = STACKTOP; //@line 28803
 STACKTOP = STACKTOP + 16 | 0; //@line 28803
 $1 = sp | 0; //@line 28805
 _sprintf($1 | 0, 32672, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAPU16[$da + 12 >> 1] | 0, tempInt) | 0) | 0; //@line 28809
 _strcpy($da + 32 | 0, $1 | 0) | 0; //@line 28811
 HEAP32[$da + 28 >> 2] = 0; //@line 28813
 $9 = $da | 0; //@line 28814
 HEAP32[$9 >> 2] = HEAP32[$9 >> 2] | 4; //@line 28817
 STACKTOP = sp; //@line 28818
 return;
}
function _dasm_arg($da, $dst, $src, $arg, $size) {
 $da = $da | 0;
 $dst = $dst | 0;
 $src = $src | 0;
 $arg = $arg | 0;
 $size = $size | 0;
 var $first_i104 = 0, $first_i = 0, $10 = 0, $21 = 0, $36 = 0, $69 = 0, $111 = 0, $113 = 0, $120 = 0, $122 = 0, $128 = 0, $130 = 0, $142 = 0, $144 = 0, $165 = 0, $167 = 0, $174 = 0, $181 = 0, $186 = 0, $199 = 0, $204 = 0, $207 = 0, $208 = 0, $209 = 0, $217 = 0, $222 = 0, $227 = 0, $230 = 0, $231 = 0, $232 = 0, $250 = 0, $255 = 0, $265 = 0, $267 = 0, $rn_025_i = 0, $ri_024_i = 0, $i_123_i = 0, $rn_1_i = 0, $276 = 0, $ri_1_i = 0, $rn_2_i = 0, $282 = 0, $287 = 0, $293 = 0, $297 = 0, $356 = 0, $rn_025_i105 = 0, $ri_024_i106 = 0, $i_123_i107 = 0, $rn_1_i109 = 0, $365 = 0, $ri_1_i111 = 0, $rn_2_i112 = 0, $371 = 0, $376 = 0, $380 = 0, $383 = 0, $394 = 0, $396 = 0, $400 = 0, $404 = 0, $408 = 0, $413 = 0, $str_0_i = 0, $417 = 0, $418 = 0, $423 = 0, $431 = 0, $444 = 0, $445 = 0, $446 = 0, $454 = 0, $455 = 0, $461 = 0, $_sum25_i = 0, $464 = 0, $465 = 0, $467 = 0, $470 = 0, $472 = 0, $475 = 0, $_sum26_i = 0, $_sum27_i = 0, $480 = 0, $481 = 0, $483 = 0, $__i = 0, $488 = 0, $494 = 0, sp = 0;
 sp = STACKTOP; //@line 28888
 STACKTOP = STACKTOP + 16 | 0; //@line 28888
 $first_i104 = sp | 0; //@line 28889
 $first_i = sp + 8 | 0; //@line 28890
 if (($arg | 0) == 28) {
  $383 = $dst; //@line 28892
  tempBigInt = 5264213; //@line 28893
  HEAP8[$383] = tempBigInt & 255; //@line 28893
  tempBigInt = tempBigInt >> 8; //@line 28893
  HEAP8[$383 + 1 | 0] = tempBigInt & 255; //@line 28893
  tempBigInt = tempBigInt >> 8; //@line 28893
  HEAP8[$383 + 2 | 0] = tempBigInt & 255; //@line 28893
  tempBigInt = tempBigInt >> 8; //@line 28893
  HEAP8[$383 + 3 | 0] = tempBigInt & 255; //@line 28893
  STACKTOP = sp; //@line 28895
  return;
 } else if (($arg | 0) == 29) {
  $394 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 4095; //@line 28907
  if (($394 | 0) == 0) {
   $396 = $da | 0; //@line 28909
   HEAP32[$396 >> 2] = HEAP32[$396 >> 2] | 64; //@line 28912
   $str_0_i = 48824; //@line 28914
  } else if (($394 | 0) == 1) {
   $400 = $da | 0; //@line 28916
   HEAP32[$400 >> 2] = HEAP32[$400 >> 2] | 64; //@line 28919
   $str_0_i = 48424; //@line 28921
  } else if (($394 | 0) == 2048) {
   $404 = $da | 0; //@line 28923
   HEAP32[$404 >> 2] = HEAP32[$404 >> 2] | 64; //@line 28926
   $str_0_i = 50984; //@line 28928
  } else if (($394 | 0) == 2049) {
   $408 = $da | 0; //@line 28930
   HEAP32[$408 >> 2] = HEAP32[$408 >> 2] | 64; //@line 28933
   $str_0_i = 48032; //@line 28935
  } else {
   _sprintf($dst | 0, 47736, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $394, tempInt) | 0) | 0; //@line 28937
   $413 = $da | 0; //@line 28938
   HEAP32[$413 >> 2] = HEAP32[$413 >> 2] | 64; //@line 28941
   STACKTOP = sp; //@line 28943
   return;
  }
  $417 = $str_0_i; //@line 28947
  $418 = $dst; //@line 28948
  tempBigInt = HEAPU8[$417] | HEAPU8[$417 + 1 | 0] << 8 | HEAPU8[$417 + 2 | 0] << 16 | HEAPU8[$417 + 3 | 0] << 24 | 0; //@line 28950
  HEAP8[$418] = tempBigInt & 255; //@line 28950
  tempBigInt = tempBigInt >> 8; //@line 28950
  HEAP8[$418 + 1 | 0] = tempBigInt & 255; //@line 28950
  tempBigInt = tempBigInt >> 8; //@line 28950
  HEAP8[$418 + 2 | 0] = tempBigInt & 255; //@line 28950
  tempBigInt = tempBigInt >> 8; //@line 28950
  HEAP8[$418 + 3 | 0] = tempBigInt & 255; //@line 28950
  STACKTOP = sp; //@line 28952
  return;
 } else if (($arg | 0) == 9) {
  $69 = HEAPU8[$src + 2 | 0] | 0; //@line 28957
  _sprintf($dst | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = ($69 & 128 | 0) != 0 ? 34768 : 32184, HEAP32[tempInt + 8 >> 2] = $69 >>> 4 & 7, tempInt) | 0) | 0; //@line 28963
  STACKTOP = sp; //@line 28965
  return;
 } else if (($arg | 0) == 6) {
  _sprintf($dst | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 28972
  STACKTOP = sp; //@line 28974
  return;
 } else if (($arg | 0) == 1) {
  $10 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 28984
  _sprintf($dst | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $10, tempInt) | 0) | 0; //@line 28985
  STACKTOP = sp; //@line 28987
  return;
 } else if (($arg | 0) == 2) {
  $21 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 28998
  _sprintf($dst | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $21, tempInt) | 0) | 0; //@line 28999
  STACKTOP = sp; //@line 29001
  return;
 } else if (($arg | 0) == 32 | ($arg | 0) == 34) {
  _sprintf($dst | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$da + 14 >> 1] | 0) >>> 12 & 7, tempInt) | 0) | 0; //@line 29009
  STACKTOP = sp; //@line 29011
  return;
 } else if (($arg | 0) == 33) {
  $444 = $da + 8 | 0; //@line 29014
  $445 = HEAP32[$444 >> 2] | 0; //@line 29015
  $446 = $445 << 1; //@line 29016
  $454 = (HEAPU8[$src + $446 | 0] | 0) << 8 | (HEAPU8[$src + ($446 | 1) | 0] | 0); //@line 29025
  $455 = $445 + 1 | 0; //@line 29026
  HEAP32[$444 >> 2] = $455; //@line 29027
  HEAP16[$da + 12 + ($455 << 1) >> 1] = $454; //@line 29029
  _dasm_ea($da, $dst, $src, HEAP8[$src + 1 | 0] & 63, 8); //@line 29034
  $461 = _strlen($dst | 0) | 0; //@line 29035
  HEAP8[$dst + $461 | 0] = 32; //@line 29039
  $_sum25_i = $461 + 2 | 0; //@line 29040
  $464 = $dst + $_sum25_i | 0; //@line 29041
  HEAP8[$dst + ($461 + 1) | 0] = 123; //@line 29042
  $465 = $da + 14 | 0; //@line 29043
  $467 = HEAPU16[$465 >> 1] | 0; //@line 29045
  $470 = $467 >>> 6; //@line 29048
  if (($467 & 2048 | 0) == 0) {
   $475 = $470 & 31; //@line 29051
   _sprintf($464 | 0, 49848, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $475, tempInt) | 0) | 0; //@line 29052
  } else {
   $472 = $470 & 7; //@line 29054
   _sprintf($464 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $472, tempInt) | 0) | 0; //@line 29055
  }
  $_sum26_i = (_strlen($464 | 0) | 0) + $_sum25_i | 0; //@line 29059
  $_sum27_i = $_sum26_i + 1 | 0; //@line 29061
  $480 = $dst + $_sum27_i | 0; //@line 29062
  HEAP8[$dst + $_sum26_i | 0] = 58; //@line 29063
  $481 = HEAP16[$465 >> 1] | 0; //@line 29064
  $483 = $481 & 31; //@line 29066
  $__i = ($483 | 0) == 0 ? 32 : $483; //@line 29068
  if (($481 & 32) == 0) {
   _sprintf($480 | 0, 49848, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $__i, tempInt) | 0) | 0; //@line 29073
  } else {
   $488 = $__i & 7; //@line 29075
   _sprintf($480 | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $488, tempInt) | 0) | 0; //@line 29076
  }
  $494 = $dst + ((_strlen($480 | 0) | 0) + $_sum27_i) | 0; //@line 29082
  tempBigInt = 125; //@line 29083
  HEAP8[$494] = tempBigInt & 255; //@line 29083
  tempBigInt = tempBigInt >> 8; //@line 29083
  HEAP8[$494 + 1 | 0] = tempBigInt & 255; //@line 29083
  STACKTOP = sp; //@line 29085
  return;
 } else if (($arg | 0) == 15) {
  $128 = HEAPU8[$src + 3 | 0] | 0; //@line 29090
  _sprintf($dst | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $128, tempInt) | 0) | 0; //@line 29091
  $130 = $da + 8 | 0; //@line 29092
  HEAP32[$130 >> 2] = (HEAP32[$130 >> 2] | 0) + 1; //@line 29095
  STACKTOP = sp; //@line 29097
  return;
 } else if (($arg | 0) == 16) {
  $142 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 29108
  _sprintf($dst | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $142, tempInt) | 0) | 0; //@line 29109
  $144 = $da + 8 | 0; //@line 29110
  HEAP32[$144 >> 2] = (HEAP32[$144 >> 2] | 0) + 1; //@line 29113
  STACKTOP = sp; //@line 29115
  return;
 } else if (($arg | 0) == 23) {
  $230 = $da + 8 | 0; //@line 29118
  $231 = HEAP32[$230 >> 2] | 0; //@line 29119
  $232 = $231 << 1; //@line 29120
  $250 = (((HEAPU8[$src + $232 | 0] | 0) << 8 | (HEAPU8[$src + ($232 | 1) | 0] | 0)) << 8 | (HEAPU8[$src + ($232 + 2) | 0] | 0)) << 8 | (HEAPU8[$src + ($232 + 3) | 0] | 0); //@line 29141
  HEAP32[$230 >> 2] = $231 + 2; //@line 29143
  $255 = (HEAP32[$da + 4 >> 2] | 0) + 2 + $250 | 0; //@line 29147
  _sprintf($dst | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $255, tempInt) | 0) | 0; //@line 29148
  STACKTOP = sp; //@line 29150
  return;
 } else if (($arg | 0) == 24) {
  $265 = (HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0); //@line 29160
  HEAP32[$first_i >> 2] = 1; //@line 29162
  HEAP8[$dst] = 0; //@line 29163
  $267 = $265 & 65535; //@line 29164
  $i_123_i = 0;
  $ri_024_i = 0;
  $rn_025_i = 0;
  while (1) {
   if (($i_123_i | 0) != 8 | ($rn_025_i | 0) == 0) {
    $rn_1_i = $rn_025_i; //@line 29176
   } else {
    _dasm_reginterval($dst, $ri_024_i, $rn_025_i, $first_i); //@line 29178
    $rn_1_i = 0; //@line 29180
   }
   $276 = ($rn_1_i | 0) == 0; //@line 29186
   do {
    if ((1 << $i_123_i & $267 | 0) == 0) {
     if ($276) {
      $rn_2_i = 0;
      $ri_1_i = $ri_024_i;
      break;
     }
     _dasm_reginterval($dst, $ri_024_i, $rn_1_i, $first_i); //@line 29195
     $rn_2_i = 0;
     $ri_1_i = $ri_024_i;
    } else {
     $rn_2_i = $rn_1_i + 1 | 0;
     $ri_1_i = $276 ? $i_123_i : $ri_024_i;
    }
   } while (0);
   $282 = $i_123_i + 1 | 0; //@line 29207
   if ($282 >>> 0 < 16) {
    $i_123_i = $282;
    $ri_024_i = $ri_1_i;
    $rn_025_i = $rn_2_i;
   } else {
    break;
   }
  }
  if (($rn_2_i | 0) != 0) {
   _dasm_reginterval($dst, $ri_1_i, $rn_2_i, $first_i); //@line 29219
  }
  $287 = $da + 8 | 0; //@line 29222
  HEAP32[$287 >> 2] = (HEAP32[$287 >> 2] | 0) + 1; //@line 29225
  STACKTOP = sp; //@line 29227
  return;
 } else if (($arg | 0) == 21) {
  $199 = HEAPU8[$src + 1 | 0] | 0; //@line 29235
  $204 = (HEAP32[$da + 4 >> 2] | 0) + 2 + (($199 & 128 | 0) != 0 ? $199 | -256 : $199) | 0; //@line 29240
  _sprintf($dst | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $204, tempInt) | 0) | 0; //@line 29241
  STACKTOP = sp; //@line 29243
  return;
 } else if (($arg | 0) == 22) {
  $207 = $da + 8 | 0; //@line 29246
  $208 = HEAP32[$207 >> 2] | 0; //@line 29247
  $209 = $208 << 1; //@line 29248
  $217 = (HEAPU8[$src + $209 | 0] | 0) << 8 | (HEAPU8[$src + ($209 | 1) | 0] | 0); //@line 29257
  HEAP32[$207 >> 2] = $208 + 1; //@line 29259
  $222 = $217 & 65535; //@line 29263
  $227 = (HEAP32[$da + 4 >> 2] | 0) + 2 + (($222 & 32768 | 0) != 0 ? $222 | -65536 : $222) | 0; //@line 29268
  _sprintf($dst | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $227, tempInt) | 0) | 0; //@line 29269
  STACKTOP = sp; //@line 29271
  return;
 } else if (($arg | 0) == 19) {
  $181 = HEAP16[$da + 12 >> 1] & 15; //@line 29277
  _sprintf($dst | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $181, tempInt) | 0) | 0; //@line 29278
  STACKTOP = sp; //@line 29280
  return;
 } else if (($arg | 0) == 4) {
  $36 = ((HEAPU8[$src] | 0) << 8 | (HEAPU8[$src + 1 | 0] | 0)) & 65535; //@line 29290
  _dasm_ea($da, $dst, $src, $36 >>> 3 & 56 | $36 >>> 9 & 7, $size); //@line 29296
  STACKTOP = sp; //@line 29298
  return;
 } else if (($arg | 0) == 30) {
  $423 = HEAPU16[$da + 14 >> 1] | 0; //@line 29303
  _sprintf($dst | 0, 50584, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $423 & 7, HEAP32[tempInt + 8 >> 2] = $423 >>> 12 & 7, tempInt) | 0) | 0; //@line 29307
  STACKTOP = sp; //@line 29309
  return;
 } else if (($arg | 0) == 31) {
  $431 = HEAPU16[$da + 14 >> 1] | 0; //@line 29314
  _sprintf($dst | 0, 50584, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $431 & 7, HEAP32[tempInt + 8 >> 2] = $431 >>> 12 & 7, tempInt) | 0) | 0; //@line 29318
  STACKTOP = sp; //@line 29320
  return;
 } else if (($arg | 0) == 13) {
  _sprintf($dst | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$da + 12 >> 1] | 0) >>> 9 & 7, tempInt) | 0) | 0; //@line 29328
  STACKTOP = sp; //@line 29330
  return;
 } else if (($arg | 0) == 3) {
  _dasm_ea($da, $dst, $src, HEAP8[$src + 1 | 0] & 63, $size); //@line 29337
  STACKTOP = sp; //@line 29339
  return;
 } else if (($arg | 0) == 5) {
  _sprintf($dst | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$da + 12 >> 1] & 7, tempInt) | 0) | 0; //@line 29346
  STACKTOP = sp; //@line 29348
  return;
 } else if (($arg | 0) == 18) {
  $174 = (HEAP8[$src] & 255) >>> 1 & 7; //@line 29354
  _sprintf($dst | 0, 53544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $174 << 16 >> 16 == 0 ? 8 : $174 & 65535, tempInt) | 0) | 0; //@line 29358
  STACKTOP = sp; //@line 29360
  return;
 } else if (($arg | 0) == 20) {
  $186 = HEAPU16[$da + 12 >> 1] | 0; //@line 29365
  _sprintf($dst | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = ($186 & 128 | 0) != 0 ? $186 | -256 : $186 & 255, tempInt) | 0) | 0; //@line 29371
  STACKTOP = sp; //@line 29373
  return;
 } else if (($arg | 0) == 8) {
  _sprintf($dst | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU8[$src] | 0) >>> 1 & 7, tempInt) | 0) | 0; //@line 29380
  STACKTOP = sp; //@line 29382
  return;
 } else if (($arg | 0) == 26) {
  $380 = $dst; //@line 29385
  tempBigInt = 5391171; //@line 29386
  HEAP8[$380] = tempBigInt & 255; //@line 29386
  tempBigInt = tempBigInt >> 8; //@line 29386
  HEAP8[$380 + 1 | 0] = tempBigInt & 255; //@line 29386
  tempBigInt = tempBigInt >> 8; //@line 29386
  HEAP8[$380 + 2 | 0] = tempBigInt & 255; //@line 29386
  tempBigInt = tempBigInt >> 8; //@line 29386
  HEAP8[$380 + 3 | 0] = tempBigInt & 255; //@line 29386
  STACKTOP = sp; //@line 29388
  return;
 } else if (($arg | 0) == 10) {
  _sprintf($dst | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$da + 12 >> 1] & 7, tempInt) | 0) | 0; //@line 29395
  STACKTOP = sp; //@line 29397
  return;
 } else if (($arg | 0) == 0) {
  HEAP8[$dst] = 0; //@line 29400
  STACKTOP = sp; //@line 29402
  return;
 } else if (($arg | 0) == 17) {
  $165 = (((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) << 8 | (HEAPU8[$src + 4 | 0] | 0)) << 8 | (HEAPU8[$src + 5 | 0] | 0); //@line 29422
  _sprintf($dst | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $165, tempInt) | 0) | 0; //@line 29423
  $167 = $da + 8 | 0; //@line 29424
  HEAP32[$167 >> 2] = (HEAP32[$167 >> 2] | 0) + 2; //@line 29427
  STACKTOP = sp; //@line 29429
  return;
 } else if (($arg | 0) == 14) {
  $111 = ((HEAPU8[$src + 2 | 0] | 0) << 8 | (HEAPU8[$src + 3 | 0] | 0)) & 65535; //@line 29440
  $113 = ($111 & 32768 | 0) != 0; //@line 29442
  $120 = HEAP16[$da + 12 >> 1] & 7; //@line 29450
  _sprintf($dst | 0, 57472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $113 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = ($113 ? -$111 | 0 : $111) & 65535, HEAP32[tempInt + 24 >> 2] = $120, tempInt) | 0) | 0; //@line 29451
  $122 = $da + 8 | 0; //@line 29452
  HEAP32[$122 >> 2] = (HEAP32[$122 >> 2] | 0) + 1; //@line 29455
  STACKTOP = sp; //@line 29457
  return;
 } else if (($arg | 0) == 7) {
  _sprintf($dst | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$da + 12 >> 1] & 7, tempInt) | 0) | 0; //@line 29464
  STACKTOP = sp; //@line 29466
  return;
 } else if (($arg | 0) == 27) {
  HEAP8[$dst] = HEAP8[51464] | 0; //@line 29469
  HEAP8[$dst + 1 | 0] = HEAP8[51465 | 0] | 0; //@line 29469
  HEAP8[$dst + 2 | 0] = HEAP8[51466 | 0] | 0; //@line 29469
  STACKTOP = sp; //@line 29471
  return;
 } else if (($arg | 0) == 25) {
  $293 = HEAPU8[$src + 2 | 0] | 0; //@line 29476
  $297 = HEAPU8[$src + 3 | 0] | 0; //@line 29480
  HEAP32[$first_i104 >> 2] = 1; //@line 29483
  HEAP8[$dst] = 0; //@line 29484
  $356 = ((((((($293 & 65535) >>> 2 & 1 | $293 & 2 | (((((((($297 & 65535) >>> 2 & 1 | $297 & 2 | (($293 << 8 | $297) << 1 | $297 & 1) << 2) << 1 | ($297 & 65535) >>> 3 & 1) << 1 | ($297 & 65535) >>> 4 & 1) << 1 | ($297 & 65535) >>> 5 & 1) << 1 | ($297 & 65535) >>> 6 & 1) << 1 | ($297 & 65535) >>> 7) << 1 | $293 & 1) << 2) << 1 | ($293 & 65535) >>> 3 & 1) << 1 | ($293 & 65535) >>> 4 & 1) << 1 | ($293 & 65535) >>> 5 & 1) << 1 | ($293 & 65535) >>> 6 & 1) << 1 | ($293 & 65535) >>> 7) & 65535; //@line 29541
  $i_123_i107 = 0;
  $ri_024_i106 = 0;
  $rn_025_i105 = 0;
  while (1) {
   if (($i_123_i107 | 0) != 8 | ($rn_025_i105 | 0) == 0) {
    $rn_1_i109 = $rn_025_i105; //@line 29553
   } else {
    _dasm_reginterval($dst, $ri_024_i106, $rn_025_i105, $first_i104); //@line 29555
    $rn_1_i109 = 0; //@line 29557
   }
   $365 = ($rn_1_i109 | 0) == 0; //@line 29563
   do {
    if ((1 << $i_123_i107 & $356 | 0) == 0) {
     if ($365) {
      $rn_2_i112 = 0;
      $ri_1_i111 = $ri_024_i106;
      break;
     }
     _dasm_reginterval($dst, $ri_024_i106, $rn_1_i109, $first_i104); //@line 29572
     $rn_2_i112 = 0;
     $ri_1_i111 = $ri_024_i106;
    } else {
     $rn_2_i112 = $rn_1_i109 + 1 | 0;
     $ri_1_i111 = $365 ? $i_123_i107 : $ri_024_i106;
    }
   } while (0);
   $371 = $i_123_i107 + 1 | 0; //@line 29584
   if ($371 >>> 0 < 16) {
    $i_123_i107 = $371;
    $ri_024_i106 = $ri_1_i111;
    $rn_025_i105 = $rn_2_i112;
   } else {
    break;
   }
  }
  if (($rn_2_i112 | 0) != 0) {
   _dasm_reginterval($dst, $ri_1_i111, $rn_2_i112, $first_i104); //@line 29596
  }
  $376 = $da + 8 | 0; //@line 29599
  HEAP32[$376 >> 2] = (HEAP32[$376 >> 2] | 0) + 1; //@line 29602
  STACKTOP = sp; //@line 29604
  return;
 } else if (($arg | 0) == 11) {
  _sprintf($dst | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = (HEAPU16[$da + 12 >> 1] | 0) >>> 9 & 7, tempInt) | 0) | 0; //@line 29612
  STACKTOP = sp; //@line 29614
  return;
 } else if (($arg | 0) == 12) {
  _sprintf($dst | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP16[$da + 12 >> 1] & 7, tempInt) | 0) | 0; //@line 29621
  STACKTOP = sp; //@line 29623
  return;
 } else {
  HEAP8[$dst] = 0; //@line 29626
  STACKTOP = sp; //@line 29628
  return;
 }
}
function _e68_set_mem_fct($c, $ext, $get8, $get16, $get32, $set8, $set16, $set32) {
 $c = $c | 0;
 $ext = $ext | 0;
 $get8 = $get8 | 0;
 $get16 = $get16 | 0;
 $get32 = $get32 | 0;
 $set8 = $set8 | 0;
 $set16 = $set16 | 0;
 $set32 = $set32 | 0;
 HEAP32[$c + 4 >> 2] = $ext; //@line 29648
 HEAP32[$c + 8 >> 2] = $get8; //@line 29651
 HEAP32[$c + 12 >> 2] = $get16; //@line 29654
 HEAP32[$c + 16 >> 2] = $get32; //@line 29657
 HEAP32[$c + 20 >> 2] = $set8; //@line 29660
 HEAP32[$c + 24 >> 2] = $set16; //@line 29663
 HEAP32[$c + 28 >> 2] = $set32; //@line 29666
 return;
}
function _dasm_ea($da, $dst, $src, $ea, $size) {
 $da = $da | 0;
 $dst = $dst | 0;
 $src = $src | 0;
 $ea = $ea | 0;
 $size = $size | 0;
 var $2 = 0, $13 = 0, $19 = 0, $20 = 0, $21 = 0, $30 = 0, $33 = 0, $40 = 0, $41 = 0, $42 = 0, $51 = 0, $58 = 0, $78 = 0, $82 = 0, $84 = 0, $85 = 0, $86 = 0, $95 = 0, $98 = 0, $99 = 0, $101 = 0, $104 = 0, $105 = 0, $106 = 0, $115 = 0, $116 = 0, $117 = 0, $126 = 0, $132 = 0, $133 = 0, $134 = 0, $143 = 0, $152 = 0, $155 = 0, $156 = 0, $157 = 0, $166 = 0, $173 = 0, $192 = 0, $197 = 0, $198 = 0, $202 = 0, $206 = 0, $207 = 0, $208 = 0, $217 = 0, $221 = 0, $222 = 0, $223 = 0, $232 = 0, $233 = 0, $234 = 0, $243 = 0, sp = 0;
 sp = STACKTOP; //@line 29710
 $2 = $ea >>> 3 & 7; //@line 29712
 if (($2 | 0) == 3) {
  $13 = $ea & 7; //@line 29714
  _sprintf($dst | 0, 31160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $13, tempInt) | 0) | 0; //@line 29715
  STACKTOP = sp; //@line 29717
  return;
 } else if (($2 | 0) == 5) {
  $19 = $da + 8 | 0; //@line 29720
  $20 = HEAP32[$19 >> 2] | 0; //@line 29721
  $21 = $20 << 1; //@line 29722
  $30 = ((HEAPU8[$src + $21 | 0] | 0) << 8 | (HEAPU8[$src + ($21 | 1) | 0] | 0)) & 65535; //@line 29732
  HEAP32[$19 >> 2] = $20 + 1; //@line 29734
  $33 = ($30 & 32768 | 0) != 0; //@line 29736
  _sprintf($dst | 0, 57472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $33 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = ($33 ? -$30 | 0 : $30) & 65535, HEAP32[tempInt + 24 >> 2] = $ea & 7, tempInt) | 0) | 0; //@line 29742
  STACKTOP = sp; //@line 29744
  return;
 } else if (($2 | 0) == 6) {
  $40 = $da + 8 | 0; //@line 29747
  $41 = HEAP32[$40 >> 2] | 0; //@line 29748
  $42 = $41 << 1; //@line 29749
  $51 = ((HEAPU8[$src + $42 | 0] | 0) << 8 | (HEAPU8[$src + ($42 | 1) | 0] | 0)) & 65535; //@line 29759
  HEAP32[$40 >> 2] = $41 + 1; //@line 29761
  if (($51 & 256 | 0) != 0) {
   _dasm_ea_full($da, $dst, $src); //@line 29766
   STACKTOP = sp; //@line 29768
   return;
  }
  $58 = ($51 & 128 | 0) != 0; //@line 29772
  _sprintf($dst | 0, 46008, (tempInt = STACKTOP, STACKTOP = STACKTOP + 64 | 0, HEAP32[tempInt >> 2] = $58 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = ($58 ? -$51 | 0 : $51) & 255, HEAP32[tempInt + 24 >> 2] = $ea & 7, HEAP32[tempInt + 32 >> 2] = ($51 & 32768 | 0) != 0 ? 34768 : 32184, HEAP32[tempInt + 40 >> 2] = $51 >>> 12 & 7, HEAP32[tempInt + 48 >> 2] = ($51 & 2048 | 0) != 0 ? 45520 : 45216, HEAP32[tempInt + 56 >> 2] = 1 << ($51 >>> 9 & 3), tempInt) | 0) | 0; //@line 29789
  if (($51 & 1536 | 0) == 0) {
   STACKTOP = sp; //@line 29794
   return;
  }
  $78 = $da | 0; //@line 29797
  HEAP32[$78 >> 2] = HEAP32[$78 >> 2] | 128; //@line 29800
  STACKTOP = sp; //@line 29802
  return;
 } else if (($2 | 0) == 4) {
  _sprintf($dst | 0, 30264, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $ea & 7, tempInt) | 0) | 0; //@line 29806
  STACKTOP = sp; //@line 29808
  return;
 } else if (($2 | 0) == 1) {
  _sprintf($dst | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $ea & 7, tempInt) | 0) | 0; //@line 29812
  STACKTOP = sp; //@line 29814
  return;
 } else if (($2 | 0) == 0) {
  _sprintf($dst | 0, 44016, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $ea & 7, tempInt) | 0) | 0; //@line 29818
  STACKTOP = sp; //@line 29820
  return;
 } else if (($2 | 0) == 7) {
  $82 = $ea & 7; //@line 29823
  if (($82 | 0) == 0) {
   $84 = $da + 8 | 0; //@line 29825
   $85 = HEAP32[$84 >> 2] | 0; //@line 29826
   $86 = $85 << 1; //@line 29827
   $95 = ((HEAPU8[$src + $86 | 0] | 0) << 8 | (HEAPU8[$src + ($86 | 1) | 0] | 0)) & 65535; //@line 29837
   HEAP32[$84 >> 2] = $85 + 1; //@line 29839
   $98 = ($95 & 32768 | 0) != 0; //@line 29841
   $99 = $98 ? 56344 : 62888; //@line 29842
   $101 = ($98 ? -$95 | 0 : $95) & 65535; //@line 29845
   _sprintf($dst | 0, 44896, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $99, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $101, tempInt) | 0) | 0; //@line 29846
   STACKTOP = sp; //@line 29848
   return;
  } else if (($82 | 0) == 1) {
   $104 = $da + 8 | 0; //@line 29851
   $105 = HEAP32[$104 >> 2] | 0; //@line 29852
   $106 = $105 << 1; //@line 29853
   $115 = ((HEAPU8[$src + $106 | 0] | 0) << 8 | (HEAPU8[$src + ($106 | 1) | 0] | 0)) & 65535; //@line 29863
   $116 = $105 + 1 | 0; //@line 29864
   HEAP32[$104 >> 2] = $116; //@line 29865
   $117 = $116 << 1; //@line 29866
   $126 = ((HEAPU8[$src + $117 | 0] | 0) << 8 | (HEAPU8[$src + ($117 | 1) | 0] | 0)) & 65535; //@line 29876
   HEAP32[$104 >> 2] = $105 + 2; //@line 29878
   _sprintf($dst | 0, 52704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $126 | $115 << 16, tempInt) | 0) | 0; //@line 29881
   STACKTOP = sp; //@line 29883
   return;
  } else if (($82 | 0) == 2) {
   $132 = $da + 8 | 0; //@line 29886
   $133 = HEAP32[$132 >> 2] | 0; //@line 29887
   $134 = $133 << 1; //@line 29888
   $143 = ((HEAPU8[$src + $134 | 0] | 0) << 8 | (HEAPU8[$src + ($134 | 1) | 0] | 0)) & 65535; //@line 29898
   HEAP32[$132 >> 2] = $133 + 1; //@line 29900
   $152 = (HEAP32[$da + 4 >> 2] | 0) + 2 + (($143 & 32768 | 0) != 0 ? $143 | -65536 : $143) | 0; //@line 29908
   _sprintf($dst | 0, 44536, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $152, tempInt) | 0) | 0; //@line 29909
   STACKTOP = sp; //@line 29911
   return;
  } else if (($82 | 0) == 3) {
   $155 = $da + 8 | 0; //@line 29914
   $156 = HEAP32[$155 >> 2] | 0; //@line 29915
   $157 = $156 << 1; //@line 29916
   $166 = ((HEAPU8[$src + $157 | 0] | 0) << 8 | (HEAPU8[$src + ($157 | 1) | 0] | 0)) & 65535; //@line 29926
   HEAP32[$155 >> 2] = $156 + 1; //@line 29928
   if (($166 & 256 | 0) != 0) {
    _dasm_ea_full($da, $dst, $src); //@line 29933
    STACKTOP = sp; //@line 29935
    return;
   }
   $173 = ($166 & 128 | 0) != 0; //@line 29939
   _sprintf($dst | 0, 44208, (tempInt = STACKTOP, STACKTOP = STACKTOP + 56 | 0, HEAP32[tempInt >> 2] = $173 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = ($173 ? -$166 | 0 : $166) & 255, HEAP32[tempInt + 24 >> 2] = ($166 & 32768 | 0) != 0 ? 34768 : 32184, HEAP32[tempInt + 32 >> 2] = $166 >>> 12 & 7, HEAP32[tempInt + 40 >> 2] = ($166 & 2048 | 0) != 0 ? 45520 : 45216, HEAP32[tempInt + 48 >> 2] = 1 << ($166 >>> 9 & 3), tempInt) | 0) | 0; //@line 29955
   if (($166 & 1536 | 0) == 0) {
    STACKTOP = sp; //@line 29960
    return;
   }
   $192 = $da | 0; //@line 29963
   HEAP32[$192 >> 2] = HEAP32[$192 >> 2] | 128; //@line 29966
   STACKTOP = sp; //@line 29968
   return;
  } else if (($82 | 0) == 4) {
   if (($size | 0) == 8) {
    $197 = $da + 8 | 0; //@line 29972
    $198 = HEAP32[$197 >> 2] | 0; //@line 29973
    $202 = HEAPU8[$src + ($198 << 1 | 1) | 0] | 0; //@line 29978
    HEAP32[$197 >> 2] = $198 + 1; //@line 29980
    _sprintf($dst | 0, 54856, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $202, tempInt) | 0) | 0; //@line 29981
    STACKTOP = sp; //@line 29983
    return;
   } else if (($size | 0) == 16) {
    $206 = $da + 8 | 0; //@line 29986
    $207 = HEAP32[$206 >> 2] | 0; //@line 29987
    $208 = $207 << 1; //@line 29988
    $217 = ((HEAPU8[$src + $208 | 0] | 0) << 8 | (HEAPU8[$src + ($208 | 1) | 0] | 0)) & 65535; //@line 29998
    HEAP32[$206 >> 2] = $207 + 1; //@line 30000
    _sprintf($dst | 0, 47464, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $217, tempInt) | 0) | 0; //@line 30001
    STACKTOP = sp; //@line 30003
    return;
   } else if (($size | 0) == 32) {
    $221 = $da + 8 | 0; //@line 30006
    $222 = HEAP32[$221 >> 2] | 0; //@line 30007
    $223 = $222 << 1; //@line 30008
    $232 = ((HEAPU8[$src + $223 | 0] | 0) << 8 | (HEAPU8[$src + ($223 | 1) | 0] | 0)) & 65535; //@line 30018
    $233 = $222 + 1 | 0; //@line 30019
    HEAP32[$221 >> 2] = $233; //@line 30020
    $234 = $233 << 1; //@line 30021
    $243 = ((HEAPU8[$src + $234 | 0] | 0) << 8 | (HEAPU8[$src + ($234 | 1) | 0] | 0)) & 65535; //@line 30031
    HEAP32[$221 >> 2] = $222 + 2; //@line 30033
    _sprintf($dst | 0, 54072, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 41376, HEAP32[tempInt + 8 >> 2] = $243 | $232 << 16, tempInt) | 0) | 0; //@line 30036
    STACKTOP = sp; //@line 30038
    return;
   } else {
    STACKTOP = sp; //@line 30041
    return;
   }
  } else {
   _sprintf($dst | 0, 43936, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $ea & 63, tempInt) | 0) | 0; //@line 30046
   STACKTOP = sp; //@line 30048
   return;
  }
 } else if (($2 | 0) == 2) {
  _sprintf($dst | 0, 46536, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $ea & 7, tempInt) | 0) | 0; //@line 30053
  STACKTOP = sp; //@line 30055
  return;
 } else {
  _sprintf($dst | 0, 43936, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $ea & 63, tempInt) | 0) | 0; //@line 30059
  STACKTOP = sp; //@line 30061
  return;
 }
}
function _dasm_reginterval($dst, $i, $n, $first) {
 $dst = $dst | 0;
 $i = $i | 0;
 $n = $n | 0;
 $first = $first | 0;
 var $tmp = 0, $1 = 0, $_0 = 0, $reg_0 = 0, $6 = 0, $10 = 0, $12 = 0, $16 = 0, $18 = 0, sp = 0;
 sp = STACKTOP; //@line 30076
 STACKTOP = STACKTOP + 32 | 0; //@line 30076
 $tmp = sp | 0; //@line 30077
 $1 = $i >>> 0 < 8; //@line 30078
 $_0 = $1 ? $i : $i - 8 | 0; //@line 30080
 $reg_0 = $1 ? 32184 : 34768; //@line 30081
 if ((HEAP32[$first >> 2] | 0) == 0) {
  $6 = $dst + (_strlen($dst | 0) | 0) | 0; //@line 30088
  tempBigInt = 47; //@line 30089
  HEAP8[$6] = tempBigInt & 255; //@line 30089
  tempBigInt = tempBigInt >> 8; //@line 30089
  HEAP8[$6 + 1 | 0] = tempBigInt & 255; //@line 30089
 }
 do {
  if ($n >>> 0 > 2) {
   $10 = $tmp | 0; //@line 30096
   $12 = $n - 1 + $_0 | 0; //@line 30098
   _sprintf($10 | 0, 47136, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $reg_0, HEAP32[tempInt + 8 >> 2] = $_0, HEAP32[tempInt + 16 >> 2] = $reg_0, HEAP32[tempInt + 24 >> 2] = $12, tempInt) | 0) | 0; //@line 30099
  } else {
   $16 = $tmp | 0; //@line 30103
   if (($n | 0) == 2) {
    $18 = $_0 + 1 | 0; //@line 30106
    _sprintf($16 | 0, 46848, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $reg_0, HEAP32[tempInt + 8 >> 2] = $_0, HEAP32[tempInt + 16 >> 2] = $reg_0, HEAP32[tempInt + 24 >> 2] = $18, tempInt) | 0) | 0; //@line 30107
    break;
   } else {
    _sprintf($16 | 0, 37704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $reg_0, HEAP32[tempInt + 8 >> 2] = $_0, tempInt) | 0) | 0; //@line 30111
    break;
   }
  }
 } while (0);
 _strcat($dst | 0, $tmp | 0) | 0; //@line 30117
 HEAP32[$first >> 2] = 0; //@line 30118
 STACKTOP = sp; //@line 30119
 return;
}
function _dasm_ea_full($da, $dst, $src) {
 $da = $da | 0;
 $dst = $dst | 0;
 $src = $src | 0;
 var $br39 = 0, $ix41 = 0, $ix41_sub = 0, $bd45 = 0, $bd45_sub = 0, $od43 = 0, $od43_sub = 0, $scale = 0, $3 = 0, $7 = 0, $12 = 0, $15 = 0, $18 = 0, $23 = 0, $26 = 0, $28 = 0, $31 = 0, $35 = 0, $37 = 0, $40 = 0, $44 = 0, $47 = 0, $48 = 0, $49 = 0, $58 = 0, $62 = 0, $68 = 0, $71 = 0, $72 = 0, $73 = 0, $82 = 0, $83 = 0, $85 = 0, $94 = 0, $96 = 0, $98 = 0, $104 = 0, $107 = 0, $108 = 0, $109 = 0, $118 = 0, $122 = 0, $128 = 0, $131 = 0, $132 = 0, $133 = 0, $142 = 0, $143 = 0, $145 = 0, $154 = 0, $156 = 0, $158 = 0, $171 = 0, $172 = 0, $173 = 0, sp = 0;
 sp = STACKTOP; //@line 30150
 STACKTOP = STACKTOP + 32 | 0; //@line 30150
 $br39 = sp | 0; //@line 30151
 $ix41 = sp + 16 | 0; //@line 30152
 $ix41_sub = $ix41 | 0; //@line 30153
 $bd45 = STACKTOP; //@line 30154
 STACKTOP = STACKTOP + 16 | 0; //@line 30154
 $bd45_sub = $bd45 | 0; //@line 30155
 $od43 = STACKTOP; //@line 30156
 STACKTOP = STACKTOP + 16 | 0; //@line 30156
 $od43_sub = $od43 | 0; //@line 30157
 $scale = STACKTOP; //@line 30158
 STACKTOP = STACKTOP + 16 | 0; //@line 30158
 $3 = HEAPU16[$da + 14 >> 1] | 0; //@line 30161
 $7 = ($3 & 64 | 0) == 0; //@line 30165
 do {
  if (($3 & 128 | 0) == 0) {
   $12 = HEAPU16[$da + 12 >> 1] | 0; //@line 30171
   $15 = $br39; //@line 30174
   if (($12 & 56 | 0) == 56) {
    HEAP8[$15] = HEAP8[43688] | 0; //@line 30177
    HEAP8[$15 + 1 | 0] = HEAP8[43689 | 0] | 0; //@line 30177
    HEAP8[$15 + 2 | 0] = HEAP8[43690 | 0] | 0; //@line 30177
    break;
   } else {
    $18 = $12 & 7; //@line 30181
    _sprintf($15 | 0, 40696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $18, tempInt) | 0) | 0; //@line 30182
    break;
   }
  } else {
   HEAP16[$br39 >> 1] = 45; //@line 30187
  }
 } while (0);
 if ($7) {
  $23 = $ix41; //@line 30193
  $26 = ($3 & 32768 | 0) != 0 ? 34768 : 32184; //@line 30196
  $28 = $3 >>> 12 & 7; //@line 30198
  $31 = ($3 & 2048 | 0) != 0 ? 45520 : 45216; //@line 30201
  _sprintf($23 | 0, 43384, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $26, HEAP32[tempInt + 8 >> 2] = $28, HEAP32[tempInt + 16 >> 2] = $31, tempInt) | 0) | 0; //@line 30202
 } else {
  HEAP16[$ix41_sub >> 1] = 45; //@line 30204
 }
 $35 = $3 >>> 9 & 3; //@line 30208
 $37 = $scale | 0; //@line 30210
 if (($35 | 0) == 0) {
  HEAP8[$37] = 0; //@line 30213
 } else {
  $40 = 1 << $35; //@line 30216
  _sprintf($37 | 0, 43008, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $40, tempInt) | 0) | 0; //@line 30217
 }
 $44 = $3 >>> 4 & 3; //@line 30220
 if (($44 | 0) == 0 | ($44 | 0) == 1) {
  HEAP16[$bd45_sub >> 1] = 45; //@line 30222
 } else if (($44 | 0) == 2) {
  $47 = $da + 8 | 0; //@line 30225
  $48 = HEAP32[$47 >> 2] | 0; //@line 30226
  $49 = $48 << 1; //@line 30227
  $58 = ((HEAPU8[$src + $49 | 0] | 0) << 8 | (HEAPU8[$src + ($49 | 1) | 0] | 0)) & 65535; //@line 30237
  HEAP32[$47 >> 2] = $48 + 1; //@line 30239
  $62 = ($58 & 32768 | 0) != 0; //@line 30242
  if ($62) {
   $68 = -$58 & 65535; //@line 30249
  } else {
   $68 = $58; //@line 30251
  }
  _sprintf($bd45 | 0, 44896, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $62 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $68, tempInt) | 0) | 0; //@line 30254
 } else if (($44 | 0) == 3) {
  $71 = $da + 8 | 0; //@line 30257
  $72 = HEAP32[$71 >> 2] | 0; //@line 30258
  $73 = $72 << 1; //@line 30259
  $82 = ((HEAPU8[$src + $73 | 0] | 0) << 8 | (HEAPU8[$src + ($73 | 1) | 0] | 0)) & 65535; //@line 30269
  $83 = $72 + 1 | 0; //@line 30270
  HEAP32[$71 >> 2] = $83; //@line 30271
  $85 = $83 << 1; //@line 30273
  $94 = ((HEAPU8[$src + $85 | 0] | 0) << 8 | (HEAPU8[$src + ($85 | 1) | 0] | 0)) & 65535; //@line 30283
  HEAP32[$71 >> 2] = $72 + 2; //@line 30285
  $96 = $94 | $82 << 16; //@line 30286
  $98 = ($96 | 0) < 0; //@line 30288
  _sprintf($bd45 | 0, 42576, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $98 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $98 ? -$96 | 0 : $96, tempInt) | 0) | 0; //@line 30292
 }
 $104 = $3 & 3; //@line 30295
 if (($104 | 0) == 0 | ($104 | 0) == 1) {
  HEAP16[$od43_sub >> 1] = 45; //@line 30297
 } else if (($104 | 0) == 2) {
  $107 = $da + 8 | 0; //@line 30300
  $108 = HEAP32[$107 >> 2] | 0; //@line 30301
  $109 = $108 << 1; //@line 30302
  $118 = ((HEAPU8[$src + $109 | 0] | 0) << 8 | (HEAPU8[$src + ($109 | 1) | 0] | 0)) & 65535; //@line 30312
  HEAP32[$107 >> 2] = $108 + 1; //@line 30314
  $122 = ($118 & 32768 | 0) != 0; //@line 30317
  if ($122) {
   $128 = -$118 & 65535; //@line 30324
  } else {
   $128 = $118; //@line 30326
  }
  _sprintf($od43 | 0, 44896, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $122 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $128, tempInt) | 0) | 0; //@line 30329
 } else if (($104 | 0) == 3) {
  $131 = $da + 8 | 0; //@line 30332
  $132 = HEAP32[$131 >> 2] | 0; //@line 30333
  $133 = $132 << 1; //@line 30334
  $142 = ((HEAPU8[$src + $133 | 0] | 0) << 8 | (HEAPU8[$src + ($133 | 1) | 0] | 0)) & 65535; //@line 30344
  $143 = $132 + 1 | 0; //@line 30345
  HEAP32[$131 >> 2] = $143; //@line 30346
  $145 = $143 << 1; //@line 30348
  $154 = ((HEAPU8[$src + $145 | 0] | 0) << 8 | (HEAPU8[$src + ($145 | 1) | 0] | 0)) & 65535; //@line 30358
  HEAP32[$131 >> 2] = $132 + 2; //@line 30360
  $156 = $154 | $142 << 16; //@line 30361
  $158 = ($156 | 0) < 0; //@line 30363
  _sprintf($od43 | 0, 42576, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $158 ? 56344 : 62888, HEAP32[tempInt + 8 >> 2] = 41376, HEAP32[tempInt + 16 >> 2] = $158 ? -$156 | 0 : $156, tempInt) | 0) | 0; //@line 30367
 }
 if (($3 & 4 | 0) == 0) {
  _sprintf($dst | 0, 41720, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = $br39, HEAP32[tempInt + 8 >> 2] = $bd45_sub, HEAP32[tempInt + 16 >> 2] = $ix41, HEAP32[tempInt + 24 >> 2] = $37, HEAP32[tempInt + 32 >> 2] = $od43_sub, tempInt) | 0) | 0; //@line 30374
  $171 = $da | 0; //@line 30375
  $172 = HEAP32[$171 >> 2] | 0; //@line 30376
  $173 = $172 | 128; //@line 30377
  HEAP32[$171 >> 2] = $173; //@line 30378
  STACKTOP = sp; //@line 30379
  return;
 } else {
  _sprintf($dst | 0, 42040, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = $br39, HEAP32[tempInt + 8 >> 2] = $bd45_sub, HEAP32[tempInt + 16 >> 2] = $ix41, HEAP32[tempInt + 24 >> 2] = $37, HEAP32[tempInt + 32 >> 2] = $od43_sub, tempInt) | 0) | 0; //@line 30382
  $171 = $da | 0; //@line 30384
  $172 = HEAP32[$171 >> 2] | 0; //@line 30385
  $173 = $172 | 128; //@line 30386
  HEAP32[$171 >> 2] = $173; //@line 30387
  STACKTOP = sp; //@line 30388
  return;
 }
}
function _e68_new() {
 var $1 = 0, $2 = 0, $6 = 0, $29 = 0, $_0 = 0;
 $1 = _malloc(4528) | 0; //@line 30402
 $2 = $1; //@line 30403
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 30407
  return $_0 | 0; //@line 30410
 }
 $6 = $1 + 334 | 0; //@line 30413
 _memset($1 | 0, 0, 50); //@line 30414
 _memset($1 + 52 | 0, 0, 36); //@line 30415
 HEAP8[$6] = 1; //@line 30416
 HEAP8[$1 + 335 | 0] = 2; //@line 30418
 HEAP32[$1 + 364 >> 2] = 0; //@line 30421
 HEAP8[$1 + 368 | 0] = 0; //@line 30423
 HEAP32[$1 + 372 >> 2] = 1; //@line 30426
 HEAP32[$1 + 376 >> 2] = 0; //@line 30429
 HEAP32[$1 + 380 >> 2] = 0; //@line 30432
 HEAP32[$1 + 384 >> 2] = 0; //@line 30435
 HEAP32[$1 + 388 >> 2] = 30136; //@line 30438
 HEAP32[$1 + 392 >> 2] = 0; //@line 30441
 HEAP32[$1 + 396 >> 2] = 0; //@line 30444
 _e68_set_opcodes($2); //@line 30445
 HEAP16[$1 + 166 >> 1] = 8192; //@line 30448
 $29 = $1 + 148 | 0; //@line 30451
 _memset($1 + 88 | 0, 0, 64); //@line 30452
 if ((HEAP8[$6] | 0) == 0) {
  HEAP32[$29 >> 2] = 0; //@line 30457
  HEAP32[$1 + 172 >> 2] = 0; //@line 30460
 } else {
  HEAP32[$1 + 168 >> 2] = 0; //@line 30464
  HEAP32[$29 >> 2] = 0; //@line 30465
 }
 HEAP32[$1 + 152 >> 2] = 0; //@line 30470
 _memset($1 + 176 | 0, 0, 156); //@line 30472
 $_0 = $2; //@line 30474
 return $_0 | 0; //@line 30477
}
function _e68_set_ram($c, $ram, $cnt) {
 $c = $c | 0;
 $ram = $ram | 0;
 $cnt = $cnt | 0;
 HEAP32[$c + 32 >> 2] = $ram; //@line 30491
 HEAP32[$c + 36 >> 2] = ($ram | 0) == 0 ? 0 : $cnt; //@line 30493
 return;
}
function _e68_set_reset_fct($c, $ext, $fct) {
 $c = $c | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$c + 40 >> 2] = $ext; //@line 30507
 HEAP32[$c + 44 >> 2] = $fct; //@line 30510
 return;
}
function _e68_set_hook_fct($c, $ext, $fct) {
 $c = $c | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$c + 60 >> 2] = $ext; //@line 30524
 HEAP32[$c + 64 >> 2] = $fct; //@line 30527
 return;
}
function _e68_set_address_check($c, $check) {
 $c = $c | 0;
 $check = $check | 0;
 var $2 = 0, $3 = 0;
 $2 = $c | 0; //@line 30540
 $3 = HEAP32[$2 >> 2] | 0; //@line 30541
 HEAP32[$2 >> 2] = ($check | 0) == 0 ? $3 | 1 : $3 & -2; //@line 30545
 return;
}
function _e68_get_opcnt($c) {
 $c = $c | 0;
 return HEAP32[$c + 392 >> 2] | 0; //@line 30559
}
function _e68_get_clkcnt($c) {
 $c = $c | 0;
 return HEAP32[$c + 396 >> 2] | 0; //@line 30571
}
function _e68_get_delay($c) {
 $c = $c | 0;
 return HEAP32[$c + 372 >> 2] | 0; //@line 30583
}
function _e68_set_halt($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 HEAP8[$c + 335 | 0] = $val & 3; //@line 30596
 return;
}
function _e68_get_exception_cnt($c) {
 $c = $c | 0;
 return HEAP32[$c + 376 >> 2] | 0; //@line 30610
}
function _e68_get_exception($c) {
 $c = $c | 0;
 return HEAP32[$c + 384 >> 2] | 0; //@line 30622
}
function _e68_get_exception_name($c) {
 $c = $c | 0;
 return HEAP32[$c + 388 >> 2] | 0; //@line 30634
}
function _e68_get_last_pc($c, $idx) {
 $c = $c | 0;
 $idx = $idx | 0;
 var $_0 = 0;
 if ($idx >>> 0 > 31) {
  $_0 = 0; //@line 30647
  return $_0 | 0; //@line 30650
 }
 $_0 = HEAP32[$c + 200 + (((HEAP32[$c + 196 >> 2] | 0) - $idx & 31) << 2) >> 2] | 0; //@line 30659
 return $_0 | 0; //@line 30662
}
function _e68_get_last_trap_a($c) {
 $c = $c | 0;
 return HEAP16[$c + 328 >> 1] | 0; //@line 30674
}
function _e68_set_sr($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $1 = 0, $_lobit = 0, $7 = 0, $10 = 0, $11 = 0, $13 = 0, $15 = 0, $_pre_phi9_i = 0, $_pre_phi_i = 0, $19 = 0;
 $1 = $c + 166 | 0; //@line 30686
 if (((HEAP16[$1 >> 1] ^ $val) & 8192) == 0) {
  $19 = $val & -22753; //@line 30693
  HEAP16[$1 >> 1] = $19; //@line 30694
  return;
 }
 $_lobit = $val & 8192; //@line 30698
 $7 = $c + 334 | 0; //@line 30699
 $10 = $c + 148 | 0; //@line 30702
 $11 = HEAP32[$10 >> 2] | 0; //@line 30703
 if ((HEAP8[$7] | 0) == 0) {
  $15 = $c + 168 | 0; //@line 30706
  HEAP32[$15 >> 2] = $11; //@line 30707
  $_pre_phi_i = $15;
  $_pre_phi9_i = $c + 172 | 0;
 } else {
  $13 = $c + 172 | 0; //@line 30711
  HEAP32[$13 >> 2] = $11; //@line 30712
  $_pre_phi_i = $c + 168 | 0;
  $_pre_phi9_i = $13;
 }
 HEAP32[$10 >> 2] = HEAP32[($_lobit << 16 >> 16 != 0 ? $_pre_phi9_i : $_pre_phi_i) >> 2]; //@line 30722
 HEAP8[$7] = ($_lobit & 65535) >>> 13 & 255; //@line 30725
 $19 = $val & -22753; //@line 30727
 HEAP16[$1 >> 1] = $19; //@line 30728
 return;
}
function _e68_set_68000($c) {
 $c = $c | 0;
 HEAP32[$c >> 2] = 0; //@line 30740
 _e68_set_opcodes($c); //@line 30741
 return;
}
function _e68_set_68010($c) {
 $c = $c | 0;
 HEAP32[$c >> 2] = 2; //@line 30753
 _e68_set_opcodes($c); //@line 30754
 return;
}
function _e68_set_68020($c) {
 $c = $c | 0;
 HEAP32[$c >> 2] = 7; //@line 30766
 _e68_set_opcodes_020($c); //@line 30767
 return;
}
function _e68_get_reg($c, $reg, $val) {
 $c = $c | 0;
 $reg = $reg | 0;
 $val = $val | 0;
 var $_reg = 0, $19 = 0, $26 = 0, $28 = 0, $idx_066 = 0, $_165 = 0, $32 = 0, $35 = 0, $_lcssa = 0, $idx_0_lcssa = 0, $42 = 0, $43 = 0, $49 = 0, $_0_i = 0, $type_0 = 0, $_268 = 0, $108 = 0, $110 = 0, $_271 = 0, $idx_170 = 0, $114 = 0, $_2 = 0, $115 = 0, $_2_lcssa = 0, $idx_1_lcssa = 0, $_060_pn_lcssa = 0, $storemerge_in = 0, $storemerge = 0, $123 = 0, $128 = 0, $136 = 0, $_0 = 0;
 $_reg = (HEAP8[$reg] | 0) == 37 ? $reg + 1 | 0 : $reg; //@line 30799
 if ((_strcmp($_reg | 0, 50920) | 0) == 0) {
  HEAP32[$val >> 2] = HEAP32[$c + 152 >> 2]; //@line 30806
  $_0 = 0; //@line 30808
  return $_0 | 0; //@line 30811
 }
 if ((_strcmp($_reg | 0, 46808) | 0) == 0) {
  HEAP32[$val >> 2] = HEAP32[$c + 200 + ((HEAP32[$c + 196 >> 2] & 31) << 2) >> 2]; //@line 30822
  $_0 = 0; //@line 30824
  return $_0 | 0; //@line 30827
 }
 $19 = HEAP8[$_reg] | 0; //@line 30829
 do {
  if ($19 << 24 >> 24 == 111) {
   if ((HEAP8[$_reg + 1 | 0] | 0) != 112) {
    break;
   }
   $26 = HEAP8[$_reg + 2 | 0] | 0; //@line 30842
   if (($26 - 48 & 255) < 10) {
    $_165 = $_reg;
    $idx_066 = 0;
    $28 = $26;
    while (1) {
     $32 = ($idx_066 * 10 | 0) - 48 + ($28 << 24 >> 24) | 0; //@line 30855
     $35 = HEAP8[$_165 + 3 | 0] | 0; //@line 30858
     if (($35 - 48 & 255) < 10) {
      $_165 = $_165 + 1 | 0;
      $idx_066 = $32;
      $28 = $35;
     } else {
      break;
     }
    }
    $idx_0_lcssa = $32 << 1;
    $_lcssa = $35;
   } else {
    $idx_0_lcssa = 0;
    $_lcssa = $26;
   }
   if ($_lcssa << 24 >> 24 != 0) {
    $_0 = 1; //@line 30879
    return $_0 | 0; //@line 30882
   }
   $42 = (HEAP32[$c + 152 >> 2] | 0) + $idx_0_lcssa & 16777215; //@line 30887
   $43 = $42 + 1 | 0; //@line 30888
   if ($43 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $49 = HEAP32[$c + 32 >> 2] | 0; //@line 30895
    $_0_i = HEAPU8[$49 + $42 | 0] << 8 | HEAPU8[$49 + $43 | 0]; //@line 30905
   } else {
    $_0_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $42) | 0; //@line 30913
   }
   HEAP32[$val >> 2] = $_0_i & 65535; //@line 30917
   $_0 = 0; //@line 30919
   return $_0 | 0; //@line 30922
  }
 } while (0);
 if ((_strcmp($_reg | 0, 43344) | 0) == 0) {
  HEAP32[$val >> 2] = HEAPU16[$c + 166 >> 1] | 0; //@line 30932
  $_0 = 0; //@line 30934
  return $_0 | 0; //@line 30937
 }
 if ((_strcmp($_reg | 0, 40080) | 0) == 0) {
  HEAP32[$val >> 2] = HEAP32[$c + 148 >> 2]; //@line 30945
  $_0 = 0; //@line 30947
  return $_0 | 0; //@line 30950
 }
 if ((_strcmp($_reg | 0, 37112) | 0) == 0) {
  HEAP32[$val >> 2] = HEAP16[$c + 166 >> 1] & 255; //@line 30960
  $_0 = 0; //@line 30962
  return $_0 | 0; //@line 30965
 }
 if ((_strcmp($_reg | 0, 34080) | 0) == 0) {
  HEAP32[$val >> 2] = HEAP32[((HEAP8[$c + 334 | 0] | 0) == 0 ? $c + 148 | 0 : $c + 168 | 0) >> 2]; //@line 30978
  $_0 = 0; //@line 30980
  return $_0 | 0; //@line 30983
 }
 if ((_strcmp($_reg | 0, 31944) | 0) == 0) {
  HEAP32[$val >> 2] = HEAP32[((HEAP8[$c + 334 | 0] | 0) == 0 ? $c + 172 | 0 : $c + 148 | 0) >> 2]; //@line 30996
  $_0 = 0; //@line 30998
  return $_0 | 0; //@line 31001
 }
 if (($19 << 24 >> 24 | 0) == 100 | ($19 << 24 >> 24 | 0) == 68) {
  $type_0 = 100; //@line 31004
 } else if (($19 << 24 >> 24 | 0) == 97 | ($19 << 24 >> 24 | 0) == 65) {
  $type_0 = 97;
 } else {
  $_0 = 1; //@line 31008
  return $_0 | 0; //@line 31011
 }
 $_268 = $_reg + 1 | 0; //@line 31014
 $108 = HEAP8[$_268] | 0; //@line 31015
 if (($108 - 48 & 255) < 10) {
  $idx_170 = 0;
  $_271 = $_268;
  $110 = $108;
  while (1) {
   $114 = ($idx_170 * 10 | 0) - 48 + ($110 << 24 >> 24) | 0; //@line 31028
   $_2 = $_271 + 1 | 0; //@line 31029
   $115 = HEAP8[$_2] | 0; //@line 31030
   if (($115 - 48 & 255) < 10) {
    $idx_170 = $114;
    $_271 = $_2;
    $110 = $115;
   } else {
    break;
   }
  }
  $_060_pn_lcssa = $_271;
  $idx_1_lcssa = $114 & 7;
  $_2_lcssa = $_2;
 } else {
  $_060_pn_lcssa = $_reg;
  $idx_1_lcssa = 0;
  $_2_lcssa = $_268;
 }
 if (($type_0 | 0) == 97) {
  $storemerge_in = $c + 120 + ($idx_1_lcssa << 2) | 0; //@line 31054
 } else {
  $storemerge_in = $c + 88 + ($idx_1_lcssa << 2) | 0; //@line 31057
 }
 $storemerge = HEAP32[$storemerge_in >> 2] | 0; //@line 31060
 HEAP32[$val >> 2] = $storemerge; //@line 31061
 $123 = HEAP8[$_2_lcssa] | 0; //@line 31062
 if ($123 << 24 >> 24 == 46) {
  $128 = HEAP8[$_060_pn_lcssa + 2 | 0] | 0; //@line 31068
  if (($128 | 0) == 98 | ($128 | 0) == 66) {
   HEAP32[$val >> 2] = $storemerge & 255; //@line 31071
  } else if (($128 | 0) == 119 | ($128 | 0) == 87) {
   HEAP32[$val >> 2] = $storemerge & 65535; //@line 31075
  } else if (!(($128 | 0) == 108 | ($128 | 0) == 76)) {
   $_0 = 1; //@line 31078
   return $_0 | 0; //@line 31081
  }
  $136 = HEAP8[$_060_pn_lcssa + 3 | 0] | 0; //@line 31086
 } else {
  $136 = $123; //@line 31088
 }
 $_0 = $136 << 24 >> 24 != 0 | 0; //@line 31094
 return $_0 | 0; //@line 31097
}
function _e68_set_reg($c, $reg, $val) {
 $c = $c | 0;
 $reg = $reg | 0;
 $val = $val | 0;
 var $_reg = 0, $11 = 0, $12 = 0, $_lobit_i = 0, $18 = 0, $21 = 0, $22 = 0, $24 = 0, $26 = 0, $_pre_phi9_i_i = 0, $_pre_phi_i_i = 0, $39 = 0, $68 = 0, $type_0 = 0, $_148 = 0, $71 = 0, $73 = 0, $_151 = 0, $idx_050 = 0, $77 = 0, $_1 = 0, $78 = 0, $81 = 0, $idx_0_lcssa = 0, $_0_pn_lcssa = 0, $86 = 0, $mask_0 = 0, $92 = 0, $mask_1 = 0, $97 = 0, $104 = 0, $_047 = 0;
 $_reg = (HEAP8[$reg] | 0) == 37 ? $reg + 1 | 0 : $reg; //@line 31123
 if ((_strcmp($_reg | 0, 50920) | 0) == 0) {
  _e68_set_pc_prefetch($c, $val); //@line 31128
  $_047 = 0; //@line 31130
  return $_047 | 0; //@line 31133
 }
 if ((_strcmp($_reg | 0, 43344) | 0) == 0) {
  $11 = $val & 65535; //@line 31139
  $12 = $c + 166 | 0; //@line 31140
  if (((HEAP16[$12 >> 1] ^ $11) & 8192) != 0) {
   $_lobit_i = $11 & 8192; //@line 31147
   $18 = $c + 334 | 0; //@line 31148
   $21 = $c + 148 | 0; //@line 31151
   $22 = HEAP32[$21 >> 2] | 0; //@line 31152
   if ((HEAP8[$18] | 0) == 0) {
    $26 = $c + 168 | 0; //@line 31155
    HEAP32[$26 >> 2] = $22; //@line 31156
    $_pre_phi_i_i = $26;
    $_pre_phi9_i_i = $c + 172 | 0;
   } else {
    $24 = $c + 172 | 0; //@line 31160
    HEAP32[$24 >> 2] = $22; //@line 31161
    $_pre_phi_i_i = $c + 168 | 0;
    $_pre_phi9_i_i = $24;
   }
   HEAP32[$21 >> 2] = HEAP32[($_lobit_i << 16 >> 16 != 0 ? $_pre_phi9_i_i : $_pre_phi_i_i) >> 2]; //@line 31171
   HEAP8[$18] = ($_lobit_i & 65535) >>> 13 & 255; //@line 31174
  }
  HEAP16[$12 >> 1] = $11 & -22753; //@line 31178
  $_047 = 0; //@line 31180
  return $_047 | 0; //@line 31183
 }
 if ((_strcmp($_reg | 0, 40080) | 0) == 0) {
  HEAP32[$c + 148 >> 2] = $val; //@line 31190
  $_047 = 0; //@line 31192
  return $_047 | 0; //@line 31195
 }
 if ((_strcmp($_reg | 0, 37112) | 0) == 0) {
  $39 = $c + 166 | 0; //@line 31201
  HEAP16[$39 >> 1] = HEAP16[$39 >> 1] & -256 | $val & 255; //@line 31207
  $_047 = 0; //@line 31209
  return $_047 | 0; //@line 31212
 }
 if ((_strcmp($_reg | 0, 34080) | 0) == 0) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   HEAP32[$c + 148 >> 2] = $val; //@line 31224
   $_047 = 0; //@line 31225
   return $_047 | 0; //@line 31228
  } else {
   HEAP32[$c + 168 >> 2] = $val; //@line 31231
   $_047 = 0; //@line 31233
   return $_047 | 0; //@line 31236
  }
 }
 if ((_strcmp($_reg | 0, 31944) | 0) == 0) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   HEAP32[$c + 172 >> 2] = $val; //@line 31249
   $_047 = 0; //@line 31250
   return $_047 | 0; //@line 31253
  } else {
   HEAP32[$c + 148 >> 2] = $val; //@line 31256
   $_047 = 0; //@line 31258
   return $_047 | 0; //@line 31261
  }
 }
 $68 = HEAP8[$_reg] | 0; //@line 31264
 if (($68 << 24 >> 24 | 0) == 100 | ($68 << 24 >> 24 | 0) == 68) {
  $type_0 = 100; //@line 31266
 } else if (($68 << 24 >> 24 | 0) == 97 | ($68 << 24 >> 24 | 0) == 65) {
  $type_0 = 97;
 } else {
  $_047 = 1; //@line 31270
  return $_047 | 0; //@line 31273
 }
 $_148 = $_reg + 1 | 0; //@line 31276
 $71 = HEAP8[$_148] | 0; //@line 31277
 if (($71 - 48 & 255) < 10) {
  $idx_050 = 0;
  $_151 = $_148;
  $73 = $71;
  while (1) {
   $77 = ($idx_050 * 10 | 0) - 48 + ($73 << 24 >> 24) | 0; //@line 31289
   $_1 = $_151 + 1 | 0; //@line 31290
   $78 = HEAP8[$_1] | 0; //@line 31291
   if (($78 - 48 & 255) < 10) {
    $idx_050 = $77;
    $_151 = $_1;
    $73 = $78;
   } else {
    break;
   }
  }
  $_0_pn_lcssa = $_151;
  $idx_0_lcssa = $77 & 7;
  $81 = $78;
 } else {
  $_0_pn_lcssa = $_reg;
  $idx_0_lcssa = 0;
  $81 = $71;
 }
 if ($81 << 24 >> 24 == 46) {
  $86 = HEAP8[$_0_pn_lcssa + 2 | 0] | 0; //@line 31313
  if (($86 | 0) == 119 | ($86 | 0) == 87) {
   $mask_0 = 65535; //@line 31316
  } else if (($86 | 0) == 108 | ($86 | 0) == 76) {
   $mask_0 = -1; //@line 31319
  } else if (($86 | 0) == 98 | ($86 | 0) == 66) {
   $mask_0 = 255;
  } else {
   $_047 = 1; //@line 31323
   return $_047 | 0; //@line 31326
  }
  $mask_1 = $mask_0;
  $92 = HEAP8[$_0_pn_lcssa + 3 | 0] | 0;
 } else {
  $mask_1 = -1;
  $92 = $81;
 }
 if ($92 << 24 >> 24 != 0) {
  $_047 = 1; //@line 31341
  return $_047 | 0; //@line 31344
 }
 if (($type_0 | 0) == 97) {
  $97 = $c + 120 + ($idx_0_lcssa << 2) | 0; //@line 31349
  HEAP32[$97 >> 2] = HEAP32[$97 >> 2] & ~$mask_1 | $mask_1 & $val; //@line 31355
  $_047 = 0; //@line 31357
  return $_047 | 0; //@line 31360
 } else {
  $104 = $c + 88 + ($idx_0_lcssa << 2) | 0; //@line 31362
  HEAP32[$104 >> 2] = HEAP32[$104 >> 2] & ~$mask_1 | $mask_1 & $val; //@line 31368
  $_047 = 0; //@line 31369
  return $_047 | 0; //@line 31372
 }
 return 0;
}
function _e68_set_pc_prefetch($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $1 = 0, $6 = 0, $9 = 0, $10 = 0, $16 = 0, $_0_i_i = 0, $38 = 0, $41 = 0, $46 = 0, $49 = 0, $50 = 0, $56 = 0, $_0_i_i6 = 0, $78 = 0, $81 = 0;
 $1 = $c + 156 | 0; //@line 31391
 HEAP32[$1 >> 2] = $val; //@line 31392
 do {
  if (($val & 1 | 0) == 0) {
   $6 = $c + 164 | 0; //@line 31398
   HEAP16[$c + 162 >> 1] = HEAP16[$6 >> 1] | 0; //@line 31401
   $9 = $val & 16777215; //@line 31402
   $10 = $9 + 1 | 0; //@line 31403
   if ($10 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $16 = HEAP32[$c + 32 >> 2] | 0; //@line 31410
    $_0_i_i = HEAPU8[$16 + $9 | 0] << 8 | HEAPU8[$16 + $10 | 0]; //@line 31420
   } else {
    $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $9) | 0; //@line 31428
   }
   HEAP16[$6 >> 1] = $_0_i_i; //@line 31431
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 31439
    $38 = $c + 152 | 0; //@line 31440
    HEAP32[$38 >> 2] = (HEAP32[$38 >> 2] | 0) + 2; //@line 31443
    break;
   } else {
    _e68_exception_bus($c); //@line 31447
    break;
   }
  } else {
   _e68_exception_address($c, $val, 0, 0); //@line 31452
  }
 } while (0);
 $41 = HEAP32[$1 >> 2] | 0; //@line 31456
 if (($41 & 1 | 0) != 0) {
  _e68_exception_address($c, $41, 0, 0); //@line 31461
  $81 = $c + 152 | 0; //@line 31463
  HEAP32[$81 >> 2] = $val; //@line 31464
  return;
 }
 $46 = $c + 164 | 0; //@line 31468
 HEAP16[$c + 162 >> 1] = HEAP16[$46 >> 1] | 0; //@line 31471
 $49 = $41 & 16777215; //@line 31472
 $50 = $49 + 1 | 0; //@line 31473
 if ($50 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $56 = HEAP32[$c + 32 >> 2] | 0; //@line 31480
  $_0_i_i6 = HEAPU8[$56 + $49 | 0] << 8 | HEAPU8[$56 + $50 | 0]; //@line 31490
 } else {
  $_0_i_i6 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $49) | 0; //@line 31498
 }
 HEAP16[$46 >> 1] = $_0_i_i6; //@line 31501
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 31509
  $78 = $c + 152 | 0; //@line 31510
  HEAP32[$78 >> 2] = (HEAP32[$78 >> 2] | 0) + 2; //@line 31513
  $81 = $c + 152 | 0; //@line 31515
  HEAP32[$81 >> 2] = $val; //@line 31516
  return;
 } else {
  _e68_exception_bus($c); //@line 31520
  $81 = $c + 152 | 0; //@line 31522
  HEAP32[$81 >> 2] = $val; //@line 31523
  return;
 }
}
function _e68_exception_reset($c) {
 $c = $c | 0;
 var $1 = 0, $4 = 0, $9 = 0, $14 = 0, $17 = 0, $18 = 0, $storemerge_i_i = 0, $23 = 0, $24 = 0, $28 = 0, $51 = 0, $52 = 0, $_0_i = 0, $57 = 0, $_0_i15 = 0, $82 = 0, $87 = 0, $90 = 0, $91 = 0, $96 = 0, $_0_i_i17 = 0, $120 = 0, $125 = 0, $128 = 0, $129 = 0, $134 = 0, $_0_i_i = 0, $158 = 0, $159 = 0, $160 = 0, $161 = 0, $162 = 0;
 $1 = $c + 376 | 0; //@line 31553
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 1; //@line 31556
 $4 = $c + 152 | 0; //@line 31557
 HEAP32[$c + 380 >> 2] = HEAP32[$4 >> 2]; //@line 31560
 HEAP32[$c + 384 >> 2] = 0; //@line 31562
 HEAP32[$c + 388 >> 2] = 31032; //@line 31564
 $9 = $c + 166 | 0; //@line 31565
 if ((HEAP16[$9 >> 1] & 8192) == 0) {
  $14 = $c + 334 | 0; //@line 31571
  $17 = $c + 148 | 0; //@line 31574
  $18 = HEAP32[$17 >> 2] | 0; //@line 31575
  if ((HEAP8[$14] | 0) == 0) {
   HEAP32[$c + 168 >> 2] = $18; //@line 31579
   $storemerge_i_i = HEAP32[$c + 172 >> 2] | 0; //@line 31582
  } else {
   HEAP32[$c + 172 >> 2] = $18; //@line 31585
   $storemerge_i_i = $18; //@line 31587
  }
  HEAP32[$17 >> 2] = $storemerge_i_i; //@line 31590
  HEAP8[$14] = 1; //@line 31591
 }
 HEAP16[$9 >> 1] = 9984; //@line 31594
 $23 = $c + 36 | 0; //@line 31595
 $24 = HEAP32[$23 >> 2] | 0; //@line 31596
 if ($24 >>> 0 > 3) {
  $28 = HEAP32[$c + 32 >> 2] | 0; //@line 31601
  $_0_i = ((HEAPU8[$28] << 8 | HEAPU8[$28 + 1 | 0]) << 8 | HEAPU8[$28 + 2 | 0]) << 8 | HEAPU8[$28 + 3 | 0];
  $52 = $24;
 } else {
  $51 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, 0) | 0; //@line 31626
  $_0_i = $51;
  $52 = HEAP32[$23 >> 2] | 0;
 }
 HEAP32[$c + 148 >> 2] = $_0_i; //@line 31634
 if ($52 >>> 0 > 7) {
  $57 = HEAP32[$c + 32 >> 2] | 0; //@line 31639
  $_0_i15 = ((HEAPU8[$57 + 4 | 0] << 8 | HEAPU8[$57 + 5 | 0]) << 8 | HEAPU8[$57 + 6 | 0]) << 8 | HEAPU8[$57 + 7 | 0]; //@line 31659
 } else {
  $_0_i15 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, 4) | 0; //@line 31667
 }
 $82 = $c + 156 | 0; //@line 31670
 HEAP32[$82 >> 2] = $_0_i15; //@line 31671
 do {
  if (($_0_i15 & 1 | 0) == 0) {
   $87 = $c + 164 | 0; //@line 31677
   HEAP16[$c + 162 >> 1] = HEAP16[$87 >> 1] | 0; //@line 31680
   $90 = $_0_i15 & 16777215; //@line 31681
   $91 = $90 + 1 | 0; //@line 31682
   if ($91 >>> 0 < (HEAP32[$23 >> 2] | 0) >>> 0) {
    $96 = HEAP32[$c + 32 >> 2] | 0; //@line 31688
    $_0_i_i17 = HEAPU8[$96 + $90 | 0] << 8 | HEAPU8[$96 + $91 | 0]; //@line 31698
   } else {
    $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $90) | 0; //@line 31706
   }
   HEAP16[$87 >> 1] = $_0_i_i17; //@line 31709
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$82 >> 2] = (HEAP32[$82 >> 2] | 0) + 2; //@line 31717
    HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 31720
    break;
   } else {
    _e68_exception_bus($c); //@line 31724
    break;
   }
  } else {
   _e68_exception_address($c, $_0_i15, 0, 0); //@line 31729
  }
 } while (0);
 $120 = HEAP32[$82 >> 2] | 0; //@line 31733
 if (($120 & 1 | 0) != 0) {
  _e68_exception_address($c, $120, 0, 0); //@line 31738
  $158 = HEAP32[$82 >> 2] | 0; //@line 31740
  $159 = $158 - 4 | 0; //@line 31741
  HEAP32[$4 >> 2] = $159; //@line 31742
  $160 = $c + 372 | 0; //@line 31743
  $161 = HEAP32[$160 >> 2] | 0; //@line 31744
  $162 = $161 + 64 | 0; //@line 31745
  HEAP32[$160 >> 2] = $162; //@line 31746
  return;
 }
 $125 = $c + 164 | 0; //@line 31750
 HEAP16[$c + 162 >> 1] = HEAP16[$125 >> 1] | 0; //@line 31753
 $128 = $120 & 16777215; //@line 31754
 $129 = $128 + 1 | 0; //@line 31755
 if ($129 >>> 0 < (HEAP32[$23 >> 2] | 0) >>> 0) {
  $134 = HEAP32[$c + 32 >> 2] | 0; //@line 31761
  $_0_i_i = HEAPU8[$134 + $128 | 0] << 8 | HEAPU8[$134 + $129 | 0]; //@line 31771
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $128) | 0; //@line 31779
 }
 HEAP16[$125 >> 1] = $_0_i_i; //@line 31782
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$82 >> 2] = (HEAP32[$82 >> 2] | 0) + 2; //@line 31790
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 31793
  $158 = HEAP32[$82 >> 2] | 0; //@line 31795
  $159 = $158 - 4 | 0; //@line 31796
  HEAP32[$4 >> 2] = $159; //@line 31797
  $160 = $c + 372 | 0; //@line 31798
  $161 = HEAP32[$160 >> 2] | 0; //@line 31799
  $162 = $161 + 64 | 0; //@line 31800
  HEAP32[$160 >> 2] = $162; //@line 31801
  return;
 } else {
  _e68_exception_bus($c); //@line 31805
  $158 = HEAP32[$82 >> 2] | 0; //@line 31807
  $159 = $158 - 4 | 0; //@line 31808
  HEAP32[$4 >> 2] = $159; //@line 31809
  $160 = $c + 372 | 0; //@line 31810
  $161 = HEAP32[$160 >> 2] | 0; //@line 31811
  $162 = $161 + 64 | 0; //@line 31812
  HEAP32[$160 >> 2] = $162; //@line 31813
  return;
 }
}
function _e68_exception_bus($c) {
 $c = $c | 0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $11 = 0, $27 = 0, $28 = 0, $29 = 0, $33 = 0, $49 = 0, $50 = 0, $51 = 0;
 HEAP8[$c + 336 | 0] = 0; //@line 31831
 _e68_exception($c, 2, 0, 30088); //@line 31832
 $2 = $c + 148 | 0; //@line 31833
 $3 = HEAP32[$2 >> 2] | 0; //@line 31834
 $4 = $3 - 4 | 0; //@line 31835
 $5 = $4 & 16777215; //@line 31836
 $6 = $5 + 3 | 0; //@line 31837
 $7 = $c + 36 | 0; //@line 31838
 if ($6 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
  $11 = $c + 32 | 0; //@line 31843
  HEAP8[(HEAP32[$11 >> 2] | 0) + $5 | 0] = 0; //@line 31846
  HEAP8[(HEAP32[$11 >> 2] | 0) + ($5 + 1) | 0] = 0; //@line 31850
  HEAP8[(HEAP32[$11 >> 2] | 0) + ($5 + 2) | 0] = 0; //@line 31854
  HEAP8[(HEAP32[$11 >> 2] | 0) + $6 | 0] = 0; //@line 31857
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $5, 0); //@line 31864
 }
 HEAP32[$2 >> 2] = $4; //@line 31866
 $27 = $3 - 8 | 0; //@line 31867
 $28 = $27 & 16777215; //@line 31868
 $29 = $28 + 3 | 0; //@line 31869
 if ($29 >>> 0 < (HEAP32[$7 >> 2] | 0) >>> 0) {
  $33 = $c + 32 | 0; //@line 31874
  HEAP8[(HEAP32[$33 >> 2] | 0) + $28 | 0] = 0; //@line 31877
  HEAP8[(HEAP32[$33 >> 2] | 0) + ($28 + 1) | 0] = 0; //@line 31881
  HEAP8[(HEAP32[$33 >> 2] | 0) + ($28 + 2) | 0] = 0; //@line 31885
  HEAP8[(HEAP32[$33 >> 2] | 0) + $29 | 0] = 0; //@line 31888
  HEAP32[$2 >> 2] = $27; //@line 31890
  $49 = $c + 372 | 0; //@line 31891
  $50 = HEAP32[$49 >> 2] | 0; //@line 31892
  $51 = $50 + 62 | 0; //@line 31893
  HEAP32[$49 >> 2] = $51; //@line 31894
  return;
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $28, 0); //@line 31902
  HEAP32[$2 >> 2] = $27; //@line 31903
  $49 = $c + 372 | 0; //@line 31904
  $50 = HEAP32[$49 >> 2] | 0; //@line 31905
  $51 = $50 + 62 | 0; //@line 31906
  HEAP32[$49 >> 2] = $51; //@line 31907
  return;
 }
}
function _e68_exception($c, $vct, $fmt, $name) {
 $c = $c | 0;
 $vct = $vct | 0;
 $fmt = $fmt | 0;
 $name = $name | 0;
 var $1 = 0, $2 = 0, $5 = 0, $11 = 0, $22 = 0, $23 = 0, $25 = 0, $29 = 0, $32 = 0, $33 = 0, $storemerge_i_i = 0, $44 = 0, $46 = 0, $47 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $58 = 0, $_pre_phi = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $81 = 0, $102 = 0, $103 = 0, $104 = 0, $110 = 0, $125 = 0, $126 = 0, $131 = 0, $158 = 0, $159 = 0, $164 = 0, $167 = 0, $168 = 0, $173 = 0, $_0_i_i = 0, $197 = 0, $202 = 0, $205 = 0, $206 = 0, $211 = 0, $_0_i_i36 = 0;
 $1 = $vct & 255; //@line 31948
 $2 = $c + 376 | 0; //@line 31949
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 1; //@line 31952
 $5 = $c + 152 | 0; //@line 31953
 HEAP32[$c + 380 >> 2] = HEAP32[$5 >> 2]; //@line 31956
 HEAP32[$c + 384 >> 2] = $1; //@line 31958
 HEAP32[$c + 388 >> 2] = $name; //@line 31960
 $11 = HEAP32[$c + 80 >> 2] | 0; //@line 31962
 if (($11 | 0) != 0) {
  FUNCTION_TABLE_vii[$11 & 511](HEAP32[$c + 68 >> 2] | 0, $1); //@line 31968
 }
 if (($1 | 0) != 7 & ($1 - 32 | 0) >>> 0 > 15) {
  HEAP16[$c + 332 >> 1] = 0; //@line 31978
 }
 $22 = $c + 166 | 0; //@line 31981
 $23 = HEAP16[$22 >> 1] | 0; //@line 31982
 $25 = $23 & 1823 | 8192; //@line 31984
 if (($23 & 8192) == 0) {
  $29 = $c + 334 | 0; //@line 31989
  $32 = $c + 148 | 0; //@line 31992
  $33 = HEAP32[$32 >> 2] | 0; //@line 31993
  if ((HEAP8[$29] | 0) == 0) {
   HEAP32[$c + 168 >> 2] = $33; //@line 31997
   $storemerge_i_i = HEAP32[$c + 172 >> 2] | 0; //@line 32000
  } else {
   HEAP32[$c + 172 >> 2] = $33; //@line 32003
   $storemerge_i_i = $33; //@line 32005
  }
  HEAP32[$32 >> 2] = $storemerge_i_i; //@line 32008
  HEAP8[$29] = 1; //@line 32009
 }
 HEAP16[$22 >> 1] = $25; //@line 32012
 if ((HEAP32[$c >> 2] & 2 | 0) == 0) {
  $70 = HEAP32[$c + 148 >> 2] | 0;
  $_pre_phi = $c + 36 | 0;
 } else {
  $44 = $1 << 2; //@line 32026
  $46 = ($fmt << 12 | $44) & 65535; //@line 32028
  $47 = $c + 148 | 0; //@line 32029
  $49 = (HEAP32[$47 >> 2] | 0) - 2 | 0; //@line 32031
  $50 = $49 & 16777215; //@line 32032
  $51 = $50 + 1 | 0; //@line 32033
  $52 = $c + 36 | 0; //@line 32034
  if ($51 >>> 0 < (HEAP32[$52 >> 2] | 0) >>> 0) {
   $58 = $c + 32 | 0; //@line 32041
   HEAP8[(HEAP32[$58 >> 2] | 0) + $50 | 0] = ($46 & 65535) >>> 8 & 255; //@line 32044
   HEAP8[(HEAP32[$58 >> 2] | 0) + $51 | 0] = $44 & 255; //@line 32048
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 24 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $50, $46); //@line 32055
  }
  HEAP32[$47 >> 2] = $49; //@line 32057
  $70 = $49;
  $_pre_phi = $52;
 }
 $71 = HEAP32[$5 >> 2] | 0; //@line 32063
 $72 = $c + 148 | 0; //@line 32064
 $73 = $70 - 4 | 0; //@line 32065
 $74 = $73 & 16777215; //@line 32066
 $75 = $74 + 3 | 0; //@line 32067
 if ($75 >>> 0 < (HEAP32[$_pre_phi >> 2] | 0) >>> 0) {
  $81 = $c + 32 | 0; //@line 32074
  HEAP8[(HEAP32[$81 >> 2] | 0) + $74 | 0] = $71 >>> 24 & 255; //@line 32077
  HEAP8[(HEAP32[$81 >> 2] | 0) + ($74 + 1) | 0] = $71 >>> 16 & 255; //@line 32083
  HEAP8[(HEAP32[$81 >> 2] | 0) + ($74 + 2) | 0] = $71 >>> 8 & 255; //@line 32089
  HEAP8[(HEAP32[$81 >> 2] | 0) + $75 | 0] = $71 & 255; //@line 32093
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $74, $71); //@line 32100
 }
 HEAP32[$72 >> 2] = $73; //@line 32102
 $102 = $70 - 6 | 0; //@line 32103
 $103 = $102 & 16777215; //@line 32104
 $104 = $103 + 1 | 0; //@line 32105
 if ($104 >>> 0 < (HEAP32[$_pre_phi >> 2] | 0) >>> 0) {
  $110 = $c + 32 | 0; //@line 32112
  HEAP8[(HEAP32[$110 >> 2] | 0) + $103 | 0] = ($23 & 65535) >>> 8 & 255; //@line 32115
  HEAP8[(HEAP32[$110 >> 2] | 0) + $104 | 0] = $23 & 255; //@line 32119
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 24 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $103, $23); //@line 32126
 }
 HEAP32[$72 >> 2] = $102; //@line 32128
 $125 = (HEAP32[$c + 176 >> 2] | 0) + ($1 << 2) & 16777215; //@line 32133
 $126 = $125 + 3 | 0; //@line 32134
 if ($126 >>> 0 < (HEAP32[$_pre_phi >> 2] | 0) >>> 0) {
  $131 = HEAP32[$c + 32 >> 2] | 0; //@line 32140
  $158 = ((HEAPU8[$131 + $125 | 0] << 8 | HEAPU8[$131 + ($125 + 1) | 0]) << 8 | HEAPU8[$131 + ($125 + 2) | 0]) << 8 | HEAPU8[$131 + $126 | 0]; //@line 32162
 } else {
  $158 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $125) | 0; //@line 32170
 }
 $159 = $c + 156 | 0; //@line 32173
 HEAP32[$159 >> 2] = $158; //@line 32174
 do {
  if (($158 & 1 | 0) == 0) {
   $164 = $c + 164 | 0; //@line 32180
   HEAP16[$c + 162 >> 1] = HEAP16[$164 >> 1] | 0; //@line 32183
   $167 = $158 & 16777215; //@line 32184
   $168 = $167 + 1 | 0; //@line 32185
   if ($168 >>> 0 < (HEAP32[$_pre_phi >> 2] | 0) >>> 0) {
    $173 = HEAP32[$c + 32 >> 2] | 0; //@line 32191
    $_0_i_i = HEAPU8[$173 + $167 | 0] << 8 | HEAPU8[$173 + $168 | 0]; //@line 32201
   } else {
    $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $167) | 0; //@line 32209
   }
   HEAP16[$164 >> 1] = $_0_i_i; //@line 32212
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$159 >> 2] = (HEAP32[$159 >> 2] | 0) + 2; //@line 32220
    HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 32223
    break;
   } else {
    _e68_exception_bus($c); //@line 32227
    break;
   }
  } else {
   _e68_exception_address($c, $158, 0, 0); //@line 32232
  }
 } while (0);
 $197 = HEAP32[$159 >> 2] | 0; //@line 32236
 if (($197 & 1 | 0) != 0) {
  _e68_exception_address($c, $197, 0, 0); //@line 32241
  HEAP32[$5 >> 2] = $158; //@line 32243
  return;
 }
 $202 = $c + 164 | 0; //@line 32247
 HEAP16[$c + 162 >> 1] = HEAP16[$202 >> 1] | 0; //@line 32250
 $205 = $197 & 16777215; //@line 32251
 $206 = $205 + 1 | 0; //@line 32252
 if ($206 >>> 0 < (HEAP32[$_pre_phi >> 2] | 0) >>> 0) {
  $211 = HEAP32[$c + 32 >> 2] | 0; //@line 32258
  $_0_i_i36 = HEAPU8[$211 + $205 | 0] << 8 | HEAPU8[$211 + $206 | 0]; //@line 32268
 } else {
  $_0_i_i36 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $205) | 0; //@line 32276
 }
 HEAP16[$202 >> 1] = $_0_i_i36; //@line 32279
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$159 >> 2] = (HEAP32[$159 >> 2] | 0) + 2; //@line 32287
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 32290
  HEAP32[$5 >> 2] = $158; //@line 32292
  return;
 } else {
  _e68_exception_bus($c); //@line 32296
  HEAP32[$5 >> 2] = $158; //@line 32298
  return;
 }
}
function _e68_exception_address($c, $addr, $data, $wr) {
 $c = $c | 0;
 $addr = $addr | 0;
 $data = $data | 0;
 $wr = $wr | 0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $14 = 0, $25 = 0, $26 = 0, $27 = 0, $33 = 0, $_ = 0, $val_1 = 0, $57 = 0, $58 = 0, $59 = 0, $63 = 0, $74 = 0, $75 = 0, $76 = 0;
 _e68_exception($c, 3, 8, 58064); //@line 32321
 $2 = HEAP16[$c + 160 >> 1] | 0; //@line 32323
 $3 = $c + 148 | 0; //@line 32324
 $4 = HEAP32[$3 >> 2] | 0; //@line 32325
 $5 = $4 - 2 | 0; //@line 32326
 $6 = $5 & 16777215; //@line 32327
 $7 = $6 + 1 | 0; //@line 32328
 $8 = $c + 36 | 0; //@line 32329
 if ($7 >>> 0 < (HEAP32[$8 >> 2] | 0) >>> 0) {
  $14 = $c + 32 | 0; //@line 32336
  HEAP8[(HEAP32[$14 >> 2] | 0) + $6 | 0] = ($2 & 65535) >>> 8 & 255; //@line 32339
  HEAP8[(HEAP32[$14 >> 2] | 0) + $7 | 0] = $2 & 255; //@line 32343
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 24 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $6, $2); //@line 32350
 }
 HEAP32[$3 >> 2] = $5; //@line 32352
 $25 = $4 - 6 | 0; //@line 32353
 $26 = $25 & 16777215; //@line 32354
 $27 = $26 + 3 | 0; //@line 32355
 if ($27 >>> 0 < (HEAP32[$8 >> 2] | 0) >>> 0) {
  $33 = $c + 32 | 0; //@line 32362
  HEAP8[(HEAP32[$33 >> 2] | 0) + $26 | 0] = $addr >>> 24 & 255; //@line 32365
  HEAP8[(HEAP32[$33 >> 2] | 0) + ($26 + 1) | 0] = $addr >>> 16 & 255; //@line 32371
  HEAP8[(HEAP32[$33 >> 2] | 0) + ($26 + 2) | 0] = $addr >>> 8 & 255; //@line 32377
  HEAP8[(HEAP32[$33 >> 2] | 0) + $27 | 0] = $addr & 255; //@line 32381
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26, $addr); //@line 32388
 }
 HEAP32[$3 >> 2] = $25; //@line 32390
 $_ = ($wr | 0) == 0 ? 16 : 0; //@line 32392
 $val_1 = ($data | 0) == 0 ? $_ : $_ | 8; //@line 32395
 $57 = $4 - 8 | 0; //@line 32396
 $58 = $57 & 16777215; //@line 32397
 $59 = $58 + 1 | 0; //@line 32398
 if ($59 >>> 0 < (HEAP32[$8 >> 2] | 0) >>> 0) {
  $63 = $c + 32 | 0; //@line 32403
  HEAP8[(HEAP32[$63 >> 2] | 0) + $58 | 0] = 0; //@line 32406
  HEAP8[(HEAP32[$63 >> 2] | 0) + $59 | 0] = $val_1 & 255; //@line 32410
  HEAP32[$3 >> 2] = $57; //@line 32412
  $74 = $c + 372 | 0; //@line 32413
  $75 = HEAP32[$74 >> 2] | 0; //@line 32414
  $76 = $75 + 64 | 0; //@line 32415
  HEAP32[$74 >> 2] = $76; //@line 32416
  return;
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 24 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $58, $val_1); //@line 32424
  HEAP32[$3 >> 2] = $57; //@line 32425
  $74 = $c + 372 | 0; //@line 32426
  $75 = HEAP32[$74 >> 2] | 0; //@line 32427
  $76 = $75 + 64 | 0; //@line 32428
  HEAP32[$74 >> 2] = $76; //@line 32429
  return;
 }
}
function _e68_interrupt($c, $level) {
 $c = $c | 0;
 $level = $level | 0;
 var $2 = 0;
 do {
  if (($level | 0) != 0) {
   $2 = $c + 335 | 0; //@line 32447
   HEAP8[$2] = HEAP8[$2] & -2; //@line 32450
   if (($level | 0) != 7) {
    break;
   }
   if ((HEAP32[$c + 364 >> 2] | 0) == 7) {
    break;
   }
   HEAP8[$c + 368 | 0] = 1; //@line 32464
  }
 } while (0);
 HEAP32[$c + 364 >> 2] = $level; //@line 32469
 return;
}
function _e68_exception_illegal($c) {
 $c = $c | 0;
 var $2 = 0, $11 = 0;
 $2 = HEAP32[$c + 76 >> 2] | 0; //@line 32482
 if (($2 | 0) != 0) {
  FUNCTION_TABLE_vii[$2 & 511](HEAP32[$c + 68 >> 2] | 0, HEAPU16[$c + 160 >> 1] | 0); //@line 32491
 }
 _e68_exception($c, 4, 0, 57272); //@line 32494
 $11 = $c + 372 | 0; //@line 32495
 HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 62; //@line 32498
 return;
}
function _e68_exception_divzero($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 5, 0, 56080); //@line 32509
 $1 = $c + 372 | 0; //@line 32510
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 66; //@line 32513
 return;
}
function _e68_exception_check($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 6, 0, 55312); //@line 32524
 $1 = $c + 372 | 0; //@line 32525
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 68; //@line 32528
 return;
}
function _e68_exception_overflow($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 7, 0, 54648); //@line 32539
 $1 = $c + 372 | 0; //@line 32540
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 68; //@line 32543
 return;
}
function _e68_exception_privilege($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 8, 0, 53960); //@line 32554
 $1 = $c + 372 | 0; //@line 32555
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 62; //@line 32558
 return;
}
function _e68_exception_axxx($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 10, 0, 52528); //@line 32569
 $1 = $c + 372 | 0; //@line 32570
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 62; //@line 32573
 return;
}
function _e68_exception_fxxx($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 11, 0, 51864); //@line 32584
 $1 = $c + 372 | 0; //@line 32585
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 62; //@line 32588
 return;
}
function _e68_exception_format($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception($c, 14, 0, 51336); //@line 32599
 $1 = $c + 372 | 0; //@line 32600
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 62; //@line 32603
 return;
}
function _e68_exception_trap($c, $n) {
 $c = $c | 0;
 $n = $n | 0;
 var $2 = 0;
 _e68_exception($c, $n + 32 | 0, 0, 50504); //@line 32616
 $2 = $c + 372 | 0; //@line 32617
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 62; //@line 32620
 return;
}
function _e68_reset($c) {
 $c = $c | 0;
 var $1 = 0, $5 = 0, $6 = 0, $11 = 0, $15 = 0, $16 = 0, $19 = 0, $20 = 0, $_pre24 = 0, $_pre_phi26_ph = 0, $40 = 0, label = 0;
 $1 = $c + 48 | 0; //@line 32635
 if ((HEAP8[$1] | 0) != 0) {
  return;
 }
 HEAP8[$1] = 1; //@line 32643
 $5 = $c + 44 | 0; //@line 32644
 $6 = HEAP32[$5 >> 2] | 0; //@line 32645
 if (($6 | 0) != 0) {
  FUNCTION_TABLE_vii[$6 & 511](HEAP32[$c + 40 >> 2] | 0, 1); //@line 32651
 }
 $11 = $c + 166 | 0; //@line 32654
 $15 = $c + 334 | 0; //@line 32658
 $16 = HEAP8[$15] | 0; //@line 32659
 do {
  if ((HEAP16[$11 >> 1] & 8192) == 0) {
   $19 = $c + 148 | 0; //@line 32664
   $20 = HEAP32[$19 >> 2] | 0; //@line 32665
   if ($16 << 24 >> 24 == 0) {
    HEAP32[$c + 168 >> 2] = $20; //@line 32669
   } else {
    HEAP32[$c + 172 >> 2] = $20; //@line 32672
   }
   HEAP8[$15] = 1; //@line 32675
   HEAP16[$11 >> 1] = 8192; //@line 32676
   _memset($c + 88 | 0, 0, 60); //@line 32679
   HEAP32[$19 >> 2] = 0; //@line 32680
   $_pre_phi26_ph = $19; //@line 32682
   label = 3619; //@line 32683
  } else {
   $_pre24 = $c + 148 | 0; //@line 32685
   HEAP16[$11 >> 1] = 8192; //@line 32687
   _memset($c + 88 | 0, 0, 60); //@line 32690
   HEAP32[$_pre24 >> 2] = 0; //@line 32691
   if ($16 << 24 >> 24 != 0) {
    $_pre_phi26_ph = $_pre24; //@line 32694
    label = 3619; //@line 32695
    break;
   }
   HEAP32[$_pre24 >> 2] = 0; //@line 32698
   HEAP32[$c + 172 >> 2] = 0; //@line 32700
  }
 } while (0);
 if ((label | 0) == 3619) {
  HEAP32[$c + 168 >> 2] = 0; //@line 32706
  HEAP32[$_pre_phi26_ph >> 2] = 0; //@line 32707
 }
 HEAP8[$c + 335 | 0] = 0; //@line 32712
 HEAP8[$c + 336 | 0] = 0; //@line 32714
 _memset($c + 176 | 0, 0, 16); //@line 32716
 _e68_exception_reset($c); //@line 32717
 if ((HEAP8[$1] | 0) == 0) {
  return;
 }
 HEAP8[$1] = 0; //@line 32725
 $40 = HEAP32[$5 >> 2] | 0; //@line 32726
 if (($40 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$40 & 511](HEAP32[$c + 40 >> 2] | 0, 0); //@line 32735
 return;
}
function _e68_execute($c) {
 $c = $c | 0;
 var $2 = 0, $3 = 0, $5 = 0, $9 = 0, $11 = 0, $13 = 0, $21 = 0, $27 = 0, $31 = 0, $37 = 0, $42 = 0, $52 = 0, $57 = 0, $67 = 0, $78 = 0;
 $2 = HEAP32[$c + 152 >> 2] | 0; //@line 32756
 $3 = $c + 196 | 0; //@line 32757
 $5 = (HEAP32[$3 >> 2] | 0) + 1 | 0; //@line 32759
 HEAP32[$3 >> 2] = $5; //@line 32760
 HEAP32[$c + 200 + (($5 & 31) << 2) >> 2] = $2; //@line 32763
 HEAP8[$c + 336 | 0] = 0; //@line 32765
 $9 = $c + 166 | 0; //@line 32766
 $11 = $c + 332 | 0; //@line 32768
 HEAP16[$11 >> 1] = HEAP16[$9 >> 1] | 0; //@line 32769
 $13 = HEAP16[$c + 162 >> 1] | 0; //@line 32771
 HEAP16[$c + 160 >> 1] = $13; //@line 32773
 FUNCTION_TABLE_vi[HEAP32[$c + 400 + (($13 & 65535) >>> 6 << 2) >> 2] & 1023]($c); //@line 32780
 $21 = $c + 392 | 0; //@line 32781
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 1; //@line 32784
 if ((HEAP16[$11 >> 1] | 0) < 0) {
  _e68_exception($c, 9, 0, 53384); //@line 32789
  $27 = $c + 372 | 0; //@line 32790
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 62; //@line 32793
 }
 $31 = $c + 368 | 0; //@line 32796
 if ((HEAP8[$31] | 0) != 0) {
  _e68_exception($c, 31, 0, 50824); //@line 32801
  HEAP16[$9 >> 1] = HEAP16[$9 >> 1] | 1792; //@line 32804
  $37 = $c + 372 | 0; //@line 32805
  HEAP32[$37 >> 2] = (HEAP32[$37 >> 2] | 0) + 62; //@line 32808
  HEAP8[$31] = 0; //@line 32809
  return;
 }
 $42 = HEAP32[$c + 364 >> 2] | 0; //@line 32815
 if (($42 | 0) == 0) {
  return;
 }
 if (((HEAPU16[$9 >> 1] | 0) >>> 8 & 7) >>> 0 >= $42 >>> 0) {
  return;
 }
 $52 = HEAP32[$c + 56 >> 2] | 0; //@line 32833
 do {
  if (($52 | 0) != 0) {
   $57 = FUNCTION_TABLE_iii[$52 & 63](HEAP32[$c + 52 >> 2] | 0, $42) | 0; //@line 32840
   if ($57 >>> 0 >= 256) {
    break;
   }
   _e68_exception($c, $57, 0, 49560); //@line 32846
   HEAP16[$9 >> 1] = (HEAP16[$9 >> 1] & -1793 & 65535 | $42 << 8 & 1792) & 65535; //@line 32854
   $67 = $c + 372 | 0; //@line 32855
   HEAP32[$67 >> 2] = (HEAP32[$67 >> 2] | 0) + 62; //@line 32858
   return;
  }
 } while (0);
 _e68_exception($c, $42 + 24 | 0, 0, 50824); //@line 32865
 HEAP16[$9 >> 1] = (HEAP16[$9 >> 1] & -1793 & 65535 | $42 << 8 & 1792) & 65535; //@line 32873
 $78 = $c + 372 | 0; //@line 32874
 HEAP32[$78 >> 2] = (HEAP32[$78 >> 2] | 0) + 62; //@line 32877
 return;
}
function _e68_clock($c, $n) {
 $c = $c | 0;
 $n = $n | 0;
 var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $_0 = 0, $8 = 0, $14 = 0, $23 = 0, $_1 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 32891
 $1 = $c + 372 | 0; //@line 32892
 $2 = $c + 396 | 0; //@line 32893
 $3 = $c + 335 | 0; //@line 32894
 $_0 = $n;
 $5 = HEAP32[$1 >> 2] | 0;
 while (1) {
  if ($_0 >>> 0 < $5 >>> 0) {
   $_1 = $_0;
   $23 = $5;
   break;
  }
  $8 = $_0 - $5 | 0; //@line 32907
  HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + $5; //@line 32910
  HEAP32[$1 >> 2] = 0; //@line 32911
  if ((HEAP8[$3] | 0) != 0) {
   label = 3653; //@line 32916
   break;
  }
  _e68_execute($c); //@line 32919
  $14 = HEAP32[$1 >> 2] | 0; //@line 32920
  if (($14 | 0) == 0) {
   label = 3649; //@line 32924
   break;
  } else {
   $_0 = $8;
   $5 = $14;
  }
 }
 if ((label | 0) == 3653) {
  STACKTOP = sp; //@line 32931
  return;
 } else if ((label | 0) == 3649) {
  _fprintf(HEAP32[_stderr >> 2] | 0, 49080, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$c + 152 >> 2], tempInt) | 0) | 0; //@line 32938
  _fflush(HEAP32[_stderr >> 2] | 0) | 0; //@line 32940
  $_1 = $8;
  $23 = HEAP32[$1 >> 2] | 0;
 }
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + $_1; //@line 32949
 HEAP32[$1 >> 2] = $23 - $_1; //@line 32951
 STACKTOP = sp; //@line 32953
 return;
}
function _e68_op_dbcc($c, $cond) {
 $c = $c | 0;
 $cond = $cond | 0;
 var $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $42 = 0, $44 = 0, $48 = 0, $51 = 0, $58 = 0, $59 = 0, $63 = 0, $76 = 0, $phitmp = 0, $88 = 0, $89 = 0, $92 = 0, $95 = 0, $96 = 0, $99 = 0, $105 = 0, $106 = 0, $111 = 0, $_0_i_i22 = 0, $136 = 0, $142 = 0, $143 = 0, $148 = 0, $163 = 0, $169 = 0, $176 = 0, $177 = 0, $181 = 0, $194 = 0, $phitmp35 = 0, $197 = 0;
 $1 = $c + 156 | 0; //@line 32985
 $2 = HEAP32[$1 >> 2] | 0; //@line 32986
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 32991
  return;
 }
 $7 = $c + 164 | 0; //@line 32996
 $9 = $c + 162 | 0; //@line 32998
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 32999
 $10 = $2 & 16777215; //@line 33000
 $11 = $10 + 1 | 0; //@line 33001
 $12 = $c + 36 | 0; //@line 33002
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 33008
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 33018
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 33026
 }
 HEAP16[$7 >> 1] = $32; //@line 33029
 $33 = $c + 336 | 0; //@line 33030
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 33035
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 33041
 HEAP32[$1 >> 2] = $39; //@line 33042
 $40 = $c + 152 | 0; //@line 33043
 $42 = (HEAP32[$40 >> 2] | 0) + 2 | 0; //@line 33045
 HEAP32[$40 >> 2] = $42; //@line 33046
 $44 = HEAPU16[$9 >> 1] | 0; //@line 33048
 $48 = ($44 & 32768 | 0) != 0 ? $44 | -65536 : $44; //@line 33052
 if (($cond | 0) != 0) {
  $51 = $c + 372 | 0; //@line 33056
  HEAP32[$51 >> 2] = (HEAP32[$51 >> 2] | 0) + 12; //@line 33059
  if (($39 & 1 | 0) != 0) {
   _e68_exception_address($c, $39, 0, 0); //@line 33064
   return;
  }
  HEAP16[$9 >> 1] = $32; //@line 33069
  $58 = $39 & 16777215; //@line 33070
  $59 = $58 + 1 | 0; //@line 33071
  do {
   if ($59 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
    $63 = HEAP32[$c + 32 >> 2] | 0; //@line 33078
    HEAP16[$7 >> 1] = HEAPU8[$63 + $58 | 0] << 8 | HEAPU8[$63 + $59 | 0]; //@line 33087
   } else {
    $76 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $58) | 0; //@line 33094
    $phitmp = (HEAP8[$33] | 0) == 0; //@line 33096
    HEAP16[$7 >> 1] = $76; //@line 33097
    if ($phitmp) {
     break;
    }
    _e68_exception_bus($c); //@line 33102
    return;
   }
  } while (0);
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 33110
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 33113
  return;
 }
 $88 = $c + 88 + ((HEAP16[$c + 160 >> 1] & 7) << 2) | 0; //@line 33122
 $89 = HEAP32[$88 >> 2] | 0; //@line 33123
 $92 = $89 + 65535 & 65535; //@line 33126
 HEAP32[$88 >> 2] = $92 | $89 & -65536; //@line 33128
 $95 = $c + 372 | 0; //@line 33130
 $96 = HEAP32[$95 >> 2] | 0; //@line 33131
 if (($92 | 0) == 65535) {
  HEAP32[$95 >> 2] = $96 + 14; //@line 33135
  $99 = HEAP32[$1 >> 2] | 0; //@line 33136
  if (($99 & 1 | 0) != 0) {
   _e68_exception_address($c, $99, 0, 0); //@line 33141
   return;
  }
  HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 33147
  $105 = $99 & 16777215; //@line 33148
  $106 = $105 + 1 | 0; //@line 33149
  if ($106 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $111 = HEAP32[$c + 32 >> 2] | 0; //@line 33155
   $_0_i_i22 = HEAPU8[$111 + $105 | 0] << 8 | HEAPU8[$111 + $106 | 0]; //@line 33165
  } else {
   $_0_i_i22 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $105) | 0; //@line 33173
  }
  HEAP16[$7 >> 1] = $_0_i_i22; //@line 33176
  if ((HEAP8[$33] | 0) == 0) {
   HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 33183
   HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 33186
   return;
  } else {
   _e68_exception_bus($c); //@line 33191
   return;
  }
 }
 HEAP32[$95 >> 2] = $96 + 10; //@line 33198
 $136 = $48 + $42 | 0; //@line 33199
 HEAP32[$1 >> 2] = $136; //@line 33200
 if (($136 & 1 | 0) != 0) {
  _e68_exception_address($c, $136, 0, 0); //@line 33205
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 33211
 $142 = $136 & 16777215; //@line 33212
 $143 = $142 + 1 | 0; //@line 33213
 if ($143 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $148 = HEAP32[$c + 32 >> 2] | 0; //@line 33219
  $163 = HEAPU8[$148 + $142 | 0] << 8 | HEAPU8[$148 + $143 | 0]; //@line 33229
 } else {
  $163 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $142) | 0; //@line 33237
 }
 HEAP16[$7 >> 1] = $163; //@line 33240
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 33245
  return;
 }
 $169 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 33251
 HEAP32[$1 >> 2] = $169; //@line 33252
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 33255
 if (($169 & 1 | 0) != 0) {
  _e68_exception_address($c, $169, 0, 0); //@line 33260
  return;
 }
 HEAP16[$9 >> 1] = $163; //@line 33265
 $176 = $169 & 16777215; //@line 33266
 $177 = $176 + 1 | 0; //@line 33267
 do {
  if ($177 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $181 = HEAP32[$c + 32 >> 2] | 0; //@line 33274
   HEAP16[$7 >> 1] = HEAPU8[$181 + $176 | 0] << 8 | HEAPU8[$181 + $177 | 0]; //@line 33283
  } else {
   $194 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $176) | 0; //@line 33290
   $phitmp35 = (HEAP8[$33] | 0) == 0; //@line 33292
   HEAP16[$7 >> 1] = $194; //@line 33293
   if ($phitmp35) {
    break;
   }
   _e68_exception_bus($c); //@line 33298
   return;
  }
 } while (0);
 $197 = HEAP32[$1 >> 2] | 0; //@line 33304
 HEAP32[$1 >> 2] = $197 + 2; //@line 33306
 HEAP32[$40 >> 2] = $197 - 2; //@line 33308
 return;
}
function _e68_set_opcodes($c) {
 $c = $c | 0;
 var $i_013 = 0, $3 = 0;
 $i_013 = 0; //@line 33322
 do {
  $3 = HEAP32[16472 + ($i_013 << 2) >> 2] | 0; //@line 33326
  HEAP32[$c + 400 + ($i_013 << 2) >> 2] = ($3 | 0) == 0 ? 396 : $3; //@line 33330
  $i_013 = $i_013 + 1 | 0; //@line 33331
 } while ($i_013 >>> 0 < 1024);
 HEAP32[$c + 4496 >> 2] = 396; //@line 33341
 HEAP32[$c + 4500 >> 2] = 282; //@line 33343
 HEAP32[$c + 4504 >> 2] = 282; //@line 33345
 HEAP32[$c + 4508 >> 2] = 282; //@line 33347
 HEAP32[$c + 4512 >> 2] = 282; //@line 33349
 HEAP32[$c + 4516 >> 2] = 282; //@line 33351
 HEAP32[$c + 4520 >> 2] = 282; //@line 33353
 HEAP32[$c + 4524 >> 2] = 282; //@line 33355
 return;
}
function _e68_op_scc($c, $cond) {
 $c = $c | 0;
 $cond = $cond | 0;
 var $1 = 0, $7 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $34 = 0, $_0_i_i = 0, $56 = 0;
 $1 = $c + 372 | 0; //@line 33373
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 4; //@line 33376
 $7 = HEAP16[$c + 160 >> 1] & 63; //@line 33380
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($7 << 2) >> 2] & 127]($c, $7, 509, 8) | 0) != 0) {
  return;
 }
 if ((_e68_ea_set_val8($c, (($cond | 0) != 0) << 31 >> 31) | 0) != 0) {
  return;
 }
 $18 = $c + 156 | 0; //@line 33399
 $19 = HEAP32[$18 >> 2] | 0; //@line 33400
 if (($19 & 1 | 0) != 0) {
  _e68_exception_address($c, $19, 0, 0); //@line 33405
  return;
 }
 $24 = $c + 164 | 0; //@line 33410
 HEAP16[$c + 162 >> 1] = HEAP16[$24 >> 1] | 0; //@line 33413
 $27 = $19 & 16777215; //@line 33414
 $28 = $27 + 1 | 0; //@line 33415
 if ($28 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $34 = HEAP32[$c + 32 >> 2] | 0; //@line 33422
  $_0_i_i = HEAPU8[$34 + $27 | 0] << 8 | HEAPU8[$34 + $28 | 0]; //@line 33432
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $27) | 0; //@line 33440
 }
 HEAP16[$24 >> 1] = $_0_i_i; //@line 33443
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 33451
  $56 = $c + 152 | 0; //@line 33452
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 2; //@line 33455
  return;
 } else {
  _e68_exception_bus($c); //@line 33460
  return;
 }
}
function _e68_op_undefined($c) {
 $c = $c | 0;
 var $1 = 0;
 _e68_exception_illegal($c); //@line 33473
 $1 = $c + 372 | 0; //@line 33474
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 33477
 return;
}
function _op41c0($c) {
 $c = $c | 0;
 var $1 = 0, $4 = 0, $15 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0;
 $1 = $c + 160 | 0; //@line 33495
 $4 = HEAP16[$1 >> 1] & 63; //@line 33498
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 2020, 32) | 0) != 0) {
  return;
 }
 if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
  _e68_exception_illegal($c); //@line 33513
  return;
 }
 $15 = $c + 372 | 0; //@line 33518
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 4; //@line 33521
 HEAP32[$c + 120 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] = HEAP32[$c + 344 >> 2]; //@line 33529
 $25 = $c + 156 | 0; //@line 33530
 $26 = HEAP32[$25 >> 2] | 0; //@line 33531
 if (($26 & 1 | 0) != 0) {
  _e68_exception_address($c, $26, 0, 0); //@line 33536
  return;
 }
 $31 = $c + 164 | 0; //@line 33541
 HEAP16[$c + 162 >> 1] = HEAP16[$31 >> 1] | 0; //@line 33544
 $34 = $26 & 16777215; //@line 33545
 $35 = $34 + 1 | 0; //@line 33546
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 33553
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 33563
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 33571
 }
 HEAP16[$31 >> 1] = $_0_i_i; //@line 33574
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 2; //@line 33582
  $63 = $c + 152 | 0; //@line 33583
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 33586
  return;
 } else {
  _e68_exception_bus($c); //@line 33591
  return;
 }
}
function _op0000($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $47 = 0, $50 = 0, $57 = 0, $58 = 0, $62 = 0, $75 = 0, $phitmp = 0, $82 = 0, $83 = 0, $99 = 0, $100 = 0, $103 = 0, $109 = 0, $110 = 0, $115 = 0, $_0_i_i20 = 0, sp = 0;
 sp = STACKTOP; //@line 33618
 STACKTOP = STACKTOP + 8 | 0; //@line 33618
 $s2 = sp | 0; //@line 33619
 $1 = $c + 156 | 0; //@line 33620
 $2 = HEAP32[$1 >> 2] | 0; //@line 33621
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 33626
  STACKTOP = sp; //@line 33628
  return;
 }
 $7 = $c + 164 | 0; //@line 33631
 $9 = $c + 162 | 0; //@line 33633
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 33634
 $10 = $2 & 16777215; //@line 33635
 $11 = $10 + 1 | 0; //@line 33636
 $12 = $c + 36 | 0; //@line 33637
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 33643
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 33653
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 33661
 }
 HEAP16[$7 >> 1] = $32; //@line 33664
 $33 = $c + 336 | 0; //@line 33665
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 33670
  STACKTOP = sp; //@line 33672
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 33676
 HEAP32[$1 >> 2] = $39; //@line 33677
 $40 = $c + 152 | 0; //@line 33678
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 33681
 $43 = HEAP16[$9 >> 1] | 0; //@line 33682
 $47 = HEAP16[$c + 160 >> 1] & 63; //@line 33686
 if (($47 | 0) == 60) {
  $50 = $c + 372 | 0; //@line 33690
  HEAP32[$50 >> 2] = (HEAP32[$50 >> 2] | 0) + 20; //@line 33693
  if (($39 & 1 | 0) != 0) {
   _e68_exception_address($c, $39, 0, 0); //@line 33698
   STACKTOP = sp; //@line 33700
   return;
  }
  HEAP16[$9 >> 1] = $32; //@line 33703
  $57 = $39 & 16777215; //@line 33704
  $58 = $57 + 1 | 0; //@line 33705
  do {
   if ($58 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
    $62 = HEAP32[$c + 32 >> 2] | 0; //@line 33712
    HEAP16[$7 >> 1] = HEAPU8[$62 + $57 | 0] << 8 | HEAPU8[$62 + $58 | 0]; //@line 33721
   } else {
    $75 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $57) | 0; //@line 33728
    $phitmp = (HEAP8[$33] | 0) == 0; //@line 33730
    HEAP16[$7 >> 1] = $75; //@line 33731
    if ($phitmp) {
     break;
    }
    _e68_exception_bus($c); //@line 33736
    STACKTOP = sp; //@line 33738
    return;
   }
  } while (0);
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 33744
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 33747
  $82 = $c + 166 | 0; //@line 33748
  $83 = HEAP16[$82 >> 1] | 0; //@line 33749
  HEAP16[$82 >> 1] = ($83 | $43) & 31 | $83 & -256; //@line 33754
  STACKTOP = sp; //@line 33756
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($47 << 2) >> 2] & 127]($c, $47, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 33765
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 33772
  return;
 }
 $99 = HEAP8[$s2] | $43 & 255; //@line 33777
 $100 = $c + 372 | 0; //@line 33778
 HEAP32[$100 >> 2] = (HEAP32[$100 >> 2] | 0) + 8; //@line 33781
 _e68_cc_set_nz_8($c, 15, $99); //@line 33782
 $103 = HEAP32[$1 >> 2] | 0; //@line 33783
 if (($103 & 1 | 0) != 0) {
  _e68_exception_address($c, $103, 0, 0); //@line 33788
  STACKTOP = sp; //@line 33790
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 33794
 $109 = $103 & 16777215; //@line 33795
 $110 = $109 + 1 | 0; //@line 33796
 if ($110 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $115 = HEAP32[$c + 32 >> 2] | 0; //@line 33802
  $_0_i_i20 = HEAPU8[$115 + $109 | 0] << 8 | HEAPU8[$115 + $110 | 0]; //@line 33812
 } else {
  $_0_i_i20 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $109) | 0; //@line 33820
 }
 HEAP16[$7 >> 1] = $_0_i_i20; //@line 33823
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 33830
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 33833
  _e68_ea_set_val8($c, $99) | 0; //@line 33834
  STACKTOP = sp; //@line 33836
  return;
 } else {
  _e68_exception_bus($c); //@line 33839
  STACKTOP = sp; //@line 33841
  return;
 }
}
function _op0040($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $27 = 0, $42 = 0, $43 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $61 = 0, $62 = 0, $66 = 0, $79 = 0, $phitmp_i = 0, $82 = 0, $83 = 0, $91 = 0, $92 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i = 0, $122 = 0, $129 = 0, $132 = 0, $135 = 0, $145 = 0, $146 = 0, $149 = 0, $155 = 0, $156 = 0, $161 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 33871
 STACKTOP = STACKTOP + 8 | 0; //@line 33871
 $s2 = sp | 0; //@line 33872
 $1 = $c + 160 | 0; //@line 33873
 if ((HEAP16[$1 >> 1] & 63) == 60) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   _e68_exception_privilege($c); //@line 33884
   STACKTOP = sp; //@line 33886
   return;
  }
  $11 = $c + 156 | 0; //@line 33889
  $12 = HEAP32[$11 >> 2] | 0; //@line 33890
  if (($12 & 1 | 0) != 0) {
   _e68_exception_address($c, $12, 0, 0); //@line 33895
   STACKTOP = sp; //@line 33897
   return;
  }
  $17 = $c + 164 | 0; //@line 33900
  $19 = $c + 162 | 0; //@line 33902
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 33903
  $20 = $12 & 16777215; //@line 33904
  $21 = $20 + 1 | 0; //@line 33905
  $22 = $c + 36 | 0; //@line 33906
  if ($21 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $27 = HEAP32[$c + 32 >> 2] | 0; //@line 33912
   $42 = HEAPU8[$27 + $20 | 0] << 8 | HEAPU8[$27 + $21 | 0]; //@line 33922
  } else {
   $42 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $20) | 0; //@line 33930
  }
  HEAP16[$17 >> 1] = $42; //@line 33933
  $43 = $c + 336 | 0; //@line 33934
  if ((HEAP8[$43] | 0) != 0) {
   _e68_exception_bus($c); //@line 33939
   STACKTOP = sp; //@line 33941
   return;
  }
  $49 = (HEAP32[$11 >> 2] | 0) + 2 | 0; //@line 33945
  HEAP32[$11 >> 2] = $49; //@line 33946
  $50 = $c + 152 | 0; //@line 33947
  $52 = (HEAP32[$50 >> 2] | 0) + 2 | 0; //@line 33949
  HEAP32[$50 >> 2] = $52; //@line 33950
  $53 = HEAP16[$19 >> 1] | 0; //@line 33951
  $54 = $c + 372 | 0; //@line 33952
  HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 20; //@line 33955
  if (($49 & 1 | 0) != 0) {
   _e68_exception_address($c, $49, 0, 0); //@line 33960
   STACKTOP = sp; //@line 33962
   return;
  }
  HEAP16[$19 >> 1] = $42; //@line 33965
  $61 = $49 & 16777215; //@line 33966
  $62 = $61 + 1 | 0; //@line 33967
  do {
   if ($62 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
    $66 = HEAP32[$c + 32 >> 2] | 0; //@line 33974
    HEAP16[$17 >> 1] = HEAPU8[$66 + $61 | 0] << 8 | HEAPU8[$66 + $62 | 0]; //@line 33983
    $83 = $49;
    $82 = $52;
   } else {
    $79 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $61) | 0; //@line 33991
    $phitmp_i = (HEAP8[$43] | 0) == 0; //@line 33993
    HEAP16[$17 >> 1] = $79; //@line 33994
    if ($phitmp_i) {
     $83 = HEAP32[$11 >> 2] | 0;
     $82 = HEAP32[$50 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 34003
    STACKTOP = sp; //@line 34005
    return;
   }
  } while (0);
  HEAP32[$11 >> 2] = $83 + 2; //@line 34012
  HEAP32[$50 >> 2] = $82 + 2; //@line 34014
  _e68_set_sr($c, (HEAP16[$c + 166 >> 1] | $53) & -22753); //@line 34019
  STACKTOP = sp; //@line 34021
  return;
 }
 $91 = $c + 156 | 0; //@line 34024
 $92 = HEAP32[$91 >> 2] | 0; //@line 34025
 if (($92 & 1 | 0) != 0) {
  _e68_exception_address($c, $92, 0, 0); //@line 34030
  STACKTOP = sp; //@line 34032
  return;
 }
 $97 = $c + 164 | 0; //@line 34035
 $99 = $c + 162 | 0; //@line 34037
 HEAP16[$99 >> 1] = HEAP16[$97 >> 1] | 0; //@line 34038
 $100 = $92 & 16777215; //@line 34039
 $101 = $100 + 1 | 0; //@line 34040
 $102 = $c + 36 | 0; //@line 34041
 if ($101 >>> 0 < (HEAP32[$102 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 34047
  $_0_i_i = HEAPU8[$107 + $100 | 0] << 8 | HEAPU8[$107 + $101 | 0]; //@line 34057
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $100) | 0; //@line 34065
 }
 HEAP16[$97 >> 1] = $_0_i_i; //@line 34068
 $122 = $c + 336 | 0; //@line 34069
 if ((HEAP8[$122] | 0) != 0) {
  _e68_exception_bus($c); //@line 34074
  STACKTOP = sp; //@line 34076
  return;
 }
 HEAP32[$91 >> 2] = (HEAP32[$91 >> 2] | 0) + 2; //@line 34081
 $129 = $c + 152 | 0; //@line 34082
 HEAP32[$129 >> 2] = (HEAP32[$129 >> 2] | 0) + 2; //@line 34085
 $132 = HEAP16[$99 >> 1] | 0; //@line 34086
 $135 = HEAP16[$1 >> 1] & 63; //@line 34089
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($135 << 2) >> 2] & 127]($c, $135, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 34096
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 34103
  return;
 }
 $145 = HEAP16[$s2 >> 1] | $132; //@line 34107
 $146 = $c + 372 | 0; //@line 34108
 HEAP32[$146 >> 2] = (HEAP32[$146 >> 2] | 0) + 8; //@line 34111
 _e68_cc_set_nz_16($c, 15, $145); //@line 34112
 $149 = HEAP32[$91 >> 2] | 0; //@line 34113
 if (($149 & 1 | 0) != 0) {
  _e68_exception_address($c, $149, 0, 0); //@line 34118
  STACKTOP = sp; //@line 34120
  return;
 }
 HEAP16[$99 >> 1] = HEAP16[$97 >> 1] | 0; //@line 34124
 $155 = $149 & 16777215; //@line 34125
 $156 = $155 + 1 | 0; //@line 34126
 if ($156 >>> 0 < (HEAP32[$102 >> 2] | 0) >>> 0) {
  $161 = HEAP32[$c + 32 >> 2] | 0; //@line 34132
  $_0_i_i11 = HEAPU8[$161 + $155 | 0] << 8 | HEAPU8[$161 + $156 | 0]; //@line 34142
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $155) | 0; //@line 34150
 }
 HEAP16[$97 >> 1] = $_0_i_i11; //@line 34153
 if ((HEAP8[$122] | 0) == 0) {
  HEAP32[$91 >> 2] = (HEAP32[$91 >> 2] | 0) + 2; //@line 34160
  HEAP32[$129 >> 2] = (HEAP32[$129 >> 2] | 0) + 2; //@line 34163
  _e68_ea_set_val16($c, $145) | 0; //@line 34164
  STACKTOP = sp; //@line 34166
  return;
 } else {
  _e68_exception_bus($c); //@line 34169
  STACKTOP = sp; //@line 34171
  return;
 }
}
function _op0080($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $48 = 0, $49 = 0, $53 = 0, $66 = 0, $phitmp = 0, $77 = 0, $81 = 0, $91 = 0, $92 = 0, $95 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i17 = 0, sp = 0;
 sp = STACKTOP; //@line 34195
 STACKTOP = STACKTOP + 8 | 0; //@line 34195
 $s2 = sp | 0; //@line 34196
 $1 = $c + 156 | 0; //@line 34197
 $2 = HEAP32[$1 >> 2] | 0; //@line 34198
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 34203
  STACKTOP = sp; //@line 34205
  return;
 }
 $7 = $c + 164 | 0; //@line 34208
 $9 = $c + 162 | 0; //@line 34210
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 34211
 $10 = $2 & 16777215; //@line 34212
 $11 = $10 + 1 | 0; //@line 34213
 $12 = $c + 36 | 0; //@line 34214
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 34220
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 34230
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 34238
 }
 HEAP16[$7 >> 1] = $32; //@line 34241
 $33 = $c + 336 | 0; //@line 34242
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 34247
  STACKTOP = sp; //@line 34249
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 34253
 HEAP32[$1 >> 2] = $39; //@line 34254
 $40 = $c + 152 | 0; //@line 34255
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 34258
 $43 = HEAP16[$9 >> 1] | 0; //@line 34259
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 34264
  STACKTOP = sp; //@line 34266
  return;
 }
 HEAP16[$9 >> 1] = $32; //@line 34269
 $48 = $39 & 16777215; //@line 34270
 $49 = $48 + 1 | 0; //@line 34271
 do {
  if ($49 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $53 = HEAP32[$c + 32 >> 2] | 0; //@line 34278
   HEAP16[$7 >> 1] = HEAPU8[$53 + $48 | 0] << 8 | HEAPU8[$53 + $49 | 0]; //@line 34287
  } else {
   $66 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 34294
   $phitmp = (HEAP8[$33] | 0) == 0; //@line 34296
   HEAP16[$7 >> 1] = $66; //@line 34297
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 34302
   STACKTOP = sp; //@line 34304
   return;
  }
 } while (0);
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 34310
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 34313
 $77 = HEAPU16[$9 >> 1] | ($43 & 65535) << 16; //@line 34318
 $81 = HEAP16[$c + 160 >> 1] & 63; //@line 34322
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($81 << 2) >> 2] & 127]($c, $81, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 34329
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 34336
  return;
 }
 $91 = $77 | HEAP32[$s2 >> 2]; //@line 34340
 $92 = $c + 372 | 0; //@line 34341
 HEAP32[$92 >> 2] = (HEAP32[$92 >> 2] | 0) + 16; //@line 34344
 _e68_cc_set_nz_32($c, 15, $91); //@line 34345
 $95 = HEAP32[$1 >> 2] | 0; //@line 34346
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 34351
  STACKTOP = sp; //@line 34353
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 34357
 $101 = $95 & 16777215; //@line 34358
 $102 = $101 + 1 | 0; //@line 34359
 if ($102 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 34365
  $_0_i_i17 = HEAPU8[$107 + $101 | 0] << 8 | HEAPU8[$107 + $102 | 0]; //@line 34375
 } else {
  $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 34383
 }
 HEAP16[$7 >> 1] = $_0_i_i17; //@line 34386
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 34393
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 34396
  _e68_ea_set_val32($c, $91) | 0; //@line 34397
  STACKTOP = sp; //@line 34399
  return;
 } else {
  _e68_exception_bus($c); //@line 34402
  STACKTOP = sp; //@line 34404
  return;
 }
}
function _op0100($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $3 = 0, $4 = 0, $8 = 0, $14 = 0, $15 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i_i = 0, $62 = 0, $66 = 0, $67 = 0, $72 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $82 = 0, $_0_i_i_i11 = 0, $97 = 0, $104 = 0, $113 = 0, $118 = 0, $119 = 0, $120 = 0, $132 = 0, $133 = 0, $_0_i12_i = 0, $137 = 0, $_0_i13_i = 0, $152 = 0, $159 = 0, $164 = 0, $170 = 0, $171 = 0, $176 = 0, $_0_i_i15_i = 0, $200 = 0, $216 = 0, $217 = 0, $224 = 0, $225 = 0, $228 = 0, $229 = 0, $234 = 0, $237 = 0, $238 = 0, $244 = 0, $_0_i_i = 0, $266 = 0, sp = 0;
 sp = STACKTOP; //@line 34444
 STACKTOP = STACKTOP + 8 | 0; //@line 34444
 $s = sp | 0; //@line 34445
 $1 = $c + 160 | 0; //@line 34446
 $3 = HEAPU16[$1 >> 1] | 0; //@line 34448
 $4 = $3 & 56; //@line 34449
 if (($4 | 0) == 0) {
  $8 = HEAP32[$c + 88 + (($3 & 7) << 2) >> 2] | 0; //@line 34453
  $14 = 1 << (HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] & 31); //@line 34459
  $15 = $c + 372 | 0; //@line 34460
  HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 6; //@line 34463
  $20 = $c + 166 | 0; //@line 34466
  $21 = HEAP16[$20 >> 1] | 0; //@line 34467
  HEAP16[$20 >> 1] = ($14 & $8 | 0) == 0 ? $21 | 4 : $21 & -5; //@line 34471
  $24 = $c + 156 | 0; //@line 34472
  $25 = HEAP32[$24 >> 2] | 0; //@line 34473
  if (($25 & 1 | 0) != 0) {
   _e68_exception_address($c, $25, 0, 0); //@line 34478
   STACKTOP = sp; //@line 34480
   return;
  }
  $30 = $c + 164 | 0; //@line 34483
  HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 34486
  $33 = $25 & 16777215; //@line 34487
  $34 = $33 + 1 | 0; //@line 34488
  if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $40 = HEAP32[$c + 32 >> 2] | 0; //@line 34495
   $_0_i_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 34505
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 34513
  }
  HEAP16[$30 >> 1] = $_0_i_i_i; //@line 34516
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 34524
   $62 = $c + 152 | 0; //@line 34525
   HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 34528
   STACKTOP = sp; //@line 34530
   return;
  } else {
   _e68_exception_bus($c); //@line 34533
   STACKTOP = sp; //@line 34535
   return;
  }
 } else if (($4 | 0) == 8) {
  $66 = $c + 156 | 0; //@line 34539
  $67 = HEAP32[$66 >> 2] | 0; //@line 34540
  if (($67 & 1 | 0) != 0) {
   _e68_exception_address($c, $67, 0, 0); //@line 34545
   STACKTOP = sp; //@line 34547
   return;
  }
  $72 = $c + 164 | 0; //@line 34550
  $74 = $c + 162 | 0; //@line 34552
  HEAP16[$74 >> 1] = HEAP16[$72 >> 1] | 0; //@line 34553
  $75 = $67 & 16777215; //@line 34554
  $76 = $75 + 1 | 0; //@line 34555
  $77 = $c + 36 | 0; //@line 34556
  if ($76 >>> 0 < (HEAP32[$77 >> 2] | 0) >>> 0) {
   $82 = HEAP32[$c + 32 >> 2] | 0; //@line 34562
   $_0_i_i_i11 = HEAPU8[$82 + $75 | 0] << 8 | HEAPU8[$82 + $76 | 0]; //@line 34572
  } else {
   $_0_i_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $75) | 0; //@line 34580
  }
  HEAP16[$72 >> 1] = $_0_i_i_i11; //@line 34583
  $97 = $c + 336 | 0; //@line 34584
  if ((HEAP8[$97] | 0) != 0) {
   _e68_exception_bus($c); //@line 34589
   STACKTOP = sp; //@line 34591
   return;
  }
  HEAP32[$66 >> 2] = (HEAP32[$66 >> 2] | 0) + 2; //@line 34596
  $104 = $c + 152 | 0; //@line 34597
  HEAP32[$104 >> 2] = (HEAP32[$104 >> 2] | 0) + 2; //@line 34600
  $113 = HEAPU16[$74 >> 1] | 0; //@line 34607
  $118 = (($113 & 32768 | 0) != 0 ? $113 | -65536 : $113) + (HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] | 0) | 0; //@line 34612
  $119 = $118 & 16777215; //@line 34613
  $120 = HEAP32[$77 >> 2] | 0; //@line 34614
  if ($119 >>> 0 < $120 >>> 0) {
   $_0_i12_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $119 | 0] | 0;
   $133 = $120;
  } else {
   $132 = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $119) | 0; //@line 34629
   $_0_i12_i = $132;
   $133 = HEAP32[$77 >> 2] | 0;
  }
  $137 = $118 + 2 & 16777215; //@line 34639
  if ($137 >>> 0 < $133 >>> 0) {
   $_0_i13_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $137 | 0] | 0; //@line 34648
  } else {
   $_0_i13_i = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $137) | 0; //@line 34656
  }
  $152 = $c + 372 | 0; //@line 34661
  HEAP32[$152 >> 2] = (HEAP32[$152 >> 2] | 0) + 16; //@line 34664
  $159 = $c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) | 0; //@line 34669
  HEAP32[$159 >> 2] = HEAP32[$159 >> 2] & -65536 | ($_0_i13_i & 255 | ($_0_i12_i & 255) << 8) & 65535; //@line 34674
  $164 = HEAP32[$66 >> 2] | 0; //@line 34675
  if (($164 & 1 | 0) != 0) {
   _e68_exception_address($c, $164, 0, 0); //@line 34680
   STACKTOP = sp; //@line 34682
   return;
  }
  HEAP16[$74 >> 1] = HEAP16[$72 >> 1] | 0; //@line 34686
  $170 = $164 & 16777215; //@line 34687
  $171 = $170 + 1 | 0; //@line 34688
  if ($171 >>> 0 < (HEAP32[$77 >> 2] | 0) >>> 0) {
   $176 = HEAP32[$c + 32 >> 2] | 0; //@line 34694
   $_0_i_i15_i = HEAPU8[$176 + $170 | 0] << 8 | HEAPU8[$176 + $171 | 0]; //@line 34704
  } else {
   $_0_i_i15_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $170) | 0; //@line 34712
  }
  HEAP16[$72 >> 1] = $_0_i_i15_i; //@line 34715
  if ((HEAP8[$97] | 0) == 0) {
   HEAP32[$66 >> 2] = (HEAP32[$66 >> 2] | 0) + 2; //@line 34722
   HEAP32[$104 >> 2] = (HEAP32[$104 >> 2] | 0) + 2; //@line 34725
   STACKTOP = sp; //@line 34727
   return;
  } else {
   _e68_exception_bus($c); //@line 34730
   STACKTOP = sp; //@line 34732
   return;
  }
 } else {
  $200 = $3 & 63; //@line 34736
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($200 << 2) >> 2] & 127]($c, $200, 4092, 8) | 0) != 0) {
   STACKTOP = sp; //@line 34743
   return;
  }
  if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
   STACKTOP = sp; //@line 34750
   return;
  }
  $216 = 1 << (HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] & 7); //@line 34760
  $217 = $c + 372 | 0; //@line 34761
  HEAP32[$217 >> 2] = (HEAP32[$217 >> 2] | 0) + 4; //@line 34764
  $224 = $c + 166 | 0; //@line 34769
  $225 = HEAP16[$224 >> 1] | 0; //@line 34770
  HEAP16[$224 >> 1] = ($216 & HEAPU8[$s] | 0) == 0 ? $225 | 4 : $225 & -5; //@line 34774
  $228 = $c + 156 | 0; //@line 34775
  $229 = HEAP32[$228 >> 2] | 0; //@line 34776
  if (($229 & 1 | 0) != 0) {
   _e68_exception_address($c, $229, 0, 0); //@line 34781
   STACKTOP = sp; //@line 34783
   return;
  }
  $234 = $c + 164 | 0; //@line 34786
  HEAP16[$c + 162 >> 1] = HEAP16[$234 >> 1] | 0; //@line 34789
  $237 = $229 & 16777215; //@line 34790
  $238 = $237 + 1 | 0; //@line 34791
  if ($238 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $244 = HEAP32[$c + 32 >> 2] | 0; //@line 34798
   $_0_i_i = HEAPU8[$244 + $237 | 0] << 8 | HEAPU8[$244 + $238 | 0]; //@line 34808
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $237) | 0; //@line 34816
  }
  HEAP16[$234 >> 1] = $_0_i_i; //@line 34819
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$228 >> 2] = (HEAP32[$228 >> 2] | 0) + 2; //@line 34827
   $266 = $c + 152 | 0; //@line 34828
   HEAP32[$266 >> 2] = (HEAP32[$266 >> 2] | 0) + 2; //@line 34831
   STACKTOP = sp; //@line 34833
   return;
  } else {
   _e68_exception_bus($c); //@line 34836
   STACKTOP = sp; //@line 34838
   return;
  }
 }
}
function _op0140($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $3 = 0, $5 = 0, $8 = 0, $9 = 0, $15 = 0, $17 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $32 = 0, $35 = 0, $36 = 0, $42 = 0, $_0_i_i_i = 0, $64 = 0, $68 = 0, $69 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $84 = 0, $_0_i_i_i13 = 0, $99 = 0, $106 = 0, $115 = 0, $120 = 0, $121 = 0, $122 = 0, $134 = 0, $135 = 0, $_0_i18_i = 0, $139 = 0, $151 = 0, $152 = 0, $_0_i19_i = 0, $157 = 0, $169 = 0, $170 = 0, $_0_i21_i = 0, $175 = 0, $_0_i23_i = 0, $190 = 0, $198 = 0, $204 = 0, $205 = 0, $210 = 0, $_0_i_i25_i = 0, $234 = 0, $250 = 0, $252 = 0, $255 = 0, $260 = 0, $261 = 0, $264 = 0, $265 = 0, $270 = 0, $273 = 0, $274 = 0, $280 = 0, $_0_i_i = 0, $302 = 0, sp = 0;
 sp = STACKTOP; //@line 34884
 STACKTOP = STACKTOP + 8 | 0; //@line 34884
 $s = sp | 0; //@line 34885
 $1 = $c + 160 | 0; //@line 34886
 $3 = HEAPU16[$1 >> 1] | 0; //@line 34888
 $5 = $3 >>> 3 & 7; //@line 34890
 if (($5 | 0) == 1) {
  $68 = $c + 156 | 0; //@line 34892
  $69 = HEAP32[$68 >> 2] | 0; //@line 34893
  if (($69 & 1 | 0) != 0) {
   _e68_exception_address($c, $69, 0, 0); //@line 34898
   STACKTOP = sp; //@line 34900
   return;
  }
  $74 = $c + 164 | 0; //@line 34903
  $76 = $c + 162 | 0; //@line 34905
  HEAP16[$76 >> 1] = HEAP16[$74 >> 1] | 0; //@line 34906
  $77 = $69 & 16777215; //@line 34907
  $78 = $77 + 1 | 0; //@line 34908
  $79 = $c + 36 | 0; //@line 34909
  if ($78 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   $84 = HEAP32[$c + 32 >> 2] | 0; //@line 34915
   $_0_i_i_i13 = HEAPU8[$84 + $77 | 0] << 8 | HEAPU8[$84 + $78 | 0]; //@line 34925
  } else {
   $_0_i_i_i13 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $77) | 0; //@line 34933
  }
  HEAP16[$74 >> 1] = $_0_i_i_i13; //@line 34936
  $99 = $c + 336 | 0; //@line 34937
  if ((HEAP8[$99] | 0) != 0) {
   _e68_exception_bus($c); //@line 34942
   STACKTOP = sp; //@line 34944
   return;
  }
  HEAP32[$68 >> 2] = (HEAP32[$68 >> 2] | 0) + 2; //@line 34949
  $106 = $c + 152 | 0; //@line 34950
  HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 34953
  $115 = HEAPU16[$76 >> 1] | 0; //@line 34960
  $120 = (($115 & 32768 | 0) != 0 ? $115 | -65536 : $115) + (HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] | 0) | 0; //@line 34965
  $121 = $120 & 16777215; //@line 34966
  $122 = HEAP32[$79 >> 2] | 0; //@line 34967
  if ($121 >>> 0 < $122 >>> 0) {
   $_0_i18_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $121 | 0] | 0;
   $135 = $122;
  } else {
   $134 = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $121) | 0; //@line 34982
   $_0_i18_i = $134;
   $135 = HEAP32[$79 >> 2] | 0;
  }
  $139 = $120 + 2 & 16777215; //@line 34992
  if ($139 >>> 0 < $135 >>> 0) {
   $_0_i19_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $139 | 0] | 0;
   $152 = $135;
  } else {
   $151 = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $139) | 0; //@line 35007
   $_0_i19_i = $151;
   $152 = HEAP32[$79 >> 2] | 0;
  }
  $157 = $120 + 4 & 16777215; //@line 35018
  if ($157 >>> 0 < $152 >>> 0) {
   $_0_i21_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $157 | 0] | 0;
   $170 = $152;
  } else {
   $169 = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $157) | 0; //@line 35033
   $_0_i21_i = $169;
   $170 = HEAP32[$79 >> 2] | 0;
  }
  $175 = $120 + 6 & 16777215; //@line 35044
  if ($175 >>> 0 < $170 >>> 0) {
   $_0_i23_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $175 | 0] | 0; //@line 35053
  } else {
   $_0_i23_i = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $175) | 0; //@line 35061
  }
  $190 = $c + 372 | 0; //@line 35066
  HEAP32[$190 >> 2] = (HEAP32[$190 >> 2] | 0) + 24; //@line 35069
  HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] = $_0_i23_i & 255 | ($_0_i21_i & 255 | ($_0_i19_i & 255 | ($_0_i18_i & 255) << 8) << 8) << 8; //@line 35075
  $198 = HEAP32[$68 >> 2] | 0; //@line 35076
  if (($198 & 1 | 0) != 0) {
   _e68_exception_address($c, $198, 0, 0); //@line 35081
   STACKTOP = sp; //@line 35083
   return;
  }
  HEAP16[$76 >> 1] = HEAP16[$74 >> 1] | 0; //@line 35087
  $204 = $198 & 16777215; //@line 35088
  $205 = $204 + 1 | 0; //@line 35089
  if ($205 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   $210 = HEAP32[$c + 32 >> 2] | 0; //@line 35095
   $_0_i_i25_i = HEAPU8[$210 + $204 | 0] << 8 | HEAPU8[$210 + $205 | 0]; //@line 35105
  } else {
   $_0_i_i25_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $204) | 0; //@line 35113
  }
  HEAP16[$74 >> 1] = $_0_i_i25_i; //@line 35116
  if ((HEAP8[$99] | 0) == 0) {
   HEAP32[$68 >> 2] = (HEAP32[$68 >> 2] | 0) + 2; //@line 35123
   HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 35126
   STACKTOP = sp; //@line 35128
   return;
  } else {
   _e68_exception_bus($c); //@line 35131
   STACKTOP = sp; //@line 35133
   return;
  }
 } else if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 35138
  $9 = HEAP32[$8 >> 2] | 0; //@line 35139
  $15 = 1 << (HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] & 31); //@line 35145
  $17 = $c + 372 | 0; //@line 35147
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 8; //@line 35150
  HEAP32[$8 >> 2] = $15 ^ $9; //@line 35151
  $22 = $c + 166 | 0; //@line 35154
  $23 = HEAP16[$22 >> 1] | 0; //@line 35155
  HEAP16[$22 >> 1] = ($15 & $9 | 0) == 0 ? $23 | 4 : $23 & -5; //@line 35159
  $26 = $c + 156 | 0; //@line 35160
  $27 = HEAP32[$26 >> 2] | 0; //@line 35161
  if (($27 & 1 | 0) != 0) {
   _e68_exception_address($c, $27, 0, 0); //@line 35166
   STACKTOP = sp; //@line 35168
   return;
  }
  $32 = $c + 164 | 0; //@line 35171
  HEAP16[$c + 162 >> 1] = HEAP16[$32 >> 1] | 0; //@line 35174
  $35 = $27 & 16777215; //@line 35175
  $36 = $35 + 1 | 0; //@line 35176
  if ($36 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $42 = HEAP32[$c + 32 >> 2] | 0; //@line 35183
   $_0_i_i_i = HEAPU8[$42 + $35 | 0] << 8 | HEAPU8[$42 + $36 | 0]; //@line 35193
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $35) | 0; //@line 35201
  }
  HEAP16[$32 >> 1] = $_0_i_i_i; //@line 35204
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 2; //@line 35212
   $64 = $c + 152 | 0; //@line 35213
   HEAP32[$64 >> 2] = (HEAP32[$64 >> 2] | 0) + 2; //@line 35216
   STACKTOP = sp; //@line 35218
   return;
  } else {
   _e68_exception_bus($c); //@line 35221
   STACKTOP = sp; //@line 35223
   return;
  }
 } else {
  $234 = $3 & 63; //@line 35227
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($234 << 2) >> 2] & 127]($c, $234, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 35234
   return;
  }
  if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
   STACKTOP = sp; //@line 35241
   return;
  }
  $250 = 1 << (HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] & 7); //@line 35251
  $252 = HEAPU8[$s] | 0; //@line 35253
  $255 = $c + 372 | 0; //@line 35256
  HEAP32[$255 >> 2] = (HEAP32[$255 >> 2] | 0) + 8; //@line 35259
  $260 = $c + 166 | 0; //@line 35262
  $261 = HEAP16[$260 >> 1] | 0; //@line 35263
  HEAP16[$260 >> 1] = ($250 & $252 | 0) == 0 ? $261 | 4 : $261 & -5; //@line 35267
  $264 = $c + 156 | 0; //@line 35268
  $265 = HEAP32[$264 >> 2] | 0; //@line 35269
  if (($265 & 1 | 0) != 0) {
   _e68_exception_address($c, $265, 0, 0); //@line 35274
   STACKTOP = sp; //@line 35276
   return;
  }
  $270 = $c + 164 | 0; //@line 35279
  HEAP16[$c + 162 >> 1] = HEAP16[$270 >> 1] | 0; //@line 35282
  $273 = $265 & 16777215; //@line 35283
  $274 = $273 + 1 | 0; //@line 35284
  if ($274 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $280 = HEAP32[$c + 32 >> 2] | 0; //@line 35291
   $_0_i_i = HEAPU8[$280 + $273 | 0] << 8 | HEAPU8[$280 + $274 | 0]; //@line 35301
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $273) | 0; //@line 35309
  }
  HEAP16[$270 >> 1] = $_0_i_i; //@line 35312
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$264 >> 2] = (HEAP32[$264 >> 2] | 0) + 2; //@line 35320
   $302 = $c + 152 | 0; //@line 35321
   HEAP32[$302 >> 2] = (HEAP32[$302 >> 2] | 0) + 2; //@line 35324
   _e68_ea_set_val8($c, ($252 ^ $250) & 255) | 0; //@line 35325
   STACKTOP = sp; //@line 35327
   return;
  } else {
   _e68_exception_bus($c); //@line 35330
   STACKTOP = sp; //@line 35332
   return;
  }
 }
}
function _op0180($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $3 = 0, $5 = 0, $8 = 0, $9 = 0, $15 = 0, $18 = 0, $23 = 0, $24 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i_i = 0, $65 = 0, $69 = 0, $70 = 0, $75 = 0, $77 = 0, $78 = 0, $79 = 0, $80 = 0, $85 = 0, $_0_i_i_i13 = 0, $100 = 0, $107 = 0, $111 = 0, $116 = 0, $121 = 0, $125 = 0, $127 = 0, $128 = 0, $141 = 0, $142 = 0, $154 = 0, $157 = 0, $163 = 0, $164 = 0, $169 = 0, $_0_i_i13_i = 0, $193 = 0, $209 = 0, $211 = 0, $215 = 0, $220 = 0, $221 = 0, $224 = 0, $225 = 0, $230 = 0, $233 = 0, $234 = 0, $240 = 0, $_0_i_i = 0, $262 = 0, sp = 0;
 sp = STACKTOP; //@line 35372
 STACKTOP = STACKTOP + 8 | 0; //@line 35372
 $s = sp | 0; //@line 35373
 $1 = $c + 160 | 0; //@line 35374
 $3 = HEAPU16[$1 >> 1] | 0; //@line 35376
 $5 = $3 >>> 3 & 7; //@line 35378
 if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 35381
  $9 = HEAP32[$8 >> 2] | 0; //@line 35382
  $15 = 1 << (HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] & 31); //@line 35388
  $18 = $c + 372 | 0; //@line 35391
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 10; //@line 35394
  $23 = $c + 166 | 0; //@line 35397
  $24 = HEAP16[$23 >> 1] | 0; //@line 35398
  HEAP16[$23 >> 1] = ($15 & $9 | 0) == 0 ? $24 | 4 : $24 & -5; //@line 35402
  HEAP32[$8 >> 2] = $9 & ~$15; //@line 35403
  $27 = $c + 156 | 0; //@line 35404
  $28 = HEAP32[$27 >> 2] | 0; //@line 35405
  if (($28 & 1 | 0) != 0) {
   _e68_exception_address($c, $28, 0, 0); //@line 35410
   STACKTOP = sp; //@line 35412
   return;
  }
  $33 = $c + 164 | 0; //@line 35415
  HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 35418
  $36 = $28 & 16777215; //@line 35419
  $37 = $36 + 1 | 0; //@line 35420
  if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $43 = HEAP32[$c + 32 >> 2] | 0; //@line 35427
   $_0_i_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 35437
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 35445
  }
  HEAP16[$33 >> 1] = $_0_i_i_i; //@line 35448
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 35456
   $65 = $c + 152 | 0; //@line 35457
   HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 35460
   STACKTOP = sp; //@line 35462
   return;
  } else {
   _e68_exception_bus($c); //@line 35465
   STACKTOP = sp; //@line 35467
   return;
  }
 } else if (($5 | 0) == 1) {
  $69 = $c + 156 | 0; //@line 35471
  $70 = HEAP32[$69 >> 2] | 0; //@line 35472
  if (($70 & 1 | 0) != 0) {
   _e68_exception_address($c, $70, 0, 0); //@line 35477
   STACKTOP = sp; //@line 35479
   return;
  }
  $75 = $c + 164 | 0; //@line 35482
  $77 = $c + 162 | 0; //@line 35484
  HEAP16[$77 >> 1] = HEAP16[$75 >> 1] | 0; //@line 35485
  $78 = $70 & 16777215; //@line 35486
  $79 = $78 + 1 | 0; //@line 35487
  $80 = $c + 36 | 0; //@line 35488
  if ($79 >>> 0 < (HEAP32[$80 >> 2] | 0) >>> 0) {
   $85 = HEAP32[$c + 32 >> 2] | 0; //@line 35494
   $_0_i_i_i13 = HEAPU8[$85 + $78 | 0] << 8 | HEAPU8[$85 + $79 | 0]; //@line 35504
  } else {
   $_0_i_i_i13 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $78) | 0; //@line 35512
  }
  HEAP16[$75 >> 1] = $_0_i_i_i13; //@line 35515
  $100 = $c + 336 | 0; //@line 35516
  if ((HEAP8[$100] | 0) != 0) {
   _e68_exception_bus($c); //@line 35521
   STACKTOP = sp; //@line 35523
   return;
  }
  HEAP32[$69 >> 2] = (HEAP32[$69 >> 2] | 0) + 2; //@line 35528
  $107 = $c + 152 | 0; //@line 35529
  HEAP32[$107 >> 2] = (HEAP32[$107 >> 2] | 0) + 2; //@line 35532
  $111 = HEAPU16[$1 >> 1] | 0; //@line 35534
  $116 = HEAPU16[$77 >> 1] | 0; //@line 35539
  $121 = (($116 & 32768 | 0) != 0 ? $116 | -65536 : $116) + (HEAP32[$c + 120 + (($111 & 7) << 2) >> 2] | 0) | 0; //@line 35544
  $125 = HEAP32[$c + 88 + (($111 >>> 9 & 7) << 2) >> 2] | 0; //@line 35548
  $127 = $125 >>> 8 & 255; //@line 35550
  $128 = $121 & 16777215; //@line 35551
  if ($128 >>> 0 < (HEAP32[$80 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $128 | 0] = $127; //@line 35559
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $128, $127); //@line 35566
  }
  $141 = $125 & 255; //@line 35569
  $142 = $121 + 2 & 16777215; //@line 35570
  if ($142 >>> 0 < (HEAP32[$80 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $142 | 0] = $141; //@line 35578
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $142, $141); //@line 35585
  }
  $154 = $c + 372 | 0; //@line 35587
  HEAP32[$154 >> 2] = (HEAP32[$154 >> 2] | 0) + 16; //@line 35590
  $157 = HEAP32[$69 >> 2] | 0; //@line 35591
  if (($157 & 1 | 0) != 0) {
   _e68_exception_address($c, $157, 0, 0); //@line 35596
   STACKTOP = sp; //@line 35598
   return;
  }
  HEAP16[$77 >> 1] = HEAP16[$75 >> 1] | 0; //@line 35602
  $163 = $157 & 16777215; //@line 35603
  $164 = $163 + 1 | 0; //@line 35604
  if ($164 >>> 0 < (HEAP32[$80 >> 2] | 0) >>> 0) {
   $169 = HEAP32[$c + 32 >> 2] | 0; //@line 35610
   $_0_i_i13_i = HEAPU8[$169 + $163 | 0] << 8 | HEAPU8[$169 + $164 | 0]; //@line 35620
  } else {
   $_0_i_i13_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $163) | 0; //@line 35628
  }
  HEAP16[$75 >> 1] = $_0_i_i13_i; //@line 35631
  if ((HEAP8[$100] | 0) == 0) {
   HEAP32[$69 >> 2] = (HEAP32[$69 >> 2] | 0) + 2; //@line 35638
   HEAP32[$107 >> 2] = (HEAP32[$107 >> 2] | 0) + 2; //@line 35641
   STACKTOP = sp; //@line 35643
   return;
  } else {
   _e68_exception_bus($c); //@line 35646
   STACKTOP = sp; //@line 35648
   return;
  }
 } else {
  $193 = $3 & 63; //@line 35652
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($193 << 2) >> 2] & 127]($c, $193, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 35659
   return;
  }
  if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
   STACKTOP = sp; //@line 35666
   return;
  }
  $209 = 1 << (HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] & 7); //@line 35676
  $211 = HEAPU8[$s] | 0; //@line 35678
  $215 = $c + 372 | 0; //@line 35682
  HEAP32[$215 >> 2] = (HEAP32[$215 >> 2] | 0) + 8; //@line 35685
  $220 = $c + 166 | 0; //@line 35688
  $221 = HEAP16[$220 >> 1] | 0; //@line 35689
  HEAP16[$220 >> 1] = ($209 & $211 | 0) == 0 ? $221 | 4 : $221 & -5; //@line 35693
  $224 = $c + 156 | 0; //@line 35694
  $225 = HEAP32[$224 >> 2] | 0; //@line 35695
  if (($225 & 1 | 0) != 0) {
   _e68_exception_address($c, $225, 0, 0); //@line 35700
   STACKTOP = sp; //@line 35702
   return;
  }
  $230 = $c + 164 | 0; //@line 35705
  HEAP16[$c + 162 >> 1] = HEAP16[$230 >> 1] | 0; //@line 35708
  $233 = $225 & 16777215; //@line 35709
  $234 = $233 + 1 | 0; //@line 35710
  if ($234 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $240 = HEAP32[$c + 32 >> 2] | 0; //@line 35717
   $_0_i_i = HEAPU8[$240 + $233 | 0] << 8 | HEAPU8[$240 + $234 | 0]; //@line 35727
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $233) | 0; //@line 35735
  }
  HEAP16[$230 >> 1] = $_0_i_i; //@line 35738
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$224 >> 2] = (HEAP32[$224 >> 2] | 0) + 2; //@line 35746
   $262 = $c + 152 | 0; //@line 35747
   HEAP32[$262 >> 2] = (HEAP32[$262 >> 2] | 0) + 2; //@line 35750
   _e68_ea_set_val8($c, ($209 ^ 255) & $211 & 255) | 0; //@line 35751
   STACKTOP = sp; //@line 35753
   return;
  } else {
   _e68_exception_bus($c); //@line 35756
   STACKTOP = sp; //@line 35758
   return;
  }
 }
}
function _op01c0($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $3 = 0, $5 = 0, $8 = 0, $9 = 0, $15 = 0, $17 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $32 = 0, $35 = 0, $36 = 0, $42 = 0, $_0_i_i_i = 0, $64 = 0, $68 = 0, $69 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $84 = 0, $_0_i_i_i13 = 0, $99 = 0, $106 = 0, $110 = 0, $115 = 0, $120 = 0, $124 = 0, $126 = 0, $127 = 0, $141 = 0, $142 = 0, $156 = 0, $157 = 0, $170 = 0, $171 = 0, $183 = 0, $186 = 0, $192 = 0, $193 = 0, $198 = 0, $_0_i_i21_i = 0, $222 = 0, $238 = 0, $240 = 0, $243 = 0, $248 = 0, $249 = 0, $252 = 0, $253 = 0, $258 = 0, $261 = 0, $262 = 0, $268 = 0, $_0_i_i = 0, $290 = 0, sp = 0;
 sp = STACKTOP; //@line 35801
 STACKTOP = STACKTOP + 8 | 0; //@line 35801
 $s = sp | 0; //@line 35802
 $1 = $c + 160 | 0; //@line 35803
 $3 = HEAPU16[$1 >> 1] | 0; //@line 35805
 $5 = $3 >>> 3 & 7; //@line 35807
 if (($5 | 0) == 1) {
  $68 = $c + 156 | 0; //@line 35809
  $69 = HEAP32[$68 >> 2] | 0; //@line 35810
  if (($69 & 1 | 0) != 0) {
   _e68_exception_address($c, $69, 0, 0); //@line 35815
   STACKTOP = sp; //@line 35817
   return;
  }
  $74 = $c + 164 | 0; //@line 35820
  $76 = $c + 162 | 0; //@line 35822
  HEAP16[$76 >> 1] = HEAP16[$74 >> 1] | 0; //@line 35823
  $77 = $69 & 16777215; //@line 35824
  $78 = $77 + 1 | 0; //@line 35825
  $79 = $c + 36 | 0; //@line 35826
  if ($78 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   $84 = HEAP32[$c + 32 >> 2] | 0; //@line 35832
   $_0_i_i_i13 = HEAPU8[$84 + $77 | 0] << 8 | HEAPU8[$84 + $78 | 0]; //@line 35842
  } else {
   $_0_i_i_i13 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $77) | 0; //@line 35850
  }
  HEAP16[$74 >> 1] = $_0_i_i_i13; //@line 35853
  $99 = $c + 336 | 0; //@line 35854
  if ((HEAP8[$99] | 0) != 0) {
   _e68_exception_bus($c); //@line 35859
   STACKTOP = sp; //@line 35861
   return;
  }
  HEAP32[$68 >> 2] = (HEAP32[$68 >> 2] | 0) + 2; //@line 35866
  $106 = $c + 152 | 0; //@line 35867
  HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 35870
  $110 = HEAPU16[$1 >> 1] | 0; //@line 35872
  $115 = HEAPU16[$76 >> 1] | 0; //@line 35877
  $120 = (($115 & 32768 | 0) != 0 ? $115 | -65536 : $115) + (HEAP32[$c + 120 + (($110 & 7) << 2) >> 2] | 0) | 0; //@line 35882
  $124 = HEAP32[$c + 88 + (($110 >>> 9 & 7) << 2) >> 2] | 0; //@line 35886
  $126 = $124 >>> 24 & 255; //@line 35888
  $127 = $120 & 16777215; //@line 35889
  if ($127 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $127 | 0] = $126; //@line 35897
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $127, $126); //@line 35904
  }
  $141 = $124 >>> 16 & 255; //@line 35908
  $142 = $120 + 2 & 16777215; //@line 35909
  if ($142 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $142 | 0] = $141; //@line 35917
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $142, $141); //@line 35924
  }
  $156 = $124 >>> 8 & 255; //@line 35928
  $157 = $120 + 4 & 16777215; //@line 35929
  if ($157 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $157 | 0] = $156; //@line 35937
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $157, $156); //@line 35944
  }
  $170 = $124 & 255; //@line 35947
  $171 = $120 + 6 & 16777215; //@line 35948
  if ($171 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $171 | 0] = $170; //@line 35956
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $171, $170); //@line 35963
  }
  $183 = $c + 372 | 0; //@line 35965
  HEAP32[$183 >> 2] = (HEAP32[$183 >> 2] | 0) + 24; //@line 35968
  $186 = HEAP32[$68 >> 2] | 0; //@line 35969
  if (($186 & 1 | 0) != 0) {
   _e68_exception_address($c, $186, 0, 0); //@line 35974
   STACKTOP = sp; //@line 35976
   return;
  }
  HEAP16[$76 >> 1] = HEAP16[$74 >> 1] | 0; //@line 35980
  $192 = $186 & 16777215; //@line 35981
  $193 = $192 + 1 | 0; //@line 35982
  if ($193 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
   $198 = HEAP32[$c + 32 >> 2] | 0; //@line 35988
   $_0_i_i21_i = HEAPU8[$198 + $192 | 0] << 8 | HEAPU8[$198 + $193 | 0]; //@line 35998
  } else {
   $_0_i_i21_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $192) | 0; //@line 36006
  }
  HEAP16[$74 >> 1] = $_0_i_i21_i; //@line 36009
  if ((HEAP8[$99] | 0) == 0) {
   HEAP32[$68 >> 2] = (HEAP32[$68 >> 2] | 0) + 2; //@line 36016
   HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 36019
   STACKTOP = sp; //@line 36021
   return;
  } else {
   _e68_exception_bus($c); //@line 36024
   STACKTOP = sp; //@line 36026
   return;
  }
 } else if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 36031
  $9 = HEAP32[$8 >> 2] | 0; //@line 36032
  $15 = 1 << (HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] & 31); //@line 36038
  $17 = $c + 372 | 0; //@line 36040
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 8; //@line 36043
  $22 = $c + 166 | 0; //@line 36046
  $23 = HEAP16[$22 >> 1] | 0; //@line 36047
  HEAP16[$22 >> 1] = ($15 & $9 | 0) == 0 ? $23 | 4 : $23 & -5; //@line 36051
  HEAP32[$8 >> 2] = $15 | $9; //@line 36052
  $26 = $c + 156 | 0; //@line 36053
  $27 = HEAP32[$26 >> 2] | 0; //@line 36054
  if (($27 & 1 | 0) != 0) {
   _e68_exception_address($c, $27, 0, 0); //@line 36059
   STACKTOP = sp; //@line 36061
   return;
  }
  $32 = $c + 164 | 0; //@line 36064
  HEAP16[$c + 162 >> 1] = HEAP16[$32 >> 1] | 0; //@line 36067
  $35 = $27 & 16777215; //@line 36068
  $36 = $35 + 1 | 0; //@line 36069
  if ($36 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $42 = HEAP32[$c + 32 >> 2] | 0; //@line 36076
   $_0_i_i_i = HEAPU8[$42 + $35 | 0] << 8 | HEAPU8[$42 + $36 | 0]; //@line 36086
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $35) | 0; //@line 36094
  }
  HEAP16[$32 >> 1] = $_0_i_i_i; //@line 36097
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 2; //@line 36105
   $64 = $c + 152 | 0; //@line 36106
   HEAP32[$64 >> 2] = (HEAP32[$64 >> 2] | 0) + 2; //@line 36109
   STACKTOP = sp; //@line 36111
   return;
  } else {
   _e68_exception_bus($c); //@line 36114
   STACKTOP = sp; //@line 36116
   return;
  }
 } else {
  $222 = $3 & 63; //@line 36120
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($222 << 2) >> 2] & 127]($c, $222, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 36127
   return;
  }
  if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
   STACKTOP = sp; //@line 36134
   return;
  }
  $238 = 1 << (HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] & 7); //@line 36144
  $240 = HEAPU8[$s] | 0; //@line 36146
  $243 = $c + 372 | 0; //@line 36149
  HEAP32[$243 >> 2] = (HEAP32[$243 >> 2] | 0) + 8; //@line 36152
  $248 = $c + 166 | 0; //@line 36155
  $249 = HEAP16[$248 >> 1] | 0; //@line 36156
  HEAP16[$248 >> 1] = ($238 & $240 | 0) == 0 ? $249 | 4 : $249 & -5; //@line 36160
  $252 = $c + 156 | 0; //@line 36161
  $253 = HEAP32[$252 >> 2] | 0; //@line 36162
  if (($253 & 1 | 0) != 0) {
   _e68_exception_address($c, $253, 0, 0); //@line 36167
   STACKTOP = sp; //@line 36169
   return;
  }
  $258 = $c + 164 | 0; //@line 36172
  HEAP16[$c + 162 >> 1] = HEAP16[$258 >> 1] | 0; //@line 36175
  $261 = $253 & 16777215; //@line 36176
  $262 = $261 + 1 | 0; //@line 36177
  if ($262 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $268 = HEAP32[$c + 32 >> 2] | 0; //@line 36184
   $_0_i_i = HEAPU8[$268 + $261 | 0] << 8 | HEAPU8[$268 + $262 | 0]; //@line 36194
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $261) | 0; //@line 36202
  }
  HEAP16[$258 >> 1] = $_0_i_i; //@line 36205
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$252 >> 2] = (HEAP32[$252 >> 2] | 0) + 2; //@line 36213
   $290 = $c + 152 | 0; //@line 36214
   HEAP32[$290 >> 2] = (HEAP32[$290 >> 2] | 0) + 2; //@line 36217
   _e68_ea_set_val8($c, ($240 | $238) & 255) | 0; //@line 36218
   STACKTOP = sp; //@line 36220
   return;
  } else {
   _e68_exception_bus($c); //@line 36223
   STACKTOP = sp; //@line 36225
   return;
  }
 }
}
function _op0200($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $47 = 0, $50 = 0, $57 = 0, $58 = 0, $62 = 0, $75 = 0, $phitmp = 0, $82 = 0, $98 = 0, $99 = 0, $102 = 0, $108 = 0, $109 = 0, $114 = 0, $_0_i_i20 = 0, sp = 0;
 sp = STACKTOP; //@line 36251
 STACKTOP = STACKTOP + 8 | 0; //@line 36251
 $s2 = sp | 0; //@line 36252
 $1 = $c + 156 | 0; //@line 36253
 $2 = HEAP32[$1 >> 2] | 0; //@line 36254
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 36259
  STACKTOP = sp; //@line 36261
  return;
 }
 $7 = $c + 164 | 0; //@line 36264
 $9 = $c + 162 | 0; //@line 36266
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 36267
 $10 = $2 & 16777215; //@line 36268
 $11 = $10 + 1 | 0; //@line 36269
 $12 = $c + 36 | 0; //@line 36270
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 36276
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 36286
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 36294
 }
 HEAP16[$7 >> 1] = $32; //@line 36297
 $33 = $c + 336 | 0; //@line 36298
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 36303
  STACKTOP = sp; //@line 36305
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 36309
 HEAP32[$1 >> 2] = $39; //@line 36310
 $40 = $c + 152 | 0; //@line 36311
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 36314
 $43 = HEAP16[$9 >> 1] | 0; //@line 36315
 $47 = HEAP16[$c + 160 >> 1] & 63; //@line 36319
 if (($47 | 0) == 60) {
  $50 = $c + 372 | 0; //@line 36323
  HEAP32[$50 >> 2] = (HEAP32[$50 >> 2] | 0) + 20; //@line 36326
  if (($39 & 1 | 0) != 0) {
   _e68_exception_address($c, $39, 0, 0); //@line 36331
   STACKTOP = sp; //@line 36333
   return;
  }
  HEAP16[$9 >> 1] = $32; //@line 36336
  $57 = $39 & 16777215; //@line 36337
  $58 = $57 + 1 | 0; //@line 36338
  do {
   if ($58 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
    $62 = HEAP32[$c + 32 >> 2] | 0; //@line 36345
    HEAP16[$7 >> 1] = HEAPU8[$62 + $57 | 0] << 8 | HEAPU8[$62 + $58 | 0]; //@line 36354
   } else {
    $75 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $57) | 0; //@line 36361
    $phitmp = (HEAP8[$33] | 0) == 0; //@line 36363
    HEAP16[$7 >> 1] = $75; //@line 36364
    if ($phitmp) {
     break;
    }
    _e68_exception_bus($c); //@line 36369
    STACKTOP = sp; //@line 36371
    return;
   }
  } while (0);
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 36377
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 36380
  $82 = $c + 166 | 0; //@line 36381
  HEAP16[$82 >> 1] = HEAP16[$82 >> 1] & ($43 & 31 | -256); //@line 36386
  STACKTOP = sp; //@line 36388
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($47 << 2) >> 2] & 127]($c, $47, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 36397
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 36404
  return;
 }
 $98 = HEAP8[$s2] & ($43 & 255); //@line 36409
 $99 = $c + 372 | 0; //@line 36410
 HEAP32[$99 >> 2] = (HEAP32[$99 >> 2] | 0) + 8; //@line 36413
 _e68_cc_set_nz_8($c, 15, $98); //@line 36414
 $102 = HEAP32[$1 >> 2] | 0; //@line 36415
 if (($102 & 1 | 0) != 0) {
  _e68_exception_address($c, $102, 0, 0); //@line 36420
  STACKTOP = sp; //@line 36422
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 36426
 $108 = $102 & 16777215; //@line 36427
 $109 = $108 + 1 | 0; //@line 36428
 if ($109 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $114 = HEAP32[$c + 32 >> 2] | 0; //@line 36434
  $_0_i_i20 = HEAPU8[$114 + $108 | 0] << 8 | HEAPU8[$114 + $109 | 0]; //@line 36444
 } else {
  $_0_i_i20 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $108) | 0; //@line 36452
 }
 HEAP16[$7 >> 1] = $_0_i_i20; //@line 36455
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 36462
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 36465
  _e68_ea_set_val8($c, $98) | 0; //@line 36466
  STACKTOP = sp; //@line 36468
  return;
 } else {
  _e68_exception_bus($c); //@line 36471
  STACKTOP = sp; //@line 36473
  return;
 }
}
function _op0240($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $27 = 0, $42 = 0, $43 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $61 = 0, $62 = 0, $66 = 0, $79 = 0, $phitmp_i = 0, $82 = 0, $83 = 0, $90 = 0, $91 = 0, $96 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $106 = 0, $_0_i_i = 0, $121 = 0, $128 = 0, $131 = 0, $134 = 0, $144 = 0, $145 = 0, $148 = 0, $154 = 0, $155 = 0, $160 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 36503
 STACKTOP = STACKTOP + 8 | 0; //@line 36503
 $s2 = sp | 0; //@line 36504
 $1 = $c + 160 | 0; //@line 36505
 if ((HEAP16[$1 >> 1] & 63) == 60) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   _e68_exception_privilege($c); //@line 36516
   STACKTOP = sp; //@line 36518
   return;
  }
  $11 = $c + 156 | 0; //@line 36521
  $12 = HEAP32[$11 >> 2] | 0; //@line 36522
  if (($12 & 1 | 0) != 0) {
   _e68_exception_address($c, $12, 0, 0); //@line 36527
   STACKTOP = sp; //@line 36529
   return;
  }
  $17 = $c + 164 | 0; //@line 36532
  $19 = $c + 162 | 0; //@line 36534
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 36535
  $20 = $12 & 16777215; //@line 36536
  $21 = $20 + 1 | 0; //@line 36537
  $22 = $c + 36 | 0; //@line 36538
  if ($21 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $27 = HEAP32[$c + 32 >> 2] | 0; //@line 36544
   $42 = HEAPU8[$27 + $20 | 0] << 8 | HEAPU8[$27 + $21 | 0]; //@line 36554
  } else {
   $42 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $20) | 0; //@line 36562
  }
  HEAP16[$17 >> 1] = $42; //@line 36565
  $43 = $c + 336 | 0; //@line 36566
  if ((HEAP8[$43] | 0) != 0) {
   _e68_exception_bus($c); //@line 36571
   STACKTOP = sp; //@line 36573
   return;
  }
  $49 = (HEAP32[$11 >> 2] | 0) + 2 | 0; //@line 36577
  HEAP32[$11 >> 2] = $49; //@line 36578
  $50 = $c + 152 | 0; //@line 36579
  $52 = (HEAP32[$50 >> 2] | 0) + 2 | 0; //@line 36581
  HEAP32[$50 >> 2] = $52; //@line 36582
  $53 = HEAP16[$19 >> 1] | 0; //@line 36583
  $54 = $c + 372 | 0; //@line 36584
  HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 20; //@line 36587
  if (($49 & 1 | 0) != 0) {
   _e68_exception_address($c, $49, 0, 0); //@line 36592
   STACKTOP = sp; //@line 36594
   return;
  }
  HEAP16[$19 >> 1] = $42; //@line 36597
  $61 = $49 & 16777215; //@line 36598
  $62 = $61 + 1 | 0; //@line 36599
  do {
   if ($62 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
    $66 = HEAP32[$c + 32 >> 2] | 0; //@line 36606
    HEAP16[$17 >> 1] = HEAPU8[$66 + $61 | 0] << 8 | HEAPU8[$66 + $62 | 0]; //@line 36615
    $83 = $49;
    $82 = $52;
   } else {
    $79 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $61) | 0; //@line 36623
    $phitmp_i = (HEAP8[$43] | 0) == 0; //@line 36625
    HEAP16[$17 >> 1] = $79; //@line 36626
    if ($phitmp_i) {
     $83 = HEAP32[$11 >> 2] | 0;
     $82 = HEAP32[$50 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 36635
    STACKTOP = sp; //@line 36637
    return;
   }
  } while (0);
  HEAP32[$11 >> 2] = $83 + 2; //@line 36644
  HEAP32[$50 >> 2] = $82 + 2; //@line 36646
  _e68_set_sr($c, HEAP16[$c + 166 >> 1] & $53); //@line 36650
  STACKTOP = sp; //@line 36652
  return;
 }
 $90 = $c + 156 | 0; //@line 36655
 $91 = HEAP32[$90 >> 2] | 0; //@line 36656
 if (($91 & 1 | 0) != 0) {
  _e68_exception_address($c, $91, 0, 0); //@line 36661
  STACKTOP = sp; //@line 36663
  return;
 }
 $96 = $c + 164 | 0; //@line 36666
 $98 = $c + 162 | 0; //@line 36668
 HEAP16[$98 >> 1] = HEAP16[$96 >> 1] | 0; //@line 36669
 $99 = $91 & 16777215; //@line 36670
 $100 = $99 + 1 | 0; //@line 36671
 $101 = $c + 36 | 0; //@line 36672
 if ($100 >>> 0 < (HEAP32[$101 >> 2] | 0) >>> 0) {
  $106 = HEAP32[$c + 32 >> 2] | 0; //@line 36678
  $_0_i_i = HEAPU8[$106 + $99 | 0] << 8 | HEAPU8[$106 + $100 | 0]; //@line 36688
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $99) | 0; //@line 36696
 }
 HEAP16[$96 >> 1] = $_0_i_i; //@line 36699
 $121 = $c + 336 | 0; //@line 36700
 if ((HEAP8[$121] | 0) != 0) {
  _e68_exception_bus($c); //@line 36705
  STACKTOP = sp; //@line 36707
  return;
 }
 HEAP32[$90 >> 2] = (HEAP32[$90 >> 2] | 0) + 2; //@line 36712
 $128 = $c + 152 | 0; //@line 36713
 HEAP32[$128 >> 2] = (HEAP32[$128 >> 2] | 0) + 2; //@line 36716
 $131 = HEAP16[$98 >> 1] | 0; //@line 36717
 $134 = HEAP16[$1 >> 1] & 63; //@line 36720
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($134 << 2) >> 2] & 127]($c, $134, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 36727
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 36734
  return;
 }
 $144 = HEAP16[$s2 >> 1] & $131; //@line 36738
 $145 = $c + 372 | 0; //@line 36739
 HEAP32[$145 >> 2] = (HEAP32[$145 >> 2] | 0) + 8; //@line 36742
 _e68_cc_set_nz_16($c, 15, $144); //@line 36743
 $148 = HEAP32[$90 >> 2] | 0; //@line 36744
 if (($148 & 1 | 0) != 0) {
  _e68_exception_address($c, $148, 0, 0); //@line 36749
  STACKTOP = sp; //@line 36751
  return;
 }
 HEAP16[$98 >> 1] = HEAP16[$96 >> 1] | 0; //@line 36755
 $154 = $148 & 16777215; //@line 36756
 $155 = $154 + 1 | 0; //@line 36757
 if ($155 >>> 0 < (HEAP32[$101 >> 2] | 0) >>> 0) {
  $160 = HEAP32[$c + 32 >> 2] | 0; //@line 36763
  $_0_i_i11 = HEAPU8[$160 + $154 | 0] << 8 | HEAPU8[$160 + $155 | 0]; //@line 36773
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $154) | 0; //@line 36781
 }
 HEAP16[$96 >> 1] = $_0_i_i11; //@line 36784
 if ((HEAP8[$121] | 0) == 0) {
  HEAP32[$90 >> 2] = (HEAP32[$90 >> 2] | 0) + 2; //@line 36791
  HEAP32[$128 >> 2] = (HEAP32[$128 >> 2] | 0) + 2; //@line 36794
  _e68_ea_set_val16($c, $144) | 0; //@line 36795
  STACKTOP = sp; //@line 36797
  return;
 } else {
  _e68_exception_bus($c); //@line 36800
  STACKTOP = sp; //@line 36802
  return;
 }
}
function _op0280($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $48 = 0, $49 = 0, $53 = 0, $66 = 0, $phitmp = 0, $77 = 0, $81 = 0, $91 = 0, $92 = 0, $95 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i17 = 0, sp = 0;
 sp = STACKTOP; //@line 36826
 STACKTOP = STACKTOP + 8 | 0; //@line 36826
 $s2 = sp | 0; //@line 36827
 $1 = $c + 156 | 0; //@line 36828
 $2 = HEAP32[$1 >> 2] | 0; //@line 36829
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 36834
  STACKTOP = sp; //@line 36836
  return;
 }
 $7 = $c + 164 | 0; //@line 36839
 $9 = $c + 162 | 0; //@line 36841
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 36842
 $10 = $2 & 16777215; //@line 36843
 $11 = $10 + 1 | 0; //@line 36844
 $12 = $c + 36 | 0; //@line 36845
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 36851
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 36861
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 36869
 }
 HEAP16[$7 >> 1] = $32; //@line 36872
 $33 = $c + 336 | 0; //@line 36873
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 36878
  STACKTOP = sp; //@line 36880
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 36884
 HEAP32[$1 >> 2] = $39; //@line 36885
 $40 = $c + 152 | 0; //@line 36886
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 36889
 $43 = HEAP16[$9 >> 1] | 0; //@line 36890
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 36895
  STACKTOP = sp; //@line 36897
  return;
 }
 HEAP16[$9 >> 1] = $32; //@line 36900
 $48 = $39 & 16777215; //@line 36901
 $49 = $48 + 1 | 0; //@line 36902
 do {
  if ($49 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $53 = HEAP32[$c + 32 >> 2] | 0; //@line 36909
   HEAP16[$7 >> 1] = HEAPU8[$53 + $48 | 0] << 8 | HEAPU8[$53 + $49 | 0]; //@line 36918
  } else {
   $66 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 36925
   $phitmp = (HEAP8[$33] | 0) == 0; //@line 36927
   HEAP16[$7 >> 1] = $66; //@line 36928
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 36933
   STACKTOP = sp; //@line 36935
   return;
  }
 } while (0);
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 36941
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 36944
 $77 = HEAPU16[$9 >> 1] | ($43 & 65535) << 16; //@line 36949
 $81 = HEAP16[$c + 160 >> 1] & 63; //@line 36953
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($81 << 2) >> 2] & 127]($c, $81, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 36960
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 36967
  return;
 }
 $91 = HEAP32[$s2 >> 2] & $77; //@line 36971
 $92 = $c + 372 | 0; //@line 36972
 HEAP32[$92 >> 2] = (HEAP32[$92 >> 2] | 0) + 16; //@line 36975
 _e68_cc_set_nz_32($c, 15, $91); //@line 36976
 $95 = HEAP32[$1 >> 2] | 0; //@line 36977
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 36982
  STACKTOP = sp; //@line 36984
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 36988
 $101 = $95 & 16777215; //@line 36989
 $102 = $101 + 1 | 0; //@line 36990
 if ($102 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 36996
  $_0_i_i17 = HEAPU8[$107 + $101 | 0] << 8 | HEAPU8[$107 + $102 | 0]; //@line 37006
 } else {
  $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 37014
 }
 HEAP16[$7 >> 1] = $_0_i_i17; //@line 37017
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37024
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 37027
  _e68_ea_set_val32($c, $91) | 0; //@line 37028
  STACKTOP = sp; //@line 37030
  return;
 } else {
  _e68_exception_bus($c); //@line 37033
  STACKTOP = sp; //@line 37035
  return;
 }
}
function _op0400($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $43 = 0, $47 = 0, $56 = 0, $57 = 0, $58 = 0, $61 = 0, $67 = 0, $68 = 0, $73 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 37055
 STACKTOP = STACKTOP + 8 | 0; //@line 37055
 $s2 = sp | 0; //@line 37056
 $1 = $c + 156 | 0; //@line 37057
 $2 = HEAP32[$1 >> 2] | 0; //@line 37058
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 37063
  STACKTOP = sp; //@line 37065
  return;
 }
 $7 = $c + 164 | 0; //@line 37068
 $9 = $c + 162 | 0; //@line 37070
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37071
 $10 = $2 & 16777215; //@line 37072
 $11 = $10 + 1 | 0; //@line 37073
 $12 = $c + 36 | 0; //@line 37074
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 37080
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 37090
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 37098
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 37101
 $32 = $c + 336 | 0; //@line 37102
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 37107
  STACKTOP = sp; //@line 37109
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37114
 $39 = $c + 152 | 0; //@line 37115
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37118
 $43 = HEAP16[$9 >> 1] & 255; //@line 37120
 $47 = HEAP16[$c + 160 >> 1] & 63; //@line 37124
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($47 << 2) >> 2] & 127]($c, $47, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 37131
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 37138
  return;
 }
 $56 = HEAP8[$s2] | 0; //@line 37141
 $57 = $56 - $43 & 255; //@line 37142
 $58 = $c + 372 | 0; //@line 37143
 HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 8; //@line 37146
 _e68_cc_set_sub_8($c, $57, $43, $56); //@line 37147
 $61 = HEAP32[$1 >> 2] | 0; //@line 37148
 if (($61 & 1 | 0) != 0) {
  _e68_exception_address($c, $61, 0, 0); //@line 37153
  STACKTOP = sp; //@line 37155
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37159
 $67 = $61 & 16777215; //@line 37160
 $68 = $67 + 1 | 0; //@line 37161
 if ($68 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $73 = HEAP32[$c + 32 >> 2] | 0; //@line 37167
  $_0_i_i11 = HEAPU8[$73 + $67 | 0] << 8 | HEAPU8[$73 + $68 | 0]; //@line 37177
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $67) | 0; //@line 37185
 }
 HEAP16[$7 >> 1] = $_0_i_i11; //@line 37188
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37195
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37198
  _e68_ea_set_val8($c, $57) | 0; //@line 37199
  STACKTOP = sp; //@line 37201
  return;
 } else {
  _e68_exception_bus($c); //@line 37204
  STACKTOP = sp; //@line 37206
  return;
 }
}
function _op0440($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $42 = 0, $46 = 0, $55 = 0, $56 = 0, $57 = 0, $60 = 0, $66 = 0, $67 = 0, $72 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 37226
 STACKTOP = STACKTOP + 8 | 0; //@line 37226
 $s2 = sp | 0; //@line 37227
 $1 = $c + 156 | 0; //@line 37228
 $2 = HEAP32[$1 >> 2] | 0; //@line 37229
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 37234
  STACKTOP = sp; //@line 37236
  return;
 }
 $7 = $c + 164 | 0; //@line 37239
 $9 = $c + 162 | 0; //@line 37241
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37242
 $10 = $2 & 16777215; //@line 37243
 $11 = $10 + 1 | 0; //@line 37244
 $12 = $c + 36 | 0; //@line 37245
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 37251
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 37261
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 37269
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 37272
 $32 = $c + 336 | 0; //@line 37273
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 37278
  STACKTOP = sp; //@line 37280
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37285
 $39 = $c + 152 | 0; //@line 37286
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37289
 $42 = HEAP16[$9 >> 1] | 0; //@line 37290
 $46 = HEAP16[$c + 160 >> 1] & 63; //@line 37294
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($46 << 2) >> 2] & 127]($c, $46, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 37301
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 37308
  return;
 }
 $55 = HEAP16[$s2 >> 1] | 0; //@line 37311
 $56 = $55 - $42 & 65535; //@line 37312
 $57 = $c + 372 | 0; //@line 37313
 HEAP32[$57 >> 2] = (HEAP32[$57 >> 2] | 0) + 8; //@line 37316
 _e68_cc_set_sub_16($c, $56, $42, $55); //@line 37317
 $60 = HEAP32[$1 >> 2] | 0; //@line 37318
 if (($60 & 1 | 0) != 0) {
  _e68_exception_address($c, $60, 0, 0); //@line 37323
  STACKTOP = sp; //@line 37325
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37329
 $66 = $60 & 16777215; //@line 37330
 $67 = $66 + 1 | 0; //@line 37331
 if ($67 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $72 = HEAP32[$c + 32 >> 2] | 0; //@line 37337
  $_0_i_i11 = HEAPU8[$72 + $66 | 0] << 8 | HEAPU8[$72 + $67 | 0]; //@line 37347
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $66) | 0; //@line 37355
 }
 HEAP16[$7 >> 1] = $_0_i_i11; //@line 37358
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37365
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37368
  _e68_ea_set_val16($c, $56) | 0; //@line 37369
  STACKTOP = sp; //@line 37371
  return;
 } else {
  _e68_exception_bus($c); //@line 37374
  STACKTOP = sp; //@line 37376
  return;
 }
}
function _op0480($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $48 = 0, $49 = 0, $53 = 0, $66 = 0, $phitmp = 0, $77 = 0, $81 = 0, $90 = 0, $91 = 0, $92 = 0, $95 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i18 = 0, sp = 0;
 sp = STACKTOP; //@line 37400
 STACKTOP = STACKTOP + 8 | 0; //@line 37400
 $s2 = sp | 0; //@line 37401
 $1 = $c + 156 | 0; //@line 37402
 $2 = HEAP32[$1 >> 2] | 0; //@line 37403
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 37408
  STACKTOP = sp; //@line 37410
  return;
 }
 $7 = $c + 164 | 0; //@line 37413
 $9 = $c + 162 | 0; //@line 37415
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37416
 $10 = $2 & 16777215; //@line 37417
 $11 = $10 + 1 | 0; //@line 37418
 $12 = $c + 36 | 0; //@line 37419
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 37425
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 37435
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 37443
 }
 HEAP16[$7 >> 1] = $32; //@line 37446
 $33 = $c + 336 | 0; //@line 37447
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 37452
  STACKTOP = sp; //@line 37454
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 37458
 HEAP32[$1 >> 2] = $39; //@line 37459
 $40 = $c + 152 | 0; //@line 37460
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 37463
 $43 = HEAP16[$9 >> 1] | 0; //@line 37464
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 37469
  STACKTOP = sp; //@line 37471
  return;
 }
 HEAP16[$9 >> 1] = $32; //@line 37474
 $48 = $39 & 16777215; //@line 37475
 $49 = $48 + 1 | 0; //@line 37476
 do {
  if ($49 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $53 = HEAP32[$c + 32 >> 2] | 0; //@line 37483
   HEAP16[$7 >> 1] = HEAPU8[$53 + $48 | 0] << 8 | HEAPU8[$53 + $49 | 0]; //@line 37492
  } else {
   $66 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 37499
   $phitmp = (HEAP8[$33] | 0) == 0; //@line 37501
   HEAP16[$7 >> 1] = $66; //@line 37502
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 37507
   STACKTOP = sp; //@line 37509
   return;
  }
 } while (0);
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37515
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 37518
 $77 = HEAPU16[$9 >> 1] | ($43 & 65535) << 16; //@line 37523
 $81 = HEAP16[$c + 160 >> 1] & 63; //@line 37527
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($81 << 2) >> 2] & 127]($c, $81, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 37534
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 37541
  return;
 }
 $90 = HEAP32[$s2 >> 2] | 0; //@line 37544
 $91 = $90 - $77 | 0; //@line 37545
 $92 = $c + 372 | 0; //@line 37546
 HEAP32[$92 >> 2] = (HEAP32[$92 >> 2] | 0) + 16; //@line 37549
 _e68_cc_set_sub_32($c, $91, $77, $90); //@line 37550
 $95 = HEAP32[$1 >> 2] | 0; //@line 37551
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 37556
  STACKTOP = sp; //@line 37558
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37562
 $101 = $95 & 16777215; //@line 37563
 $102 = $101 + 1 | 0; //@line 37564
 if ($102 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 37570
  $_0_i_i18 = HEAPU8[$107 + $101 | 0] << 8 | HEAPU8[$107 + $102 | 0]; //@line 37580
 } else {
  $_0_i_i18 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 37588
 }
 HEAP16[$7 >> 1] = $_0_i_i18; //@line 37591
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37598
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 37601
  _e68_ea_set_val32($c, $91) | 0; //@line 37602
  STACKTOP = sp; //@line 37604
  return;
 } else {
  _e68_exception_bus($c); //@line 37607
  STACKTOP = sp; //@line 37609
  return;
 }
}
function _op0600($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $43 = 0, $47 = 0, $56 = 0, $57 = 0, $58 = 0, $61 = 0, $67 = 0, $68 = 0, $73 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 37629
 STACKTOP = STACKTOP + 8 | 0; //@line 37629
 $s2 = sp | 0; //@line 37630
 $1 = $c + 156 | 0; //@line 37631
 $2 = HEAP32[$1 >> 2] | 0; //@line 37632
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 37637
  STACKTOP = sp; //@line 37639
  return;
 }
 $7 = $c + 164 | 0; //@line 37642
 $9 = $c + 162 | 0; //@line 37644
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37645
 $10 = $2 & 16777215; //@line 37646
 $11 = $10 + 1 | 0; //@line 37647
 $12 = $c + 36 | 0; //@line 37648
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 37654
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 37664
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 37672
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 37675
 $32 = $c + 336 | 0; //@line 37676
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 37681
  STACKTOP = sp; //@line 37683
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37688
 $39 = $c + 152 | 0; //@line 37689
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37692
 $43 = HEAP16[$9 >> 1] & 255; //@line 37694
 $47 = HEAP16[$c + 160 >> 1] & 63; //@line 37698
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($47 << 2) >> 2] & 127]($c, $47, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 37705
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 37712
  return;
 }
 $56 = HEAP8[$s2] | 0; //@line 37715
 $57 = $56 + $43 & 255; //@line 37716
 $58 = $c + 372 | 0; //@line 37717
 HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 8; //@line 37720
 _e68_cc_set_add_8($c, $57, $43, $56); //@line 37721
 $61 = HEAP32[$1 >> 2] | 0; //@line 37722
 if (($61 & 1 | 0) != 0) {
  _e68_exception_address($c, $61, 0, 0); //@line 37727
  STACKTOP = sp; //@line 37729
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37733
 $67 = $61 & 16777215; //@line 37734
 $68 = $67 + 1 | 0; //@line 37735
 if ($68 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $73 = HEAP32[$c + 32 >> 2] | 0; //@line 37741
  $_0_i_i11 = HEAPU8[$73 + $67 | 0] << 8 | HEAPU8[$73 + $68 | 0]; //@line 37751
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $67) | 0; //@line 37759
 }
 HEAP16[$7 >> 1] = $_0_i_i11; //@line 37762
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37769
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37772
  _e68_ea_set_val8($c, $57) | 0; //@line 37773
  STACKTOP = sp; //@line 37775
  return;
 } else {
  _e68_exception_bus($c); //@line 37778
  STACKTOP = sp; //@line 37780
  return;
 }
}
function _op0640($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $42 = 0, $46 = 0, $55 = 0, $56 = 0, $57 = 0, $60 = 0, $66 = 0, $67 = 0, $72 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 37800
 STACKTOP = STACKTOP + 8 | 0; //@line 37800
 $s2 = sp | 0; //@line 37801
 $1 = $c + 156 | 0; //@line 37802
 $2 = HEAP32[$1 >> 2] | 0; //@line 37803
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 37808
  STACKTOP = sp; //@line 37810
  return;
 }
 $7 = $c + 164 | 0; //@line 37813
 $9 = $c + 162 | 0; //@line 37815
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37816
 $10 = $2 & 16777215; //@line 37817
 $11 = $10 + 1 | 0; //@line 37818
 $12 = $c + 36 | 0; //@line 37819
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 37825
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 37835
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 37843
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 37846
 $32 = $c + 336 | 0; //@line 37847
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 37852
  STACKTOP = sp; //@line 37854
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37859
 $39 = $c + 152 | 0; //@line 37860
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37863
 $42 = HEAP16[$9 >> 1] | 0; //@line 37864
 $46 = HEAP16[$c + 160 >> 1] & 63; //@line 37868
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($46 << 2) >> 2] & 127]($c, $46, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 37875
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 37882
  return;
 }
 $55 = HEAP16[$s2 >> 1] | 0; //@line 37885
 $56 = $55 + $42 & 65535; //@line 37886
 $57 = $c + 372 | 0; //@line 37887
 HEAP32[$57 >> 2] = (HEAP32[$57 >> 2] | 0) + 8; //@line 37890
 _e68_cc_set_add_16($c, $56, $42, $55); //@line 37891
 $60 = HEAP32[$1 >> 2] | 0; //@line 37892
 if (($60 & 1 | 0) != 0) {
  _e68_exception_address($c, $60, 0, 0); //@line 37897
  STACKTOP = sp; //@line 37899
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37903
 $66 = $60 & 16777215; //@line 37904
 $67 = $66 + 1 | 0; //@line 37905
 if ($67 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $72 = HEAP32[$c + 32 >> 2] | 0; //@line 37911
  $_0_i_i11 = HEAPU8[$72 + $66 | 0] << 8 | HEAPU8[$72 + $67 | 0]; //@line 37921
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $66) | 0; //@line 37929
 }
 HEAP16[$7 >> 1] = $_0_i_i11; //@line 37932
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 37939
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 37942
  _e68_ea_set_val16($c, $56) | 0; //@line 37943
  STACKTOP = sp; //@line 37945
  return;
 } else {
  _e68_exception_bus($c); //@line 37948
  STACKTOP = sp; //@line 37950
  return;
 }
}
function _op0680($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $48 = 0, $49 = 0, $53 = 0, $66 = 0, $phitmp = 0, $77 = 0, $81 = 0, $90 = 0, $91 = 0, $92 = 0, $95 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i18 = 0, sp = 0;
 sp = STACKTOP; //@line 37974
 STACKTOP = STACKTOP + 8 | 0; //@line 37974
 $s2 = sp | 0; //@line 37975
 $1 = $c + 156 | 0; //@line 37976
 $2 = HEAP32[$1 >> 2] | 0; //@line 37977
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 37982
  STACKTOP = sp; //@line 37984
  return;
 }
 $7 = $c + 164 | 0; //@line 37987
 $9 = $c + 162 | 0; //@line 37989
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 37990
 $10 = $2 & 16777215; //@line 37991
 $11 = $10 + 1 | 0; //@line 37992
 $12 = $c + 36 | 0; //@line 37993
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 37999
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 38009
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 38017
 }
 HEAP16[$7 >> 1] = $32; //@line 38020
 $33 = $c + 336 | 0; //@line 38021
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 38026
  STACKTOP = sp; //@line 38028
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 38032
 HEAP32[$1 >> 2] = $39; //@line 38033
 $40 = $c + 152 | 0; //@line 38034
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 38037
 $43 = HEAP16[$9 >> 1] | 0; //@line 38038
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 38043
  STACKTOP = sp; //@line 38045
  return;
 }
 HEAP16[$9 >> 1] = $32; //@line 38048
 $48 = $39 & 16777215; //@line 38049
 $49 = $48 + 1 | 0; //@line 38050
 do {
  if ($49 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $53 = HEAP32[$c + 32 >> 2] | 0; //@line 38057
   HEAP16[$7 >> 1] = HEAPU8[$53 + $48 | 0] << 8 | HEAPU8[$53 + $49 | 0]; //@line 38066
  } else {
   $66 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 38073
   $phitmp = (HEAP8[$33] | 0) == 0; //@line 38075
   HEAP16[$7 >> 1] = $66; //@line 38076
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 38081
   STACKTOP = sp; //@line 38083
   return;
  }
 } while (0);
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 38089
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 38092
 $77 = HEAPU16[$9 >> 1] | ($43 & 65535) << 16; //@line 38097
 $81 = HEAP16[$c + 160 >> 1] & 63; //@line 38101
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($81 << 2) >> 2] & 127]($c, $81, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 38108
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 38115
  return;
 }
 $90 = HEAP32[$s2 >> 2] | 0; //@line 38118
 $91 = $90 + $77 | 0; //@line 38119
 $92 = $c + 372 | 0; //@line 38120
 HEAP32[$92 >> 2] = (HEAP32[$92 >> 2] | 0) + 16; //@line 38123
 _e68_cc_set_add_32($c, $91, $77, $90); //@line 38124
 $95 = HEAP32[$1 >> 2] | 0; //@line 38125
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 38130
  STACKTOP = sp; //@line 38132
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 38136
 $101 = $95 & 16777215; //@line 38137
 $102 = $101 + 1 | 0; //@line 38138
 if ($102 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 38144
  $_0_i_i18 = HEAPU8[$107 + $101 | 0] << 8 | HEAPU8[$107 + $102 | 0]; //@line 38154
 } else {
  $_0_i_i18 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 38162
 }
 HEAP16[$7 >> 1] = $_0_i_i18; //@line 38165
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 38172
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 38175
  _e68_ea_set_val32($c, $91) | 0; //@line 38176
  STACKTOP = sp; //@line 38178
  return;
 } else {
  _e68_exception_bus($c); //@line 38181
  STACKTOP = sp; //@line 38183
  return;
 }
}
function _op0800($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $5 = 0, $6 = 0, $8 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $22 = 0, $37 = 0, $38 = 0, $44 = 0, $45 = 0, $47 = 0, $57 = 0, $58 = 0, $62 = 0, $63 = 0, $70 = 0, $71 = 0, $75 = 0, $88 = 0, $phitmp_i = 0, $91 = 0, $92 = 0, $98 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $108 = 0, $_0_i_i = 0, $123 = 0, $130 = 0, $133 = 0, $136 = 0, $150 = 0, $151 = 0, $155 = 0, $156 = 0, $159 = 0, $165 = 0, $166 = 0, $171 = 0, $_0_i_i9 = 0, sp = 0;
 sp = STACKTOP; //@line 38214
 STACKTOP = STACKTOP + 8 | 0; //@line 38214
 $s2 = sp | 0; //@line 38215
 $1 = $c + 160 | 0; //@line 38216
 $5 = $c + 156 | 0; //@line 38220
 $6 = HEAP32[$5 >> 2] | 0; //@line 38221
 $8 = ($6 & 1 | 0) == 0; //@line 38223
 if ((HEAP16[$1 >> 1] & 56) == 0) {
  if (!$8) {
   _e68_exception_address($c, $6, 0, 0); //@line 38228
   STACKTOP = sp; //@line 38230
   return;
  }
  $12 = $c + 164 | 0; //@line 38233
  $14 = $c + 162 | 0; //@line 38235
  HEAP16[$14 >> 1] = HEAP16[$12 >> 1] | 0; //@line 38236
  $15 = $6 & 16777215; //@line 38237
  $16 = $15 + 1 | 0; //@line 38238
  $17 = $c + 36 | 0; //@line 38239
  if ($16 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
   $22 = HEAP32[$c + 32 >> 2] | 0; //@line 38245
   $37 = HEAPU8[$22 + $15 | 0] << 8 | HEAPU8[$22 + $16 | 0]; //@line 38255
  } else {
   $37 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $15) | 0; //@line 38263
  }
  HEAP16[$12 >> 1] = $37; //@line 38266
  $38 = $c + 336 | 0; //@line 38267
  if ((HEAP8[$38] | 0) != 0) {
   _e68_exception_bus($c); //@line 38272
   STACKTOP = sp; //@line 38274
   return;
  }
  $44 = (HEAP32[$5 >> 2] | 0) + 2 | 0; //@line 38278
  HEAP32[$5 >> 2] = $44; //@line 38279
  $45 = $c + 152 | 0; //@line 38280
  $47 = (HEAP32[$45 >> 2] | 0) + 2 | 0; //@line 38282
  HEAP32[$45 >> 2] = $47; //@line 38283
  $57 = 1 << (HEAP16[$14 >> 1] & 31) & HEAP32[$c + 88 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2]; //@line 38293
  $58 = $c + 372 | 0; //@line 38294
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 10; //@line 38297
  $62 = $c + 166 | 0; //@line 38299
  $63 = HEAP16[$62 >> 1] | 0; //@line 38300
  HEAP16[$62 >> 1] = ($57 | 0) == 0 ? $63 | 4 : $63 & -5; //@line 38304
  if (($44 & 1 | 0) != 0) {
   _e68_exception_address($c, $44, 0, 0); //@line 38309
   STACKTOP = sp; //@line 38311
   return;
  }
  HEAP16[$14 >> 1] = $37; //@line 38314
  $70 = $44 & 16777215; //@line 38315
  $71 = $70 + 1 | 0; //@line 38316
  do {
   if ($71 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
    $75 = HEAP32[$c + 32 >> 2] | 0; //@line 38323
    HEAP16[$12 >> 1] = HEAPU8[$75 + $70 | 0] << 8 | HEAPU8[$75 + $71 | 0]; //@line 38332
    $92 = $44;
    $91 = $47;
   } else {
    $88 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $70) | 0; //@line 38340
    $phitmp_i = (HEAP8[$38] | 0) == 0; //@line 38342
    HEAP16[$12 >> 1] = $88; //@line 38343
    if ($phitmp_i) {
     $92 = HEAP32[$5 >> 2] | 0;
     $91 = HEAP32[$45 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 38352
    STACKTOP = sp; //@line 38354
    return;
   }
  } while (0);
  HEAP32[$5 >> 2] = $92 + 2; //@line 38361
  HEAP32[$45 >> 2] = $91 + 2; //@line 38363
  STACKTOP = sp; //@line 38365
  return;
 }
 if (!$8) {
  _e68_exception_address($c, $6, 0, 0); //@line 38370
  STACKTOP = sp; //@line 38372
  return;
 }
 $98 = $c + 164 | 0; //@line 38375
 $100 = $c + 162 | 0; //@line 38377
 HEAP16[$100 >> 1] = HEAP16[$98 >> 1] | 0; //@line 38378
 $101 = $6 & 16777215; //@line 38379
 $102 = $101 + 1 | 0; //@line 38380
 $103 = $c + 36 | 0; //@line 38381
 if ($102 >>> 0 < (HEAP32[$103 >> 2] | 0) >>> 0) {
  $108 = HEAP32[$c + 32 >> 2] | 0; //@line 38387
  $_0_i_i = HEAPU8[$108 + $101 | 0] << 8 | HEAPU8[$108 + $102 | 0]; //@line 38397
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 38405
 }
 HEAP16[$98 >> 1] = $_0_i_i; //@line 38408
 $123 = $c + 336 | 0; //@line 38409
 if ((HEAP8[$123] | 0) != 0) {
  _e68_exception_bus($c); //@line 38414
  STACKTOP = sp; //@line 38416
  return;
 }
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 38421
 $130 = $c + 152 | 0; //@line 38422
 HEAP32[$130 >> 2] = (HEAP32[$130 >> 2] | 0) + 2; //@line 38425
 $133 = HEAP16[$100 >> 1] | 0; //@line 38426
 $136 = HEAP16[$1 >> 1] & 63; //@line 38429
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($136 << 2) >> 2] & 127]($c, $136, 2044, 8) | 0) != 0) {
  STACKTOP = sp; //@line 38436
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 38443
  return;
 }
 $150 = HEAPU8[$s2] & 1 << ($133 & 7); //@line 38451
 $151 = $c + 372 | 0; //@line 38452
 HEAP32[$151 >> 2] = (HEAP32[$151 >> 2] | 0) + 8; //@line 38455
 $155 = $c + 166 | 0; //@line 38457
 $156 = HEAP16[$155 >> 1] | 0; //@line 38458
 HEAP16[$155 >> 1] = ($150 | 0) == 0 ? $156 | 4 : $156 & -5; //@line 38462
 $159 = HEAP32[$5 >> 2] | 0; //@line 38463
 if (($159 & 1 | 0) != 0) {
  _e68_exception_address($c, $159, 0, 0); //@line 38468
  STACKTOP = sp; //@line 38470
  return;
 }
 HEAP16[$100 >> 1] = HEAP16[$98 >> 1] | 0; //@line 38474
 $165 = $159 & 16777215; //@line 38475
 $166 = $165 + 1 | 0; //@line 38476
 if ($166 >>> 0 < (HEAP32[$103 >> 2] | 0) >>> 0) {
  $171 = HEAP32[$c + 32 >> 2] | 0; //@line 38482
  $_0_i_i9 = HEAPU8[$171 + $165 | 0] << 8 | HEAPU8[$171 + $166 | 0]; //@line 38492
 } else {
  $_0_i_i9 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $165) | 0; //@line 38500
 }
 HEAP16[$98 >> 1] = $_0_i_i9; //@line 38503
 if ((HEAP8[$123] | 0) == 0) {
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 38510
  HEAP32[$130 >> 2] = (HEAP32[$130 >> 2] | 0) + 2; //@line 38513
  STACKTOP = sp; //@line 38515
  return;
 } else {
  _e68_exception_bus($c); //@line 38518
  STACKTOP = sp; //@line 38520
  return;
 }
}
function _op0840($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $5 = 0, $6 = 0, $8 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $22 = 0, $37 = 0, $38 = 0, $44 = 0, $45 = 0, $47 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $63 = 0, $64 = 0, $71 = 0, $72 = 0, $76 = 0, $89 = 0, $phitmp_i = 0, $92 = 0, $93 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $109 = 0, $_0_i_i = 0, $124 = 0, $131 = 0, $136 = 0, $139 = 0, $148 = 0, $150 = 0, $153 = 0, $158 = 0, $159 = 0, $162 = 0, $168 = 0, $169 = 0, $174 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 38552
 STACKTOP = STACKTOP + 8 | 0; //@line 38552
 $s = sp | 0; //@line 38553
 $1 = $c + 160 | 0; //@line 38554
 $5 = $c + 156 | 0; //@line 38558
 $6 = HEAP32[$5 >> 2] | 0; //@line 38559
 $8 = ($6 & 1 | 0) == 0; //@line 38561
 if ((HEAP16[$1 >> 1] & 56) == 0) {
  if (!$8) {
   _e68_exception_address($c, $6, 0, 0); //@line 38566
   STACKTOP = sp; //@line 38568
   return;
  }
  $12 = $c + 164 | 0; //@line 38571
  $14 = $c + 162 | 0; //@line 38573
  HEAP16[$14 >> 1] = HEAP16[$12 >> 1] | 0; //@line 38574
  $15 = $6 & 16777215; //@line 38575
  $16 = $15 + 1 | 0; //@line 38576
  $17 = $c + 36 | 0; //@line 38577
  if ($16 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
   $22 = HEAP32[$c + 32 >> 2] | 0; //@line 38583
   $37 = HEAPU8[$22 + $15 | 0] << 8 | HEAPU8[$22 + $16 | 0]; //@line 38593
  } else {
   $37 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $15) | 0; //@line 38601
  }
  HEAP16[$12 >> 1] = $37; //@line 38604
  $38 = $c + 336 | 0; //@line 38605
  if ((HEAP8[$38] | 0) != 0) {
   _e68_exception_bus($c); //@line 38610
   STACKTOP = sp; //@line 38612
   return;
  }
  $44 = (HEAP32[$5 >> 2] | 0) + 2 | 0; //@line 38616
  HEAP32[$5 >> 2] = $44; //@line 38617
  $45 = $c + 152 | 0; //@line 38618
  $47 = (HEAP32[$45 >> 2] | 0) + 2 | 0; //@line 38620
  HEAP32[$45 >> 2] = $47; //@line 38621
  $54 = $c + 88 + ((HEAP16[$1 >> 1] & 7) << 2) | 0; //@line 38628
  $55 = HEAP32[$54 >> 2] | 0; //@line 38629
  $56 = 1 << (HEAP16[$14 >> 1] & 31); //@line 38630
  $57 = $56 ^ $55; //@line 38631
  $58 = $c + 372 | 0; //@line 38632
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 12; //@line 38635
  $63 = $c + 166 | 0; //@line 38638
  $64 = HEAP16[$63 >> 1] | 0; //@line 38639
  HEAP16[$63 >> 1] = ($56 & $55 | 0) == 0 ? $64 | 4 : $64 & -5; //@line 38643
  if (($44 & 1 | 0) != 0) {
   _e68_exception_address($c, $44, 0, 0); //@line 38648
   STACKTOP = sp; //@line 38650
   return;
  }
  HEAP16[$14 >> 1] = $37; //@line 38653
  $71 = $44 & 16777215; //@line 38654
  $72 = $71 + 1 | 0; //@line 38655
  do {
   if ($72 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
    $76 = HEAP32[$c + 32 >> 2] | 0; //@line 38662
    HEAP16[$12 >> 1] = HEAPU8[$76 + $71 | 0] << 8 | HEAPU8[$76 + $72 | 0]; //@line 38671
    $93 = $44;
    $92 = $47;
   } else {
    $89 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $71) | 0; //@line 38679
    $phitmp_i = (HEAP8[$38] | 0) == 0; //@line 38681
    HEAP16[$12 >> 1] = $89; //@line 38682
    if ($phitmp_i) {
     $93 = HEAP32[$5 >> 2] | 0;
     $92 = HEAP32[$45 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 38691
    STACKTOP = sp; //@line 38693
    return;
   }
  } while (0);
  HEAP32[$5 >> 2] = $93 + 2; //@line 38700
  HEAP32[$45 >> 2] = $92 + 2; //@line 38702
  HEAP32[$54 >> 2] = $57; //@line 38703
  STACKTOP = sp; //@line 38705
  return;
 }
 if (!$8) {
  _e68_exception_address($c, $6, 0, 0); //@line 38710
  STACKTOP = sp; //@line 38712
  return;
 }
 $99 = $c + 164 | 0; //@line 38715
 $101 = $c + 162 | 0; //@line 38717
 HEAP16[$101 >> 1] = HEAP16[$99 >> 1] | 0; //@line 38718
 $102 = $6 & 16777215; //@line 38719
 $103 = $102 + 1 | 0; //@line 38720
 $104 = $c + 36 | 0; //@line 38721
 if ($103 >>> 0 < (HEAP32[$104 >> 2] | 0) >>> 0) {
  $109 = HEAP32[$c + 32 >> 2] | 0; //@line 38727
  $_0_i_i = HEAPU8[$109 + $102 | 0] << 8 | HEAPU8[$109 + $103 | 0]; //@line 38737
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $102) | 0; //@line 38745
 }
 HEAP16[$99 >> 1] = $_0_i_i; //@line 38748
 $124 = $c + 336 | 0; //@line 38749
 if ((HEAP8[$124] | 0) != 0) {
  _e68_exception_bus($c); //@line 38754
  STACKTOP = sp; //@line 38756
  return;
 }
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 38761
 $131 = $c + 152 | 0; //@line 38762
 HEAP32[$131 >> 2] = (HEAP32[$131 >> 2] | 0) + 2; //@line 38765
 $136 = HEAP16[$101 >> 1] & 7; //@line 38768
 $139 = HEAP16[$1 >> 1] & 63; //@line 38771
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($139 << 2) >> 2] & 127]($c, $139, 508, 8) | 0) != 0) {
  STACKTOP = sp; //@line 38778
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 38785
  return;
 }
 $148 = 1 << $136; //@line 38788
 $150 = HEAPU8[$s] | 0; //@line 38790
 $153 = $c + 372 | 0; //@line 38793
 HEAP32[$153 >> 2] = (HEAP32[$153 >> 2] | 0) + 12; //@line 38796
 $158 = $c + 166 | 0; //@line 38799
 $159 = HEAP16[$158 >> 1] | 0; //@line 38800
 HEAP16[$158 >> 1] = ($148 & $150 | 0) == 0 ? $159 | 4 : $159 & -5; //@line 38804
 $162 = HEAP32[$5 >> 2] | 0; //@line 38805
 if (($162 & 1 | 0) != 0) {
  _e68_exception_address($c, $162, 0, 0); //@line 38810
  STACKTOP = sp; //@line 38812
  return;
 }
 HEAP16[$101 >> 1] = HEAP16[$99 >> 1] | 0; //@line 38816
 $168 = $162 & 16777215; //@line 38817
 $169 = $168 + 1 | 0; //@line 38818
 if ($169 >>> 0 < (HEAP32[$104 >> 2] | 0) >>> 0) {
  $174 = HEAP32[$c + 32 >> 2] | 0; //@line 38824
  $_0_i_i11 = HEAPU8[$174 + $168 | 0] << 8 | HEAPU8[$174 + $169 | 0]; //@line 38834
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $168) | 0; //@line 38842
 }
 HEAP16[$99 >> 1] = $_0_i_i11; //@line 38845
 if ((HEAP8[$124] | 0) == 0) {
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 38852
  HEAP32[$131 >> 2] = (HEAP32[$131 >> 2] | 0) + 2; //@line 38855
  _e68_ea_set_val8($c, ($150 ^ $148) & 255) | 0; //@line 38856
  STACKTOP = sp; //@line 38858
  return;
 } else {
  _e68_exception_bus($c); //@line 38861
  STACKTOP = sp; //@line 38863
  return;
 }
}
function _op0880($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $5 = 0, $6 = 0, $8 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $22 = 0, $37 = 0, $38 = 0, $44 = 0, $45 = 0, $47 = 0, $54 = 0, $55 = 0, $56 = 0, $58 = 0, $59 = 0, $64 = 0, $65 = 0, $72 = 0, $73 = 0, $77 = 0, $90 = 0, $phitmp_i = 0, $93 = 0, $94 = 0, $100 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $110 = 0, $_0_i_i = 0, $125 = 0, $132 = 0, $137 = 0, $140 = 0, $149 = 0, $151 = 0, $155 = 0, $160 = 0, $161 = 0, $164 = 0, $170 = 0, $171 = 0, $176 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 38895
 STACKTOP = STACKTOP + 8 | 0; //@line 38895
 $s = sp | 0; //@line 38896
 $1 = $c + 160 | 0; //@line 38897
 $5 = $c + 156 | 0; //@line 38901
 $6 = HEAP32[$5 >> 2] | 0; //@line 38902
 $8 = ($6 & 1 | 0) == 0; //@line 38904
 if ((HEAP16[$1 >> 1] & 56) == 0) {
  if (!$8) {
   _e68_exception_address($c, $6, 0, 0); //@line 38909
   STACKTOP = sp; //@line 38911
   return;
  }
  $12 = $c + 164 | 0; //@line 38914
  $14 = $c + 162 | 0; //@line 38916
  HEAP16[$14 >> 1] = HEAP16[$12 >> 1] | 0; //@line 38917
  $15 = $6 & 16777215; //@line 38918
  $16 = $15 + 1 | 0; //@line 38919
  $17 = $c + 36 | 0; //@line 38920
  if ($16 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
   $22 = HEAP32[$c + 32 >> 2] | 0; //@line 38926
   $37 = HEAPU8[$22 + $15 | 0] << 8 | HEAPU8[$22 + $16 | 0]; //@line 38936
  } else {
   $37 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $15) | 0; //@line 38944
  }
  HEAP16[$12 >> 1] = $37; //@line 38947
  $38 = $c + 336 | 0; //@line 38948
  if ((HEAP8[$38] | 0) != 0) {
   _e68_exception_bus($c); //@line 38953
   STACKTOP = sp; //@line 38955
   return;
  }
  $44 = (HEAP32[$5 >> 2] | 0) + 2 | 0; //@line 38959
  HEAP32[$5 >> 2] = $44; //@line 38960
  $45 = $c + 152 | 0; //@line 38961
  $47 = (HEAP32[$45 >> 2] | 0) + 2 | 0; //@line 38963
  HEAP32[$45 >> 2] = $47; //@line 38964
  $54 = $c + 88 + ((HEAP16[$1 >> 1] & 7) << 2) | 0; //@line 38971
  $55 = HEAP32[$54 >> 2] | 0; //@line 38972
  $56 = 1 << (HEAP16[$14 >> 1] & 31); //@line 38973
  $58 = $55 & ~$56; //@line 38975
  $59 = $c + 372 | 0; //@line 38976
  HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 14; //@line 38979
  $64 = $c + 166 | 0; //@line 38982
  $65 = HEAP16[$64 >> 1] | 0; //@line 38983
  HEAP16[$64 >> 1] = ($56 & $55 | 0) == 0 ? $65 | 4 : $65 & -5; //@line 38987
  if (($44 & 1 | 0) != 0) {
   _e68_exception_address($c, $44, 0, 0); //@line 38992
   STACKTOP = sp; //@line 38994
   return;
  }
  HEAP16[$14 >> 1] = $37; //@line 38997
  $72 = $44 & 16777215; //@line 38998
  $73 = $72 + 1 | 0; //@line 38999
  do {
   if ($73 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
    $77 = HEAP32[$c + 32 >> 2] | 0; //@line 39006
    HEAP16[$12 >> 1] = HEAPU8[$77 + $72 | 0] << 8 | HEAPU8[$77 + $73 | 0]; //@line 39015
    $94 = $44;
    $93 = $47;
   } else {
    $90 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $72) | 0; //@line 39023
    $phitmp_i = (HEAP8[$38] | 0) == 0; //@line 39025
    HEAP16[$12 >> 1] = $90; //@line 39026
    if ($phitmp_i) {
     $94 = HEAP32[$5 >> 2] | 0;
     $93 = HEAP32[$45 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 39035
    STACKTOP = sp; //@line 39037
    return;
   }
  } while (0);
  HEAP32[$5 >> 2] = $94 + 2; //@line 39044
  HEAP32[$45 >> 2] = $93 + 2; //@line 39046
  HEAP32[$54 >> 2] = $58; //@line 39047
  STACKTOP = sp; //@line 39049
  return;
 }
 if (!$8) {
  _e68_exception_address($c, $6, 0, 0); //@line 39054
  STACKTOP = sp; //@line 39056
  return;
 }
 $100 = $c + 164 | 0; //@line 39059
 $102 = $c + 162 | 0; //@line 39061
 HEAP16[$102 >> 1] = HEAP16[$100 >> 1] | 0; //@line 39062
 $103 = $6 & 16777215; //@line 39063
 $104 = $103 + 1 | 0; //@line 39064
 $105 = $c + 36 | 0; //@line 39065
 if ($104 >>> 0 < (HEAP32[$105 >> 2] | 0) >>> 0) {
  $110 = HEAP32[$c + 32 >> 2] | 0; //@line 39071
  $_0_i_i = HEAPU8[$110 + $103 | 0] << 8 | HEAPU8[$110 + $104 | 0]; //@line 39081
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $103) | 0; //@line 39089
 }
 HEAP16[$100 >> 1] = $_0_i_i; //@line 39092
 $125 = $c + 336 | 0; //@line 39093
 if ((HEAP8[$125] | 0) != 0) {
  _e68_exception_bus($c); //@line 39098
  STACKTOP = sp; //@line 39100
  return;
 }
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 39105
 $132 = $c + 152 | 0; //@line 39106
 HEAP32[$132 >> 2] = (HEAP32[$132 >> 2] | 0) + 2; //@line 39109
 $137 = HEAP16[$102 >> 1] & 7; //@line 39112
 $140 = HEAP16[$1 >> 1] & 63; //@line 39115
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($140 << 2) >> 2] & 127]($c, $140, 508, 8) | 0) != 0) {
  STACKTOP = sp; //@line 39122
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 39129
  return;
 }
 $149 = 1 << $137; //@line 39132
 $151 = HEAPU8[$s] | 0; //@line 39134
 $155 = $c + 372 | 0; //@line 39138
 HEAP32[$155 >> 2] = (HEAP32[$155 >> 2] | 0) + 12; //@line 39141
 $160 = $c + 166 | 0; //@line 39144
 $161 = HEAP16[$160 >> 1] | 0; //@line 39145
 HEAP16[$160 >> 1] = ($149 & $151 | 0) == 0 ? $161 | 4 : $161 & -5; //@line 39149
 $164 = HEAP32[$5 >> 2] | 0; //@line 39150
 if (($164 & 1 | 0) != 0) {
  _e68_exception_address($c, $164, 0, 0); //@line 39155
  STACKTOP = sp; //@line 39157
  return;
 }
 HEAP16[$102 >> 1] = HEAP16[$100 >> 1] | 0; //@line 39161
 $170 = $164 & 16777215; //@line 39162
 $171 = $170 + 1 | 0; //@line 39163
 if ($171 >>> 0 < (HEAP32[$105 >> 2] | 0) >>> 0) {
  $176 = HEAP32[$c + 32 >> 2] | 0; //@line 39169
  $_0_i_i11 = HEAPU8[$176 + $170 | 0] << 8 | HEAPU8[$176 + $171 | 0]; //@line 39179
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $170) | 0; //@line 39187
 }
 HEAP16[$100 >> 1] = $_0_i_i11; //@line 39190
 if ((HEAP8[$125] | 0) == 0) {
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 39197
  HEAP32[$132 >> 2] = (HEAP32[$132 >> 2] | 0) + 2; //@line 39200
  _e68_ea_set_val8($c, $151 & ($149 ^ 255) & 255) | 0; //@line 39201
  STACKTOP = sp; //@line 39203
  return;
 } else {
  _e68_exception_bus($c); //@line 39206
  STACKTOP = sp; //@line 39208
  return;
 }
}
function _op08c0($c) {
 $c = $c | 0;
 var $s = 0, $1 = 0, $5 = 0, $6 = 0, $8 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $22 = 0, $37 = 0, $38 = 0, $44 = 0, $45 = 0, $47 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $63 = 0, $64 = 0, $71 = 0, $72 = 0, $76 = 0, $89 = 0, $phitmp_i = 0, $92 = 0, $93 = 0, $99 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $109 = 0, $_0_i_i = 0, $124 = 0, $131 = 0, $136 = 0, $139 = 0, $148 = 0, $150 = 0, $153 = 0, $158 = 0, $159 = 0, $162 = 0, $168 = 0, $169 = 0, $174 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 39240
 STACKTOP = STACKTOP + 8 | 0; //@line 39240
 $s = sp | 0; //@line 39241
 $1 = $c + 160 | 0; //@line 39242
 $5 = $c + 156 | 0; //@line 39246
 $6 = HEAP32[$5 >> 2] | 0; //@line 39247
 $8 = ($6 & 1 | 0) == 0; //@line 39249
 if ((HEAP16[$1 >> 1] & 56) == 0) {
  if (!$8) {
   _e68_exception_address($c, $6, 0, 0); //@line 39254
   STACKTOP = sp; //@line 39256
   return;
  }
  $12 = $c + 164 | 0; //@line 39259
  $14 = $c + 162 | 0; //@line 39261
  HEAP16[$14 >> 1] = HEAP16[$12 >> 1] | 0; //@line 39262
  $15 = $6 & 16777215; //@line 39263
  $16 = $15 + 1 | 0; //@line 39264
  $17 = $c + 36 | 0; //@line 39265
  if ($16 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
   $22 = HEAP32[$c + 32 >> 2] | 0; //@line 39271
   $37 = HEAPU8[$22 + $15 | 0] << 8 | HEAPU8[$22 + $16 | 0]; //@line 39281
  } else {
   $37 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $15) | 0; //@line 39289
  }
  HEAP16[$12 >> 1] = $37; //@line 39292
  $38 = $c + 336 | 0; //@line 39293
  if ((HEAP8[$38] | 0) != 0) {
   _e68_exception_bus($c); //@line 39298
   STACKTOP = sp; //@line 39300
   return;
  }
  $44 = (HEAP32[$5 >> 2] | 0) + 2 | 0; //@line 39304
  HEAP32[$5 >> 2] = $44; //@line 39305
  $45 = $c + 152 | 0; //@line 39306
  $47 = (HEAP32[$45 >> 2] | 0) + 2 | 0; //@line 39308
  HEAP32[$45 >> 2] = $47; //@line 39309
  $54 = $c + 88 + ((HEAP16[$1 >> 1] & 7) << 2) | 0; //@line 39316
  $55 = HEAP32[$54 >> 2] | 0; //@line 39317
  $56 = 1 << (HEAP16[$14 >> 1] & 31); //@line 39318
  $57 = $56 | $55; //@line 39319
  $58 = $c + 372 | 0; //@line 39320
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 12; //@line 39323
  $63 = $c + 166 | 0; //@line 39326
  $64 = HEAP16[$63 >> 1] | 0; //@line 39327
  HEAP16[$63 >> 1] = ($56 & $55 | 0) == 0 ? $64 | 4 : $64 & -5; //@line 39331
  if (($44 & 1 | 0) != 0) {
   _e68_exception_address($c, $44, 0, 0); //@line 39336
   STACKTOP = sp; //@line 39338
   return;
  }
  HEAP16[$14 >> 1] = $37; //@line 39341
  $71 = $44 & 16777215; //@line 39342
  $72 = $71 + 1 | 0; //@line 39343
  do {
   if ($72 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
    $76 = HEAP32[$c + 32 >> 2] | 0; //@line 39350
    HEAP16[$12 >> 1] = HEAPU8[$76 + $71 | 0] << 8 | HEAPU8[$76 + $72 | 0]; //@line 39359
    $93 = $44;
    $92 = $47;
   } else {
    $89 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $71) | 0; //@line 39367
    $phitmp_i = (HEAP8[$38] | 0) == 0; //@line 39369
    HEAP16[$12 >> 1] = $89; //@line 39370
    if ($phitmp_i) {
     $93 = HEAP32[$5 >> 2] | 0;
     $92 = HEAP32[$45 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 39379
    STACKTOP = sp; //@line 39381
    return;
   }
  } while (0);
  HEAP32[$5 >> 2] = $93 + 2; //@line 39388
  HEAP32[$45 >> 2] = $92 + 2; //@line 39390
  HEAP32[$54 >> 2] = $57; //@line 39391
  STACKTOP = sp; //@line 39393
  return;
 }
 if (!$8) {
  _e68_exception_address($c, $6, 0, 0); //@line 39398
  STACKTOP = sp; //@line 39400
  return;
 }
 $99 = $c + 164 | 0; //@line 39403
 $101 = $c + 162 | 0; //@line 39405
 HEAP16[$101 >> 1] = HEAP16[$99 >> 1] | 0; //@line 39406
 $102 = $6 & 16777215; //@line 39407
 $103 = $102 + 1 | 0; //@line 39408
 $104 = $c + 36 | 0; //@line 39409
 if ($103 >>> 0 < (HEAP32[$104 >> 2] | 0) >>> 0) {
  $109 = HEAP32[$c + 32 >> 2] | 0; //@line 39415
  $_0_i_i = HEAPU8[$109 + $102 | 0] << 8 | HEAPU8[$109 + $103 | 0]; //@line 39425
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $102) | 0; //@line 39433
 }
 HEAP16[$99 >> 1] = $_0_i_i; //@line 39436
 $124 = $c + 336 | 0; //@line 39437
 if ((HEAP8[$124] | 0) != 0) {
  _e68_exception_bus($c); //@line 39442
  STACKTOP = sp; //@line 39444
  return;
 }
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 39449
 $131 = $c + 152 | 0; //@line 39450
 HEAP32[$131 >> 2] = (HEAP32[$131 >> 2] | 0) + 2; //@line 39453
 $136 = HEAP16[$101 >> 1] & 7; //@line 39456
 $139 = HEAP16[$1 >> 1] & 63; //@line 39459
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($139 << 2) >> 2] & 127]($c, $139, 508, 8) | 0) != 0) {
  STACKTOP = sp; //@line 39466
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 39473
  return;
 }
 $148 = 1 << $136; //@line 39476
 $150 = HEAPU8[$s] | 0; //@line 39478
 $153 = $c + 372 | 0; //@line 39481
 HEAP32[$153 >> 2] = (HEAP32[$153 >> 2] | 0) + 12; //@line 39484
 $158 = $c + 166 | 0; //@line 39487
 $159 = HEAP16[$158 >> 1] | 0; //@line 39488
 HEAP16[$158 >> 1] = ($148 & $150 | 0) == 0 ? $159 | 4 : $159 & -5; //@line 39492
 $162 = HEAP32[$5 >> 2] | 0; //@line 39493
 if (($162 & 1 | 0) != 0) {
  _e68_exception_address($c, $162, 0, 0); //@line 39498
  STACKTOP = sp; //@line 39500
  return;
 }
 HEAP16[$101 >> 1] = HEAP16[$99 >> 1] | 0; //@line 39504
 $168 = $162 & 16777215; //@line 39505
 $169 = $168 + 1 | 0; //@line 39506
 if ($169 >>> 0 < (HEAP32[$104 >> 2] | 0) >>> 0) {
  $174 = HEAP32[$c + 32 >> 2] | 0; //@line 39512
  $_0_i_i11 = HEAPU8[$174 + $168 | 0] << 8 | HEAPU8[$174 + $169 | 0]; //@line 39522
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $168) | 0; //@line 39530
 }
 HEAP16[$99 >> 1] = $_0_i_i11; //@line 39533
 if ((HEAP8[$124] | 0) == 0) {
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 39540
  HEAP32[$131 >> 2] = (HEAP32[$131 >> 2] | 0) + 2; //@line 39543
  _e68_ea_set_val8($c, ($150 | $148) & 255) | 0; //@line 39544
  STACKTOP = sp; //@line 39546
  return;
 } else {
  _e68_exception_bus($c); //@line 39549
  STACKTOP = sp; //@line 39551
  return;
 }
}
function _op0a00($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $47 = 0, $50 = 0, $57 = 0, $58 = 0, $62 = 0, $75 = 0, $phitmp = 0, $82 = 0, $83 = 0, $99 = 0, $100 = 0, $103 = 0, $109 = 0, $110 = 0, $115 = 0, $_0_i_i20 = 0, sp = 0;
 sp = STACKTOP; //@line 39576
 STACKTOP = STACKTOP + 8 | 0; //@line 39576
 $s2 = sp | 0; //@line 39577
 $1 = $c + 156 | 0; //@line 39578
 $2 = HEAP32[$1 >> 2] | 0; //@line 39579
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 39584
  STACKTOP = sp; //@line 39586
  return;
 }
 $7 = $c + 164 | 0; //@line 39589
 $9 = $c + 162 | 0; //@line 39591
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 39592
 $10 = $2 & 16777215; //@line 39593
 $11 = $10 + 1 | 0; //@line 39594
 $12 = $c + 36 | 0; //@line 39595
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 39601
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 39611
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 39619
 }
 HEAP16[$7 >> 1] = $32; //@line 39622
 $33 = $c + 336 | 0; //@line 39623
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 39628
  STACKTOP = sp; //@line 39630
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 39634
 HEAP32[$1 >> 2] = $39; //@line 39635
 $40 = $c + 152 | 0; //@line 39636
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 39639
 $43 = HEAP16[$9 >> 1] | 0; //@line 39640
 $47 = HEAP16[$c + 160 >> 1] & 63; //@line 39644
 if (($47 | 0) == 60) {
  $50 = $c + 372 | 0; //@line 39648
  HEAP32[$50 >> 2] = (HEAP32[$50 >> 2] | 0) + 20; //@line 39651
  if (($39 & 1 | 0) != 0) {
   _e68_exception_address($c, $39, 0, 0); //@line 39656
   STACKTOP = sp; //@line 39658
   return;
  }
  HEAP16[$9 >> 1] = $32; //@line 39661
  $57 = $39 & 16777215; //@line 39662
  $58 = $57 + 1 | 0; //@line 39663
  do {
   if ($58 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
    $62 = HEAP32[$c + 32 >> 2] | 0; //@line 39670
    HEAP16[$7 >> 1] = HEAPU8[$62 + $57 | 0] << 8 | HEAPU8[$62 + $58 | 0]; //@line 39679
   } else {
    $75 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $57) | 0; //@line 39686
    $phitmp = (HEAP8[$33] | 0) == 0; //@line 39688
    HEAP16[$7 >> 1] = $75; //@line 39689
    if ($phitmp) {
     break;
    }
    _e68_exception_bus($c); //@line 39694
    STACKTOP = sp; //@line 39696
    return;
   }
  } while (0);
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 39702
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 39705
  $82 = $c + 166 | 0; //@line 39706
  $83 = HEAP16[$82 >> 1] | 0; //@line 39707
  HEAP16[$82 >> 1] = ($83 ^ $43) & 31 | $83 & -256; //@line 39712
  STACKTOP = sp; //@line 39714
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($47 << 2) >> 2] & 127]($c, $47, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 39723
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 39730
  return;
 }
 $99 = HEAP8[$s2] ^ $43 & 255; //@line 39735
 $100 = $c + 372 | 0; //@line 39736
 HEAP32[$100 >> 2] = (HEAP32[$100 >> 2] | 0) + 8; //@line 39739
 _e68_cc_set_nz_8($c, 15, $99); //@line 39740
 $103 = HEAP32[$1 >> 2] | 0; //@line 39741
 if (($103 & 1 | 0) != 0) {
  _e68_exception_address($c, $103, 0, 0); //@line 39746
  STACKTOP = sp; //@line 39748
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 39752
 $109 = $103 & 16777215; //@line 39753
 $110 = $109 + 1 | 0; //@line 39754
 if ($110 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $115 = HEAP32[$c + 32 >> 2] | 0; //@line 39760
  $_0_i_i20 = HEAPU8[$115 + $109 | 0] << 8 | HEAPU8[$115 + $110 | 0]; //@line 39770
 } else {
  $_0_i_i20 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $109) | 0; //@line 39778
 }
 HEAP16[$7 >> 1] = $_0_i_i20; //@line 39781
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 39788
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 39791
  _e68_ea_set_val8($c, $99) | 0; //@line 39792
  STACKTOP = sp; //@line 39794
  return;
 } else {
  _e68_exception_bus($c); //@line 39797
  STACKTOP = sp; //@line 39799
  return;
 }
}
function _op0a40($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $27 = 0, $42 = 0, $43 = 0, $49 = 0, $50 = 0, $52 = 0, $53 = 0, $54 = 0, $61 = 0, $62 = 0, $66 = 0, $79 = 0, $phitmp_i = 0, $82 = 0, $83 = 0, $91 = 0, $92 = 0, $97 = 0, $99 = 0, $100 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i = 0, $122 = 0, $129 = 0, $132 = 0, $135 = 0, $145 = 0, $146 = 0, $149 = 0, $155 = 0, $156 = 0, $161 = 0, $_0_i_i11 = 0, sp = 0;
 sp = STACKTOP; //@line 39829
 STACKTOP = STACKTOP + 8 | 0; //@line 39829
 $s2 = sp | 0; //@line 39830
 $1 = $c + 160 | 0; //@line 39831
 if ((HEAP16[$1 >> 1] & 63) == 60) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   _e68_exception_privilege($c); //@line 39842
   STACKTOP = sp; //@line 39844
   return;
  }
  $11 = $c + 156 | 0; //@line 39847
  $12 = HEAP32[$11 >> 2] | 0; //@line 39848
  if (($12 & 1 | 0) != 0) {
   _e68_exception_address($c, $12, 0, 0); //@line 39853
   STACKTOP = sp; //@line 39855
   return;
  }
  $17 = $c + 164 | 0; //@line 39858
  $19 = $c + 162 | 0; //@line 39860
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 39861
  $20 = $12 & 16777215; //@line 39862
  $21 = $20 + 1 | 0; //@line 39863
  $22 = $c + 36 | 0; //@line 39864
  if ($21 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $27 = HEAP32[$c + 32 >> 2] | 0; //@line 39870
   $42 = HEAPU8[$27 + $20 | 0] << 8 | HEAPU8[$27 + $21 | 0]; //@line 39880
  } else {
   $42 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $20) | 0; //@line 39888
  }
  HEAP16[$17 >> 1] = $42; //@line 39891
  $43 = $c + 336 | 0; //@line 39892
  if ((HEAP8[$43] | 0) != 0) {
   _e68_exception_bus($c); //@line 39897
   STACKTOP = sp; //@line 39899
   return;
  }
  $49 = (HEAP32[$11 >> 2] | 0) + 2 | 0; //@line 39903
  HEAP32[$11 >> 2] = $49; //@line 39904
  $50 = $c + 152 | 0; //@line 39905
  $52 = (HEAP32[$50 >> 2] | 0) + 2 | 0; //@line 39907
  HEAP32[$50 >> 2] = $52; //@line 39908
  $53 = HEAP16[$19 >> 1] | 0; //@line 39909
  $54 = $c + 372 | 0; //@line 39910
  HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 20; //@line 39913
  if (($49 & 1 | 0) != 0) {
   _e68_exception_address($c, $49, 0, 0); //@line 39918
   STACKTOP = sp; //@line 39920
   return;
  }
  HEAP16[$19 >> 1] = $42; //@line 39923
  $61 = $49 & 16777215; //@line 39924
  $62 = $61 + 1 | 0; //@line 39925
  do {
   if ($62 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
    $66 = HEAP32[$c + 32 >> 2] | 0; //@line 39932
    HEAP16[$17 >> 1] = HEAPU8[$66 + $61 | 0] << 8 | HEAPU8[$66 + $62 | 0]; //@line 39941
    $83 = $49;
    $82 = $52;
   } else {
    $79 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $61) | 0; //@line 39949
    $phitmp_i = (HEAP8[$43] | 0) == 0; //@line 39951
    HEAP16[$17 >> 1] = $79; //@line 39952
    if ($phitmp_i) {
     $83 = HEAP32[$11 >> 2] | 0;
     $82 = HEAP32[$50 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 39961
    STACKTOP = sp; //@line 39963
    return;
   }
  } while (0);
  HEAP32[$11 >> 2] = $83 + 2; //@line 39970
  HEAP32[$50 >> 2] = $82 + 2; //@line 39972
  _e68_set_sr($c, (HEAP16[$c + 166 >> 1] ^ $53) & -22753); //@line 39977
  STACKTOP = sp; //@line 39979
  return;
 }
 $91 = $c + 156 | 0; //@line 39982
 $92 = HEAP32[$91 >> 2] | 0; //@line 39983
 if (($92 & 1 | 0) != 0) {
  _e68_exception_address($c, $92, 0, 0); //@line 39988
  STACKTOP = sp; //@line 39990
  return;
 }
 $97 = $c + 164 | 0; //@line 39993
 $99 = $c + 162 | 0; //@line 39995
 HEAP16[$99 >> 1] = HEAP16[$97 >> 1] | 0; //@line 39996
 $100 = $92 & 16777215; //@line 39997
 $101 = $100 + 1 | 0; //@line 39998
 $102 = $c + 36 | 0; //@line 39999
 if ($101 >>> 0 < (HEAP32[$102 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 40005
  $_0_i_i = HEAPU8[$107 + $100 | 0] << 8 | HEAPU8[$107 + $101 | 0]; //@line 40015
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $100) | 0; //@line 40023
 }
 HEAP16[$97 >> 1] = $_0_i_i; //@line 40026
 $122 = $c + 336 | 0; //@line 40027
 if ((HEAP8[$122] | 0) != 0) {
  _e68_exception_bus($c); //@line 40032
  STACKTOP = sp; //@line 40034
  return;
 }
 HEAP32[$91 >> 2] = (HEAP32[$91 >> 2] | 0) + 2; //@line 40039
 $129 = $c + 152 | 0; //@line 40040
 HEAP32[$129 >> 2] = (HEAP32[$129 >> 2] | 0) + 2; //@line 40043
 $132 = HEAP16[$99 >> 1] | 0; //@line 40044
 $135 = HEAP16[$1 >> 1] & 63; //@line 40047
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($135 << 2) >> 2] & 127]($c, $135, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 40054
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 40061
  return;
 }
 $145 = HEAP16[$s2 >> 1] ^ $132; //@line 40065
 _e68_cc_set_nz_16($c, 15, $145); //@line 40066
 $146 = $c + 372 | 0; //@line 40067
 HEAP32[$146 >> 2] = (HEAP32[$146 >> 2] | 0) + 8; //@line 40070
 $149 = HEAP32[$91 >> 2] | 0; //@line 40071
 if (($149 & 1 | 0) != 0) {
  _e68_exception_address($c, $149, 0, 0); //@line 40076
  STACKTOP = sp; //@line 40078
  return;
 }
 HEAP16[$99 >> 1] = HEAP16[$97 >> 1] | 0; //@line 40082
 $155 = $149 & 16777215; //@line 40083
 $156 = $155 + 1 | 0; //@line 40084
 if ($156 >>> 0 < (HEAP32[$102 >> 2] | 0) >>> 0) {
  $161 = HEAP32[$c + 32 >> 2] | 0; //@line 40090
  $_0_i_i11 = HEAPU8[$161 + $155 | 0] << 8 | HEAPU8[$161 + $156 | 0]; //@line 40100
 } else {
  $_0_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $155) | 0; //@line 40108
 }
 HEAP16[$97 >> 1] = $_0_i_i11; //@line 40111
 if ((HEAP8[$122] | 0) == 0) {
  HEAP32[$91 >> 2] = (HEAP32[$91 >> 2] | 0) + 2; //@line 40118
  HEAP32[$129 >> 2] = (HEAP32[$129 >> 2] | 0) + 2; //@line 40121
  _e68_ea_set_val16($c, $145) | 0; //@line 40122
  STACKTOP = sp; //@line 40124
  return;
 } else {
  _e68_exception_bus($c); //@line 40127
  STACKTOP = sp; //@line 40129
  return;
 }
}
function _op0a80($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $48 = 0, $49 = 0, $53 = 0, $66 = 0, $phitmp = 0, $77 = 0, $81 = 0, $91 = 0, $92 = 0, $95 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i17 = 0, sp = 0;
 sp = STACKTOP; //@line 40153
 STACKTOP = STACKTOP + 8 | 0; //@line 40153
 $s2 = sp | 0; //@line 40154
 $1 = $c + 156 | 0; //@line 40155
 $2 = HEAP32[$1 >> 2] | 0; //@line 40156
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 40161
  STACKTOP = sp; //@line 40163
  return;
 }
 $7 = $c + 164 | 0; //@line 40166
 $9 = $c + 162 | 0; //@line 40168
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40169
 $10 = $2 & 16777215; //@line 40170
 $11 = $10 + 1 | 0; //@line 40171
 $12 = $c + 36 | 0; //@line 40172
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 40178
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 40188
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 40196
 }
 HEAP16[$7 >> 1] = $32; //@line 40199
 $33 = $c + 336 | 0; //@line 40200
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 40205
  STACKTOP = sp; //@line 40207
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 40211
 HEAP32[$1 >> 2] = $39; //@line 40212
 $40 = $c + 152 | 0; //@line 40213
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 40216
 $43 = HEAP16[$9 >> 1] | 0; //@line 40217
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 40222
  STACKTOP = sp; //@line 40224
  return;
 }
 HEAP16[$9 >> 1] = $32; //@line 40227
 $48 = $39 & 16777215; //@line 40228
 $49 = $48 + 1 | 0; //@line 40229
 do {
  if ($49 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $53 = HEAP32[$c + 32 >> 2] | 0; //@line 40236
   HEAP16[$7 >> 1] = HEAPU8[$53 + $48 | 0] << 8 | HEAPU8[$53 + $49 | 0]; //@line 40245
  } else {
   $66 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 40252
   $phitmp = (HEAP8[$33] | 0) == 0; //@line 40254
   HEAP16[$7 >> 1] = $66; //@line 40255
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 40260
   STACKTOP = sp; //@line 40262
   return;
  }
 } while (0);
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40268
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 40271
 $77 = HEAPU16[$9 >> 1] | ($43 & 65535) << 16; //@line 40276
 $81 = HEAP16[$c + 160 >> 1] & 63; //@line 40280
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($81 << 2) >> 2] & 127]($c, $81, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 40287
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 40294
  return;
 }
 $91 = HEAP32[$s2 >> 2] ^ $77; //@line 40298
 $92 = $c + 372 | 0; //@line 40299
 HEAP32[$92 >> 2] = (HEAP32[$92 >> 2] | 0) + 12; //@line 40302
 _e68_cc_set_nz_32($c, 15, $91); //@line 40303
 $95 = HEAP32[$1 >> 2] | 0; //@line 40304
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 40309
  STACKTOP = sp; //@line 40311
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40315
 $101 = $95 & 16777215; //@line 40316
 $102 = $101 + 1 | 0; //@line 40317
 if ($102 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 40323
  $_0_i_i17 = HEAPU8[$107 + $101 | 0] << 8 | HEAPU8[$107 + $102 | 0]; //@line 40333
 } else {
  $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 40341
 }
 HEAP16[$7 >> 1] = $_0_i_i17; //@line 40344
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40351
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 40354
  _e68_ea_set_val32($c, $91) | 0; //@line 40355
  STACKTOP = sp; //@line 40357
  return;
 } else {
  _e68_exception_bus($c); //@line 40360
  STACKTOP = sp; //@line 40362
  return;
 }
}
function _op0c00($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $43 = 0, $47 = 0, $56 = 0, $59 = 0, $61 = 0, $67 = 0, $68 = 0, $73 = 0, $_0_i_i9 = 0, sp = 0;
 sp = STACKTOP; //@line 40382
 STACKTOP = STACKTOP + 8 | 0; //@line 40382
 $s2 = sp | 0; //@line 40383
 $1 = $c + 156 | 0; //@line 40384
 $2 = HEAP32[$1 >> 2] | 0; //@line 40385
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 40390
  STACKTOP = sp; //@line 40392
  return;
 }
 $7 = $c + 164 | 0; //@line 40395
 $9 = $c + 162 | 0; //@line 40397
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40398
 $10 = $2 & 16777215; //@line 40399
 $11 = $10 + 1 | 0; //@line 40400
 $12 = $c + 36 | 0; //@line 40401
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 40407
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 40417
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 40425
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 40428
 $32 = $c + 336 | 0; //@line 40429
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 40434
  STACKTOP = sp; //@line 40436
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40441
 $39 = $c + 152 | 0; //@line 40442
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 40445
 $43 = HEAP16[$9 >> 1] & 255; //@line 40447
 $47 = HEAP16[$c + 160 >> 1] & 63; //@line 40451
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($47 << 2) >> 2] & 127]($c, $47, 2045, 8) | 0) != 0) {
  STACKTOP = sp; //@line 40458
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 40465
  return;
 }
 $56 = $c + 372 | 0; //@line 40468
 HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 8; //@line 40471
 $59 = HEAP8[$s2] | 0; //@line 40472
 _e68_cc_set_cmp_8($c, $59 - $43 & 255, $43, $59); //@line 40474
 $61 = HEAP32[$1 >> 2] | 0; //@line 40475
 if (($61 & 1 | 0) != 0) {
  _e68_exception_address($c, $61, 0, 0); //@line 40480
  STACKTOP = sp; //@line 40482
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40486
 $67 = $61 & 16777215; //@line 40487
 $68 = $67 + 1 | 0; //@line 40488
 if ($68 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $73 = HEAP32[$c + 32 >> 2] | 0; //@line 40494
  $_0_i_i9 = HEAPU8[$73 + $67 | 0] << 8 | HEAPU8[$73 + $68 | 0]; //@line 40504
 } else {
  $_0_i_i9 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $67) | 0; //@line 40512
 }
 HEAP16[$7 >> 1] = $_0_i_i9; //@line 40515
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40522
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 40525
  STACKTOP = sp; //@line 40527
  return;
 } else {
  _e68_exception_bus($c); //@line 40530
  STACKTOP = sp; //@line 40532
  return;
 }
}
function _op0c40($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $42 = 0, $46 = 0, $55 = 0, $58 = 0, $60 = 0, $66 = 0, $67 = 0, $72 = 0, $_0_i_i9 = 0, sp = 0;
 sp = STACKTOP; //@line 40552
 STACKTOP = STACKTOP + 8 | 0; //@line 40552
 $s2 = sp | 0; //@line 40553
 $1 = $c + 156 | 0; //@line 40554
 $2 = HEAP32[$1 >> 2] | 0; //@line 40555
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 40560
  STACKTOP = sp; //@line 40562
  return;
 }
 $7 = $c + 164 | 0; //@line 40565
 $9 = $c + 162 | 0; //@line 40567
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40568
 $10 = $2 & 16777215; //@line 40569
 $11 = $10 + 1 | 0; //@line 40570
 $12 = $c + 36 | 0; //@line 40571
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 40577
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 40587
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 40595
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 40598
 $32 = $c + 336 | 0; //@line 40599
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 40604
  STACKTOP = sp; //@line 40606
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40611
 $39 = $c + 152 | 0; //@line 40612
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 40615
 $42 = HEAP16[$9 >> 1] | 0; //@line 40616
 $46 = HEAP16[$c + 160 >> 1] & 63; //@line 40620
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($46 << 2) >> 2] & 127]($c, $46, 2045, 16) | 0) != 0) {
  STACKTOP = sp; //@line 40627
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 40634
  return;
 }
 $55 = $c + 372 | 0; //@line 40637
 HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 8; //@line 40640
 $58 = HEAP16[$s2 >> 1] | 0; //@line 40641
 _e68_cc_set_cmp_16($c, $58 - $42 & 65535, $42, $58); //@line 40643
 $60 = HEAP32[$1 >> 2] | 0; //@line 40644
 if (($60 & 1 | 0) != 0) {
  _e68_exception_address($c, $60, 0, 0); //@line 40649
  STACKTOP = sp; //@line 40651
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40655
 $66 = $60 & 16777215; //@line 40656
 $67 = $66 + 1 | 0; //@line 40657
 if ($67 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $72 = HEAP32[$c + 32 >> 2] | 0; //@line 40663
  $_0_i_i9 = HEAPU8[$72 + $66 | 0] << 8 | HEAPU8[$72 + $67 | 0]; //@line 40673
 } else {
  $_0_i_i9 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $66) | 0; //@line 40681
 }
 HEAP16[$7 >> 1] = $_0_i_i9; //@line 40684
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40691
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 40694
  STACKTOP = sp; //@line 40696
  return;
 } else {
  _e68_exception_bus($c); //@line 40699
  STACKTOP = sp; //@line 40701
  return;
 }
}
function _op0c80($c) {
 $c = $c | 0;
 var $s2 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $48 = 0, $49 = 0, $53 = 0, $66 = 0, $phitmp = 0, $77 = 0, $81 = 0, $90 = 0, $93 = 0, $95 = 0, $101 = 0, $102 = 0, $107 = 0, $_0_i_i16 = 0, sp = 0;
 sp = STACKTOP; //@line 40725
 STACKTOP = STACKTOP + 8 | 0; //@line 40725
 $s2 = sp | 0; //@line 40726
 $1 = $c + 156 | 0; //@line 40727
 $2 = HEAP32[$1 >> 2] | 0; //@line 40728
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 40733
  STACKTOP = sp; //@line 40735
  return;
 }
 $7 = $c + 164 | 0; //@line 40738
 $9 = $c + 162 | 0; //@line 40740
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40741
 $10 = $2 & 16777215; //@line 40742
 $11 = $10 + 1 | 0; //@line 40743
 $12 = $c + 36 | 0; //@line 40744
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 40750
  $32 = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 40760
 } else {
  $32 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 40768
 }
 HEAP16[$7 >> 1] = $32; //@line 40771
 $33 = $c + 336 | 0; //@line 40772
 if ((HEAP8[$33] | 0) != 0) {
  _e68_exception_bus($c); //@line 40777
  STACKTOP = sp; //@line 40779
  return;
 }
 $39 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 40783
 HEAP32[$1 >> 2] = $39; //@line 40784
 $40 = $c + 152 | 0; //@line 40785
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 40788
 $43 = HEAP16[$9 >> 1] | 0; //@line 40789
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 40794
  STACKTOP = sp; //@line 40796
  return;
 }
 HEAP16[$9 >> 1] = $32; //@line 40799
 $48 = $39 & 16777215; //@line 40800
 $49 = $48 + 1 | 0; //@line 40801
 do {
  if ($49 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
   $53 = HEAP32[$c + 32 >> 2] | 0; //@line 40808
   HEAP16[$7 >> 1] = HEAPU8[$53 + $48 | 0] << 8 | HEAPU8[$53 + $49 | 0]; //@line 40817
  } else {
   $66 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 40824
   $phitmp = (HEAP8[$33] | 0) == 0; //@line 40826
   HEAP16[$7 >> 1] = $66; //@line 40827
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 40832
   STACKTOP = sp; //@line 40834
   return;
  }
 } while (0);
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40840
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 40843
 $77 = HEAPU16[$9 >> 1] | ($43 & 65535) << 16; //@line 40848
 $81 = HEAP16[$c + 160 >> 1] & 63; //@line 40852
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($81 << 2) >> 2] & 127]($c, $81, 2045, 32) | 0) != 0) {
  STACKTOP = sp; //@line 40859
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 40866
  return;
 }
 $90 = $c + 372 | 0; //@line 40869
 HEAP32[$90 >> 2] = (HEAP32[$90 >> 2] | 0) + 12; //@line 40872
 $93 = HEAP32[$s2 >> 2] | 0; //@line 40873
 _e68_cc_set_cmp_32($c, $93 - $77 | 0, $77, $93); //@line 40875
 $95 = HEAP32[$1 >> 2] | 0; //@line 40876
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 40881
  STACKTOP = sp; //@line 40883
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 40887
 $101 = $95 & 16777215; //@line 40888
 $102 = $101 + 1 | 0; //@line 40889
 if ($102 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $107 = HEAP32[$c + 32 >> 2] | 0; //@line 40895
  $_0_i_i16 = HEAPU8[$107 + $101 | 0] << 8 | HEAPU8[$107 + $102 | 0]; //@line 40905
 } else {
  $_0_i_i16 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $101) | 0; //@line 40913
 }
 HEAP16[$7 >> 1] = $_0_i_i16; //@line 40916
 if ((HEAP8[$33] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 40923
  HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 2; //@line 40926
  STACKTOP = sp; //@line 40928
  return;
 } else {
  _e68_exception_bus($c); //@line 40931
  STACKTOP = sp; //@line 40933
  return;
 }
}
function _op0e00($c) {
 $c = $c | 0;
 var $v = 0, $6 = 0, $10 = 0, $11 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $26 = 0, $_0_i_i = 0, $41 = 0, $48 = 0, $51 = 0, $53 = 0, $54 = 0, $60 = 0, $_sink_in = 0, $70 = 0, $83 = 0, $94 = 0, $95 = 0, $97 = 0, $104 = 0, $110 = 0, $113 = 0, $119 = 0, $120 = 0, $125 = 0, $_0_i_i17 = 0, sp = 0;
 sp = STACKTOP; //@line 40958
 STACKTOP = STACKTOP + 8 | 0; //@line 40958
 $v = sp | 0; //@line 40959
 if ((HEAP32[$c >> 2] & 2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 40966
  $6 = $c + 372 | 0; //@line 40967
  HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 40970
  STACKTOP = sp; //@line 40972
  return;
 }
 $10 = $c + 156 | 0; //@line 40975
 $11 = HEAP32[$10 >> 2] | 0; //@line 40976
 if (($11 & 1 | 0) != 0) {
  _e68_exception_address($c, $11, 0, 0); //@line 40981
  STACKTOP = sp; //@line 40983
  return;
 }
 $16 = $c + 164 | 0; //@line 40986
 $18 = $c + 162 | 0; //@line 40988
 HEAP16[$18 >> 1] = HEAP16[$16 >> 1] | 0; //@line 40989
 $19 = $11 & 16777215; //@line 40990
 $20 = $19 + 1 | 0; //@line 40991
 $21 = $c + 36 | 0; //@line 40992
 if ($20 >>> 0 < (HEAP32[$21 >> 2] | 0) >>> 0) {
  $26 = HEAP32[$c + 32 >> 2] | 0; //@line 40998
  $_0_i_i = HEAPU8[$26 + $19 | 0] << 8 | HEAPU8[$26 + $20 | 0]; //@line 41008
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $19) | 0; //@line 41016
 }
 HEAP16[$16 >> 1] = $_0_i_i; //@line 41019
 $41 = $c + 336 | 0; //@line 41020
 if ((HEAP8[$41] | 0) != 0) {
  _e68_exception_bus($c); //@line 41025
  STACKTOP = sp; //@line 41027
  return;
 }
 HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 2; //@line 41032
 $48 = $c + 152 | 0; //@line 41033
 HEAP32[$48 >> 2] = (HEAP32[$48 >> 2] | 0) + 2; //@line 41036
 $51 = $c + 160 | 0; //@line 41037
 $53 = HEAPU16[$18 >> 1] | 0; //@line 41039
 $54 = $53 >>> 12; //@line 41040
 do {
  if (($53 & 2048 | 0) == 0) {
   $83 = HEAP16[$51 >> 1] & 63; //@line 41049
   if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($83 << 2) >> 2] & 127]($c, $83, 508, 8) | 0) != 0) {
    STACKTOP = sp; //@line 41056
    return;
   }
   if ((_e68_ea_get_val8($c, $v) | 0) != 0) {
    STACKTOP = sp; //@line 41063
    return;
   }
   $94 = $54 & 7; //@line 41068
   $95 = HEAP8[$v] | 0; //@line 41069
   if (($54 & 8 | 0) == 0) {
    $104 = $c + 88 + ($94 << 2) | 0; //@line 41072
    HEAP32[$104 >> 2] = HEAP32[$104 >> 2] & -256 | $95 & 255; //@line 41077
    break;
   } else {
    $97 = $95 & 255; //@line 41080
    HEAP32[$c + 120 + ($94 << 2) >> 2] = ($97 & 128 | 0) != 0 ? $97 | -256 : $97; //@line 41086
    break;
   }
  } else {
   $60 = $54 & 7; //@line 41093
   if (($54 & 8 | 0) == 0) {
    $_sink_in = $c + 88 + ($60 << 2) | 0; //@line 41097
   } else {
    $_sink_in = $c + 120 + ($60 << 2) | 0; //@line 41101
   }
   HEAP8[$v] = HEAP32[$_sink_in >> 2] & 255; //@line 41106
   $70 = HEAP16[$51 >> 1] & 63; //@line 41110
   if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($70 << 2) >> 2] & 127]($c, $70, 508, 8) | 0) != 0) {
    STACKTOP = sp; //@line 41117
    return;
   }
   if ((_e68_ea_set_val8($c, HEAP8[$v] | 0) | 0) == 0) {
    break;
   }
   STACKTOP = sp; //@line 41127
   return;
  }
 } while (0);
 $110 = $c + 372 | 0; //@line 41131
 HEAP32[$110 >> 2] = (HEAP32[$110 >> 2] | 0) + 4; //@line 41134
 $113 = HEAP32[$10 >> 2] | 0; //@line 41135
 if (($113 & 1 | 0) != 0) {
  _e68_exception_address($c, $113, 0, 0); //@line 41140
  STACKTOP = sp; //@line 41142
  return;
 }
 HEAP16[$18 >> 1] = HEAP16[$16 >> 1] | 0; //@line 41146
 $119 = $113 & 16777215; //@line 41147
 $120 = $119 + 1 | 0; //@line 41148
 if ($120 >>> 0 < (HEAP32[$21 >> 2] | 0) >>> 0) {
  $125 = HEAP32[$c + 32 >> 2] | 0; //@line 41154
  $_0_i_i17 = HEAPU8[$125 + $119 | 0] << 8 | HEAPU8[$125 + $120 | 0]; //@line 41164
 } else {
  $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $119) | 0; //@line 41172
 }
 HEAP16[$16 >> 1] = $_0_i_i17; //@line 41175
 if ((HEAP8[$41] | 0) == 0) {
  HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 2; //@line 41182
  HEAP32[$48 >> 2] = (HEAP32[$48 >> 2] | 0) + 2; //@line 41185
  STACKTOP = sp; //@line 41187
  return;
 } else {
  _e68_exception_bus($c); //@line 41190
  STACKTOP = sp; //@line 41192
  return;
 }
}
function _op0e40($c) {
 $c = $c | 0;
 var $v = 0, $6 = 0, $10 = 0, $11 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $26 = 0, $_0_i_i = 0, $41 = 0, $48 = 0, $51 = 0, $53 = 0, $54 = 0, $60 = 0, $_sink_in = 0, $70 = 0, $83 = 0, $94 = 0, $95 = 0, $97 = 0, $103 = 0, $109 = 0, $112 = 0, $118 = 0, $119 = 0, $124 = 0, $_0_i_i17 = 0, sp = 0;
 sp = STACKTOP; //@line 41217
 STACKTOP = STACKTOP + 8 | 0; //@line 41217
 $v = sp | 0; //@line 41218
 if ((HEAP32[$c >> 2] & 2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 41225
  $6 = $c + 372 | 0; //@line 41226
  HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 41229
  STACKTOP = sp; //@line 41231
  return;
 }
 $10 = $c + 156 | 0; //@line 41234
 $11 = HEAP32[$10 >> 2] | 0; //@line 41235
 if (($11 & 1 | 0) != 0) {
  _e68_exception_address($c, $11, 0, 0); //@line 41240
  STACKTOP = sp; //@line 41242
  return;
 }
 $16 = $c + 164 | 0; //@line 41245
 $18 = $c + 162 | 0; //@line 41247
 HEAP16[$18 >> 1] = HEAP16[$16 >> 1] | 0; //@line 41248
 $19 = $11 & 16777215; //@line 41249
 $20 = $19 + 1 | 0; //@line 41250
 $21 = $c + 36 | 0; //@line 41251
 if ($20 >>> 0 < (HEAP32[$21 >> 2] | 0) >>> 0) {
  $26 = HEAP32[$c + 32 >> 2] | 0; //@line 41257
  $_0_i_i = HEAPU8[$26 + $19 | 0] << 8 | HEAPU8[$26 + $20 | 0]; //@line 41267
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $19) | 0; //@line 41275
 }
 HEAP16[$16 >> 1] = $_0_i_i; //@line 41278
 $41 = $c + 336 | 0; //@line 41279
 if ((HEAP8[$41] | 0) != 0) {
  _e68_exception_bus($c); //@line 41284
  STACKTOP = sp; //@line 41286
  return;
 }
 HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 2; //@line 41291
 $48 = $c + 152 | 0; //@line 41292
 HEAP32[$48 >> 2] = (HEAP32[$48 >> 2] | 0) + 2; //@line 41295
 $51 = $c + 160 | 0; //@line 41296
 $53 = HEAPU16[$18 >> 1] | 0; //@line 41298
 $54 = $53 >>> 12; //@line 41299
 do {
  if (($53 & 2048 | 0) == 0) {
   $83 = HEAP16[$51 >> 1] & 63; //@line 41308
   if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($83 << 2) >> 2] & 127]($c, $83, 508, 16) | 0) != 0) {
    STACKTOP = sp; //@line 41315
    return;
   }
   if ((_e68_ea_get_val16($c, $v) | 0) != 0) {
    STACKTOP = sp; //@line 41322
    return;
   }
   $94 = $54 & 7; //@line 41327
   $95 = HEAP16[$v >> 1] | 0; //@line 41328
   if (($54 & 8 | 0) == 0) {
    $103 = $c + 88 + ($94 << 2) | 0; //@line 41331
    HEAP32[$103 >> 2] = HEAP32[$103 >> 2] & -65536 | $95 & 65535; //@line 41336
    break;
   } else {
    $97 = $95 & 65535; //@line 41339
    HEAP32[$c + 120 + ($94 << 2) >> 2] = ($97 & 32768 | 0) == 0 ? $97 : $97 | -65536; //@line 41345
    break;
   }
  } else {
   $60 = $54 & 7; //@line 41352
   if (($54 & 8 | 0) == 0) {
    $_sink_in = $c + 88 + ($60 << 2) | 0; //@line 41356
   } else {
    $_sink_in = $c + 120 + ($60 << 2) | 0; //@line 41360
   }
   HEAP16[$v >> 1] = HEAP32[$_sink_in >> 2] & 65535; //@line 41365
   $70 = HEAP16[$51 >> 1] & 63; //@line 41369
   if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($70 << 2) >> 2] & 127]($c, $70, 508, 16) | 0) != 0) {
    STACKTOP = sp; //@line 41376
    return;
   }
   if ((_e68_ea_set_val16($c, HEAP16[$v >> 1] | 0) | 0) == 0) {
    break;
   }
   STACKTOP = sp; //@line 41386
   return;
  }
 } while (0);
 $109 = $c + 372 | 0; //@line 41390
 HEAP32[$109 >> 2] = (HEAP32[$109 >> 2] | 0) + 4; //@line 41393
 $112 = HEAP32[$10 >> 2] | 0; //@line 41394
 if (($112 & 1 | 0) != 0) {
  _e68_exception_address($c, $112, 0, 0); //@line 41399
  STACKTOP = sp; //@line 41401
  return;
 }
 HEAP16[$18 >> 1] = HEAP16[$16 >> 1] | 0; //@line 41405
 $118 = $112 & 16777215; //@line 41406
 $119 = $118 + 1 | 0; //@line 41407
 if ($119 >>> 0 < (HEAP32[$21 >> 2] | 0) >>> 0) {
  $124 = HEAP32[$c + 32 >> 2] | 0; //@line 41413
  $_0_i_i17 = HEAPU8[$124 + $118 | 0] << 8 | HEAPU8[$124 + $119 | 0]; //@line 41423
 } else {
  $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $118) | 0; //@line 41431
 }
 HEAP16[$16 >> 1] = $_0_i_i17; //@line 41434
 if ((HEAP8[$41] | 0) == 0) {
  HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 2; //@line 41441
  HEAP32[$48 >> 2] = (HEAP32[$48 >> 2] | 0) + 2; //@line 41444
  STACKTOP = sp; //@line 41446
  return;
 } else {
  _e68_exception_bus($c); //@line 41449
  STACKTOP = sp; //@line 41451
  return;
 }
}
function _op0e80($c) {
 $c = $c | 0;
 var $v = 0, $6 = 0, $10 = 0, $11 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $26 = 0, $_0_i_i = 0, $41 = 0, $48 = 0, $51 = 0, $53 = 0, $54 = 0, $60 = 0, $storemerge_in = 0, $69 = 0, $82 = 0, $93 = 0, $94 = 0, $100 = 0, $103 = 0, $109 = 0, $110 = 0, $115 = 0, $_0_i_i17 = 0, sp = 0;
 sp = STACKTOP; //@line 41475
 STACKTOP = STACKTOP + 8 | 0; //@line 41475
 $v = sp | 0; //@line 41476
 if ((HEAP32[$c >> 2] & 2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 41483
  $6 = $c + 372 | 0; //@line 41484
  HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 41487
  STACKTOP = sp; //@line 41489
  return;
 }
 $10 = $c + 156 | 0; //@line 41492
 $11 = HEAP32[$10 >> 2] | 0; //@line 41493
 if (($11 & 1 | 0) != 0) {
  _e68_exception_address($c, $11, 0, 0); //@line 41498
  STACKTOP = sp; //@line 41500
  return;
 }
 $16 = $c + 164 | 0; //@line 41503
 $18 = $c + 162 | 0; //@line 41505
 HEAP16[$18 >> 1] = HEAP16[$16 >> 1] | 0; //@line 41506
 $19 = $11 & 16777215; //@line 41507
 $20 = $19 + 1 | 0; //@line 41508
 $21 = $c + 36 | 0; //@line 41509
 if ($20 >>> 0 < (HEAP32[$21 >> 2] | 0) >>> 0) {
  $26 = HEAP32[$c + 32 >> 2] | 0; //@line 41515
  $_0_i_i = HEAPU8[$26 + $19 | 0] << 8 | HEAPU8[$26 + $20 | 0]; //@line 41525
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $19) | 0; //@line 41533
 }
 HEAP16[$16 >> 1] = $_0_i_i; //@line 41536
 $41 = $c + 336 | 0; //@line 41537
 if ((HEAP8[$41] | 0) != 0) {
  _e68_exception_bus($c); //@line 41542
  STACKTOP = sp; //@line 41544
  return;
 }
 HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 2; //@line 41549
 $48 = $c + 152 | 0; //@line 41550
 HEAP32[$48 >> 2] = (HEAP32[$48 >> 2] | 0) + 2; //@line 41553
 $51 = $c + 160 | 0; //@line 41554
 $53 = HEAPU16[$18 >> 1] | 0; //@line 41556
 $54 = $53 >>> 12; //@line 41557
 do {
  if (($53 & 2048 | 0) == 0) {
   $82 = HEAP16[$51 >> 1] & 63; //@line 41566
   if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($82 << 2) >> 2] & 127]($c, $82, 508, 32) | 0) != 0) {
    STACKTOP = sp; //@line 41573
    return;
   }
   if ((_e68_ea_get_val32($c, $v) | 0) != 0) {
    STACKTOP = sp; //@line 41580
    return;
   }
   $93 = $54 & 7; //@line 41585
   $94 = HEAP32[$v >> 2] | 0; //@line 41586
   if (($54 & 8 | 0) == 0) {
    HEAP32[$c + 88 + ($93 << 2) >> 2] = $94; //@line 41590
    break;
   } else {
    HEAP32[$c + 120 + ($93 << 2) >> 2] = $94; //@line 41594
    break;
   }
  } else {
   $60 = $54 & 7; //@line 41601
   if (($54 & 8 | 0) == 0) {
    $storemerge_in = $c + 88 + ($60 << 2) | 0; //@line 41605
   } else {
    $storemerge_in = $c + 120 + ($60 << 2) | 0; //@line 41609
   }
   HEAP32[$v >> 2] = HEAP32[$storemerge_in >> 2]; //@line 41613
   $69 = HEAP16[$51 >> 1] & 63; //@line 41617
   if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($69 << 2) >> 2] & 127]($c, $69, 508, 32) | 0) != 0) {
    STACKTOP = sp; //@line 41624
    return;
   }
   if ((_e68_ea_set_val32($c, HEAP32[$v >> 2] | 0) | 0) == 0) {
    break;
   }
   STACKTOP = sp; //@line 41634
   return;
  }
 } while (0);
 $100 = $c + 372 | 0; //@line 41638
 HEAP32[$100 >> 2] = (HEAP32[$100 >> 2] | 0) + 4; //@line 41641
 $103 = HEAP32[$10 >> 2] | 0; //@line 41642
 if (($103 & 1 | 0) != 0) {
  _e68_exception_address($c, $103, 0, 0); //@line 41647
  STACKTOP = sp; //@line 41649
  return;
 }
 HEAP16[$18 >> 1] = HEAP16[$16 >> 1] | 0; //@line 41653
 $109 = $103 & 16777215; //@line 41654
 $110 = $109 + 1 | 0; //@line 41655
 if ($110 >>> 0 < (HEAP32[$21 >> 2] | 0) >>> 0) {
  $115 = HEAP32[$c + 32 >> 2] | 0; //@line 41661
  $_0_i_i17 = HEAPU8[$115 + $109 | 0] << 8 | HEAPU8[$115 + $110 | 0]; //@line 41671
 } else {
  $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $109) | 0; //@line 41679
 }
 HEAP16[$16 >> 1] = $_0_i_i17; //@line 41682
 if ((HEAP8[$41] | 0) == 0) {
  HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 2; //@line 41689
  HEAP32[$48 >> 2] = (HEAP32[$48 >> 2] | 0) + 2; //@line 41692
  STACKTOP = sp; //@line 41694
  return;
 } else {
  _e68_exception_bus($c); //@line 41697
  STACKTOP = sp; //@line 41699
  return;
 }
}
function _op1000($c) {
 $c = $c | 0;
 var $val = 0, $1 = 0, $4 = 0, $14 = 0, $19 = 0, $29 = 0, $33 = 0, $34 = 0, $39 = 0, $42 = 0, $43 = 0, $49 = 0, $_0_i_i = 0, $71 = 0, sp = 0;
 sp = STACKTOP; //@line 41717
 STACKTOP = STACKTOP + 8 | 0; //@line 41717
 $val = sp | 0; //@line 41718
 $1 = $c + 160 | 0; //@line 41719
 $4 = HEAP16[$1 >> 1] & 63; //@line 41722
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 8) | 0) != 0) {
  STACKTOP = sp; //@line 41729
  return;
 }
 if ((_e68_ea_get_val8($c, $val) | 0) != 0) {
  STACKTOP = sp; //@line 41736
  return;
 }
 $14 = HEAPU16[$1 >> 1] | 0; //@line 41740
 $19 = $14 >>> 3 & 56 | $14 >>> 9 & 7; //@line 41745
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($19 << 2) >> 2] & 127]($c, $19, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 41752
  return;
 }
 if ((_e68_ea_set_val8($c, HEAP8[$val] | 0) | 0) != 0) {
  STACKTOP = sp; //@line 41760
  return;
 }
 $29 = $c + 372 | 0; //@line 41763
 HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 4; //@line 41766
 _e68_cc_set_nz_8($c, 15, HEAP8[$val] | 0); //@line 41768
 $33 = $c + 156 | 0; //@line 41769
 $34 = HEAP32[$33 >> 2] | 0; //@line 41770
 if (($34 & 1 | 0) != 0) {
  _e68_exception_address($c, $34, 0, 0); //@line 41775
  STACKTOP = sp; //@line 41777
  return;
 }
 $39 = $c + 164 | 0; //@line 41780
 HEAP16[$c + 162 >> 1] = HEAP16[$39 >> 1] | 0; //@line 41783
 $42 = $34 & 16777215; //@line 41784
 $43 = $42 + 1 | 0; //@line 41785
 if ($43 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $49 = HEAP32[$c + 32 >> 2] | 0; //@line 41792
  $_0_i_i = HEAPU8[$49 + $42 | 0] << 8 | HEAPU8[$49 + $43 | 0]; //@line 41802
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $42) | 0; //@line 41810
 }
 HEAP16[$39 >> 1] = $_0_i_i; //@line 41813
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 2; //@line 41821
  $71 = $c + 152 | 0; //@line 41822
  HEAP32[$71 >> 2] = (HEAP32[$71 >> 2] | 0) + 2; //@line 41825
  STACKTOP = sp; //@line 41827
  return;
 } else {
  _e68_exception_bus($c); //@line 41830
  STACKTOP = sp; //@line 41832
  return;
 }
}
function _op2000($c) {
 $c = $c | 0;
 var $val = 0, $1 = 0, $4 = 0, $14 = 0, $19 = 0, $29 = 0, $33 = 0, $34 = 0, $39 = 0, $42 = 0, $43 = 0, $49 = 0, $_0_i_i = 0, $71 = 0, sp = 0;
 sp = STACKTOP; //@line 41850
 STACKTOP = STACKTOP + 8 | 0; //@line 41850
 $val = sp | 0; //@line 41851
 $1 = $c + 160 | 0; //@line 41852
 $4 = HEAP16[$1 >> 1] & 63; //@line 41855
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 41862
  return;
 }
 if ((_e68_ea_get_val32($c, $val) | 0) != 0) {
  STACKTOP = sp; //@line 41869
  return;
 }
 $14 = HEAPU16[$1 >> 1] | 0; //@line 41873
 $19 = $14 >>> 3 & 56 | $14 >>> 9 & 7; //@line 41878
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($19 << 2) >> 2] & 127]($c, $19, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 41885
  return;
 }
 if ((_e68_ea_set_val32($c, HEAP32[$val >> 2] | 0) | 0) != 0) {
  STACKTOP = sp; //@line 41893
  return;
 }
 $29 = $c + 372 | 0; //@line 41896
 HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 4; //@line 41899
 _e68_cc_set_nz_32($c, 15, HEAP32[$val >> 2] | 0); //@line 41901
 $33 = $c + 156 | 0; //@line 41902
 $34 = HEAP32[$33 >> 2] | 0; //@line 41903
 if (($34 & 1 | 0) != 0) {
  _e68_exception_address($c, $34, 0, 0); //@line 41908
  STACKTOP = sp; //@line 41910
  return;
 }
 $39 = $c + 164 | 0; //@line 41913
 HEAP16[$c + 162 >> 1] = HEAP16[$39 >> 1] | 0; //@line 41916
 $42 = $34 & 16777215; //@line 41917
 $43 = $42 + 1 | 0; //@line 41918
 if ($43 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $49 = HEAP32[$c + 32 >> 2] | 0; //@line 41925
  $_0_i_i = HEAPU8[$49 + $42 | 0] << 8 | HEAPU8[$49 + $43 | 0]; //@line 41935
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $42) | 0; //@line 41943
 }
 HEAP16[$39 >> 1] = $_0_i_i; //@line 41946
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 2; //@line 41954
  $71 = $c + 152 | 0; //@line 41955
  HEAP32[$71 >> 2] = (HEAP32[$71 >> 2] | 0) + 2; //@line 41958
  STACKTOP = sp; //@line 41960
  return;
 } else {
  _e68_exception_bus($c); //@line 41963
  STACKTOP = sp; //@line 41965
  return;
 }
}
function _op2040($c) {
 $c = $c | 0;
 var $val = 0, $1 = 0, $4 = 0, $19 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 41981
 STACKTOP = STACKTOP + 8 | 0; //@line 41981
 $val = sp | 0; //@line 41982
 $1 = $c + 160 | 0; //@line 41983
 $4 = HEAP16[$1 >> 1] & 63; //@line 41986
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 41993
  return;
 }
 if ((_e68_ea_get_val32($c, $val) | 0) != 0) {
  STACKTOP = sp; //@line 42000
  return;
 }
 HEAP32[$c + 120 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] = HEAP32[$val >> 2]; //@line 42009
 $19 = $c + 372 | 0; //@line 42010
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 4; //@line 42013
 $22 = $c + 156 | 0; //@line 42014
 $23 = HEAP32[$22 >> 2] | 0; //@line 42015
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 42020
  STACKTOP = sp; //@line 42022
  return;
 }
 $28 = $c + 164 | 0; //@line 42025
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 42028
 $31 = $23 & 16777215; //@line 42029
 $32 = $31 + 1 | 0; //@line 42030
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 42037
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 42047
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 42055
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 42058
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 42066
  $60 = $c + 152 | 0; //@line 42067
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 42070
  STACKTOP = sp; //@line 42072
  return;
 } else {
  _e68_exception_bus($c); //@line 42075
  STACKTOP = sp; //@line 42077
  return;
 }
}
function _op3000($c) {
 $c = $c | 0;
 var $val = 0, $1 = 0, $4 = 0, $14 = 0, $19 = 0, $29 = 0, $33 = 0, $34 = 0, $39 = 0, $42 = 0, $43 = 0, $49 = 0, $_0_i_i = 0, $71 = 0, sp = 0;
 sp = STACKTOP; //@line 42095
 STACKTOP = STACKTOP + 8 | 0; //@line 42095
 $val = sp | 0; //@line 42096
 $1 = $c + 160 | 0; //@line 42097
 $4 = HEAP16[$1 >> 1] & 63; //@line 42100
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 42107
  return;
 }
 if ((_e68_ea_get_val16($c, $val) | 0) != 0) {
  STACKTOP = sp; //@line 42114
  return;
 }
 $14 = HEAPU16[$1 >> 1] | 0; //@line 42118
 $19 = $14 >>> 3 & 56 | $14 >>> 9 & 7; //@line 42123
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($19 << 2) >> 2] & 127]($c, $19, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 42130
  return;
 }
 if ((_e68_ea_set_val16($c, HEAP16[$val >> 1] | 0) | 0) != 0) {
  STACKTOP = sp; //@line 42138
  return;
 }
 $29 = $c + 372 | 0; //@line 42141
 HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 4; //@line 42144
 _e68_cc_set_nz_16($c, 15, HEAP16[$val >> 1] | 0); //@line 42146
 $33 = $c + 156 | 0; //@line 42147
 $34 = HEAP32[$33 >> 2] | 0; //@line 42148
 if (($34 & 1 | 0) != 0) {
  _e68_exception_address($c, $34, 0, 0); //@line 42153
  STACKTOP = sp; //@line 42155
  return;
 }
 $39 = $c + 164 | 0; //@line 42158
 HEAP16[$c + 162 >> 1] = HEAP16[$39 >> 1] | 0; //@line 42161
 $42 = $34 & 16777215; //@line 42162
 $43 = $42 + 1 | 0; //@line 42163
 if ($43 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $49 = HEAP32[$c + 32 >> 2] | 0; //@line 42170
  $_0_i_i = HEAPU8[$49 + $42 | 0] << 8 | HEAPU8[$49 + $43 | 0]; //@line 42180
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $42) | 0; //@line 42188
 }
 HEAP16[$39 >> 1] = $_0_i_i; //@line 42191
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 2; //@line 42199
  $71 = $c + 152 | 0; //@line 42200
  HEAP32[$71 >> 2] = (HEAP32[$71 >> 2] | 0) + 2; //@line 42203
  STACKTOP = sp; //@line 42205
  return;
 } else {
  _e68_exception_bus($c); //@line 42208
  STACKTOP = sp; //@line 42210
  return;
 }
}
function _op3040($c) {
 $c = $c | 0;
 var $val = 0, $1 = 0, $4 = 0, $18 = 0, $24 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 42227
 STACKTOP = STACKTOP + 8 | 0; //@line 42227
 $val = sp | 0; //@line 42228
 $1 = $c + 160 | 0; //@line 42229
 $4 = HEAP16[$1 >> 1] & 63; //@line 42232
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 42239
  return;
 }
 if ((_e68_ea_get_val16($c, $val) | 0) != 0) {
  STACKTOP = sp; //@line 42246
  return;
 }
 $18 = HEAPU16[$val >> 1] | 0; //@line 42254
 HEAP32[$c + 120 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] = ($18 & 32768 | 0) != 0 ? $18 | -65536 : $18; //@line 42260
 $24 = $c + 372 | 0; //@line 42261
 HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 4; //@line 42264
 $27 = $c + 156 | 0; //@line 42265
 $28 = HEAP32[$27 >> 2] | 0; //@line 42266
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 42271
  STACKTOP = sp; //@line 42273
  return;
 }
 $33 = $c + 164 | 0; //@line 42276
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 42279
 $36 = $28 & 16777215; //@line 42280
 $37 = $36 + 1 | 0; //@line 42281
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 42288
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 42298
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 42306
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 42309
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 42317
  $65 = $c + 152 | 0; //@line 42318
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 42321
  STACKTOP = sp; //@line 42323
  return;
 } else {
  _e68_exception_bus($c); //@line 42326
  STACKTOP = sp; //@line 42328
  return;
 }
}
function _op4000($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $16 = 0, $19 = 0, $24 = 0, $26 = 0, $27 = 0, $30 = 0, $storemerge = 0, $storemerge15 = 0, $43 = 0, $44 = 0, $49 = 0, $52 = 0, $53 = 0, $59 = 0, $_0_i_i = 0, $81 = 0, sp = 0;
 sp = STACKTOP; //@line 42348
 STACKTOP = STACKTOP + 8 | 0; //@line 42348
 $s = sp | 0; //@line 42349
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 42353
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 42360
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 42367
  return;
 }
 $14 = HEAPU8[$s] | 0; //@line 42371
 $15 = $c + 166 | 0; //@line 42372
 $16 = HEAP16[$15 >> 1] | 0; //@line 42373
 $19 = -((($16 & 65535) >>> 4 & 1) + $14 | 0) | 0; //@line 42378
 if (($19 & 255 | 0) == 0) {
  $26 = $16; //@line 42384
 } else {
  $24 = $16 & -5; //@line 42386
  HEAP16[$15 >> 1] = $24; //@line 42387
  $26 = $24; //@line 42389
 }
 $27 = $c + 372 | 0; //@line 42392
 HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 8; //@line 42395
 $30 = $19 & 128; //@line 42396
 $storemerge = ($30 | 0) == 0 ? $26 & -9 : $26 | 8; //@line 42400
 $storemerge15 = ($30 & $14 | 0) == 0 ? $storemerge & -3 : $storemerge | 2; //@line 42405
 HEAP16[$15 >> 1] = (($14 | $19) & 128 | 0) == 0 ? $storemerge15 & -18 : $storemerge15 | 17; //@line 42412
 $43 = $c + 156 | 0; //@line 42413
 $44 = HEAP32[$43 >> 2] | 0; //@line 42414
 if (($44 & 1 | 0) != 0) {
  _e68_exception_address($c, $44, 0, 0); //@line 42419
  STACKTOP = sp; //@line 42421
  return;
 }
 $49 = $c + 164 | 0; //@line 42424
 HEAP16[$c + 162 >> 1] = HEAP16[$49 >> 1] | 0; //@line 42427
 $52 = $44 & 16777215; //@line 42428
 $53 = $52 + 1 | 0; //@line 42429
 if ($53 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $59 = HEAP32[$c + 32 >> 2] | 0; //@line 42436
  $_0_i_i = HEAPU8[$59 + $52 | 0] << 8 | HEAPU8[$59 + $53 | 0]; //@line 42446
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $52) | 0; //@line 42454
 }
 HEAP16[$49 >> 1] = $_0_i_i; //@line 42457
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 42465
  $81 = $c + 152 | 0; //@line 42466
  HEAP32[$81 >> 2] = (HEAP32[$81 >> 2] | 0) + 2; //@line 42469
  _e68_ea_set_val8($c, $19 & 255) | 0; //@line 42470
  STACKTOP = sp; //@line 42472
  return;
 } else {
  _e68_exception_bus($c); //@line 42475
  STACKTOP = sp; //@line 42477
  return;
 }
}
function _op4040($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $16 = 0, $19 = 0, $24 = 0, $26 = 0, $27 = 0, $30 = 0, $storemerge = 0, $storemerge15 = 0, $43 = 0, $44 = 0, $49 = 0, $52 = 0, $53 = 0, $59 = 0, $_0_i_i = 0, $81 = 0, sp = 0;
 sp = STACKTOP; //@line 42497
 STACKTOP = STACKTOP + 8 | 0; //@line 42497
 $s = sp | 0; //@line 42498
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 42502
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 42509
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 42516
  return;
 }
 $14 = HEAPU16[$s >> 1] | 0; //@line 42520
 $15 = $c + 166 | 0; //@line 42521
 $16 = HEAP16[$15 >> 1] | 0; //@line 42522
 $19 = -((($16 & 65535) >>> 4 & 1) + $14 | 0) | 0; //@line 42527
 if (($19 & 65535 | 0) == 0) {
  $26 = $16; //@line 42533
 } else {
  $24 = $16 & -5; //@line 42535
  HEAP16[$15 >> 1] = $24; //@line 42536
  $26 = $24; //@line 42538
 }
 $27 = $c + 372 | 0; //@line 42541
 HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 8; //@line 42544
 $30 = $19 & 32768; //@line 42545
 $storemerge = ($30 | 0) == 0 ? $26 & -9 : $26 | 8; //@line 42549
 $storemerge15 = ($30 & $14 | 0) == 0 ? $storemerge & -3 : $storemerge | 2; //@line 42554
 HEAP16[$15 >> 1] = (($14 | $19) & 32768 | 0) == 0 ? $storemerge15 & -18 : $storemerge15 | 17; //@line 42561
 $43 = $c + 156 | 0; //@line 42562
 $44 = HEAP32[$43 >> 2] | 0; //@line 42563
 if (($44 & 1 | 0) != 0) {
  _e68_exception_address($c, $44, 0, 0); //@line 42568
  STACKTOP = sp; //@line 42570
  return;
 }
 $49 = $c + 164 | 0; //@line 42573
 HEAP16[$c + 162 >> 1] = HEAP16[$49 >> 1] | 0; //@line 42576
 $52 = $44 & 16777215; //@line 42577
 $53 = $52 + 1 | 0; //@line 42578
 if ($53 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $59 = HEAP32[$c + 32 >> 2] | 0; //@line 42585
  $_0_i_i = HEAPU8[$59 + $52 | 0] << 8 | HEAPU8[$59 + $53 | 0]; //@line 42595
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $52) | 0; //@line 42603
 }
 HEAP16[$49 >> 1] = $_0_i_i; //@line 42606
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 42614
  $81 = $c + 152 | 0; //@line 42615
  HEAP32[$81 >> 2] = (HEAP32[$81 >> 2] | 0) + 2; //@line 42618
  _e68_ea_set_val16($c, $19 & 65535) | 0; //@line 42619
  STACKTOP = sp; //@line 42621
  return;
 } else {
  _e68_exception_bus($c); //@line 42624
  STACKTOP = sp; //@line 42626
  return;
 }
}
function _op4080($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $_lobit = 0, $19 = 0, $22 = 0, $24 = 0, $25 = 0, $storemerge = 0, $storemerge15 = 0, $39 = 0, $40 = 0, $45 = 0, $48 = 0, $49 = 0, $55 = 0, $_0_i_i = 0, $77 = 0, sp = 0;
 sp = STACKTOP; //@line 42645
 STACKTOP = STACKTOP + 8 | 0; //@line 42645
 $s = sp | 0; //@line 42646
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 42650
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 42657
  return;
 }
 if ((_e68_ea_get_val32($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 42664
  return;
 }
 $13 = HEAP32[$s >> 2] | 0; //@line 42667
 $14 = -$13 | 0; //@line 42668
 $15 = $c + 166 | 0; //@line 42669
 $16 = HEAP16[$15 >> 1] | 0; //@line 42670
 $_lobit = ($16 & 65535) >>> 4 & 1; //@line 42673
 $19 = $14 - $_lobit | 0; //@line 42674
 if (($_lobit | 0) == ($14 | 0)) {
  $24 = $16; //@line 42678
 } else {
  $22 = $16 & -5; //@line 42680
  HEAP16[$15 >> 1] = $22; //@line 42681
  $24 = $22; //@line 42683
 }
 $25 = $c + 372 | 0; //@line 42686
 HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 10; //@line 42689
 $storemerge = ($19 | 0) < 0 ? $24 | 8 : $24 & -9; //@line 42693
 $storemerge15 = ($13 & $19 | 0) < 0 ? $storemerge | 2 : $storemerge & -3; //@line 42698
 HEAP16[$15 >> 1] = ($13 | $19 | 0) < 0 ? $storemerge15 | 17 : $storemerge15 & -18; //@line 42704
 $39 = $c + 156 | 0; //@line 42705
 $40 = HEAP32[$39 >> 2] | 0; //@line 42706
 if (($40 & 1 | 0) != 0) {
  _e68_exception_address($c, $40, 0, 0); //@line 42711
  STACKTOP = sp; //@line 42713
  return;
 }
 $45 = $c + 164 | 0; //@line 42716
 HEAP16[$c + 162 >> 1] = HEAP16[$45 >> 1] | 0; //@line 42719
 $48 = $40 & 16777215; //@line 42720
 $49 = $48 + 1 | 0; //@line 42721
 if ($49 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $55 = HEAP32[$c + 32 >> 2] | 0; //@line 42728
  $_0_i_i = HEAPU8[$55 + $48 | 0] << 8 | HEAPU8[$55 + $49 | 0]; //@line 42738
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 42746
 }
 HEAP16[$45 >> 1] = $_0_i_i; //@line 42749
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 42757
  $77 = $c + 152 | 0; //@line 42758
  HEAP32[$77 >> 2] = (HEAP32[$77 >> 2] | 0) + 2; //@line 42761
  _e68_ea_set_val32($c, $19) | 0; //@line 42762
  STACKTOP = sp; //@line 42764
  return;
 } else {
  _e68_exception_bus($c); //@line 42767
  STACKTOP = sp; //@line 42769
  return;
 }
}
function _op40c0($c) {
 $c = $c | 0;
 var $s = 0, $14 = 0, $26 = 0, $29 = 0, $30 = 0, $35 = 0, $38 = 0, $39 = 0, $45 = 0, $_0_i_i = 0, $67 = 0, $70 = 0, sp = 0;
 sp = STACKTOP; //@line 42786
 STACKTOP = STACKTOP + 8 | 0; //@line 42786
 $s = sp | 0; //@line 42787
 do {
  if ((HEAP32[$c >> 2] & 2 | 0) != 0) {
   if ((HEAP8[$c + 334 | 0] | 0) != 0) {
    break;
   }
   _e68_exception_privilege($c); //@line 42802
   STACKTOP = sp; //@line 42804
   return;
  }
 } while (0);
 $14 = HEAP16[$c + 160 >> 1] & 63; //@line 42811
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($14 << 2) >> 2] & 127]($c, $14, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 42818
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 42825
  return;
 }
 HEAP16[$s >> 1] = HEAP16[$c + 166 >> 1] & -22753; //@line 42831
 $26 = $c + 372 | 0; //@line 42832
 HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 4; //@line 42835
 $29 = $c + 156 | 0; //@line 42836
 $30 = HEAP32[$29 >> 2] | 0; //@line 42837
 if (($30 & 1 | 0) != 0) {
  _e68_exception_address($c, $30, 0, 0); //@line 42842
  STACKTOP = sp; //@line 42844
  return;
 }
 $35 = $c + 164 | 0; //@line 42847
 HEAP16[$c + 162 >> 1] = HEAP16[$35 >> 1] | 0; //@line 42850
 $38 = $30 & 16777215; //@line 42851
 $39 = $38 + 1 | 0; //@line 42852
 if ($39 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $45 = HEAP32[$c + 32 >> 2] | 0; //@line 42859
  $_0_i_i = HEAPU8[$45 + $38 | 0] << 8 | HEAPU8[$45 + $39 | 0]; //@line 42869
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $38) | 0; //@line 42877
 }
 HEAP16[$35 >> 1] = $_0_i_i; //@line 42880
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 2; //@line 42888
  $67 = $c + 152 | 0; //@line 42889
  HEAP32[$67 >> 2] = (HEAP32[$67 >> 2] | 0) + 2; //@line 42892
  $70 = HEAP16[$s >> 1] | 0; //@line 42893
  _e68_ea_set_val16($c, $70) | 0; //@line 42894
  STACKTOP = sp; //@line 42896
  return;
 } else {
  _e68_exception_bus($c); //@line 42899
  STACKTOP = sp; //@line 42901
  return;
 }
}
function _op4180($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $4 = 0, $18 = 0, $21 = 0, $24 = 0, $30 = 0, $34 = 0, $37 = 0, $41 = 0, $44 = 0, $45 = 0, $50 = 0, $53 = 0, $54 = 0, $60 = 0, $_0_i_i = 0, $82 = 0, sp = 0;
 sp = STACKTOP; //@line 42920
 STACKTOP = STACKTOP + 8 | 0; //@line 42920
 $s1 = sp | 0; //@line 42921
 $1 = $c + 160 | 0; //@line 42922
 $4 = HEAP16[$1 >> 1] & 63; //@line 42925
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 42932
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 42939
  return;
 }
 $18 = HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 42947
 do {
  if (($18 & 32768 | 0) == 0) {
   $30 = HEAPU16[$s1 >> 1] | 0; //@line 42955
   if (($30 & 32768 | 0) != 0 | ($18 & 65535) >>> 0 > $30 >>> 0) {
    $34 = $c + 166 | 0; //@line 42962
    HEAP16[$34 >> 1] = HEAP16[$34 >> 1] & -9; //@line 42965
    $37 = $c + 372 | 0; //@line 42966
    HEAP32[$37 >> 2] = (HEAP32[$37 >> 2] | 0) + 14; //@line 42969
    break;
   }
   $41 = $c + 372 | 0; //@line 42972
   HEAP32[$41 >> 2] = (HEAP32[$41 >> 2] | 0) + 14; //@line 42975
   $44 = $c + 156 | 0; //@line 42976
   $45 = HEAP32[$44 >> 2] | 0; //@line 42977
   if (($45 & 1 | 0) != 0) {
    _e68_exception_address($c, $45, 0, 0); //@line 42982
    STACKTOP = sp; //@line 42984
    return;
   }
   $50 = $c + 164 | 0; //@line 42987
   HEAP16[$c + 162 >> 1] = HEAP16[$50 >> 1] | 0; //@line 42990
   $53 = $45 & 16777215; //@line 42991
   $54 = $53 + 1 | 0; //@line 42992
   if ($54 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $60 = HEAP32[$c + 32 >> 2] | 0; //@line 42999
    $_0_i_i = HEAPU8[$60 + $53 | 0] << 8 | HEAPU8[$60 + $54 | 0]; //@line 43009
   } else {
    $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $53) | 0; //@line 43017
   }
   HEAP16[$50 >> 1] = $_0_i_i; //@line 43020
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 43028
    $82 = $c + 152 | 0; //@line 43029
    HEAP32[$82 >> 2] = (HEAP32[$82 >> 2] | 0) + 2; //@line 43032
    STACKTOP = sp; //@line 43034
    return;
   } else {
    _e68_exception_bus($c); //@line 43037
    STACKTOP = sp; //@line 43039
    return;
   }
  } else {
   $21 = $c + 166 | 0; //@line 43043
   HEAP16[$21 >> 1] = HEAP16[$21 >> 1] | 8; //@line 43046
   $24 = $c + 372 | 0; //@line 43047
   HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 14; //@line 43050
  }
 } while (0);
 _e68_exception_check($c); //@line 43053
 STACKTOP = sp; //@line 43055
 return;
}
function _op4200($c) {
 $c = $c | 0;
 var $4 = 0, $13 = 0, $16 = 0, $20 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, sp = 0;
 sp = STACKTOP; //@line 43070
 STACKTOP = STACKTOP + 8 | 0; //@line 43070
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43075
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 43082
  return;
 }
 if ((_e68_ea_get_val8($c, sp | 0) | 0) != 0) {
  STACKTOP = sp; //@line 43089
  return;
 }
 $13 = $c + 372 | 0; //@line 43092
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 4; //@line 43095
 $16 = $c + 166 | 0; //@line 43096
 HEAP16[$16 >> 1] = HEAP16[$16 >> 1] & -16 | 4; //@line 43100
 $20 = $c + 156 | 0; //@line 43101
 $21 = HEAP32[$20 >> 2] | 0; //@line 43102
 if (($21 & 1 | 0) != 0) {
  _e68_exception_address($c, $21, 0, 0); //@line 43107
  STACKTOP = sp; //@line 43109
  return;
 }
 $26 = $c + 164 | 0; //@line 43112
 HEAP16[$c + 162 >> 1] = HEAP16[$26 >> 1] | 0; //@line 43115
 $29 = $21 & 16777215; //@line 43116
 $30 = $29 + 1 | 0; //@line 43117
 if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 43124
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 43134
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 43142
 }
 HEAP16[$26 >> 1] = $_0_i_i; //@line 43145
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 43153
  $58 = $c + 152 | 0; //@line 43154
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 43157
  _e68_ea_set_val8($c, 0) | 0; //@line 43158
  STACKTOP = sp; //@line 43160
  return;
 } else {
  _e68_exception_bus($c); //@line 43163
  STACKTOP = sp; //@line 43165
  return;
 }
}
function _op4240($c) {
 $c = $c | 0;
 var $4 = 0, $13 = 0, $16 = 0, $20 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, sp = 0;
 sp = STACKTOP; //@line 43181
 STACKTOP = STACKTOP + 8 | 0; //@line 43181
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43186
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 43193
  return;
 }
 if ((_e68_ea_get_val16($c, sp | 0) | 0) != 0) {
  STACKTOP = sp; //@line 43200
  return;
 }
 $13 = $c + 372 | 0; //@line 43203
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 4; //@line 43206
 $16 = $c + 166 | 0; //@line 43207
 HEAP16[$16 >> 1] = HEAP16[$16 >> 1] & -16 | 4; //@line 43211
 $20 = $c + 156 | 0; //@line 43212
 $21 = HEAP32[$20 >> 2] | 0; //@line 43213
 if (($21 & 1 | 0) != 0) {
  _e68_exception_address($c, $21, 0, 0); //@line 43218
  STACKTOP = sp; //@line 43220
  return;
 }
 $26 = $c + 164 | 0; //@line 43223
 HEAP16[$c + 162 >> 1] = HEAP16[$26 >> 1] | 0; //@line 43226
 $29 = $21 & 16777215; //@line 43227
 $30 = $29 + 1 | 0; //@line 43228
 if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 43235
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 43245
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 43253
 }
 HEAP16[$26 >> 1] = $_0_i_i; //@line 43256
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 43264
  $58 = $c + 152 | 0; //@line 43265
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 43268
  _e68_ea_set_val16($c, 0) | 0; //@line 43269
  STACKTOP = sp; //@line 43271
  return;
 } else {
  _e68_exception_bus($c); //@line 43274
  STACKTOP = sp; //@line 43276
  return;
 }
}
function _op4280($c) {
 $c = $c | 0;
 var $4 = 0, $13 = 0, $16 = 0, $20 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, sp = 0;
 sp = STACKTOP; //@line 43292
 STACKTOP = STACKTOP + 8 | 0; //@line 43292
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43297
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 43304
  return;
 }
 if ((_e68_ea_get_val32($c, sp | 0) | 0) != 0) {
  STACKTOP = sp; //@line 43311
  return;
 }
 $13 = $c + 372 | 0; //@line 43314
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 6; //@line 43317
 $16 = $c + 166 | 0; //@line 43318
 HEAP16[$16 >> 1] = HEAP16[$16 >> 1] & -16 | 4; //@line 43322
 $20 = $c + 156 | 0; //@line 43323
 $21 = HEAP32[$20 >> 2] | 0; //@line 43324
 if (($21 & 1 | 0) != 0) {
  _e68_exception_address($c, $21, 0, 0); //@line 43329
  STACKTOP = sp; //@line 43331
  return;
 }
 $26 = $c + 164 | 0; //@line 43334
 HEAP16[$c + 162 >> 1] = HEAP16[$26 >> 1] | 0; //@line 43337
 $29 = $21 & 16777215; //@line 43338
 $30 = $29 + 1 | 0; //@line 43339
 if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 43346
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 43356
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 43364
 }
 HEAP16[$26 >> 1] = $_0_i_i; //@line 43367
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 43375
  $58 = $c + 152 | 0; //@line 43376
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 43379
  _e68_ea_set_val32($c, 0) | 0; //@line 43380
  STACKTOP = sp; //@line 43382
  return;
 } else {
  _e68_exception_bus($c); //@line 43385
  STACKTOP = sp; //@line 43387
  return;
 }
}
function _op42c0($c) {
 $c = $c | 0;
 var $s = 0, $6 = 0, $13 = 0, $25 = 0, $28 = 0, $29 = 0, $34 = 0, $37 = 0, $38 = 0, $44 = 0, $_0_i_i = 0, $66 = 0, $69 = 0, sp = 0;
 sp = STACKTOP; //@line 43404
 STACKTOP = STACKTOP + 8 | 0; //@line 43404
 $s = sp | 0; //@line 43405
 if ((HEAP32[$c >> 2] & 2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 43412
  $6 = $c + 372 | 0; //@line 43413
  HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 43416
  STACKTOP = sp; //@line 43418
  return;
 }
 $13 = HEAP16[$c + 160 >> 1] & 63; //@line 43424
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($13 << 2) >> 2] & 127]($c, $13, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 43431
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 43438
  return;
 }
 HEAP16[$s >> 1] = HEAP16[$c + 166 >> 1] & 31; //@line 43444
 $25 = $c + 372 | 0; //@line 43445
 HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 4; //@line 43448
 $28 = $c + 156 | 0; //@line 43449
 $29 = HEAP32[$28 >> 2] | 0; //@line 43450
 if (($29 & 1 | 0) != 0) {
  _e68_exception_address($c, $29, 0, 0); //@line 43455
  STACKTOP = sp; //@line 43457
  return;
 }
 $34 = $c + 164 | 0; //@line 43460
 HEAP16[$c + 162 >> 1] = HEAP16[$34 >> 1] | 0; //@line 43463
 $37 = $29 & 16777215; //@line 43464
 $38 = $37 + 1 | 0; //@line 43465
 if ($38 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $44 = HEAP32[$c + 32 >> 2] | 0; //@line 43472
  $_0_i_i = HEAPU8[$44 + $37 | 0] << 8 | HEAPU8[$44 + $38 | 0]; //@line 43482
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $37) | 0; //@line 43490
 }
 HEAP16[$34 >> 1] = $_0_i_i; //@line 43493
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$28 >> 2] = (HEAP32[$28 >> 2] | 0) + 2; //@line 43501
  $66 = $c + 152 | 0; //@line 43502
  HEAP32[$66 >> 2] = (HEAP32[$66 >> 2] | 0) + 2; //@line 43505
  $69 = HEAP16[$s >> 1] | 0; //@line 43506
  _e68_ea_set_val16($c, $69) | 0; //@line 43507
  STACKTOP = sp; //@line 43509
  return;
 } else {
  _e68_exception_bus($c); //@line 43512
  STACKTOP = sp; //@line 43514
  return;
 }
}
function _op4400($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $17 = 0, $21 = 0, $23 = 0, $24 = 0, $storemerge = 0, $storemerge14 = 0, $storemerge15 = 0, $39 = 0, $40 = 0, $45 = 0, $48 = 0, $49 = 0, $55 = 0, $_0_i_i = 0, $77 = 0, sp = 0;
 sp = STACKTOP; //@line 43533
 STACKTOP = STACKTOP + 8 | 0; //@line 43533
 $s = sp | 0; //@line 43534
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43538
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 43545
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 43552
  return;
 }
 $14 = HEAPU8[$s] | 0; //@line 43556
 $15 = -$14 | 0; //@line 43557
 $17 = $c + 372 | 0; //@line 43559
 HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 4; //@line 43562
 $21 = $15 & 128; //@line 43564
 $23 = $c + 166 | 0; //@line 43566
 $24 = HEAP16[$23 >> 1] | 0; //@line 43567
 $storemerge = ($21 | 0) == 0 ? $24 & -9 : $24 | 8; //@line 43570
 $storemerge14 = ($21 & $14 | 0) == 0 ? $storemerge & -3 : $storemerge | 2; //@line 43575
 $storemerge15 = ($15 & 255 | 0) == 0 ? $storemerge14 | 4 : $storemerge14 & -5; //@line 43579
 HEAP16[$23 >> 1] = (($14 | $15) & 128 | 0) == 0 ? $storemerge15 & -18 : $storemerge15 | 17; //@line 43586
 $39 = $c + 156 | 0; //@line 43587
 $40 = HEAP32[$39 >> 2] | 0; //@line 43588
 if (($40 & 1 | 0) != 0) {
  _e68_exception_address($c, $40, 0, 0); //@line 43593
  STACKTOP = sp; //@line 43595
  return;
 }
 $45 = $c + 164 | 0; //@line 43598
 HEAP16[$c + 162 >> 1] = HEAP16[$45 >> 1] | 0; //@line 43601
 $48 = $40 & 16777215; //@line 43602
 $49 = $48 + 1 | 0; //@line 43603
 if ($49 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $55 = HEAP32[$c + 32 >> 2] | 0; //@line 43610
  $_0_i_i = HEAPU8[$55 + $48 | 0] << 8 | HEAPU8[$55 + $49 | 0]; //@line 43620
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 43628
 }
 HEAP16[$45 >> 1] = $_0_i_i; //@line 43631
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 43639
  $77 = $c + 152 | 0; //@line 43640
  HEAP32[$77 >> 2] = (HEAP32[$77 >> 2] | 0) + 2; //@line 43643
  _e68_ea_set_val8($c, $15 & 255) | 0; //@line 43644
  STACKTOP = sp; //@line 43646
  return;
 } else {
  _e68_exception_bus($c); //@line 43649
  STACKTOP = sp; //@line 43651
  return;
 }
}
function _op4440($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $17 = 0, $21 = 0, $23 = 0, $24 = 0, $storemerge = 0, $storemerge14 = 0, $storemerge15 = 0, $39 = 0, $40 = 0, $45 = 0, $48 = 0, $49 = 0, $55 = 0, $_0_i_i = 0, $77 = 0, sp = 0;
 sp = STACKTOP; //@line 43670
 STACKTOP = STACKTOP + 8 | 0; //@line 43670
 $s = sp | 0; //@line 43671
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43675
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 43682
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 43689
  return;
 }
 $14 = HEAPU16[$s >> 1] | 0; //@line 43693
 $15 = -$14 | 0; //@line 43694
 $17 = $c + 372 | 0; //@line 43696
 HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 4; //@line 43699
 $21 = $15 & 32768; //@line 43701
 $23 = $c + 166 | 0; //@line 43703
 $24 = HEAP16[$23 >> 1] | 0; //@line 43704
 $storemerge = ($21 | 0) == 0 ? $24 & -9 : $24 | 8; //@line 43707
 $storemerge14 = ($21 & $14 | 0) == 0 ? $storemerge & -3 : $storemerge | 2; //@line 43712
 $storemerge15 = ($15 & 65535 | 0) == 0 ? $storemerge14 | 4 : $storemerge14 & -5; //@line 43716
 HEAP16[$23 >> 1] = (($14 | $15) & 32768 | 0) == 0 ? $storemerge15 & -18 : $storemerge15 | 17; //@line 43723
 $39 = $c + 156 | 0; //@line 43724
 $40 = HEAP32[$39 >> 2] | 0; //@line 43725
 if (($40 & 1 | 0) != 0) {
  _e68_exception_address($c, $40, 0, 0); //@line 43730
  STACKTOP = sp; //@line 43732
  return;
 }
 $45 = $c + 164 | 0; //@line 43735
 HEAP16[$c + 162 >> 1] = HEAP16[$45 >> 1] | 0; //@line 43738
 $48 = $40 & 16777215; //@line 43739
 $49 = $48 + 1 | 0; //@line 43740
 if ($49 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $55 = HEAP32[$c + 32 >> 2] | 0; //@line 43747
  $_0_i_i = HEAPU8[$55 + $48 | 0] << 8 | HEAPU8[$55 + $49 | 0]; //@line 43757
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 43765
 }
 HEAP16[$45 >> 1] = $_0_i_i; //@line 43768
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 43776
  $77 = $c + 152 | 0; //@line 43777
  HEAP32[$77 >> 2] = (HEAP32[$77 >> 2] | 0) + 2; //@line 43780
  _e68_ea_set_val16($c, $15 & 65535) | 0; //@line 43781
  STACKTOP = sp; //@line 43783
  return;
 } else {
  _e68_exception_bus($c); //@line 43786
  STACKTOP = sp; //@line 43788
  return;
 }
}
function _op4480($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $14 = 0, $15 = 0, $19 = 0, $20 = 0, $storemerge = 0, $storemerge14 = 0, $storemerge15 = 0, $34 = 0, $35 = 0, $40 = 0, $43 = 0, $44 = 0, $50 = 0, $_0_i_i = 0, $72 = 0, sp = 0;
 sp = STACKTOP; //@line 43807
 STACKTOP = STACKTOP + 8 | 0; //@line 43807
 $s = sp | 0; //@line 43808
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43812
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 43819
  return;
 }
 if ((_e68_ea_get_val32($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 43826
  return;
 }
 $13 = HEAP32[$s >> 2] | 0; //@line 43829
 $14 = -$13 | 0; //@line 43830
 $15 = $c + 372 | 0; //@line 43831
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 6; //@line 43834
 $19 = $c + 166 | 0; //@line 43836
 $20 = HEAP16[$19 >> 1] | 0; //@line 43837
 $storemerge = ($14 | 0) < 0 ? $20 | 8 : $20 & -9; //@line 43840
 $storemerge14 = ($13 & $14 | 0) < 0 ? $storemerge | 2 : $storemerge & -3; //@line 43845
 $storemerge15 = ($13 | 0) == 0 ? $storemerge14 | 4 : $storemerge14 & -5; //@line 43849
 HEAP16[$19 >> 1] = ($13 | $14 | 0) < 0 ? $storemerge15 | 17 : $storemerge15 & -18; //@line 43855
 $34 = $c + 156 | 0; //@line 43856
 $35 = HEAP32[$34 >> 2] | 0; //@line 43857
 if (($35 & 1 | 0) != 0) {
  _e68_exception_address($c, $35, 0, 0); //@line 43862
  STACKTOP = sp; //@line 43864
  return;
 }
 $40 = $c + 164 | 0; //@line 43867
 HEAP16[$c + 162 >> 1] = HEAP16[$40 >> 1] | 0; //@line 43870
 $43 = $35 & 16777215; //@line 43871
 $44 = $43 + 1 | 0; //@line 43872
 if ($44 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $50 = HEAP32[$c + 32 >> 2] | 0; //@line 43879
  $_0_i_i = HEAPU8[$50 + $43 | 0] << 8 | HEAPU8[$50 + $44 | 0]; //@line 43889
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $43) | 0; //@line 43897
 }
 HEAP16[$40 >> 1] = $_0_i_i; //@line 43900
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$34 >> 2] = (HEAP32[$34 >> 2] | 0) + 2; //@line 43908
  $72 = $c + 152 | 0; //@line 43909
  HEAP32[$72 >> 2] = (HEAP32[$72 >> 2] | 0) + 2; //@line 43912
  _e68_ea_set_val32($c, $14) | 0; //@line 43913
  STACKTOP = sp; //@line 43915
  return;
 } else {
  _e68_exception_bus($c); //@line 43918
  STACKTOP = sp; //@line 43920
  return;
 }
}
function _op44c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 43936
 STACKTOP = STACKTOP + 8 | 0; //@line 43936
 $s = sp | 0; //@line 43937
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 43941
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 43948
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 43955
  return;
 }
 $13 = $c + 372 | 0; //@line 43958
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 12; //@line 43961
 $17 = $c + 166 | 0; //@line 43963
 HEAP16[$17 >> 1] = HEAP16[$17 >> 1] & -256 | HEAP16[$s >> 1] & 31; //@line 43968
 $22 = $c + 156 | 0; //@line 43969
 $23 = HEAP32[$22 >> 2] | 0; //@line 43970
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 43975
  STACKTOP = sp; //@line 43977
  return;
 }
 $28 = $c + 164 | 0; //@line 43980
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 43983
 $31 = $23 & 16777215; //@line 43984
 $32 = $31 + 1 | 0; //@line 43985
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 43992
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 44002
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 44010
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 44013
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 44021
  $60 = $c + 152 | 0; //@line 44022
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 44025
  STACKTOP = sp; //@line 44027
  return;
 } else {
  _e68_exception_bus($c); //@line 44030
  STACKTOP = sp; //@line 44032
  return;
 }
}
function _op4600($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $34 = 0, $_0_i_i = 0, $56 = 0, sp = 0;
 sp = STACKTOP; //@line 44048
 STACKTOP = STACKTOP + 8 | 0; //@line 44048
 $s = sp | 0; //@line 44049
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 44053
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 44060
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 44067
  return;
 }
 $14 = ~HEAP8[$s]; //@line 44071
 $15 = $c + 372 | 0; //@line 44072
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 4; //@line 44075
 _e68_cc_set_nz_8($c, 15, $14); //@line 44076
 $18 = $c + 156 | 0; //@line 44077
 $19 = HEAP32[$18 >> 2] | 0; //@line 44078
 if (($19 & 1 | 0) != 0) {
  _e68_exception_address($c, $19, 0, 0); //@line 44083
  STACKTOP = sp; //@line 44085
  return;
 }
 $24 = $c + 164 | 0; //@line 44088
 HEAP16[$c + 162 >> 1] = HEAP16[$24 >> 1] | 0; //@line 44091
 $27 = $19 & 16777215; //@line 44092
 $28 = $27 + 1 | 0; //@line 44093
 if ($28 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $34 = HEAP32[$c + 32 >> 2] | 0; //@line 44100
  $_0_i_i = HEAPU8[$34 + $27 | 0] << 8 | HEAPU8[$34 + $28 | 0]; //@line 44110
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $27) | 0; //@line 44118
 }
 HEAP16[$24 >> 1] = $_0_i_i; //@line 44121
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 44129
  $56 = $c + 152 | 0; //@line 44130
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 2; //@line 44133
  _e68_ea_set_val8($c, $14) | 0; //@line 44134
  STACKTOP = sp; //@line 44136
  return;
 } else {
  _e68_exception_bus($c); //@line 44139
  STACKTOP = sp; //@line 44141
  return;
 }
}
function _op4640($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $34 = 0, $_0_i_i = 0, $56 = 0, sp = 0;
 sp = STACKTOP; //@line 44157
 STACKTOP = STACKTOP + 8 | 0; //@line 44157
 $s = sp | 0; //@line 44158
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 44162
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 44169
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 44176
  return;
 }
 $14 = ~HEAP16[$s >> 1]; //@line 44180
 $15 = $c + 372 | 0; //@line 44181
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 4; //@line 44184
 _e68_cc_set_nz_16($c, 15, $14); //@line 44185
 $18 = $c + 156 | 0; //@line 44186
 $19 = HEAP32[$18 >> 2] | 0; //@line 44187
 if (($19 & 1 | 0) != 0) {
  _e68_exception_address($c, $19, 0, 0); //@line 44192
  STACKTOP = sp; //@line 44194
  return;
 }
 $24 = $c + 164 | 0; //@line 44197
 HEAP16[$c + 162 >> 1] = HEAP16[$24 >> 1] | 0; //@line 44200
 $27 = $19 & 16777215; //@line 44201
 $28 = $27 + 1 | 0; //@line 44202
 if ($28 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $34 = HEAP32[$c + 32 >> 2] | 0; //@line 44209
  $_0_i_i = HEAPU8[$34 + $27 | 0] << 8 | HEAPU8[$34 + $28 | 0]; //@line 44219
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $27) | 0; //@line 44227
 }
 HEAP16[$24 >> 1] = $_0_i_i; //@line 44230
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 44238
  $56 = $c + 152 | 0; //@line 44239
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 2; //@line 44242
  _e68_ea_set_val16($c, $14) | 0; //@line 44243
  STACKTOP = sp; //@line 44245
  return;
 } else {
  _e68_exception_bus($c); //@line 44248
  STACKTOP = sp; //@line 44250
  return;
 }
}
function _op4680($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $34 = 0, $_0_i_i = 0, $56 = 0, sp = 0;
 sp = STACKTOP; //@line 44266
 STACKTOP = STACKTOP + 8 | 0; //@line 44266
 $s = sp | 0; //@line 44267
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 44271
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 44278
  return;
 }
 if ((_e68_ea_get_val32($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 44285
  return;
 }
 $14 = ~HEAP32[$s >> 2]; //@line 44289
 $15 = $c + 372 | 0; //@line 44290
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 6; //@line 44293
 _e68_cc_set_nz_32($c, 15, $14); //@line 44294
 $18 = $c + 156 | 0; //@line 44295
 $19 = HEAP32[$18 >> 2] | 0; //@line 44296
 if (($19 & 1 | 0) != 0) {
  _e68_exception_address($c, $19, 0, 0); //@line 44301
  STACKTOP = sp; //@line 44303
  return;
 }
 $24 = $c + 164 | 0; //@line 44306
 HEAP16[$c + 162 >> 1] = HEAP16[$24 >> 1] | 0; //@line 44309
 $27 = $19 & 16777215; //@line 44310
 $28 = $27 + 1 | 0; //@line 44311
 if ($28 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $34 = HEAP32[$c + 32 >> 2] | 0; //@line 44318
  $_0_i_i = HEAPU8[$34 + $27 | 0] << 8 | HEAPU8[$34 + $28 | 0]; //@line 44328
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $27) | 0; //@line 44336
 }
 HEAP16[$24 >> 1] = $_0_i_i; //@line 44339
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 44347
  $56 = $c + 152 | 0; //@line 44348
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 2; //@line 44351
  _e68_ea_set_val32($c, $14) | 0; //@line 44352
  STACKTOP = sp; //@line 44354
  return;
 } else {
  _e68_exception_bus($c); //@line 44357
  STACKTOP = sp; //@line 44359
  return;
 }
}
function _op46c0($c) {
 $c = $c | 0;
 var $s = 0, $9 = 0, $18 = 0, $23 = 0, $24 = 0, $29 = 0, $32 = 0, $33 = 0, $39 = 0, $_0_i_i = 0, $61 = 0, sp = 0;
 sp = STACKTOP; //@line 44375
 STACKTOP = STACKTOP + 8 | 0; //@line 44375
 $s = sp | 0; //@line 44376
 if ((HEAP8[$c + 334 | 0] | 0) == 0) {
  _e68_exception_privilege($c); //@line 44382
  STACKTOP = sp; //@line 44384
  return;
 }
 $9 = HEAP16[$c + 160 >> 1] & 63; //@line 44390
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($9 << 2) >> 2] & 127]($c, $9, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 44397
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 44404
  return;
 }
 $18 = $c + 372 | 0; //@line 44407
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 12; //@line 44410
 _e68_set_sr($c, HEAP16[$s >> 1] & -22753); //@line 44413
 $23 = $c + 156 | 0; //@line 44414
 $24 = HEAP32[$23 >> 2] | 0; //@line 44415
 if (($24 & 1 | 0) != 0) {
  _e68_exception_address($c, $24, 0, 0); //@line 44420
  STACKTOP = sp; //@line 44422
  return;
 }
 $29 = $c + 164 | 0; //@line 44425
 HEAP16[$c + 162 >> 1] = HEAP16[$29 >> 1] | 0; //@line 44428
 $32 = $24 & 16777215; //@line 44429
 $33 = $32 + 1 | 0; //@line 44430
 if ($33 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $39 = HEAP32[$c + 32 >> 2] | 0; //@line 44437
  $_0_i_i = HEAPU8[$39 + $32 | 0] << 8 | HEAPU8[$39 + $33 | 0]; //@line 44447
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $32) | 0; //@line 44455
 }
 HEAP16[$29 >> 1] = $_0_i_i; //@line 44458
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 44466
  $61 = $c + 152 | 0; //@line 44467
  HEAP32[$61 >> 2] = (HEAP32[$61 >> 2] | 0) + 2; //@line 44470
  STACKTOP = sp; //@line 44472
  return;
 } else {
  _e68_exception_bus($c); //@line 44475
  STACKTOP = sp; //@line 44477
  return;
 }
}
function _op4800($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $15 = 0, $16 = 0, $sum = 0, $18 = 0, $d_0 = 0, $d_0_ = 0, $25 = 0, $storemerge = 0, $33 = 0, $36 = 0, $37 = 0, $42 = 0, $45 = 0, $46 = 0, $52 = 0, $_0_i_i = 0, $74 = 0, $77 = 0, sp = 0;
 sp = STACKTOP; //@line 44496
 STACKTOP = STACKTOP + 8 | 0; //@line 44496
 $s = sp | 0; //@line 44497
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 44501
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 44508
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 44515
  return;
 }
 $15 = $c + 166 | 0; //@line 44520
 $16 = HEAP16[$15 >> 1] | 0; //@line 44521
 $sum = (($16 & 65535) >>> 4 & 1) + (HEAPU8[$s] | 0) & 65535; //@line 44524
 $18 = -$sum & 65535; //@line 44525
 $d_0 = ($18 & 15) == 0 ? $18 : -6 - $sum & 65535; //@line 44529
 $d_0_ = ($d_0 & 240) == 0 ? $d_0 : $d_0 - 96 & 65535; //@line 44533
 $25 = $d_0_ & 65535; //@line 44534
 $storemerge = ($25 & 65280 | 0) == 0 ? $16 & -18 : $16 | 17; //@line 44539
 HEAP16[$15 >> 1] = ($25 & 255 | 0) == 0 ? $storemerge : $storemerge & -5; //@line 44544
 $33 = $c + 372 | 0; //@line 44545
 HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 6; //@line 44548
 $36 = $c + 156 | 0; //@line 44549
 $37 = HEAP32[$36 >> 2] | 0; //@line 44550
 if (($37 & 1 | 0) != 0) {
  _e68_exception_address($c, $37, 0, 0); //@line 44555
  STACKTOP = sp; //@line 44557
  return;
 }
 $42 = $c + 164 | 0; //@line 44560
 HEAP16[$c + 162 >> 1] = HEAP16[$42 >> 1] | 0; //@line 44563
 $45 = $37 & 16777215; //@line 44564
 $46 = $45 + 1 | 0; //@line 44565
 if ($46 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $52 = HEAP32[$c + 32 >> 2] | 0; //@line 44572
  $_0_i_i = HEAPU8[$52 + $45 | 0] << 8 | HEAPU8[$52 + $46 | 0]; //@line 44582
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $45) | 0; //@line 44590
 }
 HEAP16[$42 >> 1] = $_0_i_i; //@line 44593
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$36 >> 2] = (HEAP32[$36 >> 2] | 0) + 2; //@line 44601
  $74 = $c + 152 | 0; //@line 44602
  HEAP32[$74 >> 2] = (HEAP32[$74 >> 2] | 0) + 2; //@line 44605
  $77 = $d_0_ & 255; //@line 44606
  _e68_ea_set_val8($c, $77) | 0; //@line 44607
  STACKTOP = sp; //@line 44609
  return;
 } else {
  _e68_exception_bus($c); //@line 44612
  STACKTOP = sp; //@line 44614
  return;
 }
}
function _op4840($c) {
 $c = $c | 0;
 var $3 = 0, $8 = 0, $9 = 0, $12 = 0, $13 = 0, $16 = 0, $17 = 0, $22 = 0, $25 = 0, $26 = 0, $32 = 0, $_0_i_i_i = 0, $54 = 0, $58 = 0, $69 = 0, $73 = 0, $74 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $85 = 0, $106 = 0, $107 = 0, $112 = 0, $115 = 0, $116 = 0, $121 = 0, $_0_i_i = 0, $143 = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 44642
 if (($3 & 56 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 44648
  $9 = HEAP32[$8 >> 2] | 0; //@line 44649
  $12 = $9 << 16 | $9 >>> 16; //@line 44652
  $13 = $c + 372 | 0; //@line 44653
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 4; //@line 44656
  _e68_cc_set_nz_32($c, 15, $12); //@line 44657
  HEAP32[$8 >> 2] = $12; //@line 44658
  $16 = $c + 156 | 0; //@line 44659
  $17 = HEAP32[$16 >> 2] | 0; //@line 44660
  if (($17 & 1 | 0) != 0) {
   _e68_exception_address($c, $17, 0, 0); //@line 44665
   return;
  }
  $22 = $c + 164 | 0; //@line 44670
  HEAP16[$c + 162 >> 1] = HEAP16[$22 >> 1] | 0; //@line 44673
  $25 = $17 & 16777215; //@line 44674
  $26 = $25 + 1 | 0; //@line 44675
  if ($26 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $32 = HEAP32[$c + 32 >> 2] | 0; //@line 44682
   $_0_i_i_i = HEAPU8[$32 + $25 | 0] << 8 | HEAPU8[$32 + $26 | 0]; //@line 44692
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $25) | 0; //@line 44700
  }
  HEAP16[$22 >> 1] = $_0_i_i_i; //@line 44703
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 2; //@line 44711
   $54 = $c + 152 | 0; //@line 44712
   HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 2; //@line 44715
   return;
  } else {
   _e68_exception_bus($c); //@line 44720
   return;
  }
 }
 $58 = $3 & 63; //@line 44726
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($58 << 2) >> 2] & 127]($c, $58, 2020, 32) | 0) != 0) {
  return;
 }
 if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
  _e68_exception_illegal($c); //@line 44741
  return;
 }
 $69 = $c + 372 | 0; //@line 44746
 HEAP32[$69 >> 2] = (HEAP32[$69 >> 2] | 0) + 12; //@line 44749
 $73 = HEAP32[$c + 344 >> 2] | 0; //@line 44751
 $74 = $c + 148 | 0; //@line 44752
 $76 = (HEAP32[$74 >> 2] | 0) - 4 | 0; //@line 44754
 $77 = $76 & 16777215; //@line 44755
 $78 = $77 + 3 | 0; //@line 44756
 $79 = $c + 36 | 0; //@line 44757
 if ($78 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
  $85 = $c + 32 | 0; //@line 44764
  HEAP8[(HEAP32[$85 >> 2] | 0) + $77 | 0] = $73 >>> 24 & 255; //@line 44767
  HEAP8[(HEAP32[$85 >> 2] | 0) + ($77 + 1) | 0] = $73 >>> 16 & 255; //@line 44773
  HEAP8[(HEAP32[$85 >> 2] | 0) + ($77 + 2) | 0] = $73 >>> 8 & 255; //@line 44779
  HEAP8[(HEAP32[$85 >> 2] | 0) + $78 | 0] = $73 & 255; //@line 44783
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $77, $73); //@line 44790
 }
 HEAP32[$74 >> 2] = $76; //@line 44792
 $106 = $c + 156 | 0; //@line 44793
 $107 = HEAP32[$106 >> 2] | 0; //@line 44794
 if (($107 & 1 | 0) != 0) {
  _e68_exception_address($c, $107, 0, 0); //@line 44799
  return;
 }
 $112 = $c + 164 | 0; //@line 44804
 HEAP16[$c + 162 >> 1] = HEAP16[$112 >> 1] | 0; //@line 44807
 $115 = $107 & 16777215; //@line 44808
 $116 = $115 + 1 | 0; //@line 44809
 if ($116 >>> 0 < (HEAP32[$79 >> 2] | 0) >>> 0) {
  $121 = HEAP32[$c + 32 >> 2] | 0; //@line 44815
  $_0_i_i = HEAPU8[$121 + $115 | 0] << 8 | HEAPU8[$121 + $116 | 0]; //@line 44825
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $115) | 0; //@line 44833
 }
 HEAP16[$112 >> 1] = $_0_i_i; //@line 44836
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 44844
  $143 = $c + 152 | 0; //@line 44845
  HEAP32[$143 >> 2] = (HEAP32[$143 >> 2] | 0) + 2; //@line 44848
  return;
 } else {
  _e68_exception_bus($c); //@line 44853
  return;
 }
}
function _op4880($c) {
 $c = $c | 0;
 var $1 = 0, $3 = 0, $5 = 0, $8 = 0, $9 = 0, $14 = 0, $16 = 0, $23 = 0, $24 = 0, $29 = 0, $32 = 0, $33 = 0, $39 = 0, $_0_i_i_i = 0, $61 = 0, $65 = 0, $66 = 0, $71 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $81 = 0, $_0_i_i_i4 = 0, $96 = 0, $103 = 0, $106 = 0, $111 = 0, $r_0_ph_i = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $a_029_i = 0, $r_028_i = 0, $i_027_i = 0, $130 = 0, $_sink_in_i = 0, $_sink_i = 0, $141 = 0, $142 = 0, $143 = 0, $a_1_i = 0, $161 = 0, $170 = 0, $176 = 0, $177 = 0, $181 = 0, $_0_i_i23_i = 0, $204 = 0, $205 = 0, $210 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $220 = 0, $_0_i_i_i6 = 0, $235 = 0, $242 = 0, $245 = 0, $248 = 0, $260 = 0, $r_0_ph_i8 = 0, $267 = 0, $268 = 0, $269 = 0, $270 = 0, $a_028_i = 0, $r_027_i = 0, $i_026_i = 0, $280 = 0, $_sink_in_i10 = 0, $_sink_i11 = 0, $286 = 0, $287 = 0, $288 = 0, $a_1_i13 = 0, $307 = 0, $312 = 0, $318 = 0, $319 = 0, $323 = 0, $_0_i_i22_i = 0;
 $1 = $c + 160 | 0; //@line 44903
 $3 = HEAPU16[$1 >> 1] | 0; //@line 44905
 $5 = $3 >>> 3 & 7; //@line 44907
 if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 44910
  $9 = HEAP32[$8 >> 2] | 0; //@line 44911
  $14 = ($9 & 128 | 0) != 0 ? $9 | 65280 : $9 & 255; //@line 44916
  $16 = $c + 372 | 0; //@line 44918
  HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 4; //@line 44921
  _e68_cc_set_nz_16($c, 15, $14 & 65535); //@line 44922
  HEAP32[$8 >> 2] = HEAP32[$8 >> 2] & -65536 | $14 & 65535; //@line 44927
  $23 = $c + 156 | 0; //@line 44928
  $24 = HEAP32[$23 >> 2] | 0; //@line 44929
  if (($24 & 1 | 0) != 0) {
   _e68_exception_address($c, $24, 0, 0); //@line 44934
   return;
  }
  $29 = $c + 164 | 0; //@line 44939
  HEAP16[$c + 162 >> 1] = HEAP16[$29 >> 1] | 0; //@line 44942
  $32 = $24 & 16777215; //@line 44943
  $33 = $32 + 1 | 0; //@line 44944
  if ($33 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $39 = HEAP32[$c + 32 >> 2] | 0; //@line 44951
   $_0_i_i_i = HEAPU8[$39 + $32 | 0] << 8 | HEAPU8[$39 + $33 | 0]; //@line 44961
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $32) | 0; //@line 44969
  }
  HEAP16[$29 >> 1] = $_0_i_i_i; //@line 44972
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 2; //@line 44980
   $61 = $c + 152 | 0; //@line 44981
   HEAP32[$61 >> 2] = (HEAP32[$61 >> 2] | 0) + 2; //@line 44984
   return;
  } else {
   _e68_exception_bus($c); //@line 44989
   return;
  }
 } else if (($5 | 0) == 4) {
  $65 = $c + 156 | 0; //@line 44995
  $66 = HEAP32[$65 >> 2] | 0; //@line 44996
  if (($66 & 1 | 0) != 0) {
   _e68_exception_address($c, $66, 0, 0); //@line 45001
   return;
  }
  $71 = $c + 164 | 0; //@line 45006
  $73 = $c + 162 | 0; //@line 45008
  HEAP16[$73 >> 1] = HEAP16[$71 >> 1] | 0; //@line 45009
  $74 = $66 & 16777215; //@line 45010
  $75 = $74 + 1 | 0; //@line 45011
  $76 = $c + 36 | 0; //@line 45012
  if ($75 >>> 0 < (HEAP32[$76 >> 2] | 0) >>> 0) {
   $81 = HEAP32[$c + 32 >> 2] | 0; //@line 45018
   $_0_i_i_i4 = HEAPU8[$81 + $74 | 0] << 8 | HEAPU8[$81 + $75 | 0]; //@line 45028
  } else {
   $_0_i_i_i4 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $74) | 0; //@line 45036
  }
  HEAP16[$71 >> 1] = $_0_i_i_i4; //@line 45039
  $96 = $c + 336 | 0; //@line 45040
  if ((HEAP8[$96] | 0) != 0) {
   _e68_exception_bus($c); //@line 45045
   return;
  }
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 45052
  $103 = $c + 152 | 0; //@line 45053
  HEAP32[$103 >> 2] = (HEAP32[$103 >> 2] | 0) + 2; //@line 45056
  $106 = HEAP16[$73 >> 1] | 0; //@line 45057
  $111 = HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] | 0; //@line 45062
  do {
   if ($106 << 16 >> 16 == 0) {
    $r_0_ph_i = 0; //@line 45067
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i = $106; //@line 45075
     break;
    }
    if (($111 & 1 | 0) == 0) {
     $r_0_ph_i = $106; //@line 45082
     break;
    }
    _e68_exception_address($c, $111, 1, 1); //@line 45085
    return;
   }
  } while (0);
  $118 = $c + 32 | 0; //@line 45092
  $119 = $c + 372 | 0; //@line 45093
  $120 = $c + 24 | 0; //@line 45094
  $121 = $c + 4 | 0; //@line 45095
  $i_027_i = 0;
  $r_028_i = $r_0_ph_i;
  $a_029_i = $111;
  while (1) {
   if (($r_028_i & 1) == 0) {
    $a_1_i = $a_029_i; //@line 45106
   } else {
    $130 = $a_029_i - 2 | 0; //@line 45108
    if ($i_027_i >>> 0 < 8) {
     $_sink_in_i = $c + 120 + ((7 - $i_027_i & 7) << 2) | 0; //@line 45116
    } else {
     $_sink_in_i = $c + 88 + ((15 - $i_027_i & 7) << 2) | 0; //@line 45121
    }
    $_sink_i = HEAP32[$_sink_in_i >> 2] | 0; //@line 45124
    $141 = $_sink_i & 65535; //@line 45125
    $142 = $130 & 16777215; //@line 45126
    $143 = $142 + 1 | 0; //@line 45127
    if ($143 >>> 0 < (HEAP32[$76 >> 2] | 0) >>> 0) {
     HEAP8[(HEAP32[$118 >> 2] | 0) + $142 | 0] = ($141 & 65535) >>> 8 & 255; //@line 45136
     HEAP8[(HEAP32[$118 >> 2] | 0) + $143 | 0] = $_sink_i & 255; //@line 45140
    } else {
     FUNCTION_TABLE_viii[HEAP32[$120 >> 2] & 63](HEAP32[$121 >> 2] | 0, $142, $141); //@line 45145
    }
    HEAP32[$119 >> 2] = (HEAP32[$119 >> 2] | 0) + 4; //@line 45149
    $a_1_i = $130; //@line 45151
   }
   $161 = $i_027_i + 1 | 0; //@line 45155
   if ($161 >>> 0 < 16) {
    $i_027_i = $161;
    $r_028_i = ($r_028_i & 65535) >>> 1;
    $a_029_i = $a_1_i;
   } else {
    break;
   }
  }
  HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] = $a_1_i; //@line 45168
  HEAP32[$119 >> 2] = (HEAP32[$119 >> 2] | 0) + 8; //@line 45171
  $170 = HEAP32[$65 >> 2] | 0; //@line 45172
  if (($170 & 1 | 0) != 0) {
   _e68_exception_address($c, $170, 0, 0); //@line 45177
   return;
  }
  HEAP16[$73 >> 1] = HEAP16[$71 >> 1] | 0; //@line 45183
  $176 = $170 & 16777215; //@line 45184
  $177 = $176 + 1 | 0; //@line 45185
  if ($177 >>> 0 < (HEAP32[$76 >> 2] | 0) >>> 0) {
   $181 = HEAP32[$118 >> 2] | 0; //@line 45190
   $_0_i_i23_i = HEAPU8[$181 + $176 | 0] << 8 | HEAPU8[$181 + $177 | 0]; //@line 45200
  } else {
   $_0_i_i23_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$121 >> 2] | 0, $176) | 0; //@line 45207
  }
  HEAP16[$71 >> 1] = $_0_i_i23_i; //@line 45210
  if ((HEAP8[$96] | 0) == 0) {
   HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 45217
   HEAP32[$103 >> 2] = (HEAP32[$103 >> 2] | 0) + 2; //@line 45220
   return;
  } else {
   _e68_exception_bus($c); //@line 45225
   return;
  }
 } else {
  $204 = $c + 156 | 0; //@line 45231
  $205 = HEAP32[$204 >> 2] | 0; //@line 45232
  if (($205 & 1 | 0) != 0) {
   _e68_exception_address($c, $205, 0, 0); //@line 45237
   return;
  }
  $210 = $c + 164 | 0; //@line 45242
  $212 = $c + 162 | 0; //@line 45244
  HEAP16[$212 >> 1] = HEAP16[$210 >> 1] | 0; //@line 45245
  $213 = $205 & 16777215; //@line 45246
  $214 = $213 + 1 | 0; //@line 45247
  $215 = $c + 36 | 0; //@line 45248
  if ($214 >>> 0 < (HEAP32[$215 >> 2] | 0) >>> 0) {
   $220 = HEAP32[$c + 32 >> 2] | 0; //@line 45254
   $_0_i_i_i6 = HEAPU8[$220 + $213 | 0] << 8 | HEAPU8[$220 + $214 | 0]; //@line 45264
  } else {
   $_0_i_i_i6 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $213) | 0; //@line 45272
  }
  HEAP16[$210 >> 1] = $_0_i_i_i6; //@line 45275
  $235 = $c + 336 | 0; //@line 45276
  if ((HEAP8[$235] | 0) != 0) {
   _e68_exception_bus($c); //@line 45281
   return;
  }
  HEAP32[$204 >> 2] = (HEAP32[$204 >> 2] | 0) + 2; //@line 45288
  $242 = $c + 152 | 0; //@line 45289
  HEAP32[$242 >> 2] = (HEAP32[$242 >> 2] | 0) + 2; //@line 45292
  $245 = HEAP16[$212 >> 1] | 0; //@line 45293
  $248 = HEAP16[$1 >> 1] & 63; //@line 45296
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($248 << 2) >> 2] & 127]($c, $248, 484, 16) | 0) != 0) {
   return;
  }
  if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
   _e68_exception_illegal($c); //@line 45311
   return;
  }
  $260 = HEAP32[$c + 344 >> 2] | 0; //@line 45317
  do {
   if ($245 << 16 >> 16 == 0) {
    $r_0_ph_i8 = 0; //@line 45322
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i8 = $245; //@line 45330
     break;
    }
    if (($260 & 1 | 0) == 0) {
     $r_0_ph_i8 = $245; //@line 45337
     break;
    }
    _e68_exception_address($c, $260, 1, 1); //@line 45340
    return;
   }
  } while (0);
  $267 = $c + 32 | 0; //@line 45347
  $268 = $c + 372 | 0; //@line 45348
  $269 = $c + 24 | 0; //@line 45349
  $270 = $c + 4 | 0; //@line 45350
  $i_026_i = 0;
  $r_027_i = $r_0_ph_i8;
  $a_028_i = $260;
  while (1) {
   if (($r_027_i & 1) == 0) {
    $a_1_i13 = $a_028_i; //@line 45361
   } else {
    $280 = $i_026_i & 7; //@line 45364
    if ($i_026_i >>> 0 < 8) {
     $_sink_in_i10 = $c + 88 + ($280 << 2) | 0; //@line 45369
    } else {
     $_sink_in_i10 = $c + 120 + ($280 << 2) | 0; //@line 45372
    }
    $_sink_i11 = HEAP32[$_sink_in_i10 >> 2] | 0; //@line 45375
    $286 = $_sink_i11 & 65535; //@line 45376
    $287 = $a_028_i & 16777215; //@line 45377
    $288 = $287 + 1 | 0; //@line 45378
    if ($288 >>> 0 < (HEAP32[$215 >> 2] | 0) >>> 0) {
     HEAP8[(HEAP32[$267 >> 2] | 0) + $287 | 0] = ($286 & 65535) >>> 8 & 255; //@line 45387
     HEAP8[(HEAP32[$267 >> 2] | 0) + $288 | 0] = $_sink_i11 & 255; //@line 45391
    } else {
     FUNCTION_TABLE_viii[HEAP32[$269 >> 2] & 63](HEAP32[$270 >> 2] | 0, $287, $286); //@line 45396
    }
    HEAP32[$268 >> 2] = (HEAP32[$268 >> 2] | 0) + 4; //@line 45401
    $a_1_i13 = $a_028_i + 2 | 0; //@line 45403
   }
   $307 = $i_026_i + 1 | 0; //@line 45407
   if ($307 >>> 0 < 16) {
    $i_026_i = $307;
    $r_027_i = ($r_027_i & 65535) >>> 1;
    $a_028_i = $a_1_i13;
   } else {
    break;
   }
  }
  HEAP32[$268 >> 2] = (HEAP32[$268 >> 2] | 0) + 8; //@line 45418
  $312 = HEAP32[$204 >> 2] | 0; //@line 45419
  if (($312 & 1 | 0) != 0) {
   _e68_exception_address($c, $312, 0, 0); //@line 45424
   return;
  }
  HEAP16[$212 >> 1] = HEAP16[$210 >> 1] | 0; //@line 45430
  $318 = $312 & 16777215; //@line 45431
  $319 = $318 + 1 | 0; //@line 45432
  if ($319 >>> 0 < (HEAP32[$215 >> 2] | 0) >>> 0) {
   $323 = HEAP32[$267 >> 2] | 0; //@line 45437
   $_0_i_i22_i = HEAPU8[$323 + $318 | 0] << 8 | HEAPU8[$323 + $319 | 0]; //@line 45447
  } else {
   $_0_i_i22_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$270 >> 2] | 0, $318) | 0; //@line 45454
  }
  HEAP16[$210 >> 1] = $_0_i_i22_i; //@line 45457
  if ((HEAP8[$235] | 0) == 0) {
   HEAP32[$204 >> 2] = (HEAP32[$204 >> 2] | 0) + 2; //@line 45464
   HEAP32[$242 >> 2] = (HEAP32[$242 >> 2] | 0) + 2; //@line 45467
   return;
  } else {
   _e68_exception_bus($c); //@line 45472
   return;
  }
 }
}
function _op48c0($c) {
 $c = $c | 0;
 var $1 = 0, $3 = 0, $5 = 0, $8 = 0, $9 = 0, $14 = 0, $15 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $34 = 0, $_0_i_i_i = 0, $56 = 0, $60 = 0, $61 = 0, $66 = 0, $68 = 0, $69 = 0, $70 = 0, $71 = 0, $76 = 0, $_0_i_i_i4 = 0, $91 = 0, $98 = 0, $101 = 0, $106 = 0, $r_0_ph_i = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $a_029_i = 0, $r_028_i = 0, $i_027_i = 0, $125 = 0, $v_0_in_i = 0, $v_0_i = 0, $136 = 0, $137 = 0, $a_1_i = 0, $165 = 0, $174 = 0, $180 = 0, $181 = 0, $185 = 0, $_0_i_i23_i = 0, $208 = 0, $209 = 0, $214 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $224 = 0, $_0_i_i_i6 = 0, $239 = 0, $246 = 0, $249 = 0, $252 = 0, $264 = 0, $r_0_ph_i8 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $a_028_i = 0, $r_027_i = 0, $i_026_i = 0, $284 = 0, $v_0_in_i10 = 0, $v_0_i11 = 0, $290 = 0, $291 = 0, $a_1_i13 = 0, $320 = 0, $325 = 0, $331 = 0, $332 = 0, $336 = 0, $_0_i_i22_i = 0;
 $1 = $c + 160 | 0; //@line 45525
 $3 = HEAPU16[$1 >> 1] | 0; //@line 45527
 $5 = $3 >>> 3 & 7; //@line 45529
 if (($5 | 0) == 4) {
  $60 = $c + 156 | 0; //@line 45531
  $61 = HEAP32[$60 >> 2] | 0; //@line 45532
  if (($61 & 1 | 0) != 0) {
   _e68_exception_address($c, $61, 0, 0); //@line 45537
   return;
  }
  $66 = $c + 164 | 0; //@line 45542
  $68 = $c + 162 | 0; //@line 45544
  HEAP16[$68 >> 1] = HEAP16[$66 >> 1] | 0; //@line 45545
  $69 = $61 & 16777215; //@line 45546
  $70 = $69 + 1 | 0; //@line 45547
  $71 = $c + 36 | 0; //@line 45548
  if ($70 >>> 0 < (HEAP32[$71 >> 2] | 0) >>> 0) {
   $76 = HEAP32[$c + 32 >> 2] | 0; //@line 45554
   $_0_i_i_i4 = HEAPU8[$76 + $69 | 0] << 8 | HEAPU8[$76 + $70 | 0]; //@line 45564
  } else {
   $_0_i_i_i4 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $69) | 0; //@line 45572
  }
  HEAP16[$66 >> 1] = $_0_i_i_i4; //@line 45575
  $91 = $c + 336 | 0; //@line 45576
  if ((HEAP8[$91] | 0) != 0) {
   _e68_exception_bus($c); //@line 45581
   return;
  }
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 45588
  $98 = $c + 152 | 0; //@line 45589
  HEAP32[$98 >> 2] = (HEAP32[$98 >> 2] | 0) + 2; //@line 45592
  $101 = HEAP16[$68 >> 1] | 0; //@line 45593
  $106 = HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] | 0; //@line 45598
  do {
   if ($101 << 16 >> 16 == 0) {
    $r_0_ph_i = 0; //@line 45603
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i = $101; //@line 45611
     break;
    }
    if (($106 & 1 | 0) == 0) {
     $r_0_ph_i = $101; //@line 45618
     break;
    }
    _e68_exception_address($c, $106, 1, 1); //@line 45621
    return;
   }
  } while (0);
  $113 = $c + 32 | 0; //@line 45628
  $114 = $c + 372 | 0; //@line 45629
  $115 = $c + 28 | 0; //@line 45630
  $116 = $c + 4 | 0; //@line 45631
  $i_027_i = 0;
  $r_028_i = $r_0_ph_i;
  $a_029_i = $106;
  while (1) {
   if (($r_028_i & 1) == 0) {
    $a_1_i = $a_029_i; //@line 45642
   } else {
    $125 = $a_029_i - 4 | 0; //@line 45644
    if ($i_027_i >>> 0 < 8) {
     $v_0_in_i = $c + 120 + ((7 - $i_027_i & 7) << 2) | 0; //@line 45652
    } else {
     $v_0_in_i = $c + 88 + ((15 - $i_027_i & 7) << 2) | 0; //@line 45657
    }
    $v_0_i = HEAP32[$v_0_in_i >> 2] | 0; //@line 45660
    $136 = $125 & 16777215; //@line 45661
    $137 = $136 + 3 | 0; //@line 45662
    if ($137 >>> 0 < (HEAP32[$71 >> 2] | 0) >>> 0) {
     HEAP8[(HEAP32[$113 >> 2] | 0) + $136 | 0] = $v_0_i >>> 24 & 255; //@line 45671
     HEAP8[(HEAP32[$113 >> 2] | 0) + ($136 + 1) | 0] = $v_0_i >>> 16 & 255; //@line 45677
     HEAP8[(HEAP32[$113 >> 2] | 0) + ($136 + 2) | 0] = $v_0_i >>> 8 & 255; //@line 45683
     HEAP8[(HEAP32[$113 >> 2] | 0) + $137 | 0] = $v_0_i & 255; //@line 45687
    } else {
     FUNCTION_TABLE_viii[HEAP32[$115 >> 2] & 63](HEAP32[$116 >> 2] | 0, $136, $v_0_i); //@line 45692
    }
    HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 8; //@line 45696
    $a_1_i = $125; //@line 45698
   }
   $165 = $i_027_i + 1 | 0; //@line 45702
   if ($165 >>> 0 < 16) {
    $i_027_i = $165;
    $r_028_i = ($r_028_i & 65535) >>> 1;
    $a_029_i = $a_1_i;
   } else {
    break;
   }
  }
  HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] = $a_1_i; //@line 45715
  HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 8; //@line 45718
  $174 = HEAP32[$60 >> 2] | 0; //@line 45719
  if (($174 & 1 | 0) != 0) {
   _e68_exception_address($c, $174, 0, 0); //@line 45724
   return;
  }
  HEAP16[$68 >> 1] = HEAP16[$66 >> 1] | 0; //@line 45730
  $180 = $174 & 16777215; //@line 45731
  $181 = $180 + 1 | 0; //@line 45732
  if ($181 >>> 0 < (HEAP32[$71 >> 2] | 0) >>> 0) {
   $185 = HEAP32[$113 >> 2] | 0; //@line 45737
   $_0_i_i23_i = HEAPU8[$185 + $180 | 0] << 8 | HEAPU8[$185 + $181 | 0]; //@line 45747
  } else {
   $_0_i_i23_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$116 >> 2] | 0, $180) | 0; //@line 45754
  }
  HEAP16[$66 >> 1] = $_0_i_i23_i; //@line 45757
  if ((HEAP8[$91] | 0) == 0) {
   HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 45764
   HEAP32[$98 >> 2] = (HEAP32[$98 >> 2] | 0) + 2; //@line 45767
   return;
  } else {
   _e68_exception_bus($c); //@line 45772
   return;
  }
 } else if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 45779
  $9 = HEAP32[$8 >> 2] | 0; //@line 45780
  $14 = ($9 & 32768 | 0) != 0 ? $9 | -65536 : $9 & 65535; //@line 45785
  $15 = $c + 372 | 0; //@line 45786
  HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 4; //@line 45789
  _e68_cc_set_nz_32($c, 15, $14); //@line 45790
  HEAP32[$8 >> 2] = $14; //@line 45791
  $18 = $c + 156 | 0; //@line 45792
  $19 = HEAP32[$18 >> 2] | 0; //@line 45793
  if (($19 & 1 | 0) != 0) {
   _e68_exception_address($c, $19, 0, 0); //@line 45798
   return;
  }
  $24 = $c + 164 | 0; //@line 45803
  HEAP16[$c + 162 >> 1] = HEAP16[$24 >> 1] | 0; //@line 45806
  $27 = $19 & 16777215; //@line 45807
  $28 = $27 + 1 | 0; //@line 45808
  if ($28 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $34 = HEAP32[$c + 32 >> 2] | 0; //@line 45815
   $_0_i_i_i = HEAPU8[$34 + $27 | 0] << 8 | HEAPU8[$34 + $28 | 0]; //@line 45825
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $27) | 0; //@line 45833
  }
  HEAP16[$24 >> 1] = $_0_i_i_i; //@line 45836
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 45844
   $56 = $c + 152 | 0; //@line 45845
   HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 2; //@line 45848
   return;
  } else {
   _e68_exception_bus($c); //@line 45853
   return;
  }
 } else {
  $208 = $c + 156 | 0; //@line 45859
  $209 = HEAP32[$208 >> 2] | 0; //@line 45860
  if (($209 & 1 | 0) != 0) {
   _e68_exception_address($c, $209, 0, 0); //@line 45865
   return;
  }
  $214 = $c + 164 | 0; //@line 45870
  $216 = $c + 162 | 0; //@line 45872
  HEAP16[$216 >> 1] = HEAP16[$214 >> 1] | 0; //@line 45873
  $217 = $209 & 16777215; //@line 45874
  $218 = $217 + 1 | 0; //@line 45875
  $219 = $c + 36 | 0; //@line 45876
  if ($218 >>> 0 < (HEAP32[$219 >> 2] | 0) >>> 0) {
   $224 = HEAP32[$c + 32 >> 2] | 0; //@line 45882
   $_0_i_i_i6 = HEAPU8[$224 + $217 | 0] << 8 | HEAPU8[$224 + $218 | 0]; //@line 45892
  } else {
   $_0_i_i_i6 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $217) | 0; //@line 45900
  }
  HEAP16[$214 >> 1] = $_0_i_i_i6; //@line 45903
  $239 = $c + 336 | 0; //@line 45904
  if ((HEAP8[$239] | 0) != 0) {
   _e68_exception_bus($c); //@line 45909
   return;
  }
  HEAP32[$208 >> 2] = (HEAP32[$208 >> 2] | 0) + 2; //@line 45916
  $246 = $c + 152 | 0; //@line 45917
  HEAP32[$246 >> 2] = (HEAP32[$246 >> 2] | 0) + 2; //@line 45920
  $249 = HEAP16[$216 >> 1] | 0; //@line 45921
  $252 = HEAP16[$1 >> 1] & 63; //@line 45924
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($252 << 2) >> 2] & 127]($c, $252, 484, 32) | 0) != 0) {
   return;
  }
  if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
   _e68_exception_illegal($c); //@line 45939
   return;
  }
  $264 = HEAP32[$c + 344 >> 2] | 0; //@line 45945
  do {
   if ($249 << 16 >> 16 == 0) {
    $r_0_ph_i8 = 0; //@line 45950
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i8 = $249; //@line 45958
     break;
    }
    if (($264 & 1 | 0) == 0) {
     $r_0_ph_i8 = $249; //@line 45965
     break;
    }
    _e68_exception_address($c, $264, 1, 1); //@line 45968
    return;
   }
  } while (0);
  $271 = $c + 32 | 0; //@line 45975
  $272 = $c + 372 | 0; //@line 45976
  $273 = $c + 28 | 0; //@line 45977
  $274 = $c + 4 | 0; //@line 45978
  $i_026_i = 0;
  $r_027_i = $r_0_ph_i8;
  $a_028_i = $264;
  while (1) {
   if (($r_027_i & 1) == 0) {
    $a_1_i13 = $a_028_i; //@line 45989
   } else {
    $284 = $i_026_i & 7; //@line 45992
    if ($i_026_i >>> 0 < 8) {
     $v_0_in_i10 = $c + 88 + ($284 << 2) | 0; //@line 45997
    } else {
     $v_0_in_i10 = $c + 120 + ($284 << 2) | 0; //@line 46000
    }
    $v_0_i11 = HEAP32[$v_0_in_i10 >> 2] | 0; //@line 46003
    $290 = $a_028_i & 16777215; //@line 46004
    $291 = $290 + 3 | 0; //@line 46005
    if ($291 >>> 0 < (HEAP32[$219 >> 2] | 0) >>> 0) {
     HEAP8[(HEAP32[$271 >> 2] | 0) + $290 | 0] = $v_0_i11 >>> 24 & 255; //@line 46014
     HEAP8[(HEAP32[$271 >> 2] | 0) + ($290 + 1) | 0] = $v_0_i11 >>> 16 & 255; //@line 46020
     HEAP8[(HEAP32[$271 >> 2] | 0) + ($290 + 2) | 0] = $v_0_i11 >>> 8 & 255; //@line 46026
     HEAP8[(HEAP32[$271 >> 2] | 0) + $291 | 0] = $v_0_i11 & 255; //@line 46030
    } else {
     FUNCTION_TABLE_viii[HEAP32[$273 >> 2] & 63](HEAP32[$274 >> 2] | 0, $290, $v_0_i11); //@line 46035
    }
    HEAP32[$272 >> 2] = (HEAP32[$272 >> 2] | 0) + 8; //@line 46040
    $a_1_i13 = $a_028_i + 4 | 0; //@line 46042
   }
   $320 = $i_026_i + 1 | 0; //@line 46046
   if ($320 >>> 0 < 16) {
    $i_026_i = $320;
    $r_027_i = ($r_027_i & 65535) >>> 1;
    $a_028_i = $a_1_i13;
   } else {
    break;
   }
  }
  HEAP32[$272 >> 2] = (HEAP32[$272 >> 2] | 0) + 8; //@line 46057
  $325 = HEAP32[$208 >> 2] | 0; //@line 46058
  if (($325 & 1 | 0) != 0) {
   _e68_exception_address($c, $325, 0, 0); //@line 46063
   return;
  }
  HEAP16[$216 >> 1] = HEAP16[$214 >> 1] | 0; //@line 46069
  $331 = $325 & 16777215; //@line 46070
  $332 = $331 + 1 | 0; //@line 46071
  if ($332 >>> 0 < (HEAP32[$219 >> 2] | 0) >>> 0) {
   $336 = HEAP32[$271 >> 2] | 0; //@line 46076
   $_0_i_i22_i = HEAPU8[$336 + $331 | 0] << 8 | HEAPU8[$336 + $332 | 0]; //@line 46086
  } else {
   $_0_i_i22_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$274 >> 2] | 0, $331) | 0; //@line 46093
  }
  HEAP16[$214 >> 1] = $_0_i_i22_i; //@line 46096
  if ((HEAP8[$239] | 0) == 0) {
   HEAP32[$208 >> 2] = (HEAP32[$208 >> 2] | 0) + 2; //@line 46103
   HEAP32[$246 >> 2] = (HEAP32[$246 >> 2] | 0) + 2; //@line 46106
   return;
  } else {
   _e68_exception_bus($c); //@line 46111
   return;
  }
 }
}
function _op49c0($c) {
 $c = $c | 0;
 FUNCTION_TABLE_vi[HEAP32[$c + 4496 + (((HEAP16[$c + 160 >> 1] & 65535) >>> 3 & 7) << 2) >> 2] & 1023]($c); //@line 46132
 return;
}
function _op4a00($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0, sp = 0;
 sp = STACKTOP; //@line 46148
 STACKTOP = STACKTOP + 8 | 0; //@line 46148
 $s = sp | 0; //@line 46149
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 46153
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 46160
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 46167
  return;
 }
 $13 = $c + 372 | 0; //@line 46170
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 46173
 _e68_cc_set_nz_8($c, 15, HEAP8[$s] | 0); //@line 46175
 $17 = $c + 156 | 0; //@line 46176
 $18 = HEAP32[$17 >> 2] | 0; //@line 46177
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 46182
  STACKTOP = sp; //@line 46184
  return;
 }
 $23 = $c + 164 | 0; //@line 46187
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 46190
 $26 = $18 & 16777215; //@line 46191
 $27 = $26 + 1 | 0; //@line 46192
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 46199
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 46209
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 46217
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 46220
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 46228
  $55 = $c + 152 | 0; //@line 46229
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 46232
  STACKTOP = sp; //@line 46234
  return;
 } else {
  _e68_exception_bus($c); //@line 46237
  STACKTOP = sp; //@line 46239
  return;
 }
}
function _op4a40($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0, sp = 0;
 sp = STACKTOP; //@line 46255
 STACKTOP = STACKTOP + 8 | 0; //@line 46255
 $s = sp | 0; //@line 46256
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 46260
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 46267
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 46274
  return;
 }
 $13 = $c + 372 | 0; //@line 46277
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 46280
 _e68_cc_set_nz_16($c, 15, HEAP16[$s >> 1] | 0); //@line 46282
 $17 = $c + 156 | 0; //@line 46283
 $18 = HEAP32[$17 >> 2] | 0; //@line 46284
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 46289
  STACKTOP = sp; //@line 46291
  return;
 }
 $23 = $c + 164 | 0; //@line 46294
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 46297
 $26 = $18 & 16777215; //@line 46298
 $27 = $26 + 1 | 0; //@line 46299
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 46306
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 46316
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 46324
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 46327
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 46335
  $55 = $c + 152 | 0; //@line 46336
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 46339
  STACKTOP = sp; //@line 46341
  return;
 } else {
  _e68_exception_bus($c); //@line 46344
  STACKTOP = sp; //@line 46346
  return;
 }
}
function _op4a80($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0, sp = 0;
 sp = STACKTOP; //@line 46362
 STACKTOP = STACKTOP + 8 | 0; //@line 46362
 $s = sp | 0; //@line 46363
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 46367
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 46374
  return;
 }
 if ((_e68_ea_get_val32($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 46381
  return;
 }
 $13 = $c + 372 | 0; //@line 46384
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 46387
 _e68_cc_set_nz_32($c, 15, HEAP32[$s >> 2] | 0); //@line 46389
 $17 = $c + 156 | 0; //@line 46390
 $18 = HEAP32[$17 >> 2] | 0; //@line 46391
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 46396
  STACKTOP = sp; //@line 46398
  return;
 }
 $23 = $c + 164 | 0; //@line 46401
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 46404
 $26 = $18 & 16777215; //@line 46405
 $27 = $26 + 1 | 0; //@line 46406
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 46413
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 46423
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 46431
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 46434
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 46442
  $55 = $c + 152 | 0; //@line 46443
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 46446
  STACKTOP = sp; //@line 46448
  return;
 } else {
  _e68_exception_bus($c); //@line 46451
  STACKTOP = sp; //@line 46453
  return;
 }
}
function _op4ac0($c) {
 $c = $c | 0;
 var $s = 0, $2 = 0, $6 = 0, $9 = 0, $10 = 0, $13 = 0, $22 = 0, $23 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $37 = 0, $52 = 0, $53 = 0, $59 = 0, $61 = 0, $66 = 0, $67 = 0, $71 = 0, $84 = 0, $phitmp_i = 0, $86 = 0, $87 = 0, $91 = 0, $97 = 0, $106 = 0, $107 = 0, $110 = 0, $111 = 0, $116 = 0, $119 = 0, $120 = 0, $126 = 0, $_0_i_i = 0, $148 = 0, $151 = 0, sp = 0;
 sp = STACKTOP; //@line 46479
 STACKTOP = STACKTOP + 8 | 0; //@line 46479
 $s = sp | 0; //@line 46480
 $2 = HEAP16[$c + 160 >> 1] | 0; //@line 46482
 if ($2 << 16 >> 16 != 19196) {
  $97 = $2 & 63; //@line 46487
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($97 << 2) >> 2] & 127]($c, $97, 509, 8) | 0) != 0) {
   STACKTOP = sp; //@line 46494
   return;
  }
  if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
   STACKTOP = sp; //@line 46501
   return;
  }
  $106 = HEAP8[$s] | 0; //@line 46504
  $107 = $c + 372 | 0; //@line 46505
  HEAP32[$107 >> 2] = (HEAP32[$107 >> 2] | 0) + 8; //@line 46508
  _e68_cc_set_nz_8($c, 15, $106); //@line 46509
  $110 = $c + 156 | 0; //@line 46510
  $111 = HEAP32[$110 >> 2] | 0; //@line 46511
  if (($111 & 1 | 0) != 0) {
   _e68_exception_address($c, $111, 0, 0); //@line 46516
   STACKTOP = sp; //@line 46518
   return;
  }
  $116 = $c + 164 | 0; //@line 46521
  HEAP16[$c + 162 >> 1] = HEAP16[$116 >> 1] | 0; //@line 46524
  $119 = $111 & 16777215; //@line 46525
  $120 = $119 + 1 | 0; //@line 46526
  if ($120 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $126 = HEAP32[$c + 32 >> 2] | 0; //@line 46533
   $_0_i_i = HEAPU8[$126 + $119 | 0] << 8 | HEAPU8[$126 + $120 | 0]; //@line 46543
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $119) | 0; //@line 46551
  }
  HEAP16[$116 >> 1] = $_0_i_i; //@line 46554
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$110 >> 2] = (HEAP32[$110 >> 2] | 0) + 2; //@line 46562
   $148 = $c + 152 | 0; //@line 46563
   HEAP32[$148 >> 2] = (HEAP32[$148 >> 2] | 0) + 2; //@line 46566
   $151 = $106 | -128; //@line 46567
   _e68_ea_set_val8($c, $151) | 0; //@line 46568
   STACKTOP = sp; //@line 46570
   return;
  } else {
   _e68_exception_bus($c); //@line 46573
   STACKTOP = sp; //@line 46575
   return;
  }
 }
 $6 = HEAP32[$c + 64 >> 2] | 0; //@line 46580
 do {
  if (($6 | 0) != 0) {
   $9 = $c + 152 | 0; //@line 46585
   $10 = HEAP32[$9 >> 2] | 0; //@line 46586
   $13 = $c + 164 | 0; //@line 46589
   if ((FUNCTION_TABLE_iii[$6 & 63](HEAP32[$c + 60 >> 2] | 0, HEAPU16[$13 >> 1] | 0) | 0) != 0) {
    break;
   }
   if ((HEAP32[$9 >> 2] | 0) == ($10 | 0)) {
    $22 = $c + 156 | 0; //@line 46602
    $23 = HEAP32[$22 >> 2] | 0; //@line 46603
    if (($23 & 1 | 0) != 0) {
     _e68_exception_address($c, $23, 0, 0); //@line 46608
     STACKTOP = sp; //@line 46610
     return;
    }
    $29 = $c + 162 | 0; //@line 46614
    HEAP16[$29 >> 1] = HEAP16[$13 >> 1] | 0; //@line 46615
    $30 = $23 & 16777215; //@line 46616
    $31 = $30 + 1 | 0; //@line 46617
    $32 = $c + 36 | 0; //@line 46618
    if ($31 >>> 0 < (HEAP32[$32 >> 2] | 0) >>> 0) {
     $37 = HEAP32[$c + 32 >> 2] | 0; //@line 46624
     $52 = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 46634
    } else {
     $52 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 46642
    }
    HEAP16[$13 >> 1] = $52; //@line 46645
    $53 = $c + 336 | 0; //@line 46646
    if ((HEAP8[$53] | 0) != 0) {
     _e68_exception_bus($c); //@line 46651
     STACKTOP = sp; //@line 46653
     return;
    }
    $59 = (HEAP32[$22 >> 2] | 0) + 2 | 0; //@line 46657
    HEAP32[$22 >> 2] = $59; //@line 46658
    $61 = (HEAP32[$9 >> 2] | 0) + 2 | 0; //@line 46660
    HEAP32[$9 >> 2] = $61; //@line 46661
    if (($59 & 1 | 0) != 0) {
     _e68_exception_address($c, $59, 0, 0); //@line 46666
     STACKTOP = sp; //@line 46668
     return;
    }
    HEAP16[$29 >> 1] = $52; //@line 46671
    $66 = $59 & 16777215; //@line 46672
    $67 = $66 + 1 | 0; //@line 46673
    do {
     if ($67 >>> 0 < (HEAP32[$32 >> 2] | 0) >>> 0) {
      $71 = HEAP32[$c + 32 >> 2] | 0; //@line 46680
      HEAP16[$13 >> 1] = HEAPU8[$71 + $66 | 0] << 8 | HEAPU8[$71 + $67 | 0]; //@line 46689
      $87 = $59;
      $86 = $61;
     } else {
      $84 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $66) | 0; //@line 46697
      $phitmp_i = (HEAP8[$53] | 0) == 0; //@line 46699
      HEAP16[$13 >> 1] = $84; //@line 46700
      if ($phitmp_i) {
       $87 = HEAP32[$22 >> 2] | 0;
       $86 = HEAP32[$9 >> 2] | 0;
       break;
      }
      _e68_exception_bus($c); //@line 46709
      STACKTOP = sp; //@line 46711
      return;
     }
    } while (0);
    HEAP32[$22 >> 2] = $87 + 2; //@line 46718
    HEAP32[$9 >> 2] = $86 + 2; //@line 46720
   }
   $91 = $c + 372 | 0; //@line 46723
   HEAP32[$91 >> 2] = (HEAP32[$91 >> 2] | 0) + 8; //@line 46726
   STACKTOP = sp; //@line 46728
   return;
  }
 } while (0);
 _e68_exception_illegal($c); //@line 46732
 STACKTOP = sp; //@line 46734
 return;
}
function _op4c80($c) {
 $c = $c | 0;
 var $1 = 0, $5 = 0, $7 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $27 = 0, $_0_i_i_i = 0, $42 = 0, $49 = 0, $52 = 0, $57 = 0, $r_0_ph_i = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $a_032_i = 0, $r_031_i = 0, $i_029_i = 0, $76 = 0, $77 = 0, $81 = 0, $_0_i24_i = 0, $94 = 0, $98 = 0, $100 = 0, $a_1_i = 0, $111 = 0, $120 = 0, $126 = 0, $127 = 0, $131 = 0, $_0_i_i25_i = 0, $153 = 0, $154 = 0, $159 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $169 = 0, $_0_i_i_i4 = 0, $184 = 0, $191 = 0, $194 = 0, $197 = 0, $209 = 0, $r_0_ph_i6 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $a_031_i = 0, $r_030_i = 0, $i_028_i = 0, $228 = 0, $229 = 0, $233 = 0, $_0_i23_i = 0, $246 = 0, $250 = 0, $252 = 0, $a_1_i9 = 0, $263 = 0, $268 = 0, $274 = 0, $275 = 0, $279 = 0, $_0_i_i24_i = 0;
 $1 = $c + 160 | 0; //@line 46776
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 46780
 if (($5 | 0) == 0) {
  _e68_exception_illegal($c); //@line 46782
  $7 = $c + 372 | 0; //@line 46783
  HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + 2; //@line 46786
  return;
 } else if (($5 | 0) == 3) {
  $11 = $c + 156 | 0; //@line 46791
  $12 = HEAP32[$11 >> 2] | 0; //@line 46792
  if (($12 & 1 | 0) != 0) {
   _e68_exception_address($c, $12, 0, 0); //@line 46797
   return;
  }
  $17 = $c + 164 | 0; //@line 46802
  $19 = $c + 162 | 0; //@line 46804
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 46805
  $20 = $12 & 16777215; //@line 46806
  $21 = $20 + 1 | 0; //@line 46807
  $22 = $c + 36 | 0; //@line 46808
  if ($21 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $27 = HEAP32[$c + 32 >> 2] | 0; //@line 46814
   $_0_i_i_i = HEAPU8[$27 + $20 | 0] << 8 | HEAPU8[$27 + $21 | 0]; //@line 46824
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $20) | 0; //@line 46832
  }
  HEAP16[$17 >> 1] = $_0_i_i_i; //@line 46835
  $42 = $c + 336 | 0; //@line 46836
  if ((HEAP8[$42] | 0) != 0) {
   _e68_exception_bus($c); //@line 46841
   return;
  }
  HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 46848
  $49 = $c + 152 | 0; //@line 46849
  HEAP32[$49 >> 2] = (HEAP32[$49 >> 2] | 0) + 2; //@line 46852
  $52 = HEAP16[$19 >> 1] | 0; //@line 46853
  $57 = HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] | 0; //@line 46858
  do {
   if ($52 << 16 >> 16 == 0) {
    $r_0_ph_i = 0; //@line 46863
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i = $52; //@line 46871
     break;
    }
    if (($57 & 1 | 0) == 0) {
     $r_0_ph_i = $52; //@line 46878
     break;
    }
    _e68_exception_address($c, $57, 1, 0); //@line 46881
    return;
   }
  } while (0);
  $64 = $c + 32 | 0; //@line 46888
  $65 = $c + 372 | 0; //@line 46889
  $66 = $c + 12 | 0; //@line 46890
  $67 = $c + 4 | 0; //@line 46891
  $i_029_i = 0;
  $r_031_i = $r_0_ph_i;
  $a_032_i = $57;
  while (1) {
   if (($r_031_i & 1) == 0) {
    $a_1_i = $a_032_i; //@line 46902
   } else {
    $76 = $a_032_i & 16777215; //@line 46904
    $77 = $76 + 1 | 0; //@line 46905
    if ($77 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
     $81 = HEAP32[$64 >> 2] | 0; //@line 46910
     $_0_i24_i = HEAPU8[$81 + $76 | 0] << 8 | HEAPU8[$81 + $77 | 0]; //@line 46920
    } else {
     $_0_i24_i = FUNCTION_TABLE_iii[HEAP32[$66 >> 2] & 63](HEAP32[$67 >> 2] | 0, $76) | 0; //@line 46926
    }
    $94 = $_0_i24_i & 65535; //@line 46929
    $98 = ($94 & 32768 | 0) != 0 ? $94 | -65536 : $94; //@line 46933
    $100 = $i_029_i & 7; //@line 46935
    if ($i_029_i >>> 0 < 8) {
     HEAP32[$c + 88 + ($100 << 2) >> 2] = $98; //@line 46939
    } else {
     HEAP32[$c + 120 + ($100 << 2) >> 2] = $98; //@line 46943
    }
    HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 4; //@line 46948
    $a_1_i = $a_032_i + 2 | 0; //@line 46950
   }
   $111 = $i_029_i + 1 | 0; //@line 46954
   if ($111 >>> 0 < 16) {
    $i_029_i = $111;
    $r_031_i = ($r_031_i & 65535) >>> 1;
    $a_032_i = $a_1_i;
   } else {
    break;
   }
  }
  HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] = $a_1_i; //@line 46967
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 12; //@line 46970
  $120 = HEAP32[$11 >> 2] | 0; //@line 46971
  if (($120 & 1 | 0) != 0) {
   _e68_exception_address($c, $120, 0, 0); //@line 46976
   return;
  }
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 46982
  $126 = $120 & 16777215; //@line 46983
  $127 = $126 + 1 | 0; //@line 46984
  if ($127 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $131 = HEAP32[$64 >> 2] | 0; //@line 46989
   $_0_i_i25_i = HEAPU8[$131 + $126 | 0] << 8 | HEAPU8[$131 + $127 | 0]; //@line 46999
  } else {
   $_0_i_i25_i = FUNCTION_TABLE_iii[HEAP32[$66 >> 2] & 63](HEAP32[$67 >> 2] | 0, $126) | 0; //@line 47005
  }
  HEAP16[$17 >> 1] = $_0_i_i25_i; //@line 47008
  if ((HEAP8[$42] | 0) == 0) {
   HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 47015
   HEAP32[$49 >> 2] = (HEAP32[$49 >> 2] | 0) + 2; //@line 47018
   return;
  } else {
   _e68_exception_bus($c); //@line 47023
   return;
  }
 } else {
  $153 = $c + 156 | 0; //@line 47029
  $154 = HEAP32[$153 >> 2] | 0; //@line 47030
  if (($154 & 1 | 0) != 0) {
   _e68_exception_address($c, $154, 0, 0); //@line 47035
   return;
  }
  $159 = $c + 164 | 0; //@line 47040
  $161 = $c + 162 | 0; //@line 47042
  HEAP16[$161 >> 1] = HEAP16[$159 >> 1] | 0; //@line 47043
  $162 = $154 & 16777215; //@line 47044
  $163 = $162 + 1 | 0; //@line 47045
  $164 = $c + 36 | 0; //@line 47046
  if ($163 >>> 0 < (HEAP32[$164 >> 2] | 0) >>> 0) {
   $169 = HEAP32[$c + 32 >> 2] | 0; //@line 47052
   $_0_i_i_i4 = HEAPU8[$169 + $162 | 0] << 8 | HEAPU8[$169 + $163 | 0]; //@line 47062
  } else {
   $_0_i_i_i4 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $162) | 0; //@line 47070
  }
  HEAP16[$159 >> 1] = $_0_i_i_i4; //@line 47073
  $184 = $c + 336 | 0; //@line 47074
  if ((HEAP8[$184] | 0) != 0) {
   _e68_exception_bus($c); //@line 47079
   return;
  }
  HEAP32[$153 >> 2] = (HEAP32[$153 >> 2] | 0) + 2; //@line 47086
  $191 = $c + 152 | 0; //@line 47087
  HEAP32[$191 >> 2] = (HEAP32[$191 >> 2] | 0) + 2; //@line 47090
  $194 = HEAP16[$161 >> 1] | 0; //@line 47091
  $197 = HEAP16[$1 >> 1] & 63; //@line 47094
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($197 << 2) >> 2] & 127]($c, $197, 2028, 16) | 0) != 0) {
   return;
  }
  if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
   _e68_exception_illegal($c); //@line 47109
   return;
  }
  $209 = HEAP32[$c + 344 >> 2] | 0; //@line 47115
  do {
   if ($194 << 16 >> 16 == 0) {
    $r_0_ph_i6 = 0; //@line 47120
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i6 = $194; //@line 47128
     break;
    }
    if (($209 & 1 | 0) == 0) {
     $r_0_ph_i6 = $194; //@line 47135
     break;
    }
    _e68_exception_address($c, $209, 1, 0); //@line 47138
    return;
   }
  } while (0);
  $216 = $c + 32 | 0; //@line 47145
  $217 = $c + 372 | 0; //@line 47146
  $218 = $c + 12 | 0; //@line 47147
  $219 = $c + 4 | 0; //@line 47148
  $i_028_i = 0;
  $r_030_i = $r_0_ph_i6;
  $a_031_i = $209;
  while (1) {
   if (($r_030_i & 1) == 0) {
    $a_1_i9 = $a_031_i; //@line 47159
   } else {
    $228 = $a_031_i & 16777215; //@line 47161
    $229 = $228 + 1 | 0; //@line 47162
    if ($229 >>> 0 < (HEAP32[$164 >> 2] | 0) >>> 0) {
     $233 = HEAP32[$216 >> 2] | 0; //@line 47167
     $_0_i23_i = HEAPU8[$233 + $228 | 0] << 8 | HEAPU8[$233 + $229 | 0]; //@line 47177
    } else {
     $_0_i23_i = FUNCTION_TABLE_iii[HEAP32[$218 >> 2] & 63](HEAP32[$219 >> 2] | 0, $228) | 0; //@line 47183
    }
    $246 = $_0_i23_i & 65535; //@line 47186
    $250 = ($246 & 32768 | 0) != 0 ? $246 | -65536 : $246; //@line 47190
    $252 = $i_028_i & 7; //@line 47192
    if ($i_028_i >>> 0 < 8) {
     HEAP32[$c + 88 + ($252 << 2) >> 2] = $250; //@line 47196
    } else {
     HEAP32[$c + 120 + ($252 << 2) >> 2] = $250; //@line 47200
    }
    HEAP32[$217 >> 2] = (HEAP32[$217 >> 2] | 0) + 4; //@line 47205
    $a_1_i9 = $a_031_i + 2 | 0; //@line 47207
   }
   $263 = $i_028_i + 1 | 0; //@line 47211
   if ($263 >>> 0 < 16) {
    $i_028_i = $263;
    $r_030_i = ($r_030_i & 65535) >>> 1;
    $a_031_i = $a_1_i9;
   } else {
    break;
   }
  }
  HEAP32[$217 >> 2] = (HEAP32[$217 >> 2] | 0) + 12; //@line 47222
  $268 = HEAP32[$153 >> 2] | 0; //@line 47223
  if (($268 & 1 | 0) != 0) {
   _e68_exception_address($c, $268, 0, 0); //@line 47228
   return;
  }
  HEAP16[$161 >> 1] = HEAP16[$159 >> 1] | 0; //@line 47234
  $274 = $268 & 16777215; //@line 47235
  $275 = $274 + 1 | 0; //@line 47236
  if ($275 >>> 0 < (HEAP32[$164 >> 2] | 0) >>> 0) {
   $279 = HEAP32[$216 >> 2] | 0; //@line 47241
   $_0_i_i24_i = HEAPU8[$279 + $274 | 0] << 8 | HEAPU8[$279 + $275 | 0]; //@line 47251
  } else {
   $_0_i_i24_i = FUNCTION_TABLE_iii[HEAP32[$218 >> 2] & 63](HEAP32[$219 >> 2] | 0, $274) | 0; //@line 47257
  }
  HEAP16[$159 >> 1] = $_0_i_i24_i; //@line 47260
  if ((HEAP8[$184] | 0) == 0) {
   HEAP32[$153 >> 2] = (HEAP32[$153 >> 2] | 0) + 2; //@line 47267
   HEAP32[$191 >> 2] = (HEAP32[$191 >> 2] | 0) + 2; //@line 47270
   return;
  } else {
   _e68_exception_bus($c); //@line 47275
   return;
  }
 }
}
function _op4cc0($c) {
 $c = $c | 0;
 var $1 = 0, $5 = 0, $7 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $27 = 0, $_0_i_i_i = 0, $42 = 0, $49 = 0, $52 = 0, $57 = 0, $r_0_ph_i = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $i_030_i = 0, $a_029_i = 0, $r_028_i = 0, $76 = 0, $77 = 0, $81 = 0, $_0_i23_i = 0, $107 = 0, $a_1_i = 0, $118 = 0, $127 = 0, $133 = 0, $134 = 0, $138 = 0, $_0_i_i24_i = 0, $161 = 0, $162 = 0, $167 = 0, $169 = 0, $170 = 0, $171 = 0, $172 = 0, $177 = 0, $_0_i_i_i4 = 0, $192 = 0, $199 = 0, $202 = 0, $205 = 0, $217 = 0, $r_0_ph_i6 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $i_029_i = 0, $a_028_i = 0, $r_027_i = 0, $236 = 0, $237 = 0, $241 = 0, $_0_i22_i = 0, $267 = 0, $a_1_i9 = 0, $278 = 0, $283 = 0, $289 = 0, $290 = 0, $294 = 0, $_0_i_i23_i = 0;
 $1 = $c + 160 | 0; //@line 47323
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 3 & 7; //@line 47327
 if (($5 | 0) == 3) {
  $11 = $c + 156 | 0; //@line 47329
  $12 = HEAP32[$11 >> 2] | 0; //@line 47330
  if (($12 & 1 | 0) != 0) {
   _e68_exception_address($c, $12, 0, 0); //@line 47335
   return;
  }
  $17 = $c + 164 | 0; //@line 47340
  $19 = $c + 162 | 0; //@line 47342
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 47343
  $20 = $12 & 16777215; //@line 47344
  $21 = $20 + 1 | 0; //@line 47345
  $22 = $c + 36 | 0; //@line 47346
  if ($21 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $27 = HEAP32[$c + 32 >> 2] | 0; //@line 47352
   $_0_i_i_i = HEAPU8[$27 + $20 | 0] << 8 | HEAPU8[$27 + $21 | 0]; //@line 47362
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $20) | 0; //@line 47370
  }
  HEAP16[$17 >> 1] = $_0_i_i_i; //@line 47373
  $42 = $c + 336 | 0; //@line 47374
  if ((HEAP8[$42] | 0) != 0) {
   _e68_exception_bus($c); //@line 47379
   return;
  }
  HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 47386
  $49 = $c + 152 | 0; //@line 47387
  HEAP32[$49 >> 2] = (HEAP32[$49 >> 2] | 0) + 2; //@line 47390
  $52 = HEAP16[$19 >> 1] | 0; //@line 47391
  $57 = HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] | 0; //@line 47396
  do {
   if ($52 << 16 >> 16 == 0) {
    $r_0_ph_i = 0; //@line 47401
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i = $52; //@line 47409
     break;
    }
    if (($57 & 1 | 0) == 0) {
     $r_0_ph_i = $52; //@line 47416
     break;
    }
    _e68_exception_address($c, $57, 1, 0); //@line 47419
    return;
   }
  } while (0);
  $64 = $c + 32 | 0; //@line 47426
  $65 = $c + 372 | 0; //@line 47427
  $66 = $c + 16 | 0; //@line 47428
  $67 = $c + 4 | 0; //@line 47429
  $r_028_i = $r_0_ph_i;
  $a_029_i = $57;
  $i_030_i = 0;
  while (1) {
   if (($r_028_i & 1) == 0) {
    $a_1_i = $a_029_i; //@line 47440
   } else {
    $76 = $a_029_i & 16777215; //@line 47442
    $77 = $76 + 3 | 0; //@line 47443
    if ($77 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
     $81 = HEAP32[$64 >> 2] | 0; //@line 47448
     $_0_i23_i = ((HEAPU8[$81 + $76 | 0] << 8 | HEAPU8[$81 + ($76 + 1) | 0]) << 8 | HEAPU8[$81 + ($76 + 2) | 0]) << 8 | HEAPU8[$81 + $77 | 0]; //@line 47470
    } else {
     $_0_i23_i = FUNCTION_TABLE_iii[HEAP32[$66 >> 2] & 63](HEAP32[$67 >> 2] | 0, $76) | 0; //@line 47476
    }
    $107 = $i_030_i & 7; //@line 47480
    if ($i_030_i >>> 0 < 8) {
     HEAP32[$c + 88 + ($107 << 2) >> 2] = $_0_i23_i; //@line 47484
    } else {
     HEAP32[$c + 120 + ($107 << 2) >> 2] = $_0_i23_i; //@line 47488
    }
    HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 8; //@line 47493
    $a_1_i = $a_029_i + 4 | 0; //@line 47495
   }
   $118 = $i_030_i + 1 | 0; //@line 47499
   if ($118 >>> 0 < 16) {
    $r_028_i = ($r_028_i & 65535) >>> 1;
    $a_029_i = $a_1_i;
    $i_030_i = $118;
   } else {
    break;
   }
  }
  HEAP32[$c + 120 + ((HEAP16[$1 >> 1] & 7) << 2) >> 2] = $a_1_i; //@line 47512
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 12; //@line 47515
  $127 = HEAP32[$11 >> 2] | 0; //@line 47516
  if (($127 & 1 | 0) != 0) {
   _e68_exception_address($c, $127, 0, 0); //@line 47521
   return;
  }
  HEAP16[$19 >> 1] = HEAP16[$17 >> 1] | 0; //@line 47527
  $133 = $127 & 16777215; //@line 47528
  $134 = $133 + 1 | 0; //@line 47529
  if ($134 >>> 0 < (HEAP32[$22 >> 2] | 0) >>> 0) {
   $138 = HEAP32[$64 >> 2] | 0; //@line 47534
   $_0_i_i24_i = HEAPU8[$138 + $133 | 0] << 8 | HEAPU8[$138 + $134 | 0]; //@line 47544
  } else {
   $_0_i_i24_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$67 >> 2] | 0, $133) | 0; //@line 47551
  }
  HEAP16[$17 >> 1] = $_0_i_i24_i; //@line 47554
  if ((HEAP8[$42] | 0) == 0) {
   HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 47561
   HEAP32[$49 >> 2] = (HEAP32[$49 >> 2] | 0) + 2; //@line 47564
   return;
  } else {
   _e68_exception_bus($c); //@line 47569
   return;
  }
 } else if (($5 | 0) == 0) {
  _e68_exception_illegal($c); //@line 47575
  $7 = $c + 372 | 0; //@line 47576
  HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + 2; //@line 47579
  return;
 } else {
  $161 = $c + 156 | 0; //@line 47584
  $162 = HEAP32[$161 >> 2] | 0; //@line 47585
  if (($162 & 1 | 0) != 0) {
   _e68_exception_address($c, $162, 0, 0); //@line 47590
   return;
  }
  $167 = $c + 164 | 0; //@line 47595
  $169 = $c + 162 | 0; //@line 47597
  HEAP16[$169 >> 1] = HEAP16[$167 >> 1] | 0; //@line 47598
  $170 = $162 & 16777215; //@line 47599
  $171 = $170 + 1 | 0; //@line 47600
  $172 = $c + 36 | 0; //@line 47601
  if ($171 >>> 0 < (HEAP32[$172 >> 2] | 0) >>> 0) {
   $177 = HEAP32[$c + 32 >> 2] | 0; //@line 47607
   $_0_i_i_i4 = HEAPU8[$177 + $170 | 0] << 8 | HEAPU8[$177 + $171 | 0]; //@line 47617
  } else {
   $_0_i_i_i4 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $170) | 0; //@line 47625
  }
  HEAP16[$167 >> 1] = $_0_i_i_i4; //@line 47628
  $192 = $c + 336 | 0; //@line 47629
  if ((HEAP8[$192] | 0) != 0) {
   _e68_exception_bus($c); //@line 47634
   return;
  }
  HEAP32[$161 >> 2] = (HEAP32[$161 >> 2] | 0) + 2; //@line 47641
  $199 = $c + 152 | 0; //@line 47642
  HEAP32[$199 >> 2] = (HEAP32[$199 >> 2] | 0) + 2; //@line 47645
  $202 = HEAP16[$169 >> 1] | 0; //@line 47646
  $205 = HEAP16[$1 >> 1] & 63; //@line 47649
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($205 << 2) >> 2] & 127]($c, $205, 2028, 32) | 0) != 0) {
   return;
  }
  if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
   _e68_exception_illegal($c); //@line 47664
   return;
  }
  $217 = HEAP32[$c + 344 >> 2] | 0; //@line 47670
  do {
   if ($202 << 16 >> 16 == 0) {
    $r_0_ph_i6 = 0; //@line 47675
   } else {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     $r_0_ph_i6 = $202; //@line 47683
     break;
    }
    if (($217 & 1 | 0) == 0) {
     $r_0_ph_i6 = $202; //@line 47690
     break;
    }
    _e68_exception_address($c, $217, 1, 0); //@line 47693
    return;
   }
  } while (0);
  $224 = $c + 32 | 0; //@line 47700
  $225 = $c + 372 | 0; //@line 47701
  $226 = $c + 16 | 0; //@line 47702
  $227 = $c + 4 | 0; //@line 47703
  $r_027_i = $r_0_ph_i6;
  $a_028_i = $217;
  $i_029_i = 0;
  while (1) {
   if (($r_027_i & 1) == 0) {
    $a_1_i9 = $a_028_i; //@line 47714
   } else {
    $236 = $a_028_i & 16777215; //@line 47716
    $237 = $236 + 3 | 0; //@line 47717
    if ($237 >>> 0 < (HEAP32[$172 >> 2] | 0) >>> 0) {
     $241 = HEAP32[$224 >> 2] | 0; //@line 47722
     $_0_i22_i = ((HEAPU8[$241 + $236 | 0] << 8 | HEAPU8[$241 + ($236 + 1) | 0]) << 8 | HEAPU8[$241 + ($236 + 2) | 0]) << 8 | HEAPU8[$241 + $237 | 0]; //@line 47744
    } else {
     $_0_i22_i = FUNCTION_TABLE_iii[HEAP32[$226 >> 2] & 63](HEAP32[$227 >> 2] | 0, $236) | 0; //@line 47750
    }
    $267 = $i_029_i & 7; //@line 47754
    if ($i_029_i >>> 0 < 8) {
     HEAP32[$c + 88 + ($267 << 2) >> 2] = $_0_i22_i; //@line 47758
    } else {
     HEAP32[$c + 120 + ($267 << 2) >> 2] = $_0_i22_i; //@line 47762
    }
    HEAP32[$225 >> 2] = (HEAP32[$225 >> 2] | 0) + 8; //@line 47767
    $a_1_i9 = $a_028_i + 4 | 0; //@line 47769
   }
   $278 = $i_029_i + 1 | 0; //@line 47773
   if ($278 >>> 0 < 16) {
    $r_027_i = ($r_027_i & 65535) >>> 1;
    $a_028_i = $a_1_i9;
    $i_029_i = $278;
   } else {
    break;
   }
  }
  HEAP32[$225 >> 2] = (HEAP32[$225 >> 2] | 0) + 12; //@line 47784
  $283 = HEAP32[$161 >> 2] | 0; //@line 47785
  if (($283 & 1 | 0) != 0) {
   _e68_exception_address($c, $283, 0, 0); //@line 47790
   return;
  }
  HEAP16[$169 >> 1] = HEAP16[$167 >> 1] | 0; //@line 47796
  $289 = $283 & 16777215; //@line 47797
  $290 = $289 + 1 | 0; //@line 47798
  if ($290 >>> 0 < (HEAP32[$172 >> 2] | 0) >>> 0) {
   $294 = HEAP32[$224 >> 2] | 0; //@line 47803
   $_0_i_i23_i = HEAPU8[$294 + $289 | 0] << 8 | HEAPU8[$294 + $290 | 0]; //@line 47813
  } else {
   $_0_i_i23_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$227 >> 2] | 0, $289) | 0; //@line 47820
  }
  HEAP16[$167 >> 1] = $_0_i_i23_i; //@line 47823
  if ((HEAP8[$192] | 0) == 0) {
   HEAP32[$161 >> 2] = (HEAP32[$161 >> 2] | 0) + 2; //@line 47830
   HEAP32[$199 >> 2] = (HEAP32[$199 >> 2] | 0) + 2; //@line 47833
   return;
  } else {
   _e68_exception_bus($c); //@line 47838
   return;
  }
 }
}
function _op4e40($c) {
 $c = $c | 0;
 var $1 = 0, $3 = 0, $14 = 0, $15 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $34 = 0, $_0_i_i_i = 0, $56 = 0, $62 = 0, $65 = 0, $66 = 0, $71 = 0, $74 = 0, $75 = 0, $81 = 0, $_0_i_i_i18 = 0, $103 = 0, $112 = 0, $113 = 0, $118 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $128 = 0, $_0_i_i_i20 = 0, $143 = 0, $150 = 0, $154 = 0, $157 = 0, $160 = 0, $166 = 0, $167 = 0, $172 = 0, $_0_i_i7_i = 0, $196 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $210 = 0, $224 = 0, $225 = 0, $_0_i_i = 0, $227 = 0, $228 = 0, $232 = 0, $259 = 0, $260 = 0, $266 = 0, $267 = 0, $272 = 0, $_0_i23_i = 0, $288 = 0, $291 = 0, $292 = 0, $297 = 0, $304 = 0, $310 = 0, $317 = 0, $319 = 0, $320 = 0, $321 = 0, $326 = 0, $341 = 0, $342 = 0, $348 = 0, $355 = 0, $356 = 0, $360 = 0, $373 = 0, $phitmp_i = 0, $376 = 0, $384 = 0, $388 = 0, $389 = 0, $394 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $404 = 0, $_0_i_i_i23 = 0, $419 = 0, $426 = 0, $430 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $443 = 0, $_0_i13_i = 0, $472 = 0, $480 = 0, $481 = 0, $486 = 0, $501 = 0, $507 = 0, $514 = 0, $515 = 0, $519 = 0, $532 = 0, $phitmp_i27 = 0, $535 = 0, $539 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $548 = 0, $_0_i_i28 = 0, $575 = 0, $577 = 0, $584 = 0, $586 = 0, $587 = 0, $588 = 0, $593 = 0, $608 = 0, $609 = 0, $615 = 0, $616 = 0, $623 = 0, $624 = 0, $628 = 0, $641 = 0, $phitmp_i32 = 0, $644 = 0, $648 = 0, $649 = 0, $654 = 0, $657 = 0, $658 = 0, $664 = 0, $_0_i_i_i34 = 0, $686 = 0, $695 = 0, $699 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $extract_t19_i = 0, $717 = 0, $_0_i_off0_i = 0, $719 = 0, $725 = 0, $726 = 0, $730 = 0, $_0_i14_i = 0, $757 = 0, $759 = 0, $766 = 0, $768 = 0, $769 = 0, $770 = 0, $775 = 0, $790 = 0, $791 = 0, $797 = 0, $798 = 0, $805 = 0, $806 = 0, $810 = 0, $823 = 0, $phitmp_i40 = 0, $826 = 0, $830 = 0, $835 = 0, $839 = 0, $844 = 0, $845 = 0, $850 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $860 = 0, $_0_i_i_i42 = 0, $875 = 0, $882 = 0, $886 = 0, $887 = 0, $888 = 0, $902 = 0, $922 = 0, $val_0_i = 0, $932 = 0, $938 = 0, $941 = 0, $947 = 0, $948 = 0, $953 = 0, $_0_i_i19_i = 0, $977 = 0, $982 = 0, $986 = 0, $991 = 0, $992 = 0, $997 = 0, $999 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1007 = 0, $1022 = 0, $1023 = 0, $1029 = 0, $1030 = 0, $1032 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1039 = 0, $val_0_in_i = 0, $val_0_i45 = 0, $1056 = 0, $1075 = 0, $1081 = 0, $1088 = 0, $1089 = 0, $1093 = 0, $1106 = 0, $phitmp_i47 = 0, $1109 = 0, $1110 = 0, $1115 = 0, $1117 = 0, $1118 = 0, $1123 = 0, $1126 = 0, $1127 = 0, $1133 = 0, $_0_i_i_i48 = 0, $1155 = 0, $1162 = 0, $1163 = 0, $1168 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1178 = 0, $_0_i_i_i50 = 0, $1193 = 0, $1200 = 0, $1205 = 0, $1207 = 0, $1212 = 0, $1215 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $1220 = 0, $1221 = 0, $1227 = 0, $1251 = 0, $1257 = 0, $1258 = 0, $1263 = 0, $_0_i_i15_i = 0, $1288 = 0, $1289 = 0, $1299 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1310 = 0, $_0_i15_i = 0, $1339 = 0, $1340 = 0, $1345 = 0, $1348 = 0, $1349 = 0, $1354 = 0, $_0_i_i_i54 = 0, $1376 = 0, $1388 = 0, $1391 = 0, $1392 = 0, $1397 = 0, $1400 = 0, $1401 = 0, $1407 = 0, $_0_i_i_i57 = 0, $1429 = 0, $1442 = 0, $1445 = 0, $1446 = 0, $1451 = 0, $1454 = 0, $1455 = 0, $1461 = 0, $_0_i_i_i60 = 0, $1483 = 0, $1487 = 0;
 $1 = $c + 160 | 0; //@line 48014
 $3 = HEAPU16[$1 >> 1] | 0; //@line 48016
 if (($3 | 0) == 20081) {
  $62 = $c + 372 | 0; //@line 48018
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 4; //@line 48021
  $65 = $c + 156 | 0; //@line 48022
  $66 = HEAP32[$65 >> 2] | 0; //@line 48023
  if (($66 & 1 | 0) != 0) {
   _e68_exception_address($c, $66, 0, 0); //@line 48028
   return;
  }
  $71 = $c + 164 | 0; //@line 48033
  HEAP16[$c + 162 >> 1] = HEAP16[$71 >> 1] | 0; //@line 48036
  $74 = $66 & 16777215; //@line 48037
  $75 = $74 + 1 | 0; //@line 48038
  if ($75 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $81 = HEAP32[$c + 32 >> 2] | 0; //@line 48045
   $_0_i_i_i18 = HEAPU8[$81 + $74 | 0] << 8 | HEAPU8[$81 + $75 | 0]; //@line 48055
  } else {
   $_0_i_i_i18 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $74) | 0; //@line 48063
  }
  HEAP16[$71 >> 1] = $_0_i_i_i18; //@line 48066
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 48074
   $103 = $c + 152 | 0; //@line 48075
   HEAP32[$103 >> 2] = (HEAP32[$103 >> 2] | 0) + 2; //@line 48078
   return;
  } else {
   _e68_exception_bus($c); //@line 48083
   return;
  }
 } else if (($3 | 0) == 20086) {
  $648 = $c + 156 | 0; //@line 48089
  $649 = HEAP32[$648 >> 2] | 0; //@line 48090
  if (($649 & 1 | 0) != 0) {
   _e68_exception_address($c, $649, 0, 0); //@line 48095
   return;
  }
  $654 = $c + 164 | 0; //@line 48100
  HEAP16[$c + 162 >> 1] = HEAP16[$654 >> 1] | 0; //@line 48103
  $657 = $649 & 16777215; //@line 48104
  $658 = $657 + 1 | 0; //@line 48105
  if ($658 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $664 = HEAP32[$c + 32 >> 2] | 0; //@line 48112
   $_0_i_i_i34 = HEAPU8[$664 + $657 | 0] << 8 | HEAPU8[$664 + $658 | 0]; //@line 48122
  } else {
   $_0_i_i_i34 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $657) | 0; //@line 48130
  }
  HEAP16[$654 >> 1] = $_0_i_i_i34; //@line 48133
  if ((HEAP8[$c + 336 | 0] | 0) != 0) {
   _e68_exception_bus($c); //@line 48139
   return;
  }
  HEAP32[$648 >> 2] = (HEAP32[$648 >> 2] | 0) + 2; //@line 48146
  $686 = $c + 152 | 0; //@line 48147
  HEAP32[$686 >> 2] = (HEAP32[$686 >> 2] | 0) + 2; //@line 48150
  if ((HEAP16[$c + 166 >> 1] & 2) == 0) {
   $695 = $c + 372 | 0; //@line 48157
   HEAP32[$695 >> 2] = (HEAP32[$695 >> 2] | 0) + 4; //@line 48160
   return;
  } else {
   _e68_exception_overflow($c); //@line 48164
   return;
  }
 } else if (($3 | 0) == 20080) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   _e68_exception_privilege($c); //@line 48175
   return;
  }
  $14 = $c + 372 | 0; //@line 48184
  $15 = HEAP32[$14 >> 2] | 0; //@line 48185
  if ((HEAP32[$c >> 2] & 8 | 0) == 0) {
   HEAP32[$14 >> 2] = $15 + 132; //@line 48189
   _e68_reset($c); //@line 48190
   return;
  }
  HEAP32[$14 >> 2] = $15 + 4; //@line 48196
  $18 = $c + 156 | 0; //@line 48197
  $19 = HEAP32[$18 >> 2] | 0; //@line 48198
  if (($19 & 1 | 0) != 0) {
   _e68_exception_address($c, $19, 0, 0); //@line 48203
   return;
  }
  $24 = $c + 164 | 0; //@line 48208
  HEAP16[$c + 162 >> 1] = HEAP16[$24 >> 1] | 0; //@line 48211
  $27 = $19 & 16777215; //@line 48212
  $28 = $27 + 1 | 0; //@line 48213
  if ($28 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $34 = HEAP32[$c + 32 >> 2] | 0; //@line 48220
   $_0_i_i_i = HEAPU8[$34 + $27 | 0] << 8 | HEAPU8[$34 + $28 | 0]; //@line 48230
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $27) | 0; //@line 48238
  }
  HEAP16[$24 >> 1] = $_0_i_i_i; //@line 48241
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 48249
   $56 = $c + 152 | 0; //@line 48250
   HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 2; //@line 48253
   return;
  } else {
   _e68_exception_bus($c); //@line 48258
   return;
  }
 } else if (($3 | 0) == 20083) {
  $196 = $c + 334 | 0; //@line 48264
  if ((HEAP8[$196] | 0) == 0) {
   _e68_exception_privilege($c); //@line 48269
   return;
  }
  $201 = $c + 148 | 0; //@line 48274
  $202 = HEAP32[$201 >> 2] | 0; //@line 48275
  $203 = $202 & 16777215; //@line 48276
  $204 = $203 + 1 | 0; //@line 48277
  $205 = $c + 36 | 0; //@line 48278
  $206 = HEAP32[$205 >> 2] | 0; //@line 48279
  if ($204 >>> 0 < $206 >>> 0) {
   $210 = HEAP32[$c + 32 >> 2] | 0; //@line 48284
   $_0_i_i = HEAPU8[$210 + $203 | 0] << 8 | HEAPU8[$210 + $204 | 0];
   $225 = $206;
  } else {
   $224 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $203) | 0; //@line 48300
   $_0_i_i = $224;
   $225 = HEAP32[$205 >> 2] | 0;
  }
  $227 = $202 + 2 & 16777215; //@line 48308
  $228 = $227 + 3 | 0; //@line 48309
  if ($228 >>> 0 < $225 >>> 0) {
   $232 = HEAP32[$c + 32 >> 2] | 0; //@line 48314
   $259 = ((HEAPU8[$232 + $227 | 0] << 8 | HEAPU8[$232 + ($227 + 1) | 0]) << 8 | HEAPU8[$232 + ($227 + 2) | 0]) << 8 | HEAPU8[$232 + $228 | 0]; //@line 48336
  } else {
   $259 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $227) | 0; //@line 48344
  }
  $260 = $c | 0; //@line 48347
  do {
   if ((HEAP32[$260 >> 2] & 2 | 0) != 0) {
    $266 = $202 + 6 & 16777215; //@line 48355
    $267 = $266 + 1 | 0; //@line 48356
    if ($267 >>> 0 < (HEAP32[$205 >> 2] | 0) >>> 0) {
     $272 = HEAP32[$c + 32 >> 2] | 0; //@line 48362
     $_0_i23_i = HEAPU8[$272 + $266 | 0] << 8 | HEAPU8[$272 + $267 | 0]; //@line 48372
    } else {
     $_0_i23_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $266) | 0; //@line 48380
    }
    $288 = ($_0_i23_i & 65535) >>> 12; //@line 48384
    if (($288 | 0) == 0 | ($288 | 0) == 8) {
     break;
    }
    _e68_exception_format($c); //@line 48388
    return;
   }
  } while (0);
  _e68_set_sr($c, $_0_i_i); //@line 48394
  $291 = $c + 152 | 0; //@line 48395
  HEAP32[$291 >> 2] = $259; //@line 48396
  $292 = $c + 156 | 0; //@line 48397
  HEAP32[$292 >> 2] = $259; //@line 48398
  do {
   if ((HEAP32[$260 >> 2] & 2 | 0) == 0) {
    $304 = $202 + 6 | 0; //@line 48405
    if ((HEAP8[$196] | 0) == 0) {
     HEAP32[$c + 172 >> 2] = $304; //@line 48411
     break;
    } else {
     HEAP32[$201 >> 2] = $304; //@line 48414
     break;
    }
   } else {
    $297 = $202 + 8 | 0; //@line 48419
    if ((HEAP8[$196] | 0) == 0) {
     HEAP32[$c + 172 >> 2] = $297; //@line 48425
     break;
    } else {
     HEAP32[$201 >> 2] = $297; //@line 48428
     break;
    }
   }
  } while (0);
  $310 = $c + 372 | 0; //@line 48434
  HEAP32[$310 >> 2] = (HEAP32[$310 >> 2] | 0) + 20; //@line 48437
  if (($259 & 1 | 0) != 0) {
   _e68_exception_address($c, $259, 0, 0); //@line 48442
   return;
  }
  $317 = $c + 164 | 0; //@line 48447
  $319 = $c + 162 | 0; //@line 48449
  HEAP16[$319 >> 1] = HEAP16[$317 >> 1] | 0; //@line 48450
  $320 = $259 & 16777215; //@line 48451
  $321 = $320 + 1 | 0; //@line 48452
  if ($321 >>> 0 < (HEAP32[$205 >> 2] | 0) >>> 0) {
   $326 = HEAP32[$c + 32 >> 2] | 0; //@line 48458
   $341 = HEAPU8[$326 + $320 | 0] << 8 | HEAPU8[$326 + $321 | 0]; //@line 48468
  } else {
   $341 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $320) | 0; //@line 48476
  }
  HEAP16[$317 >> 1] = $341; //@line 48479
  $342 = $c + 336 | 0; //@line 48480
  if ((HEAP8[$342] | 0) != 0) {
   _e68_exception_bus($c); //@line 48485
   return;
  }
  $348 = (HEAP32[$292 >> 2] | 0) + 2 | 0; //@line 48491
  HEAP32[$292 >> 2] = $348; //@line 48492
  HEAP32[$291 >> 2] = (HEAP32[$291 >> 2] | 0) + 2; //@line 48495
  if (($348 & 1 | 0) != 0) {
   _e68_exception_address($c, $348, 0, 0); //@line 48500
   return;
  }
  HEAP16[$319 >> 1] = $341; //@line 48505
  $355 = $348 & 16777215; //@line 48506
  $356 = $355 + 1 | 0; //@line 48507
  do {
   if ($356 >>> 0 < (HEAP32[$205 >> 2] | 0) >>> 0) {
    $360 = HEAP32[$c + 32 >> 2] | 0; //@line 48514
    HEAP16[$317 >> 1] = HEAPU8[$360 + $355 | 0] << 8 | HEAPU8[$360 + $356 | 0]; //@line 48523
    $376 = $348; //@line 48525
   } else {
    $373 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $355) | 0; //@line 48531
    $phitmp_i = (HEAP8[$342] | 0) == 0; //@line 48533
    HEAP16[$317 >> 1] = $373; //@line 48534
    if ($phitmp_i) {
     $376 = HEAP32[$292 >> 2] | 0; //@line 48539
     break;
    }
    _e68_exception_bus($c); //@line 48542
    return;
   }
  } while (0);
  HEAP32[$292 >> 2] = $376 + 2; //@line 48550
  HEAP32[$291 >> 2] = $259; //@line 48551
  return;
 } else if (($3 | 0) == 20091) {
  $977 = $c | 0; //@line 48556
  if ((HEAP32[$977 >> 2] & 2 | 0) == 0) {
   _e68_exception_illegal($c); //@line 48562
   $982 = $c + 372 | 0; //@line 48563
   HEAP32[$982 >> 2] = (HEAP32[$982 >> 2] | 0) + 2; //@line 48566
   return;
  }
  $986 = $c + 334 | 0; //@line 48571
  if ((HEAP8[$986] | 0) == 0) {
   _e68_exception_privilege($c); //@line 48576
   return;
  }
  $991 = $c + 156 | 0; //@line 48581
  $992 = HEAP32[$991 >> 2] | 0; //@line 48582
  if (($992 & 1 | 0) != 0) {
   _e68_exception_address($c, $992, 0, 0); //@line 48587
   return;
  }
  $997 = $c + 164 | 0; //@line 48592
  $999 = $c + 162 | 0; //@line 48594
  HEAP16[$999 >> 1] = HEAP16[$997 >> 1] | 0; //@line 48595
  $1000 = $992 & 16777215; //@line 48596
  $1001 = $1000 + 1 | 0; //@line 48597
  $1002 = $c + 36 | 0; //@line 48598
  if ($1001 >>> 0 < (HEAP32[$1002 >> 2] | 0) >>> 0) {
   $1007 = HEAP32[$c + 32 >> 2] | 0; //@line 48604
   $1022 = HEAPU8[$1007 + $1000 | 0] << 8 | HEAPU8[$1007 + $1001 | 0]; //@line 48614
  } else {
   $1022 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1000) | 0; //@line 48622
  }
  HEAP16[$997 >> 1] = $1022; //@line 48625
  $1023 = $c + 336 | 0; //@line 48626
  if ((HEAP8[$1023] | 0) != 0) {
   _e68_exception_bus($c); //@line 48631
   return;
  }
  $1029 = (HEAP32[$991 >> 2] | 0) + 2 | 0; //@line 48637
  HEAP32[$991 >> 2] = $1029; //@line 48638
  $1030 = $c + 152 | 0; //@line 48639
  $1032 = (HEAP32[$1030 >> 2] | 0) + 2 | 0; //@line 48641
  HEAP32[$1030 >> 2] = $1032; //@line 48642
  $1034 = HEAPU16[$999 >> 1] | 0; //@line 48644
  $1035 = $1034 & 4095; //@line 48645
  $1036 = $1034 >>> 12; //@line 48646
  $1039 = $1036 & 7; //@line 48649
  if (($1036 & 8 | 0) == 0) {
   $val_0_in_i = $c + 88 + ($1039 << 2) | 0; //@line 48653
  } else {
   $val_0_in_i = $c + 120 + ($1039 << 2) | 0; //@line 48657
  }
  $val_0_i45 = HEAP32[$val_0_in_i >> 2] | 0; //@line 48660
  do {
   if (($1035 | 0) == 0) {
    HEAP32[$c + 180 >> 2] = $val_0_i45 & 3; //@line 48665
   } else if (($1035 | 0) == 1) {
    HEAP32[$c + 184 >> 2] = $val_0_i45 & 3; //@line 48670
   } else if (($1035 | 0) == 2) {
    if ((HEAP32[$977 >> 2] & 4 | 0) != 0) {
     HEAP32[$c + 188 >> 2] = $val_0_i45; //@line 48679
     break;
    }
    _e68_exception_illegal($c); //@line 48683
    $1056 = $c + 372 | 0; //@line 48684
    HEAP32[$1056 >> 2] = (HEAP32[$1056 >> 2] | 0) + 2; //@line 48687
    return;
   } else if (($1035 | 0) == 2048) {
    if ((HEAP8[$986] | 0) == 0) {
     HEAP32[$c + 148 >> 2] = $val_0_i45; //@line 48697
     break;
    } else {
     HEAP32[$c + 168 >> 2] = $val_0_i45; //@line 48701
     break;
    }
   } else if (($1035 | 0) == 2049) {
    HEAP32[$c + 176 >> 2] = $val_0_i45; //@line 48707
   } else if (($1035 | 0) == 2050) {
    if ((HEAP32[$977 >> 2] & 4 | 0) != 0) {
     HEAP32[$c + 188 >> 2] = $val_0_i45; //@line 48716
     break;
    }
    _e68_exception_illegal($c); //@line 48720
    $1075 = $c + 372 | 0; //@line 48721
    HEAP32[$1075 >> 2] = (HEAP32[$1075 >> 2] | 0) + 2; //@line 48724
    return;
   } else {
    _e68_exception_illegal($c); //@line 48729
    return;
   }
  } while (0);
  $1081 = $c + 372 | 0; //@line 48735
  HEAP32[$1081 >> 2] = (HEAP32[$1081 >> 2] | 0) + 10; //@line 48738
  if (($1029 & 1 | 0) != 0) {
   _e68_exception_address($c, $1029, 0, 0); //@line 48743
   return;
  }
  HEAP16[$999 >> 1] = $1022; //@line 48748
  $1088 = $1029 & 16777215; //@line 48749
  $1089 = $1088 + 1 | 0; //@line 48750
  do {
   if ($1089 >>> 0 < (HEAP32[$1002 >> 2] | 0) >>> 0) {
    $1093 = HEAP32[$c + 32 >> 2] | 0; //@line 48757
    HEAP16[$997 >> 1] = HEAPU8[$1093 + $1088 | 0] << 8 | HEAPU8[$1093 + $1089 | 0]; //@line 48766
    $1110 = $1029;
    $1109 = $1032;
   } else {
    $1106 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1088) | 0; //@line 48774
    $phitmp_i47 = (HEAP8[$1023] | 0) == 0; //@line 48776
    HEAP16[$997 >> 1] = $1106; //@line 48777
    if ($phitmp_i47) {
     $1110 = HEAP32[$991 >> 2] | 0;
     $1109 = HEAP32[$1030 >> 2] | 0;
     break;
    }
    _e68_exception_bus($c); //@line 48786
    return;
   }
  } while (0);
  HEAP32[$991 >> 2] = $1110 + 2; //@line 48795
  HEAP32[$1030 >> 2] = $1109 + 2; //@line 48797
  return;
 } else if (($3 | 0) == 20087) {
  $699 = $c + 148 | 0; //@line 48802
  $700 = HEAP32[$699 >> 2] | 0; //@line 48803
  $701 = $700 & 16777215; //@line 48804
  $702 = $701 + 1 | 0; //@line 48805
  $703 = $c + 36 | 0; //@line 48806
  $704 = HEAP32[$703 >> 2] | 0; //@line 48807
  if ($702 >>> 0 < $704 >>> 0) {
   $_0_i_off0_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $702 | 0] | 0;
   $717 = $704;
  } else {
   $extract_t19_i = (FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $701) | 0) & 255; //@line 48823
   $_0_i_off0_i = $extract_t19_i;
   $717 = HEAP32[$703 >> 2] | 0;
  }
  $719 = $c + 166 | 0; //@line 48831
  HEAP16[$719 >> 1] = HEAP16[$719 >> 1] & -256 | $_0_i_off0_i & 31; //@line 48836
  $725 = $700 + 2 & 16777215; //@line 48838
  $726 = $725 + 3 | 0; //@line 48839
  if ($726 >>> 0 < $717 >>> 0) {
   $730 = HEAP32[$c + 32 >> 2] | 0; //@line 48844
   $_0_i14_i = ((HEAPU8[$730 + $725 | 0] << 8 | HEAPU8[$730 + ($725 + 1) | 0]) << 8 | HEAPU8[$730 + ($725 + 2) | 0]) << 8 | HEAPU8[$730 + $726 | 0]; //@line 48866
  } else {
   $_0_i14_i = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $725) | 0; //@line 48874
  }
  $757 = $c + 156 | 0; //@line 48877
  HEAP32[$757 >> 2] = $_0_i14_i; //@line 48878
  HEAP32[$699 >> 2] = $700 + 6; //@line 48880
  $759 = $c + 372 | 0; //@line 48881
  HEAP32[$759 >> 2] = (HEAP32[$759 >> 2] | 0) + 20; //@line 48884
  if (($_0_i14_i & 1 | 0) != 0) {
   _e68_exception_address($c, $_0_i14_i, 0, 0); //@line 48889
   return;
  }
  $766 = $c + 164 | 0; //@line 48894
  $768 = $c + 162 | 0; //@line 48896
  HEAP16[$768 >> 1] = HEAP16[$766 >> 1] | 0; //@line 48897
  $769 = $_0_i14_i & 16777215; //@line 48898
  $770 = $769 + 1 | 0; //@line 48899
  if ($770 >>> 0 < (HEAP32[$703 >> 2] | 0) >>> 0) {
   $775 = HEAP32[$c + 32 >> 2] | 0; //@line 48905
   $790 = HEAPU8[$775 + $769 | 0] << 8 | HEAPU8[$775 + $770 | 0]; //@line 48915
  } else {
   $790 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $769) | 0; //@line 48923
  }
  HEAP16[$766 >> 1] = $790; //@line 48926
  $791 = $c + 336 | 0; //@line 48927
  if ((HEAP8[$791] | 0) != 0) {
   _e68_exception_bus($c); //@line 48932
   return;
  }
  $797 = (HEAP32[$757 >> 2] | 0) + 2 | 0; //@line 48938
  HEAP32[$757 >> 2] = $797; //@line 48939
  $798 = $c + 152 | 0; //@line 48940
  HEAP32[$798 >> 2] = (HEAP32[$798 >> 2] | 0) + 2; //@line 48943
  if (($797 & 1 | 0) != 0) {
   _e68_exception_address($c, $797, 0, 0); //@line 48948
   return;
  }
  HEAP16[$768 >> 1] = $790; //@line 48953
  $805 = $797 & 16777215; //@line 48954
  $806 = $805 + 1 | 0; //@line 48955
  do {
   if ($806 >>> 0 < (HEAP32[$703 >> 2] | 0) >>> 0) {
    $810 = HEAP32[$c + 32 >> 2] | 0; //@line 48962
    HEAP16[$766 >> 1] = HEAPU8[$810 + $805 | 0] << 8 | HEAPU8[$810 + $806 | 0]; //@line 48971
    $826 = $797; //@line 48973
   } else {
    $823 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $805) | 0; //@line 48979
    $phitmp_i40 = (HEAP8[$791] | 0) == 0; //@line 48981
    HEAP16[$766 >> 1] = $823; //@line 48982
    if ($phitmp_i40) {
     $826 = HEAP32[$757 >> 2] | 0; //@line 48987
     break;
    }
    _e68_exception_bus($c); //@line 48990
    return;
   }
  } while (0);
  HEAP32[$757 >> 2] = $826 + 2; //@line 48998
  HEAP32[$798 >> 2] = $826 - 2; //@line 49000
  return;
 } else if (($3 | 0) == 20084) {
  if ((HEAP32[$c >> 2] & 2 | 0) == 0) {
   _e68_exception_illegal($c); //@line 49011
   $384 = $c + 372 | 0; //@line 49012
   HEAP32[$384 >> 2] = (HEAP32[$384 >> 2] | 0) + 2; //@line 49015
   return;
  }
  $388 = $c + 156 | 0; //@line 49020
  $389 = HEAP32[$388 >> 2] | 0; //@line 49021
  if (($389 & 1 | 0) != 0) {
   _e68_exception_address($c, $389, 0, 0); //@line 49026
   return;
  }
  $394 = $c + 164 | 0; //@line 49031
  $396 = $c + 162 | 0; //@line 49033
  HEAP16[$396 >> 1] = HEAP16[$394 >> 1] | 0; //@line 49034
  $397 = $389 & 16777215; //@line 49035
  $398 = $397 + 1 | 0; //@line 49036
  $399 = $c + 36 | 0; //@line 49037
  if ($398 >>> 0 < (HEAP32[$399 >> 2] | 0) >>> 0) {
   $404 = HEAP32[$c + 32 >> 2] | 0; //@line 49043
   $_0_i_i_i23 = HEAPU8[$404 + $397 | 0] << 8 | HEAPU8[$404 + $398 | 0]; //@line 49053
  } else {
   $_0_i_i_i23 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $397) | 0; //@line 49061
  }
  HEAP16[$394 >> 1] = $_0_i_i_i23; //@line 49064
  $419 = $c + 336 | 0; //@line 49065
  if ((HEAP8[$419] | 0) != 0) {
   _e68_exception_bus($c); //@line 49070
   return;
  }
  HEAP32[$388 >> 2] = (HEAP32[$388 >> 2] | 0) + 2; //@line 49077
  $426 = $c + 152 | 0; //@line 49078
  HEAP32[$426 >> 2] = (HEAP32[$426 >> 2] | 0) + 2; //@line 49081
  $430 = HEAPU16[$396 >> 1] | 0; //@line 49083
  $435 = $c + 148 | 0; //@line 49088
  $436 = HEAP32[$435 >> 2] | 0; //@line 49089
  $437 = $436 & 16777215; //@line 49090
  $438 = $437 + 3 | 0; //@line 49091
  if ($438 >>> 0 < (HEAP32[$399 >> 2] | 0) >>> 0) {
   $443 = HEAP32[$c + 32 >> 2] | 0; //@line 49097
   $_0_i13_i = ((HEAPU8[$443 + $437 | 0] << 8 | HEAPU8[$443 + ($437 + 1) | 0]) << 8 | HEAPU8[$443 + ($437 + 2) | 0]) << 8 | HEAPU8[$443 + $438 | 0]; //@line 49119
  } else {
   $_0_i13_i = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $437) | 0; //@line 49127
  }
  HEAP32[$388 >> 2] = $_0_i13_i; //@line 49130
  HEAP32[$435 >> 2] = $436 + 4 + (($430 & 32768 | 0) != 0 ? $430 | -65536 : $430); //@line 49133
  $472 = $c + 372 | 0; //@line 49134
  HEAP32[$472 >> 2] = (HEAP32[$472 >> 2] | 0) + 16; //@line 49137
  if (($_0_i13_i & 1 | 0) != 0) {
   _e68_exception_address($c, $_0_i13_i, 0, 0); //@line 49142
   return;
  }
  HEAP16[$396 >> 1] = HEAP16[$394 >> 1] | 0; //@line 49148
  $480 = $_0_i13_i & 16777215; //@line 49149
  $481 = $480 + 1 | 0; //@line 49150
  if ($481 >>> 0 < (HEAP32[$399 >> 2] | 0) >>> 0) {
   $486 = HEAP32[$c + 32 >> 2] | 0; //@line 49156
   $501 = HEAPU8[$486 + $480 | 0] << 8 | HEAPU8[$486 + $481 | 0]; //@line 49166
  } else {
   $501 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $480) | 0; //@line 49174
  }
  HEAP16[$394 >> 1] = $501; //@line 49177
  if ((HEAP8[$419] | 0) != 0) {
   _e68_exception_bus($c); //@line 49182
   return;
  }
  $507 = (HEAP32[$388 >> 2] | 0) + 2 | 0; //@line 49188
  HEAP32[$388 >> 2] = $507; //@line 49189
  HEAP32[$426 >> 2] = (HEAP32[$426 >> 2] | 0) + 2; //@line 49192
  if (($507 & 1 | 0) != 0) {
   _e68_exception_address($c, $507, 0, 0); //@line 49197
   return;
  }
  HEAP16[$396 >> 1] = $501; //@line 49202
  $514 = $507 & 16777215; //@line 49203
  $515 = $514 + 1 | 0; //@line 49204
  do {
   if ($515 >>> 0 < (HEAP32[$399 >> 2] | 0) >>> 0) {
    $519 = HEAP32[$c + 32 >> 2] | 0; //@line 49211
    HEAP16[$394 >> 1] = HEAPU8[$519 + $514 | 0] << 8 | HEAPU8[$519 + $515 | 0]; //@line 49220
    $535 = $507; //@line 49222
   } else {
    $532 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $514) | 0; //@line 49228
    $phitmp_i27 = (HEAP8[$419] | 0) == 0; //@line 49230
    HEAP16[$394 >> 1] = $532; //@line 49231
    if ($phitmp_i27) {
     $535 = HEAP32[$388 >> 2] | 0; //@line 49236
     break;
    }
    _e68_exception_bus($c); //@line 49239
    return;
   }
  } while (0);
  HEAP32[$388 >> 2] = $535 + 2; //@line 49247
  HEAP32[$426 >> 2] = $535 - 2; //@line 49249
  return;
 } else if (($3 | 0) == 20090) {
  $830 = $c | 0; //@line 49254
  if ((HEAP32[$830 >> 2] & 2 | 0) == 0) {
   _e68_exception_illegal($c); //@line 49260
   $835 = $c + 372 | 0; //@line 49261
   HEAP32[$835 >> 2] = (HEAP32[$835 >> 2] | 0) + 2; //@line 49264
   return;
  }
  $839 = $c + 334 | 0; //@line 49269
  if ((HEAP8[$839] | 0) == 0) {
   _e68_exception_privilege($c); //@line 49274
   return;
  }
  $844 = $c + 156 | 0; //@line 49279
  $845 = HEAP32[$844 >> 2] | 0; //@line 49280
  if (($845 & 1 | 0) != 0) {
   _e68_exception_address($c, $845, 0, 0); //@line 49285
   return;
  }
  $850 = $c + 164 | 0; //@line 49290
  $852 = $c + 162 | 0; //@line 49292
  HEAP16[$852 >> 1] = HEAP16[$850 >> 1] | 0; //@line 49293
  $853 = $845 & 16777215; //@line 49294
  $854 = $853 + 1 | 0; //@line 49295
  $855 = $c + 36 | 0; //@line 49296
  if ($854 >>> 0 < (HEAP32[$855 >> 2] | 0) >>> 0) {
   $860 = HEAP32[$c + 32 >> 2] | 0; //@line 49302
   $_0_i_i_i42 = HEAPU8[$860 + $853 | 0] << 8 | HEAPU8[$860 + $854 | 0]; //@line 49312
  } else {
   $_0_i_i_i42 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $853) | 0; //@line 49320
  }
  HEAP16[$850 >> 1] = $_0_i_i_i42; //@line 49323
  $875 = $c + 336 | 0; //@line 49324
  if ((HEAP8[$875] | 0) != 0) {
   _e68_exception_bus($c); //@line 49329
   return;
  }
  HEAP32[$844 >> 2] = (HEAP32[$844 >> 2] | 0) + 2; //@line 49336
  $882 = $c + 152 | 0; //@line 49337
  HEAP32[$882 >> 2] = (HEAP32[$882 >> 2] | 0) + 2; //@line 49340
  $886 = HEAPU16[$852 >> 1] | 0; //@line 49342
  $887 = $886 & 4095; //@line 49343
  $888 = $886 >>> 12; //@line 49344
  do {
   if (($887 | 0) == 0) {
    $val_0_i = HEAP32[$c + 180 >> 2] & 3; //@line 49351
   } else if (($887 | 0) == 1) {
    $val_0_i = HEAP32[$c + 184 >> 2] & 3; //@line 49357
   } else if (($887 | 0) == 2) {
    if ((HEAP32[$830 >> 2] & 4 | 0) != 0) {
     $val_0_i = HEAP32[$c + 176 >> 2] | 0; //@line 49367
     break;
    }
    _e68_exception_illegal($c); //@line 49370
    $902 = $c + 372 | 0; //@line 49371
    HEAP32[$902 >> 2] = (HEAP32[$902 >> 2] | 0) + 2; //@line 49374
    return;
   } else if (($887 | 0) == 2048) {
    $val_0_i = HEAP32[((HEAP8[$839] | 0) == 0 ? $c + 148 | 0 : $c + 168 | 0) >> 2] | 0; //@line 49386
   } else if (($887 | 0) == 2049) {
    $val_0_i = HEAP32[$c + 176 >> 2] | 0; //@line 49391
   } else if (($887 | 0) == 2050) {
    if ((HEAP32[$830 >> 2] & 4 | 0) != 0) {
     $val_0_i = HEAP32[$c + 176 >> 2] | 0; //@line 49401
     break;
    }
    _e68_exception_illegal($c); //@line 49404
    $922 = $c + 372 | 0; //@line 49405
    HEAP32[$922 >> 2] = (HEAP32[$922 >> 2] | 0) + 2; //@line 49408
    return;
   } else {
    _e68_exception_illegal($c); //@line 49413
    return;
   }
  } while (0);
  $932 = $888 & 7; //@line 49422
  if (($888 & 8 | 0) == 0) {
   HEAP32[$c + 88 + ($932 << 2) >> 2] = $val_0_i; //@line 49426
  } else {
   HEAP32[$c + 120 + ($932 << 2) >> 2] = $val_0_i; //@line 49429
  }
  $938 = $c + 372 | 0; //@line 49432
  HEAP32[$938 >> 2] = (HEAP32[$938 >> 2] | 0) + 12; //@line 49435
  $941 = HEAP32[$844 >> 2] | 0; //@line 49436
  if (($941 & 1 | 0) != 0) {
   _e68_exception_address($c, $941, 0, 0); //@line 49441
   return;
  }
  HEAP16[$852 >> 1] = HEAP16[$850 >> 1] | 0; //@line 49447
  $947 = $941 & 16777215; //@line 49448
  $948 = $947 + 1 | 0; //@line 49449
  if ($948 >>> 0 < (HEAP32[$855 >> 2] | 0) >>> 0) {
   $953 = HEAP32[$c + 32 >> 2] | 0; //@line 49455
   $_0_i_i19_i = HEAPU8[$953 + $947 | 0] << 8 | HEAPU8[$953 + $948 | 0]; //@line 49465
  } else {
   $_0_i_i19_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $947) | 0; //@line 49473
  }
  HEAP16[$850 >> 1] = $_0_i_i19_i; //@line 49476
  if ((HEAP8[$875] | 0) == 0) {
   HEAP32[$844 >> 2] = (HEAP32[$844 >> 2] | 0) + 2; //@line 49483
   HEAP32[$882 >> 2] = (HEAP32[$882 >> 2] | 0) + 2; //@line 49486
   return;
  } else {
   _e68_exception_bus($c); //@line 49491
   return;
  }
 } else if (($3 | 0) == 20085) {
  $539 = $c + 148 | 0; //@line 49497
  $540 = HEAP32[$539 >> 2] | 0; //@line 49498
  $541 = $540 & 16777215; //@line 49499
  $542 = $541 + 3 | 0; //@line 49500
  $543 = $c + 36 | 0; //@line 49501
  if ($542 >>> 0 < (HEAP32[$543 >> 2] | 0) >>> 0) {
   $548 = HEAP32[$c + 32 >> 2] | 0; //@line 49507
   $_0_i_i28 = ((HEAPU8[$548 + $541 | 0] << 8 | HEAPU8[$548 + ($541 + 1) | 0]) << 8 | HEAPU8[$548 + ($541 + 2) | 0]) << 8 | HEAPU8[$548 + $542 | 0]; //@line 49529
  } else {
   $_0_i_i28 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $541) | 0; //@line 49537
  }
  $575 = $c + 156 | 0; //@line 49540
  HEAP32[$575 >> 2] = $_0_i_i28; //@line 49541
  HEAP32[$539 >> 2] = $540 + 4; //@line 49543
  $577 = $c + 372 | 0; //@line 49544
  HEAP32[$577 >> 2] = (HEAP32[$577 >> 2] | 0) + 16; //@line 49547
  if (($_0_i_i28 & 1 | 0) != 0) {
   _e68_exception_address($c, $_0_i_i28, 0, 0); //@line 49552
   return;
  }
  $584 = $c + 164 | 0; //@line 49557
  $586 = $c + 162 | 0; //@line 49559
  HEAP16[$586 >> 1] = HEAP16[$584 >> 1] | 0; //@line 49560
  $587 = $_0_i_i28 & 16777215; //@line 49561
  $588 = $587 + 1 | 0; //@line 49562
  if ($588 >>> 0 < (HEAP32[$543 >> 2] | 0) >>> 0) {
   $593 = HEAP32[$c + 32 >> 2] | 0; //@line 49568
   $608 = HEAPU8[$593 + $587 | 0] << 8 | HEAPU8[$593 + $588 | 0]; //@line 49578
  } else {
   $608 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $587) | 0; //@line 49586
  }
  HEAP16[$584 >> 1] = $608; //@line 49589
  $609 = $c + 336 | 0; //@line 49590
  if ((HEAP8[$609] | 0) != 0) {
   _e68_exception_bus($c); //@line 49595
   return;
  }
  $615 = (HEAP32[$575 >> 2] | 0) + 2 | 0; //@line 49601
  HEAP32[$575 >> 2] = $615; //@line 49602
  $616 = $c + 152 | 0; //@line 49603
  HEAP32[$616 >> 2] = (HEAP32[$616 >> 2] | 0) + 2; //@line 49606
  if (($615 & 1 | 0) != 0) {
   _e68_exception_address($c, $615, 0, 0); //@line 49611
   return;
  }
  HEAP16[$586 >> 1] = $608; //@line 49616
  $623 = $615 & 16777215; //@line 49617
  $624 = $623 + 1 | 0; //@line 49618
  do {
   if ($624 >>> 0 < (HEAP32[$543 >> 2] | 0) >>> 0) {
    $628 = HEAP32[$c + 32 >> 2] | 0; //@line 49625
    HEAP16[$584 >> 1] = HEAPU8[$628 + $623 | 0] << 8 | HEAPU8[$628 + $624 | 0]; //@line 49634
    $644 = $615; //@line 49636
   } else {
    $641 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $623) | 0; //@line 49642
    $phitmp_i32 = (HEAP8[$609] | 0) == 0; //@line 49644
    HEAP16[$584 >> 1] = $641; //@line 49645
    if ($phitmp_i32) {
     $644 = HEAP32[$575 >> 2] | 0; //@line 49650
     break;
    }
    _e68_exception_bus($c); //@line 49653
    return;
   }
  } while (0);
  HEAP32[$575 >> 2] = $644 + 2; //@line 49661
  HEAP32[$616 >> 2] = $644 - 2; //@line 49663
  return;
 } else if (($3 | 0) == 20082) {
  if ((HEAP8[$c + 334 | 0] | 0) == 0) {
   _e68_exception_privilege($c); //@line 49673
   return;
  }
  $112 = $c + 156 | 0; //@line 49678
  $113 = HEAP32[$112 >> 2] | 0; //@line 49679
  if (($113 & 1 | 0) != 0) {
   _e68_exception_address($c, $113, 0, 0); //@line 49684
   return;
  }
  $118 = $c + 164 | 0; //@line 49689
  $120 = $c + 162 | 0; //@line 49691
  HEAP16[$120 >> 1] = HEAP16[$118 >> 1] | 0; //@line 49692
  $121 = $113 & 16777215; //@line 49693
  $122 = $121 + 1 | 0; //@line 49694
  $123 = $c + 36 | 0; //@line 49695
  if ($122 >>> 0 < (HEAP32[$123 >> 2] | 0) >>> 0) {
   $128 = HEAP32[$c + 32 >> 2] | 0; //@line 49701
   $_0_i_i_i20 = HEAPU8[$128 + $121 | 0] << 8 | HEAPU8[$128 + $122 | 0]; //@line 49711
  } else {
   $_0_i_i_i20 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $121) | 0; //@line 49719
  }
  HEAP16[$118 >> 1] = $_0_i_i_i20; //@line 49722
  $143 = $c + 336 | 0; //@line 49723
  if ((HEAP8[$143] | 0) != 0) {
   _e68_exception_bus($c); //@line 49728
   return;
  }
  HEAP32[$112 >> 2] = (HEAP32[$112 >> 2] | 0) + 2; //@line 49735
  $150 = $c + 152 | 0; //@line 49736
  HEAP32[$150 >> 2] = (HEAP32[$150 >> 2] | 0) + 2; //@line 49739
  _e68_set_sr($c, HEAP16[$120 >> 1] | 0); //@line 49741
  $154 = $c + 372 | 0; //@line 49742
  HEAP32[$154 >> 2] = (HEAP32[$154 >> 2] | 0) + 4; //@line 49745
  $157 = $c + 335 | 0; //@line 49746
  HEAP8[$157] = HEAP8[$157] | 1; //@line 49749
  $160 = HEAP32[$112 >> 2] | 0; //@line 49750
  if (($160 & 1 | 0) != 0) {
   _e68_exception_address($c, $160, 0, 0); //@line 49755
   return;
  }
  HEAP16[$120 >> 1] = HEAP16[$118 >> 1] | 0; //@line 49761
  $166 = $160 & 16777215; //@line 49762
  $167 = $166 + 1 | 0; //@line 49763
  if ($167 >>> 0 < (HEAP32[$123 >> 2] | 0) >>> 0) {
   $172 = HEAP32[$c + 32 >> 2] | 0; //@line 49769
   $_0_i_i7_i = HEAPU8[$172 + $166 | 0] << 8 | HEAPU8[$172 + $167 | 0]; //@line 49779
  } else {
   $_0_i_i7_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $166) | 0; //@line 49787
  }
  HEAP16[$118 >> 1] = $_0_i_i7_i; //@line 49790
  if ((HEAP8[$143] | 0) == 0) {
   HEAP32[$112 >> 2] = (HEAP32[$112 >> 2] | 0) + 2; //@line 49797
   HEAP32[$150 >> 2] = (HEAP32[$150 >> 2] | 0) + 2; //@line 49800
   return;
  } else {
   _e68_exception_bus($c); //@line 49805
   return;
  }
 } else {
  $1115 = $3 >>> 3 & 7; //@line 49812
  if (($1115 | 0) == 0 | ($1115 | 0) == 1) {
   $1117 = $c + 156 | 0; //@line 49814
   $1118 = HEAP32[$1117 >> 2] | 0; //@line 49815
   if (($1118 & 1 | 0) != 0) {
    _e68_exception_address($c, $1118, 0, 0); //@line 49820
    return;
   }
   $1123 = $c + 164 | 0; //@line 49825
   HEAP16[$c + 162 >> 1] = HEAP16[$1123 >> 1] | 0; //@line 49828
   $1126 = $1118 & 16777215; //@line 49829
   $1127 = $1126 + 1 | 0; //@line 49830
   if ($1127 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $1133 = HEAP32[$c + 32 >> 2] | 0; //@line 49837
    $_0_i_i_i48 = HEAPU8[$1133 + $1126 | 0] << 8 | HEAPU8[$1133 + $1127 | 0]; //@line 49847
   } else {
    $_0_i_i_i48 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1126) | 0; //@line 49855
   }
   HEAP16[$1123 >> 1] = $_0_i_i_i48; //@line 49858
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$1117 >> 2] = (HEAP32[$1117 >> 2] | 0) + 2; //@line 49866
    $1155 = $c + 152 | 0; //@line 49867
    HEAP32[$1155 >> 2] = (HEAP32[$1155 >> 2] | 0) + 2; //@line 49870
    _e68_exception_trap($c, HEAP16[$1 >> 1] & 15); //@line 49874
    return;
   } else {
    _e68_exception_bus($c); //@line 49879
    return;
   }
  } else if (($1115 | 0) == 2) {
   $1162 = $c + 156 | 0; //@line 49885
   $1163 = HEAP32[$1162 >> 2] | 0; //@line 49886
   if (($1163 & 1 | 0) != 0) {
    _e68_exception_address($c, $1163, 0, 0); //@line 49891
    return;
   }
   $1168 = $c + 164 | 0; //@line 49896
   $1170 = $c + 162 | 0; //@line 49898
   HEAP16[$1170 >> 1] = HEAP16[$1168 >> 1] | 0; //@line 49899
   $1171 = $1163 & 16777215; //@line 49900
   $1172 = $1171 + 1 | 0; //@line 49901
   $1173 = $c + 36 | 0; //@line 49902
   if ($1172 >>> 0 < (HEAP32[$1173 >> 2] | 0) >>> 0) {
    $1178 = HEAP32[$c + 32 >> 2] | 0; //@line 49908
    $_0_i_i_i50 = HEAPU8[$1178 + $1171 | 0] << 8 | HEAPU8[$1178 + $1172 | 0]; //@line 49918
   } else {
    $_0_i_i_i50 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1171) | 0; //@line 49926
   }
   HEAP16[$1168 >> 1] = $_0_i_i_i50; //@line 49929
   $1193 = $c + 336 | 0; //@line 49930
   if ((HEAP8[$1193] | 0) != 0) {
    _e68_exception_bus($c); //@line 49935
    return;
   }
   HEAP32[$1162 >> 2] = (HEAP32[$1162 >> 2] | 0) + 2; //@line 49942
   $1200 = $c + 152 | 0; //@line 49943
   HEAP32[$1200 >> 2] = (HEAP32[$1200 >> 2] | 0) + 2; //@line 49946
   $1205 = HEAP16[$1 >> 1] & 7; //@line 49949
   $1207 = HEAPU16[$1170 >> 1] | 0; //@line 49951
   $1212 = $c + 372 | 0; //@line 49956
   HEAP32[$1212 >> 2] = (HEAP32[$1212 >> 2] | 0) + 16; //@line 49959
   $1215 = $c + 148 | 0; //@line 49960
   $1217 = (HEAP32[$1215 >> 2] | 0) - 4 | 0; //@line 49962
   HEAP32[$1215 >> 2] = $1217; //@line 49963
   $1218 = $c + 120 + ($1205 << 2) | 0; //@line 49964
   $1219 = HEAP32[$1218 >> 2] | 0; //@line 49965
   $1220 = $1217 & 16777215; //@line 49966
   $1221 = $1220 + 3 | 0; //@line 49967
   if ($1221 >>> 0 < (HEAP32[$1173 >> 2] | 0) >>> 0) {
    $1227 = $c + 32 | 0; //@line 49974
    HEAP8[(HEAP32[$1227 >> 2] | 0) + $1220 | 0] = $1219 >>> 24 & 255; //@line 49977
    HEAP8[(HEAP32[$1227 >> 2] | 0) + ($1220 + 1) | 0] = $1219 >>> 16 & 255; //@line 49983
    HEAP8[(HEAP32[$1227 >> 2] | 0) + ($1220 + 2) | 0] = $1219 >>> 8 & 255; //@line 49989
    HEAP8[(HEAP32[$1227 >> 2] | 0) + $1221 | 0] = $1219 & 255; //@line 49993
   } else {
    FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1220, $1219); //@line 50000
   }
   HEAP32[$1218 >> 2] = HEAP32[$1215 >> 2]; //@line 50003
   HEAP32[$1215 >> 2] = (HEAP32[$1215 >> 2] | 0) + (($1207 & 32768 | 0) != 0 ? $1207 | -65536 : $1207); //@line 50006
   $1251 = HEAP32[$1162 >> 2] | 0; //@line 50007
   if (($1251 & 1 | 0) != 0) {
    _e68_exception_address($c, $1251, 0, 0); //@line 50012
    return;
   }
   HEAP16[$1170 >> 1] = HEAP16[$1168 >> 1] | 0; //@line 50018
   $1257 = $1251 & 16777215; //@line 50019
   $1258 = $1257 + 1 | 0; //@line 50020
   if ($1258 >>> 0 < (HEAP32[$1173 >> 2] | 0) >>> 0) {
    $1263 = HEAP32[$c + 32 >> 2] | 0; //@line 50026
    $_0_i_i15_i = HEAPU8[$1263 + $1257 | 0] << 8 | HEAPU8[$1263 + $1258 | 0]; //@line 50036
   } else {
    $_0_i_i15_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1257) | 0; //@line 50044
   }
   HEAP16[$1168 >> 1] = $_0_i_i15_i; //@line 50047
   if ((HEAP8[$1193] | 0) == 0) {
    HEAP32[$1162 >> 2] = (HEAP32[$1162 >> 2] | 0) + 2; //@line 50054
    HEAP32[$1200 >> 2] = (HEAP32[$1200 >> 2] | 0) + 2; //@line 50057
    return;
   } else {
    _e68_exception_bus($c); //@line 50062
    return;
   }
  } else if (($1115 | 0) == 3) {
   $1288 = $c + 120 + (($3 & 7) << 2) | 0; //@line 50069
   $1289 = HEAP32[$1288 >> 2] | 0; //@line 50070
   do {
    if ((HEAP32[$c >> 2] & 1 | 0) == 0) {
     if (($1289 & 1 | 0) == 0) {
      break;
     }
     _e68_exception_address($c, $1289, 1, 0); //@line 50084
     return;
    }
   } while (0);
   $1299 = $c + 372 | 0; //@line 50089
   HEAP32[$1299 >> 2] = (HEAP32[$1299 >> 2] | 0) + 12; //@line 50092
   $1302 = $c + 148 | 0; //@line 50093
   HEAP32[$1302 >> 2] = $1289; //@line 50094
   $1303 = $1289 & 16777215; //@line 50095
   $1304 = $1303 + 3 | 0; //@line 50096
   $1305 = $c + 36 | 0; //@line 50097
   if ($1304 >>> 0 < (HEAP32[$1305 >> 2] | 0) >>> 0) {
    $1310 = HEAP32[$c + 32 >> 2] | 0; //@line 50103
    $_0_i15_i = ((HEAPU8[$1310 + $1303 | 0] << 8 | HEAPU8[$1310 + ($1303 + 1) | 0]) << 8 | HEAPU8[$1310 + ($1303 + 2) | 0]) << 8 | HEAPU8[$1310 + $1304 | 0]; //@line 50125
   } else {
    $_0_i15_i = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1303) | 0; //@line 50133
   }
   HEAP32[$1288 >> 2] = $_0_i15_i; //@line 50136
   HEAP32[$1302 >> 2] = (HEAP32[$1302 >> 2] | 0) + 4; //@line 50139
   $1339 = $c + 156 | 0; //@line 50140
   $1340 = HEAP32[$1339 >> 2] | 0; //@line 50141
   if (($1340 & 1 | 0) != 0) {
    _e68_exception_address($c, $1340, 0, 0); //@line 50146
    return;
   }
   $1345 = $c + 164 | 0; //@line 50151
   HEAP16[$c + 162 >> 1] = HEAP16[$1345 >> 1] | 0; //@line 50154
   $1348 = $1340 & 16777215; //@line 50155
   $1349 = $1348 + 1 | 0; //@line 50156
   if ($1349 >>> 0 < (HEAP32[$1305 >> 2] | 0) >>> 0) {
    $1354 = HEAP32[$c + 32 >> 2] | 0; //@line 50162
    $_0_i_i_i54 = HEAPU8[$1354 + $1348 | 0] << 8 | HEAPU8[$1354 + $1349 | 0]; //@line 50172
   } else {
    $_0_i_i_i54 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1348) | 0; //@line 50180
   }
   HEAP16[$1345 >> 1] = $_0_i_i_i54; //@line 50183
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$1339 >> 2] = (HEAP32[$1339 >> 2] | 0) + 2; //@line 50191
    $1376 = $c + 152 | 0; //@line 50192
    HEAP32[$1376 >> 2] = (HEAP32[$1376 >> 2] | 0) + 2; //@line 50195
    return;
   } else {
    _e68_exception_bus($c); //@line 50200
    return;
   }
  } else if (($1115 | 0) == 5) {
   if ((HEAP8[$c + 334 | 0] | 0) == 0) {
    _e68_exception_privilege($c); //@line 50211
    return;
   }
   HEAP32[$c + 120 + (($3 & 7) << 2) >> 2] = HEAP32[$c + 168 >> 2]; //@line 50219
   $1442 = $c + 372 | 0; //@line 50220
   HEAP32[$1442 >> 2] = (HEAP32[$1442 >> 2] | 0) + 4; //@line 50223
   $1445 = $c + 156 | 0; //@line 50224
   $1446 = HEAP32[$1445 >> 2] | 0; //@line 50225
   if (($1446 & 1 | 0) != 0) {
    _e68_exception_address($c, $1446, 0, 0); //@line 50230
    return;
   }
   $1451 = $c + 164 | 0; //@line 50235
   HEAP16[$c + 162 >> 1] = HEAP16[$1451 >> 1] | 0; //@line 50238
   $1454 = $1446 & 16777215; //@line 50239
   $1455 = $1454 + 1 | 0; //@line 50240
   if ($1455 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $1461 = HEAP32[$c + 32 >> 2] | 0; //@line 50247
    $_0_i_i_i60 = HEAPU8[$1461 + $1454 | 0] << 8 | HEAPU8[$1461 + $1455 | 0]; //@line 50257
   } else {
    $_0_i_i_i60 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1454) | 0; //@line 50265
   }
   HEAP16[$1451 >> 1] = $_0_i_i_i60; //@line 50268
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$1445 >> 2] = (HEAP32[$1445 >> 2] | 0) + 2; //@line 50276
    $1483 = $c + 152 | 0; //@line 50277
    HEAP32[$1483 >> 2] = (HEAP32[$1483 >> 2] | 0) + 2; //@line 50280
    return;
   } else {
    _e68_exception_bus($c); //@line 50285
    return;
   }
  } else if (($1115 | 0) == 4) {
   if ((HEAP8[$c + 334 | 0] | 0) == 0) {
    _e68_exception_privilege($c); //@line 50296
    return;
   }
   HEAP32[$c + 168 >> 2] = HEAP32[$c + 120 + (($3 & 7) << 2) >> 2]; //@line 50304
   $1388 = $c + 372 | 0; //@line 50305
   HEAP32[$1388 >> 2] = (HEAP32[$1388 >> 2] | 0) + 4; //@line 50308
   $1391 = $c + 156 | 0; //@line 50309
   $1392 = HEAP32[$1391 >> 2] | 0; //@line 50310
   if (($1392 & 1 | 0) != 0) {
    _e68_exception_address($c, $1392, 0, 0); //@line 50315
    return;
   }
   $1397 = $c + 164 | 0; //@line 50320
   HEAP16[$c + 162 >> 1] = HEAP16[$1397 >> 1] | 0; //@line 50323
   $1400 = $1392 & 16777215; //@line 50324
   $1401 = $1400 + 1 | 0; //@line 50325
   if ($1401 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $1407 = HEAP32[$c + 32 >> 2] | 0; //@line 50332
    $_0_i_i_i57 = HEAPU8[$1407 + $1400 | 0] << 8 | HEAPU8[$1407 + $1401 | 0]; //@line 50342
   } else {
    $_0_i_i_i57 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $1400) | 0; //@line 50350
   }
   HEAP16[$1397 >> 1] = $_0_i_i_i57; //@line 50353
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$1391 >> 2] = (HEAP32[$1391 >> 2] | 0) + 2; //@line 50361
    $1429 = $c + 152 | 0; //@line 50362
    HEAP32[$1429 >> 2] = (HEAP32[$1429 >> 2] | 0) + 2; //@line 50365
    return;
   } else {
    _e68_exception_bus($c); //@line 50370
    return;
   }
  } else {
   _e68_exception_illegal($c); //@line 50376
   $1487 = $c + 372 | 0; //@line 50377
   HEAP32[$1487 >> 2] = (HEAP32[$1487 >> 2] | 0) + 2; //@line 50380
   return;
  }
 }
}
function _op4e80($c) {
 $c = $c | 0;
 var $4 = 0, $15 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $26 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $36 = 0, $_0_i_i = 0, $51 = 0, $58 = 0, $61 = 0, $62 = 0, $64 = 0, $65 = 0, $66 = 0, $72 = 0, $93 = 0, $99 = 0, $100 = 0, $105 = 0, $_0_i_i12 = 0;
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 50410
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 2020, 32) | 0) != 0) {
  return;
 }
 if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
  _e68_exception_illegal($c); //@line 50425
  return;
 }
 $15 = $c + 372 | 0; //@line 50430
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 16; //@line 50433
 $18 = $c + 156 | 0; //@line 50434
 $19 = HEAP32[$18 >> 2] | 0; //@line 50435
 $20 = $c + 344 | 0; //@line 50436
 $21 = HEAP32[$20 >> 2] | 0; //@line 50437
 HEAP32[$18 >> 2] = $21; //@line 50438
 if (($21 & 1 | 0) != 0) {
  _e68_exception_address($c, $21, 0, 0); //@line 50443
  return;
 }
 $26 = $c + 164 | 0; //@line 50448
 $28 = $c + 162 | 0; //@line 50450
 HEAP16[$28 >> 1] = HEAP16[$26 >> 1] | 0; //@line 50451
 $29 = $21 & 16777215; //@line 50452
 $30 = $29 + 1 | 0; //@line 50453
 $31 = $c + 36 | 0; //@line 50454
 if ($30 >>> 0 < (HEAP32[$31 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 50460
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 50470
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 50478
 }
 HEAP16[$26 >> 1] = $_0_i_i; //@line 50481
 $51 = $c + 336 | 0; //@line 50482
 if ((HEAP8[$51] | 0) != 0) {
  _e68_exception_bus($c); //@line 50487
  return;
 }
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 50494
 $58 = $c + 152 | 0; //@line 50495
 HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 50498
 $61 = $19 - 2 | 0; //@line 50499
 $62 = $c + 148 | 0; //@line 50500
 $64 = (HEAP32[$62 >> 2] | 0) - 4 | 0; //@line 50502
 $65 = $64 & 16777215; //@line 50503
 $66 = $65 + 3 | 0; //@line 50504
 if ($66 >>> 0 < (HEAP32[$31 >> 2] | 0) >>> 0) {
  $72 = $c + 32 | 0; //@line 50511
  HEAP8[(HEAP32[$72 >> 2] | 0) + $65 | 0] = $61 >>> 24 & 255; //@line 50514
  HEAP8[(HEAP32[$72 >> 2] | 0) + ($65 + 1) | 0] = $61 >>> 16 & 255; //@line 50520
  HEAP8[(HEAP32[$72 >> 2] | 0) + ($65 + 2) | 0] = $61 >>> 8 & 255; //@line 50526
  HEAP8[(HEAP32[$72 >> 2] | 0) + $66 | 0] = $61 & 255; //@line 50530
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $65, $61); //@line 50537
 }
 HEAP32[$62 >> 2] = $64; //@line 50539
 $93 = HEAP32[$18 >> 2] | 0; //@line 50540
 if (($93 & 1 | 0) != 0) {
  _e68_exception_address($c, $93, 0, 0); //@line 50545
  return;
 }
 HEAP16[$28 >> 1] = HEAP16[$26 >> 1] | 0; //@line 50551
 $99 = $93 & 16777215; //@line 50552
 $100 = $99 + 1 | 0; //@line 50553
 if ($100 >>> 0 < (HEAP32[$31 >> 2] | 0) >>> 0) {
  $105 = HEAP32[$c + 32 >> 2] | 0; //@line 50559
  $_0_i_i12 = HEAPU8[$105 + $99 | 0] << 8 | HEAPU8[$105 + $100 | 0]; //@line 50569
 } else {
  $_0_i_i12 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $99) | 0; //@line 50577
 }
 HEAP16[$26 >> 1] = $_0_i_i12; //@line 50580
 if ((HEAP8[$51] | 0) == 0) {
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 50587
  HEAP32[$58 >> 2] = HEAP32[$20 >> 2]; //@line 50589
  return;
 } else {
  _e68_exception_bus($c); //@line 50594
  return;
 }
}
function _op4ec0($c) {
 $c = $c | 0;
 var $4 = 0, $15 = 0, $18 = 0, $19 = 0, $20 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $35 = 0, $50 = 0, $51 = 0, $57 = 0, $58 = 0, $65 = 0, $66 = 0, $70 = 0, $83 = 0, $phitmp = 0;
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 50619
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 2020, 32) | 0) != 0) {
  return;
 }
 if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
  _e68_exception_illegal($c); //@line 50634
  return;
 }
 $15 = $c + 372 | 0; //@line 50639
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 8; //@line 50642
 $18 = $c + 344 | 0; //@line 50643
 $19 = HEAP32[$18 >> 2] | 0; //@line 50644
 $20 = $c + 156 | 0; //@line 50645
 HEAP32[$20 >> 2] = $19; //@line 50646
 if (($19 & 1 | 0) != 0) {
  _e68_exception_address($c, $19, 0, 0); //@line 50651
  return;
 }
 $25 = $c + 164 | 0; //@line 50656
 $27 = $c + 162 | 0; //@line 50658
 HEAP16[$27 >> 1] = HEAP16[$25 >> 1] | 0; //@line 50659
 $28 = $19 & 16777215; //@line 50660
 $29 = $28 + 1 | 0; //@line 50661
 $30 = $c + 36 | 0; //@line 50662
 if ($29 >>> 0 < (HEAP32[$30 >> 2] | 0) >>> 0) {
  $35 = HEAP32[$c + 32 >> 2] | 0; //@line 50668
  $50 = HEAPU8[$35 + $28 | 0] << 8 | HEAPU8[$35 + $29 | 0]; //@line 50678
 } else {
  $50 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $28) | 0; //@line 50686
 }
 HEAP16[$25 >> 1] = $50; //@line 50689
 $51 = $c + 336 | 0; //@line 50690
 if ((HEAP8[$51] | 0) != 0) {
  _e68_exception_bus($c); //@line 50695
  return;
 }
 $57 = (HEAP32[$20 >> 2] | 0) + 2 | 0; //@line 50701
 HEAP32[$20 >> 2] = $57; //@line 50702
 $58 = $c + 152 | 0; //@line 50703
 HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 50706
 if (($57 & 1 | 0) != 0) {
  _e68_exception_address($c, $57, 0, 0); //@line 50711
  return;
 }
 HEAP16[$27 >> 1] = $50; //@line 50716
 $65 = $57 & 16777215; //@line 50717
 $66 = $65 + 1 | 0; //@line 50718
 do {
  if ($66 >>> 0 < (HEAP32[$30 >> 2] | 0) >>> 0) {
   $70 = HEAP32[$c + 32 >> 2] | 0; //@line 50725
   HEAP16[$25 >> 1] = HEAPU8[$70 + $65 | 0] << 8 | HEAPU8[$70 + $66 | 0]; //@line 50734
  } else {
   $83 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $65) | 0; //@line 50741
   $phitmp = (HEAP8[$51] | 0) == 0; //@line 50743
   HEAP16[$25 >> 1] = $83; //@line 50744
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 50749
   return;
  }
 } while (0);
 HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 50757
 HEAP32[$58 >> 2] = HEAP32[$18 >> 2]; //@line 50759
 return;
}
function _op5000($c) {
 $c = $c | 0;
 var $s2 = 0, $2 = 0, $5 = 0, $6 = 0, $_ = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $31 = 0, $37 = 0, $_0_i_i = 0, $59 = 0, sp = 0;
 sp = STACKTOP; //@line 50777
 STACKTOP = STACKTOP + 8 | 0; //@line 50777
 $s2 = sp | 0; //@line 50778
 $2 = HEAP16[$c + 160 >> 1] | 0; //@line 50780
 $5 = ($2 & 65535) >>> 9 & 7; //@line 50784
 $6 = $2 & 63; //@line 50785
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 50792
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 50799
  return;
 }
 $_ = $5 << 24 >> 24 == 0 ? 8 : $5; //@line 50803
 $16 = HEAP8[$s2] | 0; //@line 50804
 $17 = $16 + $_ & 255; //@line 50805
 $18 = $c + 372 | 0; //@line 50806
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 8; //@line 50809
 _e68_cc_set_add_8($c, $17, $_, $16); //@line 50810
 $21 = $c + 156 | 0; //@line 50811
 $22 = HEAP32[$21 >> 2] | 0; //@line 50812
 if (($22 & 1 | 0) != 0) {
  _e68_exception_address($c, $22, 0, 0); //@line 50817
  STACKTOP = sp; //@line 50819
  return;
 }
 $27 = $c + 164 | 0; //@line 50822
 HEAP16[$c + 162 >> 1] = HEAP16[$27 >> 1] | 0; //@line 50825
 $30 = $22 & 16777215; //@line 50826
 $31 = $30 + 1 | 0; //@line 50827
 if ($31 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $37 = HEAP32[$c + 32 >> 2] | 0; //@line 50834
  $_0_i_i = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 50844
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 50852
 }
 HEAP16[$27 >> 1] = $_0_i_i; //@line 50855
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 50863
  $59 = $c + 152 | 0; //@line 50864
  HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 50867
  _e68_ea_set_val8($c, $17) | 0; //@line 50868
  STACKTOP = sp; //@line 50870
  return;
 } else {
  _e68_exception_bus($c); //@line 50873
  STACKTOP = sp; //@line 50875
  return;
 }
}
function _op5040($c) {
 $c = $c | 0;
 var $s2 = 0, $2 = 0, $3 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $16 = 0, $17 = 0, $22 = 0, $25 = 0, $26 = 0, $32 = 0, $_0_i_i_i = 0, $54 = 0, $60 = 0, $61 = 0, $_ = 0, $71 = 0, $72 = 0, $73 = 0, $76 = 0, $77 = 0, $82 = 0, $85 = 0, $86 = 0, $92 = 0, $_0_i_i = 0, $114 = 0, sp = 0;
 sp = STACKTOP; //@line 50898
 STACKTOP = STACKTOP + 8 | 0; //@line 50898
 $s2 = sp | 0; //@line 50899
 $2 = HEAP16[$c + 160 >> 1] | 0; //@line 50901
 $3 = $2 & 65535; //@line 50902
 if (($3 & 56 | 0) == 8) {
  $9 = $3 >>> 9 & 7; //@line 50909
  $10 = $c + 120 + (($3 & 7) << 2) | 0; //@line 50910
  $11 = HEAP32[$10 >> 2] | 0; //@line 50911
  $13 = $c + 372 | 0; //@line 50914
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 50917
  $16 = $c + 156 | 0; //@line 50918
  $17 = HEAP32[$16 >> 2] | 0; //@line 50919
  if (($17 & 1 | 0) != 0) {
   _e68_exception_address($c, $17, 0, 0); //@line 50924
   STACKTOP = sp; //@line 50926
   return;
  }
  $22 = $c + 164 | 0; //@line 50929
  HEAP16[$c + 162 >> 1] = HEAP16[$22 >> 1] | 0; //@line 50932
  $25 = $17 & 16777215; //@line 50933
  $26 = $25 + 1 | 0; //@line 50934
  if ($26 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $32 = HEAP32[$c + 32 >> 2] | 0; //@line 50941
   $_0_i_i_i = HEAPU8[$32 + $25 | 0] << 8 | HEAPU8[$32 + $26 | 0]; //@line 50951
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $25) | 0; //@line 50959
  }
  HEAP16[$22 >> 1] = $_0_i_i_i; //@line 50962
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 2; //@line 50970
   $54 = $c + 152 | 0; //@line 50971
   HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 2; //@line 50974
   HEAP32[$10 >> 2] = $11 + (($9 | 0) == 0 ? 8 : $9); //@line 50976
   STACKTOP = sp; //@line 50978
   return;
  } else {
   _e68_exception_bus($c); //@line 50981
   STACKTOP = sp; //@line 50983
   return;
  }
 }
 $60 = ($2 & 65535) >>> 9 & 7; //@line 50988
 $61 = $3 & 63; //@line 50989
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($61 << 2) >> 2] & 127]($c, $61, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 50996
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 51003
  return;
 }
 $_ = $60 << 16 >> 16 == 0 ? 8 : $60; //@line 51007
 $71 = HEAP16[$s2 >> 1] | 0; //@line 51008
 $72 = $71 + $_ & 65535; //@line 51009
 $73 = $c + 372 | 0; //@line 51010
 HEAP32[$73 >> 2] = (HEAP32[$73 >> 2] | 0) + 8; //@line 51013
 _e68_cc_set_add_16($c, $72, $_, $71); //@line 51014
 $76 = $c + 156 | 0; //@line 51015
 $77 = HEAP32[$76 >> 2] | 0; //@line 51016
 if (($77 & 1 | 0) != 0) {
  _e68_exception_address($c, $77, 0, 0); //@line 51021
  STACKTOP = sp; //@line 51023
  return;
 }
 $82 = $c + 164 | 0; //@line 51026
 HEAP16[$c + 162 >> 1] = HEAP16[$82 >> 1] | 0; //@line 51029
 $85 = $77 & 16777215; //@line 51030
 $86 = $85 + 1 | 0; //@line 51031
 if ($86 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $92 = HEAP32[$c + 32 >> 2] | 0; //@line 51038
  $_0_i_i = HEAPU8[$92 + $85 | 0] << 8 | HEAPU8[$92 + $86 | 0]; //@line 51048
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $85) | 0; //@line 51056
 }
 HEAP16[$82 >> 1] = $_0_i_i; //@line 51059
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 51067
  $114 = $c + 152 | 0; //@line 51068
  HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 2; //@line 51071
  _e68_ea_set_val16($c, $72) | 0; //@line 51072
  STACKTOP = sp; //@line 51074
  return;
 } else {
  _e68_exception_bus($c); //@line 51077
  STACKTOP = sp; //@line 51079
  return;
 }
}
function _op5080($c) {
 $c = $c | 0;
 var $s2 = 0, $3 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $16 = 0, $17 = 0, $22 = 0, $25 = 0, $26 = 0, $32 = 0, $_0_i_i_i = 0, $54 = 0, $60 = 0, $61 = 0, $_ = 0, $71 = 0, $72 = 0, $73 = 0, $76 = 0, $77 = 0, $82 = 0, $85 = 0, $86 = 0, $92 = 0, $_0_i_i = 0, $114 = 0, sp = 0;
 sp = STACKTOP; //@line 51102
 STACKTOP = STACKTOP + 8 | 0; //@line 51102
 $s2 = sp | 0; //@line 51103
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 51106
 if (($3 & 56 | 0) == 8) {
  $9 = $3 >>> 9 & 7; //@line 51113
  $10 = $c + 120 + (($3 & 7) << 2) | 0; //@line 51114
  $11 = HEAP32[$10 >> 2] | 0; //@line 51115
  $13 = $c + 372 | 0; //@line 51118
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 12; //@line 51121
  $16 = $c + 156 | 0; //@line 51122
  $17 = HEAP32[$16 >> 2] | 0; //@line 51123
  if (($17 & 1 | 0) != 0) {
   _e68_exception_address($c, $17, 0, 0); //@line 51128
   STACKTOP = sp; //@line 51130
   return;
  }
  $22 = $c + 164 | 0; //@line 51133
  HEAP16[$c + 162 >> 1] = HEAP16[$22 >> 1] | 0; //@line 51136
  $25 = $17 & 16777215; //@line 51137
  $26 = $25 + 1 | 0; //@line 51138
  if ($26 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $32 = HEAP32[$c + 32 >> 2] | 0; //@line 51145
   $_0_i_i_i = HEAPU8[$32 + $25 | 0] << 8 | HEAPU8[$32 + $26 | 0]; //@line 51155
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $25) | 0; //@line 51163
  }
  HEAP16[$22 >> 1] = $_0_i_i_i; //@line 51166
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 2; //@line 51174
   $54 = $c + 152 | 0; //@line 51175
   HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 2; //@line 51178
   HEAP32[$10 >> 2] = $11 + (($9 | 0) == 0 ? 8 : $9); //@line 51180
   STACKTOP = sp; //@line 51182
   return;
  } else {
   _e68_exception_bus($c); //@line 51185
   STACKTOP = sp; //@line 51187
   return;
  }
 }
 $60 = $3 >>> 9 & 7; //@line 51192
 $61 = $3 & 63; //@line 51193
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($61 << 2) >> 2] & 127]($c, $61, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 51200
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 51207
  return;
 }
 $_ = ($60 | 0) == 0 ? 8 : $60; //@line 51211
 $71 = HEAP32[$s2 >> 2] | 0; //@line 51212
 $72 = $71 + $_ | 0; //@line 51213
 $73 = $c + 372 | 0; //@line 51214
 HEAP32[$73 >> 2] = (HEAP32[$73 >> 2] | 0) + 12; //@line 51217
 _e68_cc_set_add_32($c, $72, $_, $71); //@line 51218
 $76 = $c + 156 | 0; //@line 51219
 $77 = HEAP32[$76 >> 2] | 0; //@line 51220
 if (($77 & 1 | 0) != 0) {
  _e68_exception_address($c, $77, 0, 0); //@line 51225
  STACKTOP = sp; //@line 51227
  return;
 }
 $82 = $c + 164 | 0; //@line 51230
 HEAP16[$c + 162 >> 1] = HEAP16[$82 >> 1] | 0; //@line 51233
 $85 = $77 & 16777215; //@line 51234
 $86 = $85 + 1 | 0; //@line 51235
 if ($86 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $92 = HEAP32[$c + 32 >> 2] | 0; //@line 51242
  $_0_i_i = HEAPU8[$92 + $85 | 0] << 8 | HEAPU8[$92 + $86 | 0]; //@line 51252
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $85) | 0; //@line 51260
 }
 HEAP16[$82 >> 1] = $_0_i_i; //@line 51263
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 51271
  $114 = $c + 152 | 0; //@line 51272
  HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 2; //@line 51275
  _e68_ea_set_val32($c, $72) | 0; //@line 51276
  STACKTOP = sp; //@line 51278
  return;
 } else {
  _e68_exception_bus($c); //@line 51281
  STACKTOP = sp; //@line 51283
  return;
 }
}
function _op50c0($c) {
 $c = $c | 0;
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, 1); //@line 51300
  return;
 } else {
  _e68_op_scc($c, 1); //@line 51305
  return;
 }
}
function _op5100($c) {
 $c = $c | 0;
 var $s2 = 0, $2 = 0, $5 = 0, $6 = 0, $_ = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $31 = 0, $37 = 0, $_0_i_i = 0, $59 = 0, sp = 0;
 sp = STACKTOP; //@line 51323
 STACKTOP = STACKTOP + 8 | 0; //@line 51323
 $s2 = sp | 0; //@line 51324
 $2 = HEAP16[$c + 160 >> 1] | 0; //@line 51326
 $5 = ($2 & 65535) >>> 9 & 7; //@line 51330
 $6 = $2 & 63; //@line 51331
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 509, 8) | 0) != 0) {
  STACKTOP = sp; //@line 51338
  return;
 }
 if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 51345
  return;
 }
 $_ = $5 << 24 >> 24 == 0 ? 8 : $5; //@line 51349
 $16 = HEAP8[$s2] | 0; //@line 51350
 $17 = $16 - $_ & 255; //@line 51351
 $18 = $c + 372 | 0; //@line 51352
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 8; //@line 51355
 _e68_cc_set_sub_8($c, $17, $_, $16); //@line 51356
 $21 = $c + 156 | 0; //@line 51357
 $22 = HEAP32[$21 >> 2] | 0; //@line 51358
 if (($22 & 1 | 0) != 0) {
  _e68_exception_address($c, $22, 0, 0); //@line 51363
  STACKTOP = sp; //@line 51365
  return;
 }
 $27 = $c + 164 | 0; //@line 51368
 HEAP16[$c + 162 >> 1] = HEAP16[$27 >> 1] | 0; //@line 51371
 $30 = $22 & 16777215; //@line 51372
 $31 = $30 + 1 | 0; //@line 51373
 if ($31 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $37 = HEAP32[$c + 32 >> 2] | 0; //@line 51380
  $_0_i_i = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 51390
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 51398
 }
 HEAP16[$27 >> 1] = $_0_i_i; //@line 51401
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 51409
  $59 = $c + 152 | 0; //@line 51410
  HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 51413
  _e68_ea_set_val8($c, $17) | 0; //@line 51414
  STACKTOP = sp; //@line 51416
  return;
 } else {
  _e68_exception_bus($c); //@line 51419
  STACKTOP = sp; //@line 51421
  return;
 }
}
function _op5140($c) {
 $c = $c | 0;
 var $s2 = 0, $2 = 0, $3 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $16 = 0, $17 = 0, $22 = 0, $25 = 0, $26 = 0, $32 = 0, $_0_i_i_i = 0, $54 = 0, $60 = 0, $61 = 0, $_ = 0, $71 = 0, $72 = 0, $73 = 0, $76 = 0, $77 = 0, $82 = 0, $85 = 0, $86 = 0, $92 = 0, $_0_i_i = 0, $114 = 0, sp = 0;
 sp = STACKTOP; //@line 51444
 STACKTOP = STACKTOP + 8 | 0; //@line 51444
 $s2 = sp | 0; //@line 51445
 $2 = HEAP16[$c + 160 >> 1] | 0; //@line 51447
 $3 = $2 & 65535; //@line 51448
 if (($3 & 56 | 0) == 8) {
  $9 = $3 >>> 9 & 7; //@line 51455
  $10 = $c + 120 + (($3 & 7) << 2) | 0; //@line 51456
  $11 = HEAP32[$10 >> 2] | 0; //@line 51457
  $13 = $c + 372 | 0; //@line 51460
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 51463
  $16 = $c + 156 | 0; //@line 51464
  $17 = HEAP32[$16 >> 2] | 0; //@line 51465
  if (($17 & 1 | 0) != 0) {
   _e68_exception_address($c, $17, 0, 0); //@line 51470
   STACKTOP = sp; //@line 51472
   return;
  }
  $22 = $c + 164 | 0; //@line 51475
  HEAP16[$c + 162 >> 1] = HEAP16[$22 >> 1] | 0; //@line 51478
  $25 = $17 & 16777215; //@line 51479
  $26 = $25 + 1 | 0; //@line 51480
  if ($26 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $32 = HEAP32[$c + 32 >> 2] | 0; //@line 51487
   $_0_i_i_i = HEAPU8[$32 + $25 | 0] << 8 | HEAPU8[$32 + $26 | 0]; //@line 51497
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $25) | 0; //@line 51505
  }
  HEAP16[$22 >> 1] = $_0_i_i_i; //@line 51508
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 2; //@line 51516
   $54 = $c + 152 | 0; //@line 51517
   HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 2; //@line 51520
   HEAP32[$10 >> 2] = $11 - (($9 | 0) == 0 ? 8 : $9); //@line 51522
   STACKTOP = sp; //@line 51524
   return;
  } else {
   _e68_exception_bus($c); //@line 51527
   STACKTOP = sp; //@line 51529
   return;
  }
 }
 $60 = ($2 & 65535) >>> 9 & 7; //@line 51534
 $61 = $3 & 63; //@line 51535
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($61 << 2) >> 2] & 127]($c, $61, 509, 16) | 0) != 0) {
  STACKTOP = sp; //@line 51542
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 51549
  return;
 }
 $_ = $60 << 16 >> 16 == 0 ? 8 : $60; //@line 51553
 $71 = HEAP16[$s2 >> 1] | 0; //@line 51554
 $72 = $71 - $_ & 65535; //@line 51555
 $73 = $c + 372 | 0; //@line 51556
 HEAP32[$73 >> 2] = (HEAP32[$73 >> 2] | 0) + 8; //@line 51559
 _e68_cc_set_sub_16($c, $72, $_, $71); //@line 51560
 $76 = $c + 156 | 0; //@line 51561
 $77 = HEAP32[$76 >> 2] | 0; //@line 51562
 if (($77 & 1 | 0) != 0) {
  _e68_exception_address($c, $77, 0, 0); //@line 51567
  STACKTOP = sp; //@line 51569
  return;
 }
 $82 = $c + 164 | 0; //@line 51572
 HEAP16[$c + 162 >> 1] = HEAP16[$82 >> 1] | 0; //@line 51575
 $85 = $77 & 16777215; //@line 51576
 $86 = $85 + 1 | 0; //@line 51577
 if ($86 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $92 = HEAP32[$c + 32 >> 2] | 0; //@line 51584
  $_0_i_i = HEAPU8[$92 + $85 | 0] << 8 | HEAPU8[$92 + $86 | 0]; //@line 51594
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $85) | 0; //@line 51602
 }
 HEAP16[$82 >> 1] = $_0_i_i; //@line 51605
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 51613
  $114 = $c + 152 | 0; //@line 51614
  HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 2; //@line 51617
  _e68_ea_set_val16($c, $72) | 0; //@line 51618
  STACKTOP = sp; //@line 51620
  return;
 } else {
  _e68_exception_bus($c); //@line 51623
  STACKTOP = sp; //@line 51625
  return;
 }
}
function _op5180($c) {
 $c = $c | 0;
 var $s2 = 0, $3 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $16 = 0, $17 = 0, $22 = 0, $25 = 0, $26 = 0, $32 = 0, $_0_i_i_i = 0, $54 = 0, $60 = 0, $61 = 0, $_ = 0, $71 = 0, $72 = 0, $73 = 0, $76 = 0, $77 = 0, $82 = 0, $85 = 0, $86 = 0, $92 = 0, $_0_i_i = 0, $114 = 0, sp = 0;
 sp = STACKTOP; //@line 51648
 STACKTOP = STACKTOP + 8 | 0; //@line 51648
 $s2 = sp | 0; //@line 51649
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 51652
 if (($3 & 56 | 0) == 8) {
  $9 = $3 >>> 9 & 7; //@line 51659
  $10 = $c + 120 + (($3 & 7) << 2) | 0; //@line 51660
  $11 = HEAP32[$10 >> 2] | 0; //@line 51661
  $13 = $c + 372 | 0; //@line 51664
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 12; //@line 51667
  $16 = $c + 156 | 0; //@line 51668
  $17 = HEAP32[$16 >> 2] | 0; //@line 51669
  if (($17 & 1 | 0) != 0) {
   _e68_exception_address($c, $17, 0, 0); //@line 51674
   STACKTOP = sp; //@line 51676
   return;
  }
  $22 = $c + 164 | 0; //@line 51679
  HEAP16[$c + 162 >> 1] = HEAP16[$22 >> 1] | 0; //@line 51682
  $25 = $17 & 16777215; //@line 51683
  $26 = $25 + 1 | 0; //@line 51684
  if ($26 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $32 = HEAP32[$c + 32 >> 2] | 0; //@line 51691
   $_0_i_i_i = HEAPU8[$32 + $25 | 0] << 8 | HEAPU8[$32 + $26 | 0]; //@line 51701
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $25) | 0; //@line 51709
  }
  HEAP16[$22 >> 1] = $_0_i_i_i; //@line 51712
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + 2; //@line 51720
   $54 = $c + 152 | 0; //@line 51721
   HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 2; //@line 51724
   HEAP32[$10 >> 2] = $11 - (($9 | 0) == 0 ? 8 : $9); //@line 51726
   STACKTOP = sp; //@line 51728
   return;
  } else {
   _e68_exception_bus($c); //@line 51731
   STACKTOP = sp; //@line 51733
   return;
  }
 }
 $60 = $3 >>> 9 & 7; //@line 51738
 $61 = $3 & 63; //@line 51739
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($61 << 2) >> 2] & 127]($c, $61, 509, 32) | 0) != 0) {
  STACKTOP = sp; //@line 51746
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 51753
  return;
 }
 $_ = ($60 | 0) == 0 ? 8 : $60; //@line 51757
 $71 = HEAP32[$s2 >> 2] | 0; //@line 51758
 $72 = $71 - $_ | 0; //@line 51759
 $73 = $c + 372 | 0; //@line 51760
 HEAP32[$73 >> 2] = (HEAP32[$73 >> 2] | 0) + 12; //@line 51763
 _e68_cc_set_sub_32($c, $72, $_, $71); //@line 51764
 $76 = $c + 156 | 0; //@line 51765
 $77 = HEAP32[$76 >> 2] | 0; //@line 51766
 if (($77 & 1 | 0) != 0) {
  _e68_exception_address($c, $77, 0, 0); //@line 51771
  STACKTOP = sp; //@line 51773
  return;
 }
 $82 = $c + 164 | 0; //@line 51776
 HEAP16[$c + 162 >> 1] = HEAP16[$82 >> 1] | 0; //@line 51779
 $85 = $77 & 16777215; //@line 51780
 $86 = $85 + 1 | 0; //@line 51781
 if ($86 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $92 = HEAP32[$c + 32 >> 2] | 0; //@line 51788
  $_0_i_i = HEAPU8[$92 + $85 | 0] << 8 | HEAPU8[$92 + $86 | 0]; //@line 51798
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $85) | 0; //@line 51806
 }
 HEAP16[$82 >> 1] = $_0_i_i; //@line 51809
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 51817
  $114 = $c + 152 | 0; //@line 51818
  HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 2; //@line 51821
  _e68_ea_set_val32($c, $72) | 0; //@line 51822
  STACKTOP = sp; //@line 51824
  return;
 } else {
  _e68_exception_bus($c); //@line 51827
  STACKTOP = sp; //@line 51829
  return;
 }
}
function _op51c0($c) {
 $c = $c | 0;
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, 0); //@line 51846
  return;
 } else {
  _e68_op_scc($c, 0); //@line 51851
  return;
 }
}
function _op52c0($c) {
 $c = $c | 0;
 var $3 = 0, $10 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 51866
 if (($3 & 1 | 0) == 0) {
  $10 = $3 >>> 2 & 1 ^ 1; //@line 51874
 } else {
  $10 = 0; //@line 51876
 }
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $10); //@line 51885
  return;
 } else {
  _e68_op_scc($c, $10); //@line 51890
  return;
 }
}
function _op53c0($c) {
 $c = $c | 0;
 var $3 = 0, $9 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 51905
 if (($3 & 1 | 0) == 0) {
  $9 = $3 >>> 2 & 1; //@line 51913
 } else {
  $9 = 1; //@line 51915
 }
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $9); //@line 51924
  return;
 } else {
  _e68_op_scc($c, $9); //@line 51929
  return;
 }
}
function _op54c0($c) {
 $c = $c | 0;
 var $5 = 0;
 $5 = (HEAP16[$c + 166 >> 1] & 1 ^ 1) & 65535; //@line 51946
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $5); //@line 51953
  return;
 } else {
  _e68_op_scc($c, $5); //@line 51958
  return;
 }
}
function _op55c0($c) {
 $c = $c | 0;
 var $4 = 0;
 $4 = HEAP16[$c + 166 >> 1] & 1; //@line 51973
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $4); //@line 51980
  return;
 } else {
  _e68_op_scc($c, $4); //@line 51985
  return;
 }
}
function _op56c0($c) {
 $c = $c | 0;
 var $5 = 0;
 $5 = ((HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1 ^ 1) & 65535; //@line 52003
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $5); //@line 52010
  return;
 } else {
  _e68_op_scc($c, $5); //@line 52015
  return;
 }
}
function _op57c0($c) {
 $c = $c | 0;
 var $4 = 0;
 $4 = (HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1; //@line 52032
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $4); //@line 52039
  return;
 } else {
  _e68_op_scc($c, $4); //@line 52044
  return;
 }
}
function _op58c0($c) {
 $c = $c | 0;
 var $5 = 0;
 $5 = ((HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1 ^ 1) & 65535; //@line 52062
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $5); //@line 52069
  return;
 } else {
  _e68_op_scc($c, $5); //@line 52074
  return;
 }
}
function _op59c0($c) {
 $c = $c | 0;
 var $4 = 0;
 $4 = (HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1; //@line 52091
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $4); //@line 52098
  return;
 } else {
  _e68_op_scc($c, $4); //@line 52103
  return;
 }
}
function _op5ac0($c) {
 $c = $c | 0;
 var $5 = 0;
 $5 = ((HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1 ^ 1) & 65535; //@line 52121
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $5); //@line 52128
  return;
 } else {
  _e68_op_scc($c, $5); //@line 52133
  return;
 }
}
function _op5bc0($c) {
 $c = $c | 0;
 var $4 = 0;
 $4 = (HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1; //@line 52150
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $4); //@line 52157
  return;
 } else {
  _e68_op_scc($c, $4); //@line 52162
  return;
 }
}
function _op5cc0($c) {
 $c = $c | 0;
 var $3 = 0, $8 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52177
 $8 = ($3 >>> 3 ^ $3 >>> 1) & 1 ^ 1; //@line 52182
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $8); //@line 52189
  return;
 } else {
  _e68_op_scc($c, $8); //@line 52194
  return;
 }
}
function _op5dc0($c) {
 $c = $c | 0;
 var $3 = 0, $7 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52209
 $7 = ($3 >>> 3 ^ $3 >>> 1) & 1; //@line 52213
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $7); //@line 52220
  return;
 } else {
  _e68_op_scc($c, $7); //@line 52225
  return;
 }
}
function _op5ec0($c) {
 $c = $c | 0;
 var $3 = 0, $13 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52240
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) == 0) {
  $13 = $3 >>> 2 & 1 ^ 1; //@line 52251
 } else {
  $13 = 0; //@line 52253
 }
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $13); //@line 52262
  return;
 } else {
  _e68_op_scc($c, $13); //@line 52267
  return;
 }
}
function _op5fc0($c) {
 $c = $c | 0;
 var $3 = 0, $12 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52282
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) == 0) {
  $12 = $3 >>> 2 & 1; //@line 52293
 } else {
  $12 = 1; //@line 52295
 }
 if ((HEAP16[$c + 160 >> 1] & 56) == 8) {
  _e68_op_dbcc($c, $12); //@line 52304
  return;
 } else {
  _e68_op_scc($c, $12); //@line 52309
  return;
 }
}
function _op6000($c) {
 $c = $c | 0;
 _e68_op_bcc($c, 1); //@line 52320
 return;
}
function _op6100($c) {
 $c = $c | 0;
 var $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $20 = 0;
 $8 = ((HEAP16[$c + 160 >> 1] & 255) != 0 ? 2 : 4) + (HEAP32[$c + 152 >> 2] | 0) | 0; //@line 52342
 $9 = $c + 148 | 0; //@line 52343
 $11 = (HEAP32[$9 >> 2] | 0) - 4 | 0; //@line 52345
 $12 = $11 & 16777215; //@line 52346
 $13 = $12 + 3 | 0; //@line 52347
 if ($13 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $20 = $c + 32 | 0; //@line 52355
  HEAP8[(HEAP32[$20 >> 2] | 0) + $12 | 0] = $8 >>> 24 & 255; //@line 52358
  HEAP8[(HEAP32[$20 >> 2] | 0) + ($12 + 1) | 0] = $8 >>> 16 & 255; //@line 52364
  HEAP8[(HEAP32[$20 >> 2] | 0) + ($12 + 2) | 0] = $8 >>> 8 & 255; //@line 52370
  HEAP8[(HEAP32[$20 >> 2] | 0) + $13 | 0] = $8 & 255; //@line 52374
  HEAP32[$9 >> 2] = $11; //@line 52376
  _e68_op_bcc($c, 1); //@line 52377
  return;
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $12, $8); //@line 52385
  HEAP32[$9 >> 2] = $11; //@line 52386
  _e68_op_bcc($c, 1); //@line 52387
  return;
 }
}
function _op6200($c) {
 $c = $c | 0;
 var $3 = 0, $10 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52402
 if (($3 & 1 | 0) != 0) {
  $10 = 0; //@line 52407
  _e68_op_bcc($c, $10); //@line 52409
  return;
 }
 $10 = $3 >>> 2 & 1 ^ 1; //@line 52416
 _e68_op_bcc($c, $10); //@line 52418
 return;
}
function _op6300($c) {
 $c = $c | 0;
 var $3 = 0, $9 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52431
 if (($3 & 1 | 0) != 0) {
  $9 = 1; //@line 52436
  _e68_op_bcc($c, $9); //@line 52438
  return;
 }
 $9 = $3 >>> 2 & 1; //@line 52445
 _e68_op_bcc($c, $9); //@line 52447
 return;
}
function _op6400($c) {
 $c = $c | 0;
 _e68_op_bcc($c, (HEAP16[$c + 166 >> 1] & 1 ^ 1) & 65535); //@line 52463
 return;
}
function _op6500($c) {
 $c = $c | 0;
 _e68_op_bcc($c, HEAP16[$c + 166 >> 1] & 1); //@line 52478
 return;
}
function _op6600($c) {
 $c = $c | 0;
 _e68_op_bcc($c, ((HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1 ^ 1) & 65535); //@line 52495
 return;
}
function _op6700($c) {
 $c = $c | 0;
 _e68_op_bcc($c, (HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1); //@line 52511
 return;
}
function _op6800($c) {
 $c = $c | 0;
 _e68_op_bcc($c, ((HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1 ^ 1) & 65535); //@line 52528
 return;
}
function _op6900($c) {
 $c = $c | 0;
 _e68_op_bcc($c, (HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1); //@line 52544
 return;
}
function _op6a00($c) {
 $c = $c | 0;
 _e68_op_bcc($c, ((HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1 ^ 1) & 65535); //@line 52561
 return;
}
function _op6b00($c) {
 $c = $c | 0;
 _e68_op_bcc($c, (HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1); //@line 52577
 return;
}
function _op6c00($c) {
 $c = $c | 0;
 var $3 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52590
 _e68_op_bcc($c, ($3 >>> 3 ^ $3 >>> 1) & 1 ^ 1); //@line 52596
 return;
}
function _op6d00($c) {
 $c = $c | 0;
 var $3 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52609
 _e68_op_bcc($c, ($3 >>> 3 ^ $3 >>> 1) & 1); //@line 52614
 return;
}
function _op6e00($c) {
 $c = $c | 0;
 var $3 = 0, $13 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52628
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) != 0) {
  $13 = 0; //@line 52636
  _e68_op_bcc($c, $13); //@line 52638
  return;
 }
 $13 = $3 >>> 2 & 1 ^ 1; //@line 52645
 _e68_op_bcc($c, $13); //@line 52647
 return;
}
function _op6f00($c) {
 $c = $c | 0;
 var $3 = 0, $12 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 52661
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) != 0) {
  $12 = 1; //@line 52669
  _e68_op_bcc($c, $12); //@line 52671
  return;
 }
 $12 = $3 >>> 2 & 1; //@line 52678
 _e68_op_bcc($c, $12); //@line 52680
 return;
}
function _op7000($c) {
 $c = $c | 0;
 var $1 = 0, $3 = 0, $8 = 0, $9 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0;
 $1 = $c + 160 | 0; //@line 52697
 $3 = HEAPU16[$1 >> 1] | 0; //@line 52699
 $8 = ($3 & 128 | 0) != 0 ? $3 | -256 : $3 & 255; //@line 52704
 $9 = $c + 372 | 0; //@line 52705
 HEAP32[$9 >> 2] = (HEAP32[$9 >> 2] | 0) + 4; //@line 52708
 _e68_cc_set_nz_32($c, 15, $8); //@line 52709
 HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] = $8; //@line 52715
 $17 = $c + 156 | 0; //@line 52716
 $18 = HEAP32[$17 >> 2] | 0; //@line 52717
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 52722
  return;
 }
 $23 = $c + 164 | 0; //@line 52727
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 52730
 $26 = $18 & 16777215; //@line 52731
 $27 = $26 + 1 | 0; //@line 52732
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 52739
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 52749
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 52757
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 52760
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 52768
  $55 = $c + 152 | 0; //@line 52769
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 52772
  return;
 } else {
  _e68_exception_bus($c); //@line 52777
  return;
 }
}
function _op8000($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $19 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 52796
 STACKTOP = STACKTOP + 8 | 0; //@line 52796
 $s1 = sp | 0; //@line 52797
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 52800
 $6 = $3 & 63; //@line 52803
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 8) | 0) != 0) {
  STACKTOP = sp; //@line 52810
  return;
 }
 if ((_e68_ea_get_val8($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 52817
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 52820
 $19 = HEAPU8[$s1] | HEAP32[$15 >> 2]; //@line 52824
 $21 = $c + 372 | 0; //@line 52826
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 8; //@line 52829
 _e68_cc_set_nz_8($c, 15, $19 & 255); //@line 52830
 $24 = $c + 156 | 0; //@line 52831
 $25 = HEAP32[$24 >> 2] | 0; //@line 52832
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 52837
  STACKTOP = sp; //@line 52839
  return;
 }
 $30 = $c + 164 | 0; //@line 52842
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 52845
 $33 = $25 & 16777215; //@line 52846
 $34 = $33 + 1 | 0; //@line 52847
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 52854
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 52864
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 52872
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 52875
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 52883
  $62 = $c + 152 | 0; //@line 52884
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 52887
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -256 | $19 & 255; //@line 52892
  STACKTOP = sp; //@line 52894
  return;
 } else {
  _e68_exception_bus($c); //@line 52897
  STACKTOP = sp; //@line 52899
  return;
 }
}
function _op8040($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $19 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 52916
 STACKTOP = STACKTOP + 8 | 0; //@line 52916
 $s1 = sp | 0; //@line 52917
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 52920
 $6 = $3 & 63; //@line 52923
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 52930
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 52937
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 52940
 $19 = HEAPU16[$s1 >> 1] | HEAP32[$15 >> 2]; //@line 52944
 $21 = $c + 372 | 0; //@line 52946
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 8; //@line 52949
 _e68_cc_set_nz_16($c, 15, $19 & 65535); //@line 52950
 $24 = $c + 156 | 0; //@line 52951
 $25 = HEAP32[$24 >> 2] | 0; //@line 52952
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 52957
  STACKTOP = sp; //@line 52959
  return;
 }
 $30 = $c + 164 | 0; //@line 52962
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 52965
 $33 = $25 & 16777215; //@line 52966
 $34 = $33 + 1 | 0; //@line 52967
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 52974
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 52984
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 52992
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 52995
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 53003
  $62 = $c + 152 | 0; //@line 53004
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 53007
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -65536 | $19 & 65535; //@line 53012
  STACKTOP = sp; //@line 53014
  return;
 } else {
  _e68_exception_bus($c); //@line 53017
  STACKTOP = sp; //@line 53019
  return;
 }
}
function _op8080($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 53035
 STACKTOP = STACKTOP + 8 | 0; //@line 53035
 $s1 = sp | 0; //@line 53036
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 53039
 $6 = $3 & 63; //@line 53042
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 32) | 0) != 0) {
  STACKTOP = sp; //@line 53049
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 53056
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 53059
 $18 = HEAP32[$s1 >> 2] | HEAP32[$15 >> 2]; //@line 53062
 $19 = $c + 372 | 0; //@line 53063
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 10; //@line 53066
 _e68_cc_set_nz_32($c, 15, $18); //@line 53067
 $22 = $c + 156 | 0; //@line 53068
 $23 = HEAP32[$22 >> 2] | 0; //@line 53069
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 53074
  STACKTOP = sp; //@line 53076
  return;
 }
 $28 = $c + 164 | 0; //@line 53079
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 53082
 $31 = $23 & 16777215; //@line 53083
 $32 = $31 + 1 | 0; //@line 53084
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 53091
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 53101
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 53109
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 53112
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 53120
  $60 = $c + 152 | 0; //@line 53121
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 53124
  HEAP32[$15 >> 2] = $18; //@line 53125
  STACKTOP = sp; //@line 53127
  return;
 } else {
  _e68_exception_bus($c); //@line 53130
  STACKTOP = sp; //@line 53132
  return;
 }
}
function _op80c0($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $31 = 0, $37 = 0, $_0_i_i = 0, $59 = 0, $63 = 0, $66 = 0, $77 = 0, $80 = 0, $81 = 0, $86 = 0, $89 = 0, $90 = 0, $96 = 0, $_0_i_i16 = 0, $118 = 0, sp = 0;
 sp = STACKTOP; //@line 53154
 STACKTOP = STACKTOP + 8 | 0; //@line 53154
 $s1 = sp | 0; //@line 53155
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 53158
 $6 = $3 & 63; //@line 53161
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 53168
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 53175
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 53178
 $16 = HEAP32[$15 >> 2] | 0; //@line 53179
 $17 = HEAP16[$s1 >> 1] | 0; //@line 53180
 $18 = $17 & 65535; //@line 53181
 if ($17 << 16 >> 16 == 0) {
  $21 = $c + 156 | 0; //@line 53185
  $22 = HEAP32[$21 >> 2] | 0; //@line 53186
  if (($22 & 1 | 0) != 0) {
   _e68_exception_address($c, $22, 0, 0); //@line 53191
   STACKTOP = sp; //@line 53193
   return;
  }
  $27 = $c + 164 | 0; //@line 53196
  HEAP16[$c + 162 >> 1] = HEAP16[$27 >> 1] | 0; //@line 53199
  $30 = $22 & 16777215; //@line 53200
  $31 = $30 + 1 | 0; //@line 53201
  if ($31 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $37 = HEAP32[$c + 32 >> 2] | 0; //@line 53208
   $_0_i_i = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 53218
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 53226
  }
  HEAP16[$27 >> 1] = $_0_i_i; //@line 53229
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 53237
   $59 = $c + 152 | 0; //@line 53238
   HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 53241
   _e68_exception_divzero($c); //@line 53242
   STACKTOP = sp; //@line 53244
   return;
  } else {
   _e68_exception_bus($c); //@line 53247
   STACKTOP = sp; //@line 53249
   return;
  }
 }
 $63 = ($16 >>> 0) / ($18 >>> 0) | 0; //@line 53253
 if ($63 >>> 0 > 65535) {
  $66 = $c + 166 | 0; //@line 53257
  HEAP16[$66 >> 1] = HEAP16[$66 >> 1] & -4 | 2; //@line 53261
 } else {
  HEAP32[$15 >> 2] = (($16 >>> 0) % ($18 >>> 0) | 0) << 16 | $63 & 65535; //@line 53268
  _e68_cc_set_nz_16($c, 15, $63 & 65535); //@line 53270
 }
 $77 = $c + 372 | 0; //@line 53272
 HEAP32[$77 >> 2] = (HEAP32[$77 >> 2] | 0) + 144; //@line 53275
 $80 = $c + 156 | 0; //@line 53276
 $81 = HEAP32[$80 >> 2] | 0; //@line 53277
 if (($81 & 1 | 0) != 0) {
  _e68_exception_address($c, $81, 0, 0); //@line 53282
  STACKTOP = sp; //@line 53284
  return;
 }
 $86 = $c + 164 | 0; //@line 53287
 HEAP16[$c + 162 >> 1] = HEAP16[$86 >> 1] | 0; //@line 53290
 $89 = $81 & 16777215; //@line 53291
 $90 = $89 + 1 | 0; //@line 53292
 if ($90 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $96 = HEAP32[$c + 32 >> 2] | 0; //@line 53299
  $_0_i_i16 = HEAPU8[$96 + $89 | 0] << 8 | HEAPU8[$96 + $90 | 0]; //@line 53309
 } else {
  $_0_i_i16 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $89) | 0; //@line 53317
 }
 HEAP16[$86 >> 1] = $_0_i_i16; //@line 53320
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$80 >> 2] = (HEAP32[$80 >> 2] | 0) + 2; //@line 53328
  $118 = $c + 152 | 0; //@line 53329
  HEAP32[$118 >> 2] = (HEAP32[$118 >> 2] | 0) + 2; //@line 53332
  STACKTOP = sp; //@line 53334
  return;
 } else {
  _e68_exception_bus($c); //@line 53337
  STACKTOP = sp; //@line 53339
  return;
 }
}
function _op8100($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $7 = 0, $9 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $32 = 0, $34 = 0, $37 = 0, $38 = 0, $40 = 0, $d_0_i = 0, $_d_0_i = 0, $49 = 0, $52 = 0, $storemerge_i = 0, $60 = 0, $61 = 0, $66 = 0, $69 = 0, $70 = 0, $76 = 0, $_0_i_i_i = 0, $98 = 0, $101 = 0, $107 = 0, $108 = 0, $120 = 0, $121 = 0, $124 = 0, $125 = 0, $130 = 0, $133 = 0, $134 = 0, $140 = 0, $_0_i_i = 0, $162 = 0, sp = 0;
 sp = STACKTOP; //@line 53368
 STACKTOP = STACKTOP + 24 | 0; //@line 53368
 $s1_i = sp | 0; //@line 53369
 $s2_i = sp + 8 | 0; //@line 53370
 $s2 = sp + 16 | 0; //@line 53371
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 53374
 if (($3 & 48 | 0) != 0) {
  $107 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 53382
  $108 = $3 & 63; //@line 53383
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($108 << 2) >> 2] & 127]($c, $108, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 53390
   return;
  }
  if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 53397
   return;
  }
  $120 = (HEAPU8[$s2] | $107) & 255; //@line 53403
  $121 = $c + 372 | 0; //@line 53404
  HEAP32[$121 >> 2] = (HEAP32[$121 >> 2] | 0) + 8; //@line 53407
  _e68_cc_set_nz_8($c, 15, $120); //@line 53408
  $124 = $c + 156 | 0; //@line 53409
  $125 = HEAP32[$124 >> 2] | 0; //@line 53410
  if (($125 & 1 | 0) != 0) {
   _e68_exception_address($c, $125, 0, 0); //@line 53415
   STACKTOP = sp; //@line 53417
   return;
  }
  $130 = $c + 164 | 0; //@line 53420
  HEAP16[$c + 162 >> 1] = HEAP16[$130 >> 1] | 0; //@line 53423
  $133 = $125 & 16777215; //@line 53424
  $134 = $133 + 1 | 0; //@line 53425
  if ($134 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $140 = HEAP32[$c + 32 >> 2] | 0; //@line 53432
   $_0_i_i = HEAPU8[$140 + $133 | 0] << 8 | HEAPU8[$140 + $134 | 0]; //@line 53442
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $133) | 0; //@line 53450
  }
  HEAP16[$130 >> 1] = $_0_i_i; //@line 53453
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$124 >> 2] = (HEAP32[$124 >> 2] | 0) + 2; //@line 53461
   $162 = $c + 152 | 0; //@line 53462
   HEAP32[$162 >> 2] = (HEAP32[$162 >> 2] | 0) + 2; //@line 53465
   _e68_ea_set_val8($c, $120) | 0; //@line 53466
   STACKTOP = sp; //@line 53468
   return;
  } else {
   _e68_exception_bus($c); //@line 53471
   STACKTOP = sp; //@line 53473
   return;
  }
 }
 $7 = $3 & 7; //@line 53477
 $9 = $3 >>> 9 & 7; //@line 53479
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $9;
  $ea1_0_i = $7;
 } else {
  $ea2_0_i = $9 | 32;
  $ea1_0_i = $7 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 53499
  return;
 }
 if ((_e68_ea_get_val8($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 53506
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 53515
  return;
 }
 if ((_e68_ea_get_val8($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 53522
  return;
 }
 $32 = HEAP8[$s2_i] | 0; //@line 53525
 $34 = HEAP8[$s1_i] | 0; //@line 53527
 $37 = $c + 166 | 0; //@line 53530
 $38 = HEAP16[$37 >> 1] | 0; //@line 53531
 $40 = (($32 & 255) - ($34 & 255) & 65535) - (($38 & 65535) >>> 4 & 1) & 65535; //@line 53534
 $d_0_i = ($32 & 15) >>> 0 < ($34 & 15) >>> 0 ? $40 - 6 & 65535 : $40; //@line 53541
 $_d_0_i = ($d_0_i & 65535) > 159 ? $d_0_i - 96 & 65535 : $d_0_i; //@line 53544
 $49 = $c + 372 | 0; //@line 53545
 HEAP32[$49 >> 2] = (HEAP32[$49 >> 2] | 0) + 10; //@line 53548
 $52 = $_d_0_i & 65535; //@line 53549
 $storemerge_i = ($52 & 65280 | 0) == 0 ? $38 & -18 : $38 | 17; //@line 53554
 HEAP16[$37 >> 1] = ($52 & 255 | 0) == 0 ? $storemerge_i : $storemerge_i & -5; //@line 53559
 $60 = $c + 156 | 0; //@line 53560
 $61 = HEAP32[$60 >> 2] | 0; //@line 53561
 if (($61 & 1 | 0) != 0) {
  _e68_exception_address($c, $61, 0, 0); //@line 53566
  STACKTOP = sp; //@line 53568
  return;
 }
 $66 = $c + 164 | 0; //@line 53571
 HEAP16[$c + 162 >> 1] = HEAP16[$66 >> 1] | 0; //@line 53574
 $69 = $61 & 16777215; //@line 53575
 $70 = $69 + 1 | 0; //@line 53576
 if ($70 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $76 = HEAP32[$c + 32 >> 2] | 0; //@line 53583
  $_0_i_i_i = HEAPU8[$76 + $69 | 0] << 8 | HEAPU8[$76 + $70 | 0]; //@line 53593
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $69) | 0; //@line 53601
 }
 HEAP16[$66 >> 1] = $_0_i_i_i; //@line 53604
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 53612
  $98 = $c + 152 | 0; //@line 53613
  HEAP32[$98 >> 2] = (HEAP32[$98 >> 2] | 0) + 2; //@line 53616
  $101 = $_d_0_i & 255; //@line 53617
  _e68_ea_set_val8($c, $101) | 0; //@line 53618
  STACKTOP = sp; //@line 53620
  return;
 } else {
  _e68_exception_bus($c); //@line 53623
  STACKTOP = sp; //@line 53625
  return;
 }
}
function _op8140($c) {
 $c = $c | 0;
 var $s2 = 0, $3 = 0, $7 = 0, $8 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 53642
 STACKTOP = STACKTOP + 8 | 0; //@line 53642
 $s2 = sp | 0; //@line 53643
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 53646
 $7 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 53650
 $8 = $3 & 63; //@line 53651
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($8 << 2) >> 2] & 127]($c, $8, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 53658
  return;
 }
 if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 53665
  return;
 }
 $20 = (HEAPU16[$s2 >> 1] | $7) & 65535; //@line 53671
 $21 = $c + 372 | 0; //@line 53672
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 8; //@line 53675
 _e68_cc_set_nz_16($c, 15, $20); //@line 53676
 $24 = $c + 156 | 0; //@line 53677
 $25 = HEAP32[$24 >> 2] | 0; //@line 53678
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 53683
  STACKTOP = sp; //@line 53685
  return;
 }
 $30 = $c + 164 | 0; //@line 53688
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 53691
 $33 = $25 & 16777215; //@line 53692
 $34 = $33 + 1 | 0; //@line 53693
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 53700
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 53710
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 53718
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 53721
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 53729
  $62 = $c + 152 | 0; //@line 53730
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 53733
  _e68_ea_set_val16($c, $20) | 0; //@line 53734
  STACKTOP = sp; //@line 53736
  return;
 } else {
  _e68_exception_bus($c); //@line 53739
  STACKTOP = sp; //@line 53741
  return;
 }
}
function _op8180($c) {
 $c = $c | 0;
 var $s2 = 0, $3 = 0, $7 = 0, $8 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 53758
 STACKTOP = STACKTOP + 8 | 0; //@line 53758
 $s2 = sp | 0; //@line 53759
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 53762
 $7 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 53766
 $8 = $3 & 63; //@line 53767
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($8 << 2) >> 2] & 127]($c, $8, 508, 32) | 0) != 0) {
  STACKTOP = sp; //@line 53774
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 53781
  return;
 }
 $18 = HEAP32[$s2 >> 2] | $7; //@line 53785
 $19 = $c + 372 | 0; //@line 53786
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 10; //@line 53789
 _e68_cc_set_nz_32($c, 15, $18); //@line 53790
 $22 = $c + 156 | 0; //@line 53791
 $23 = HEAP32[$22 >> 2] | 0; //@line 53792
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 53797
  STACKTOP = sp; //@line 53799
  return;
 }
 $28 = $c + 164 | 0; //@line 53802
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 53805
 $31 = $23 & 16777215; //@line 53806
 $32 = $31 + 1 | 0; //@line 53807
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 53814
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 53824
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 53832
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 53835
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 53843
  $60 = $c + 152 | 0; //@line 53844
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 53847
  _e68_ea_set_val32($c, $18) | 0; //@line 53848
  STACKTOP = sp; //@line 53850
  return;
 } else {
  _e68_exception_bus($c); //@line 53853
  STACKTOP = sp; //@line 53855
  return;
 }
}
function _op81c0($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $17 = 0, $20 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, $_lobit = 0, $_22 = 0, $66 = 0, $68 = 0, $n1_0 = 0, $69 = 0, $70 = 0, $71 = 0, $d2_0 = 0, $_23 = 0, $79 = 0, $82 = 0, $89 = 0, $94 = 0, $95 = 0, $100 = 0, $103 = 0, $104 = 0, $110 = 0, $_0_i_i24 = 0, $132 = 0, sp = 0;
 sp = STACKTOP; //@line 53879
 STACKTOP = STACKTOP + 8 | 0; //@line 53879
 $s1 = sp | 0; //@line 53880
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 53883
 $6 = $3 & 63; //@line 53886
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 53893
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 53900
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 53903
 $16 = HEAP32[$15 >> 2] | 0; //@line 53904
 $17 = HEAP16[$s1 >> 1] | 0; //@line 53905
 if ($17 << 16 >> 16 == 0) {
  $20 = $c + 156 | 0; //@line 53909
  $21 = HEAP32[$20 >> 2] | 0; //@line 53910
  if (($21 & 1 | 0) != 0) {
   _e68_exception_address($c, $21, 0, 0); //@line 53915
   STACKTOP = sp; //@line 53917
   return;
  }
  $26 = $c + 164 | 0; //@line 53920
  HEAP16[$c + 162 >> 1] = HEAP16[$26 >> 1] | 0; //@line 53923
  $29 = $21 & 16777215; //@line 53924
  $30 = $29 + 1 | 0; //@line 53925
  if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $36 = HEAP32[$c + 32 >> 2] | 0; //@line 53932
   $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 53942
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 53950
  }
  HEAP16[$26 >> 1] = $_0_i_i; //@line 53953
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 53961
   $58 = $c + 152 | 0; //@line 53962
   HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 53965
   _e68_exception_divzero($c); //@line 53966
   STACKTOP = sp; //@line 53968
   return;
  } else {
   _e68_exception_bus($c); //@line 53971
   STACKTOP = sp; //@line 53973
   return;
  }
 }
 $_lobit = $16 >>> 31; //@line 53979
 $_22 = ($16 | 0) < 0 ? -$16 | 0 : $16; //@line 53980
 if ($17 << 16 >> 16 > -1) {
  $n1_0 = 0;
  $68 = $17;
 } else {
  $66 = -$17 & 65535; //@line 53986
  HEAP16[$s1 >> 1] = $66; //@line 53987
  $n1_0 = 1;
  $68 = $66;
 }
 $69 = $68 & 65535; //@line 53993
 $70 = ($_22 >>> 0) / ($69 >>> 0) | 0; //@line 53994
 $71 = ($_22 >>> 0) % ($69 >>> 0) | 0; //@line 53995
 if (($_lobit | 0) == 0) {
  $d2_0 = $71; //@line 53999
 } else {
  $d2_0 = -$71 & 65535; //@line 54004
 }
 $_23 = ($n1_0 | 0) == ($_lobit | 0) ? $70 : -$70 | 0; //@line 54009
 $79 = $c + 372 | 0; //@line 54010
 HEAP32[$79 >> 2] = (HEAP32[$79 >> 2] | 0) + 162; //@line 54013
 $82 = $_23 & -32768; //@line 54014
 if (($82 | 0) == 0 | ($82 | 0) == (-32768 | 0)) {
  HEAP32[$15 >> 2] = $d2_0 << 16 | $_23 & 65535; //@line 54019
  _e68_cc_set_nz_16($c, 15, $_23 & 65535); //@line 54021
 } else {
  $89 = $c + 166 | 0; //@line 54024
  HEAP16[$89 >> 1] = HEAP16[$89 >> 1] & -4 | 2; //@line 54028
 }
 $94 = $c + 156 | 0; //@line 54031
 $95 = HEAP32[$94 >> 2] | 0; //@line 54032
 if (($95 & 1 | 0) != 0) {
  _e68_exception_address($c, $95, 0, 0); //@line 54037
  STACKTOP = sp; //@line 54039
  return;
 }
 $100 = $c + 164 | 0; //@line 54042
 HEAP16[$c + 162 >> 1] = HEAP16[$100 >> 1] | 0; //@line 54045
 $103 = $95 & 16777215; //@line 54046
 $104 = $103 + 1 | 0; //@line 54047
 if ($104 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $110 = HEAP32[$c + 32 >> 2] | 0; //@line 54054
  $_0_i_i24 = HEAPU8[$110 + $103 | 0] << 8 | HEAPU8[$110 + $104 | 0]; //@line 54064
 } else {
  $_0_i_i24 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $103) | 0; //@line 54072
 }
 HEAP16[$100 >> 1] = $_0_i_i24; //@line 54075
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$94 >> 2] = (HEAP32[$94 >> 2] | 0) + 2; //@line 54083
  $132 = $c + 152 | 0; //@line 54084
  HEAP32[$132 >> 2] = (HEAP32[$132 >> 2] | 0) + 2; //@line 54087
  STACKTOP = sp; //@line 54089
  return;
 } else {
  _e68_exception_bus($c); //@line 54092
  STACKTOP = sp; //@line 54094
  return;
 }
}
function _op9000($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0, sp = 0;
 sp = STACKTOP; //@line 54111
 STACKTOP = STACKTOP + 8 | 0; //@line 54111
 $s1 = sp | 0; //@line 54112
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 54115
 $6 = $3 & 63; //@line 54118
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 8) | 0) != 0) {
  STACKTOP = sp; //@line 54125
  return;
 }
 if ((_e68_ea_get_val8($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 54132
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 54135
 $16 = HEAP32[$15 >> 2] | 0; //@line 54136
 $18 = HEAP8[$s1] | 0; //@line 54138
 $20 = $16 - ($18 & 255) | 0; //@line 54140
 $22 = $c + 372 | 0; //@line 54142
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 8; //@line 54145
 _e68_cc_set_sub_8($c, $20 & 255, $18, $16 & 255); //@line 54146
 $25 = $c + 156 | 0; //@line 54147
 $26 = HEAP32[$25 >> 2] | 0; //@line 54148
 if (($26 & 1 | 0) != 0) {
  _e68_exception_address($c, $26, 0, 0); //@line 54153
  STACKTOP = sp; //@line 54155
  return;
 }
 $31 = $c + 164 | 0; //@line 54158
 HEAP16[$c + 162 >> 1] = HEAP16[$31 >> 1] | 0; //@line 54161
 $34 = $26 & 16777215; //@line 54162
 $35 = $34 + 1 | 0; //@line 54163
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 54170
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 54180
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 54188
 }
 HEAP16[$31 >> 1] = $_0_i_i; //@line 54191
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 2; //@line 54199
  $63 = $c + 152 | 0; //@line 54200
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 54203
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -256 | $20 & 255; //@line 54208
  STACKTOP = sp; //@line 54210
  return;
 } else {
  _e68_exception_bus($c); //@line 54213
  STACKTOP = sp; //@line 54215
  return;
 }
}
function _op9040($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0, sp = 0;
 sp = STACKTOP; //@line 54232
 STACKTOP = STACKTOP + 8 | 0; //@line 54232
 $s1 = sp | 0; //@line 54233
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 54236
 $6 = $3 & 63; //@line 54239
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 54246
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 54253
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 54256
 $16 = HEAP32[$15 >> 2] | 0; //@line 54257
 $18 = HEAP16[$s1 >> 1] | 0; //@line 54259
 $20 = $16 - ($18 & 65535) | 0; //@line 54261
 $22 = $c + 372 | 0; //@line 54263
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 8; //@line 54266
 _e68_cc_set_sub_16($c, $20 & 65535, $18, $16 & 65535); //@line 54267
 $25 = $c + 156 | 0; //@line 54268
 $26 = HEAP32[$25 >> 2] | 0; //@line 54269
 if (($26 & 1 | 0) != 0) {
  _e68_exception_address($c, $26, 0, 0); //@line 54274
  STACKTOP = sp; //@line 54276
  return;
 }
 $31 = $c + 164 | 0; //@line 54279
 HEAP16[$c + 162 >> 1] = HEAP16[$31 >> 1] | 0; //@line 54282
 $34 = $26 & 16777215; //@line 54283
 $35 = $34 + 1 | 0; //@line 54284
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 54291
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 54301
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 54309
 }
 HEAP16[$31 >> 1] = $_0_i_i; //@line 54312
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 2; //@line 54320
  $63 = $c + 152 | 0; //@line 54321
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 54324
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -65536 | $20 & 65535; //@line 54329
  STACKTOP = sp; //@line 54331
  return;
 } else {
  _e68_exception_bus($c); //@line 54334
  STACKTOP = sp; //@line 54336
  return;
 }
}
function _op9080($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 54352
 STACKTOP = STACKTOP + 8 | 0; //@line 54352
 $s1 = sp | 0; //@line 54353
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 54356
 $6 = $3 & 63; //@line 54359
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 54366
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 54373
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 54376
 $16 = HEAP32[$15 >> 2] | 0; //@line 54377
 $17 = HEAP32[$s1 >> 2] | 0; //@line 54378
 $18 = $16 - $17 | 0; //@line 54379
 $19 = $c + 372 | 0; //@line 54380
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 10; //@line 54383
 _e68_cc_set_sub_32($c, $18, $17, $16); //@line 54384
 $22 = $c + 156 | 0; //@line 54385
 $23 = HEAP32[$22 >> 2] | 0; //@line 54386
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 54391
  STACKTOP = sp; //@line 54393
  return;
 }
 $28 = $c + 164 | 0; //@line 54396
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 54399
 $31 = $23 & 16777215; //@line 54400
 $32 = $31 + 1 | 0; //@line 54401
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 54408
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 54418
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 54426
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 54429
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 54437
  $60 = $c + 152 | 0; //@line 54438
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 54441
  HEAP32[$15 >> 2] = $18; //@line 54442
  STACKTOP = sp; //@line 54444
  return;
 } else {
  _e68_exception_bus($c); //@line 54447
  STACKTOP = sp; //@line 54449
  return;
 }
}
function _op90c0($c) {
 $c = $c | 0;
 var $t = 0, $3 = 0, $6 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $32 = 0, $35 = 0, $36 = 0, $42 = 0, $_0_i_i = 0, $64 = 0, sp = 0;
 sp = STACKTOP; //@line 54466
 STACKTOP = STACKTOP + 8 | 0; //@line 54466
 $t = sp | 0; //@line 54467
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 54470
 $6 = $3 & 63; //@line 54473
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 54480
  return;
 }
 if ((_e68_ea_get_val16($c, $t) | 0) != 0) {
  STACKTOP = sp; //@line 54487
  return;
 }
 $16 = HEAPU16[$t >> 1] | 0; //@line 54491
 $21 = $c + 120 + (($3 >>> 9 & 7) << 2) | 0; //@line 54496
 $22 = HEAP32[$21 >> 2] | 0; //@line 54497
 $23 = $c + 372 | 0; //@line 54498
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 8; //@line 54501
 $26 = $c + 156 | 0; //@line 54502
 $27 = HEAP32[$26 >> 2] | 0; //@line 54503
 if (($27 & 1 | 0) != 0) {
  _e68_exception_address($c, $27, 0, 0); //@line 54508
  STACKTOP = sp; //@line 54510
  return;
 }
 $32 = $c + 164 | 0; //@line 54513
 HEAP16[$c + 162 >> 1] = HEAP16[$32 >> 1] | 0; //@line 54516
 $35 = $27 & 16777215; //@line 54517
 $36 = $35 + 1 | 0; //@line 54518
 if ($36 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $42 = HEAP32[$c + 32 >> 2] | 0; //@line 54525
  $_0_i_i = HEAPU8[$42 + $35 | 0] << 8 | HEAPU8[$42 + $36 | 0]; //@line 54535
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $35) | 0; //@line 54543
 }
 HEAP16[$32 >> 1] = $_0_i_i; //@line 54546
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 2; //@line 54554
  $64 = $c + 152 | 0; //@line 54555
  HEAP32[$64 >> 2] = (HEAP32[$64 >> 2] | 0) + 2; //@line 54558
  HEAP32[$21 >> 2] = $22 - (($16 & 32768 | 0) != 0 ? $16 | -65536 : $16); //@line 54560
  STACKTOP = sp; //@line 54562
  return;
 } else {
  _e68_exception_bus($c); //@line 54565
  STACKTOP = sp; //@line 54567
  return;
 }
}
function _op9100($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $7 = 0, $9 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $44 = 0, $49 = 0, $52 = 0, $53 = 0, $59 = 0, $_0_i_i_i = 0, $81 = 0, $89 = 0, $91 = 0, $100 = 0, $103 = 0, $104 = 0, $107 = 0, $108 = 0, $113 = 0, $116 = 0, $117 = 0, $123 = 0, $_0_i_i = 0, $145 = 0, sp = 0;
 sp = STACKTOP; //@line 54593
 STACKTOP = STACKTOP + 24 | 0; //@line 54593
 $s1_i = sp | 0; //@line 54594
 $s2_i = sp + 8 | 0; //@line 54595
 $s2 = sp + 16 | 0; //@line 54596
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 54599
 if (($3 & 48 | 0) != 0) {
  $89 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 54607
  $91 = $3 & 63; //@line 54609
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($91 << 2) >> 2] & 127]($c, $91, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 54616
   return;
  }
  if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 54623
   return;
  }
  $100 = HEAP8[$s2] | 0; //@line 54626
  $103 = ($100 & 255) - $89 & 255; //@line 54629
  $104 = $c + 372 | 0; //@line 54630
  HEAP32[$104 >> 2] = (HEAP32[$104 >> 2] | 0) + 8; //@line 54633
  _e68_cc_set_sub_8($c, $103, $89 & 255, $100); //@line 54634
  $107 = $c + 156 | 0; //@line 54635
  $108 = HEAP32[$107 >> 2] | 0; //@line 54636
  if (($108 & 1 | 0) != 0) {
   _e68_exception_address($c, $108, 0, 0); //@line 54641
   STACKTOP = sp; //@line 54643
   return;
  }
  $113 = $c + 164 | 0; //@line 54646
  HEAP16[$c + 162 >> 1] = HEAP16[$113 >> 1] | 0; //@line 54649
  $116 = $108 & 16777215; //@line 54650
  $117 = $116 + 1 | 0; //@line 54651
  if ($117 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $123 = HEAP32[$c + 32 >> 2] | 0; //@line 54658
   $_0_i_i = HEAPU8[$123 + $116 | 0] << 8 | HEAPU8[$123 + $117 | 0]; //@line 54668
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $116) | 0; //@line 54676
  }
  HEAP16[$113 >> 1] = $_0_i_i; //@line 54679
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$107 >> 2] = (HEAP32[$107 >> 2] | 0) + 2; //@line 54687
   $145 = $c + 152 | 0; //@line 54688
   HEAP32[$145 >> 2] = (HEAP32[$145 >> 2] | 0) + 2; //@line 54691
   _e68_ea_set_val8($c, $103) | 0; //@line 54692
   STACKTOP = sp; //@line 54694
   return;
  } else {
   _e68_exception_bus($c); //@line 54697
   STACKTOP = sp; //@line 54699
   return;
  }
 }
 $7 = $3 & 7; //@line 54703
 $9 = $3 >>> 9 & 7; //@line 54705
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $9;
  $ea1_0_i = $7;
 } else {
  $ea2_0_i = $9 | 32;
  $ea1_0_i = $7 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 54725
  return;
 }
 if ((_e68_ea_get_val8($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 54732
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 54741
  return;
 }
 if ((_e68_ea_get_val8($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 54748
  return;
 }
 $32 = HEAP8[$s2_i] | 0; //@line 54751
 $33 = HEAP8[$s1_i] | 0; //@line 54752
 $39 = ($32 - $33 & 255) - ((HEAPU16[$c + 166 >> 1] | 0) >>> 4 & 1) & 255; //@line 54759
 $40 = $c + 372 | 0; //@line 54760
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 8; //@line 54763
 _e68_cc_set_subx_8($c, $39, $33, $32); //@line 54764
 $43 = $c + 156 | 0; //@line 54765
 $44 = HEAP32[$43 >> 2] | 0; //@line 54766
 if (($44 & 1 | 0) != 0) {
  _e68_exception_address($c, $44, 0, 0); //@line 54771
  STACKTOP = sp; //@line 54773
  return;
 }
 $49 = $c + 164 | 0; //@line 54776
 HEAP16[$c + 162 >> 1] = HEAP16[$49 >> 1] | 0; //@line 54779
 $52 = $44 & 16777215; //@line 54780
 $53 = $52 + 1 | 0; //@line 54781
 if ($53 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $59 = HEAP32[$c + 32 >> 2] | 0; //@line 54788
  $_0_i_i_i = HEAPU8[$59 + $52 | 0] << 8 | HEAPU8[$59 + $53 | 0]; //@line 54798
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $52) | 0; //@line 54806
 }
 HEAP16[$49 >> 1] = $_0_i_i_i; //@line 54809
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 54817
  $81 = $c + 152 | 0; //@line 54818
  HEAP32[$81 >> 2] = (HEAP32[$81 >> 2] | 0) + 2; //@line 54821
  _e68_ea_set_val8($c, $39) | 0; //@line 54822
  STACKTOP = sp; //@line 54824
  return;
 } else {
  _e68_exception_bus($c); //@line 54827
  STACKTOP = sp; //@line 54829
  return;
 }
}
function _op9140($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $9 = 0, $11 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $34 = 0, $35 = 0, $40 = 0, $41 = 0, $44 = 0, $45 = 0, $50 = 0, $53 = 0, $54 = 0, $60 = 0, $_0_i_i_i = 0, $82 = 0, $90 = 0, $92 = 0, $101 = 0, $104 = 0, $105 = 0, $108 = 0, $109 = 0, $114 = 0, $117 = 0, $118 = 0, $124 = 0, $_0_i_i = 0, $146 = 0, sp = 0;
 sp = STACKTOP; //@line 54855
 STACKTOP = STACKTOP + 24 | 0; //@line 54855
 $s1_i = sp | 0; //@line 54856
 $s2_i = sp + 8 | 0; //@line 54857
 $s2 = sp + 16 | 0; //@line 54858
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 54861
 if (($3 & 48 | 0) != 0) {
  $90 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 54869
  $92 = $3 & 63; //@line 54871
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($92 << 2) >> 2] & 127]($c, $92, 508, 16) | 0) != 0) {
   STACKTOP = sp; //@line 54878
   return;
  }
  if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 54885
   return;
  }
  $101 = HEAP16[$s2 >> 1] | 0; //@line 54888
  $104 = ($101 & 65535) - $90 & 65535; //@line 54891
  $105 = $c + 372 | 0; //@line 54892
  HEAP32[$105 >> 2] = (HEAP32[$105 >> 2] | 0) + 8; //@line 54895
  _e68_cc_set_sub_16($c, $104, $90 & 65535, $101); //@line 54896
  $108 = $c + 156 | 0; //@line 54897
  $109 = HEAP32[$108 >> 2] | 0; //@line 54898
  if (($109 & 1 | 0) != 0) {
   _e68_exception_address($c, $109, 0, 0); //@line 54903
   STACKTOP = sp; //@line 54905
   return;
  }
  $114 = $c + 164 | 0; //@line 54908
  HEAP16[$c + 162 >> 1] = HEAP16[$114 >> 1] | 0; //@line 54911
  $117 = $109 & 16777215; //@line 54912
  $118 = $117 + 1 | 0; //@line 54913
  if ($118 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $124 = HEAP32[$c + 32 >> 2] | 0; //@line 54920
   $_0_i_i = HEAPU8[$124 + $117 | 0] << 8 | HEAPU8[$124 + $118 | 0]; //@line 54930
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $117) | 0; //@line 54938
  }
  HEAP16[$114 >> 1] = $_0_i_i; //@line 54941
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$108 >> 2] = (HEAP32[$108 >> 2] | 0) + 2; //@line 54949
   $146 = $c + 152 | 0; //@line 54950
   HEAP32[$146 >> 2] = (HEAP32[$146 >> 2] | 0) + 2; //@line 54953
   _e68_ea_set_val16($c, $104) | 0; //@line 54954
   STACKTOP = sp; //@line 54956
   return;
  } else {
   _e68_exception_bus($c); //@line 54959
   STACKTOP = sp; //@line 54961
   return;
  }
 }
 $9 = $3 & 7; //@line 54967
 $11 = $3 >>> 9 & 7; //@line 54969
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $11;
  $ea1_0_i = $9;
 } else {
  $ea2_0_i = $11 | 32;
  $ea1_0_i = $9 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 16) | 0) != 0) {
  STACKTOP = sp; //@line 54989
  return;
 }
 if ((_e68_ea_get_val16($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 54996
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 16) | 0) != 0) {
  STACKTOP = sp; //@line 55005
  return;
 }
 if ((_e68_ea_get_val16($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 55012
  return;
 }
 $34 = HEAP16[$s2_i >> 1] | 0; //@line 55015
 $35 = HEAP16[$s1_i >> 1] | 0; //@line 55016
 $40 = ($34 - $35 & 65535) - ((HEAPU16[$c + 166 >> 1] | 0) >>> 4 & 1) & 65535; //@line 55022
 $41 = $c + 372 | 0; //@line 55023
 HEAP32[$41 >> 2] = (HEAP32[$41 >> 2] | 0) + 8; //@line 55026
 _e68_cc_set_subx_16($c, $40, $35, $34); //@line 55027
 $44 = $c + 156 | 0; //@line 55028
 $45 = HEAP32[$44 >> 2] | 0; //@line 55029
 if (($45 & 1 | 0) != 0) {
  _e68_exception_address($c, $45, 0, 0); //@line 55034
  STACKTOP = sp; //@line 55036
  return;
 }
 $50 = $c + 164 | 0; //@line 55039
 HEAP16[$c + 162 >> 1] = HEAP16[$50 >> 1] | 0; //@line 55042
 $53 = $45 & 16777215; //@line 55043
 $54 = $53 + 1 | 0; //@line 55044
 if ($54 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $60 = HEAP32[$c + 32 >> 2] | 0; //@line 55051
  $_0_i_i_i = HEAPU8[$60 + $53 | 0] << 8 | HEAPU8[$60 + $54 | 0]; //@line 55061
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $53) | 0; //@line 55069
 }
 HEAP16[$50 >> 1] = $_0_i_i_i; //@line 55072
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 55080
  $82 = $c + 152 | 0; //@line 55081
  HEAP32[$82 >> 2] = (HEAP32[$82 >> 2] | 0) + 2; //@line 55084
  _e68_ea_set_val16($c, $40) | 0; //@line 55085
  STACKTOP = sp; //@line 55087
  return;
 } else {
  _e68_exception_bus($c); //@line 55090
  STACKTOP = sp; //@line 55092
  return;
 }
}
function _op9180($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $9 = 0, $11 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $34 = 0, $35 = 0, $41 = 0, $42 = 0, $45 = 0, $46 = 0, $51 = 0, $54 = 0, $55 = 0, $61 = 0, $_0_i_i_i = 0, $83 = 0, $91 = 0, $92 = 0, $101 = 0, $102 = 0, $103 = 0, $106 = 0, $107 = 0, $112 = 0, $115 = 0, $116 = 0, $122 = 0, $_0_i_i = 0, $144 = 0, sp = 0;
 sp = STACKTOP; //@line 55118
 STACKTOP = STACKTOP + 24 | 0; //@line 55118
 $s1_i = sp | 0; //@line 55119
 $s2_i = sp + 8 | 0; //@line 55120
 $s2 = sp + 16 | 0; //@line 55121
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 55124
 if (($3 & 48 | 0) != 0) {
  $91 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 55132
  $92 = $3 & 63; //@line 55133
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($92 << 2) >> 2] & 127]($c, $92, 508, 32) | 0) != 0) {
   STACKTOP = sp; //@line 55140
   return;
  }
  if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 55147
   return;
  }
  $101 = HEAP32[$s2 >> 2] | 0; //@line 55150
  $102 = $101 - $91 | 0; //@line 55151
  $103 = $c + 372 | 0; //@line 55152
  HEAP32[$103 >> 2] = (HEAP32[$103 >> 2] | 0) + 12; //@line 55155
  _e68_cc_set_sub_32($c, $102, $91, $101); //@line 55156
  $106 = $c + 156 | 0; //@line 55157
  $107 = HEAP32[$106 >> 2] | 0; //@line 55158
  if (($107 & 1 | 0) != 0) {
   _e68_exception_address($c, $107, 0, 0); //@line 55163
   STACKTOP = sp; //@line 55165
   return;
  }
  $112 = $c + 164 | 0; //@line 55168
  HEAP16[$c + 162 >> 1] = HEAP16[$112 >> 1] | 0; //@line 55171
  $115 = $107 & 16777215; //@line 55172
  $116 = $115 + 1 | 0; //@line 55173
  if ($116 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $122 = HEAP32[$c + 32 >> 2] | 0; //@line 55180
   $_0_i_i = HEAPU8[$122 + $115 | 0] << 8 | HEAPU8[$122 + $116 | 0]; //@line 55190
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $115) | 0; //@line 55198
  }
  HEAP16[$112 >> 1] = $_0_i_i; //@line 55201
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 55209
   $144 = $c + 152 | 0; //@line 55210
   HEAP32[$144 >> 2] = (HEAP32[$144 >> 2] | 0) + 2; //@line 55213
   _e68_ea_set_val32($c, $102) | 0; //@line 55214
   STACKTOP = sp; //@line 55216
   return;
  } else {
   _e68_exception_bus($c); //@line 55219
   STACKTOP = sp; //@line 55221
   return;
  }
 }
 $9 = $3 & 7; //@line 55227
 $11 = $3 >>> 9 & 7; //@line 55229
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $11;
  $ea1_0_i = $9;
 } else {
  $ea2_0_i = $11 | 32;
  $ea1_0_i = $9 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 32) | 0) != 0) {
  STACKTOP = sp; //@line 55249
  return;
 }
 if ((_e68_ea_get_val32($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 55256
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 32) | 0) != 0) {
  STACKTOP = sp; //@line 55265
  return;
 }
 if ((_e68_ea_get_val32($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 55272
  return;
 }
 $34 = HEAP32[$s2_i >> 2] | 0; //@line 55275
 $35 = HEAP32[$s1_i >> 2] | 0; //@line 55276
 $41 = $34 - $35 - ((HEAPU16[$c + 166 >> 1] | 0) >>> 4 & 1) | 0; //@line 55283
 $42 = $c + 372 | 0; //@line 55284
 HEAP32[$42 >> 2] = (HEAP32[$42 >> 2] | 0) + 12; //@line 55287
 _e68_cc_set_subx_32($c, $41, $35, $34); //@line 55288
 $45 = $c + 156 | 0; //@line 55289
 $46 = HEAP32[$45 >> 2] | 0; //@line 55290
 if (($46 & 1 | 0) != 0) {
  _e68_exception_address($c, $46, 0, 0); //@line 55295
  STACKTOP = sp; //@line 55297
  return;
 }
 $51 = $c + 164 | 0; //@line 55300
 HEAP16[$c + 162 >> 1] = HEAP16[$51 >> 1] | 0; //@line 55303
 $54 = $46 & 16777215; //@line 55304
 $55 = $54 + 1 | 0; //@line 55305
 if ($55 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $61 = HEAP32[$c + 32 >> 2] | 0; //@line 55312
  $_0_i_i_i = HEAPU8[$61 + $54 | 0] << 8 | HEAPU8[$61 + $55 | 0]; //@line 55322
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $54) | 0; //@line 55330
 }
 HEAP16[$51 >> 1] = $_0_i_i_i; //@line 55333
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$45 >> 2] = (HEAP32[$45 >> 2] | 0) + 2; //@line 55341
  $83 = $c + 152 | 0; //@line 55342
  HEAP32[$83 >> 2] = (HEAP32[$83 >> 2] | 0) + 2; //@line 55345
  _e68_ea_set_val32($c, $41) | 0; //@line 55346
  STACKTOP = sp; //@line 55348
  return;
 } else {
  _e68_exception_bus($c); //@line 55351
  STACKTOP = sp; //@line 55353
  return;
 }
}
function _op91c0($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $31 = 0, $37 = 0, $_0_i_i = 0, $59 = 0, sp = 0;
 sp = STACKTOP; //@line 55369
 STACKTOP = STACKTOP + 8 | 0; //@line 55369
 $s1 = sp | 0; //@line 55370
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 55373
 $6 = $3 & 63; //@line 55376
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 55383
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 55390
  return;
 }
 $15 = $c + 120 + (($3 >>> 9 & 7) << 2) | 0; //@line 55393
 $16 = HEAP32[$15 >> 2] | 0; //@line 55394
 $17 = HEAP32[$s1 >> 2] | 0; //@line 55395
 $18 = $c + 372 | 0; //@line 55396
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 10; //@line 55399
 $21 = $c + 156 | 0; //@line 55400
 $22 = HEAP32[$21 >> 2] | 0; //@line 55401
 if (($22 & 1 | 0) != 0) {
  _e68_exception_address($c, $22, 0, 0); //@line 55406
  STACKTOP = sp; //@line 55408
  return;
 }
 $27 = $c + 164 | 0; //@line 55411
 HEAP16[$c + 162 >> 1] = HEAP16[$27 >> 1] | 0; //@line 55414
 $30 = $22 & 16777215; //@line 55415
 $31 = $30 + 1 | 0; //@line 55416
 if ($31 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $37 = HEAP32[$c + 32 >> 2] | 0; //@line 55423
  $_0_i_i = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 55433
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 55441
 }
 HEAP16[$27 >> 1] = $_0_i_i; //@line 55444
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 55452
  $59 = $c + 152 | 0; //@line 55453
  HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 55456
  HEAP32[$15 >> 2] = $16 - $17; //@line 55458
  STACKTOP = sp; //@line 55460
  return;
 } else {
  _e68_exception_bus($c); //@line 55463
  STACKTOP = sp; //@line 55465
  return;
 }
}
function _opa000($c) {
 $c = $c | 0;
 HEAP16[$c + 328 >> 1] = HEAP16[$c + 160 >> 1] | 0; //@line 55479
 _e68_exception_axxx($c); //@line 55480
 return;
}
function _opb000($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $4 = 0, $18 = 0, $20 = 0, $23 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 55497
 STACKTOP = STACKTOP + 8 | 0; //@line 55497
 $s1 = sp | 0; //@line 55498
 $1 = $c + 160 | 0; //@line 55499
 $4 = HEAP16[$1 >> 1] & 63; //@line 55502
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4093, 8) | 0) != 0) {
  STACKTOP = sp; //@line 55509
  return;
 }
 if ((_e68_ea_get_val8($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 55516
  return;
 }
 $18 = HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 55524
 $20 = $c + 372 | 0; //@line 55526
 HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 4; //@line 55529
 $23 = HEAP8[$s1] | 0; //@line 55530
 _e68_cc_set_cmp_8($c, $18 - ($23 & 255) & 255, $23, $18 & 255); //@line 55534
 $27 = $c + 156 | 0; //@line 55535
 $28 = HEAP32[$27 >> 2] | 0; //@line 55536
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 55541
  STACKTOP = sp; //@line 55543
  return;
 }
 $33 = $c + 164 | 0; //@line 55546
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 55549
 $36 = $28 & 16777215; //@line 55550
 $37 = $36 + 1 | 0; //@line 55551
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 55558
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 55568
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 55576
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 55579
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 55587
  $65 = $c + 152 | 0; //@line 55588
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 55591
  STACKTOP = sp; //@line 55593
  return;
 } else {
  _e68_exception_bus($c); //@line 55596
  STACKTOP = sp; //@line 55598
  return;
 }
}
function _opb040($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $4 = 0, $18 = 0, $20 = 0, $23 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 55615
 STACKTOP = STACKTOP + 8 | 0; //@line 55615
 $s1 = sp | 0; //@line 55616
 $1 = $c + 160 | 0; //@line 55617
 $4 = HEAP16[$1 >> 1] & 63; //@line 55620
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 55627
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 55634
  return;
 }
 $18 = HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 55642
 $20 = $c + 372 | 0; //@line 55644
 HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 4; //@line 55647
 $23 = HEAP16[$s1 >> 1] | 0; //@line 55648
 _e68_cc_set_cmp_16($c, $18 - ($23 & 65535) & 65535, $23, $18 & 65535); //@line 55652
 $27 = $c + 156 | 0; //@line 55653
 $28 = HEAP32[$27 >> 2] | 0; //@line 55654
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 55659
  STACKTOP = sp; //@line 55661
  return;
 }
 $33 = $c + 164 | 0; //@line 55664
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 55667
 $36 = $28 & 16777215; //@line 55668
 $37 = $36 + 1 | 0; //@line 55669
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 55676
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 55686
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 55694
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 55697
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 55705
  $65 = $c + 152 | 0; //@line 55706
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 55709
  STACKTOP = sp; //@line 55711
  return;
 } else {
  _e68_exception_bus($c); //@line 55714
  STACKTOP = sp; //@line 55716
  return;
 }
}
function _opb080($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $4 = 0, $18 = 0, $19 = 0, $22 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 55733
 STACKTOP = STACKTOP + 8 | 0; //@line 55733
 $s1 = sp | 0; //@line 55734
 $1 = $c + 160 | 0; //@line 55735
 $4 = HEAP16[$1 >> 1] & 63; //@line 55738
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 55745
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 55752
  return;
 }
 $18 = HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 55760
 $19 = $c + 372 | 0; //@line 55761
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 6; //@line 55764
 $22 = HEAP32[$s1 >> 2] | 0; //@line 55765
 _e68_cc_set_cmp_32($c, $18 - $22 | 0, $22, $18); //@line 55767
 $24 = $c + 156 | 0; //@line 55768
 $25 = HEAP32[$24 >> 2] | 0; //@line 55769
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 55774
  STACKTOP = sp; //@line 55776
  return;
 }
 $30 = $c + 164 | 0; //@line 55779
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 55782
 $33 = $25 & 16777215; //@line 55783
 $34 = $33 + 1 | 0; //@line 55784
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 55791
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 55801
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 55809
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 55812
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 55820
  $62 = $c + 152 | 0; //@line 55821
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 55824
  STACKTOP = sp; //@line 55826
  return;
 } else {
  _e68_exception_bus($c); //@line 55829
  STACKTOP = sp; //@line 55831
  return;
 }
}
function _opb0c0($c) {
 $c = $c | 0;
 var $t = 0, $1 = 0, $4 = 0, $14 = 0, $18 = 0, $24 = 0, $25 = 0, $29 = 0, $30 = 0, $35 = 0, $38 = 0, $39 = 0, $45 = 0, $_0_i_i = 0, $67 = 0, sp = 0;
 sp = STACKTOP; //@line 55848
 STACKTOP = STACKTOP + 8 | 0; //@line 55848
 $t = sp | 0; //@line 55849
 $1 = $c + 160 | 0; //@line 55850
 $4 = HEAP16[$1 >> 1] & 63; //@line 55853
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 55860
  return;
 }
 if ((_e68_ea_get_val16($c, $t) | 0) != 0) {
  STACKTOP = sp; //@line 55867
  return;
 }
 $14 = HEAPU16[$t >> 1] | 0; //@line 55871
 $18 = ($14 & 32768 | 0) != 0 ? $14 | -65536 : $14; //@line 55875
 $24 = HEAP32[$c + 120 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 55881
 $25 = $c + 372 | 0; //@line 55882
 HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 8; //@line 55885
 _e68_cc_set_cmp_32($c, $24 - $18 | 0, $18, $24); //@line 55887
 $29 = $c + 156 | 0; //@line 55888
 $30 = HEAP32[$29 >> 2] | 0; //@line 55889
 if (($30 & 1 | 0) != 0) {
  _e68_exception_address($c, $30, 0, 0); //@line 55894
  STACKTOP = sp; //@line 55896
  return;
 }
 $35 = $c + 164 | 0; //@line 55899
 HEAP16[$c + 162 >> 1] = HEAP16[$35 >> 1] | 0; //@line 55902
 $38 = $30 & 16777215; //@line 55903
 $39 = $38 + 1 | 0; //@line 55904
 if ($39 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $45 = HEAP32[$c + 32 >> 2] | 0; //@line 55911
  $_0_i_i = HEAPU8[$45 + $38 | 0] << 8 | HEAPU8[$45 + $39 | 0]; //@line 55921
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $38) | 0; //@line 55929
 }
 HEAP16[$35 >> 1] = $_0_i_i; //@line 55932
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 2; //@line 55940
  $67 = $c + 152 | 0; //@line 55941
  HEAP32[$67 >> 2] = (HEAP32[$67 >> 2] | 0) + 2; //@line 55944
  STACKTOP = sp; //@line 55946
  return;
 } else {
  _e68_exception_bus($c); //@line 55949
  STACKTOP = sp; //@line 55951
  return;
 }
}
function _opb100($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $1 = 0, $3 = 0, $8 = 0, $21 = 0, $30 = 0, $33 = 0, $34 = 0, $36 = 0, $37 = 0, $42 = 0, $45 = 0, $46 = 0, $52 = 0, $_0_i_i_i = 0, $74 = 0, $81 = 0, $82 = 0, $94 = 0, $95 = 0, $98 = 0, $99 = 0, $104 = 0, $107 = 0, $108 = 0, $114 = 0, $_0_i_i = 0, $136 = 0, sp = 0;
 sp = STACKTOP; //@line 55976
 STACKTOP = STACKTOP + 24 | 0; //@line 55976
 $s1_i = sp | 0; //@line 55977
 $s2_i = sp + 8 | 0; //@line 55978
 $s2 = sp + 16 | 0; //@line 55979
 $1 = $c + 160 | 0; //@line 55980
 $3 = HEAPU16[$1 >> 1] | 0; //@line 55982
 if (($3 & 56 | 0) != 8) {
  $81 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 55990
  $82 = $3 & 63; //@line 55991
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($82 << 2) >> 2] & 127]($c, $82, 509, 8) | 0) != 0) {
   STACKTOP = sp; //@line 55998
   return;
  }
  if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 56005
   return;
  }
  $94 = (HEAPU8[$s2] ^ $81) & 255; //@line 56011
  $95 = $c + 372 | 0; //@line 56012
  HEAP32[$95 >> 2] = (HEAP32[$95 >> 2] | 0) + 8; //@line 56015
  _e68_cc_set_nz_8($c, 15, $94); //@line 56016
  $98 = $c + 156 | 0; //@line 56017
  $99 = HEAP32[$98 >> 2] | 0; //@line 56018
  if (($99 & 1 | 0) != 0) {
   _e68_exception_address($c, $99, 0, 0); //@line 56023
   STACKTOP = sp; //@line 56025
   return;
  }
  $104 = $c + 164 | 0; //@line 56028
  HEAP16[$c + 162 >> 1] = HEAP16[$104 >> 1] | 0; //@line 56031
  $107 = $99 & 16777215; //@line 56032
  $108 = $107 + 1 | 0; //@line 56033
  if ($108 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $114 = HEAP32[$c + 32 >> 2] | 0; //@line 56040
   $_0_i_i = HEAPU8[$114 + $107 | 0] << 8 | HEAPU8[$114 + $108 | 0]; //@line 56050
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $107) | 0; //@line 56058
  }
  HEAP16[$104 >> 1] = $_0_i_i; //@line 56061
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$98 >> 2] = (HEAP32[$98 >> 2] | 0) + 2; //@line 56069
   $136 = $c + 152 | 0; //@line 56070
   HEAP32[$136 >> 2] = (HEAP32[$136 >> 2] | 0) + 2; //@line 56073
   _e68_ea_set_val8($c, $94) | 0; //@line 56074
   STACKTOP = sp; //@line 56076
   return;
  } else {
   _e68_exception_bus($c); //@line 56079
   STACKTOP = sp; //@line 56081
   return;
  }
 }
 $8 = $3 & 7 | 24; //@line 56086
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($8 << 2) >> 2] & 127]($c, $8, 8, 8) | 0) != 0) {
  STACKTOP = sp; //@line 56093
  return;
 }
 if ((_e68_ea_get_val8($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 56100
  return;
 }
 $21 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7 | 24; //@line 56107
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($21 << 2) >> 2] & 127]($c, $21, 8, 8) | 0) != 0) {
  STACKTOP = sp; //@line 56114
  return;
 }
 if ((_e68_ea_get_val8($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 56121
  return;
 }
 $30 = $c + 372 | 0; //@line 56124
 HEAP32[$30 >> 2] = (HEAP32[$30 >> 2] | 0) + 16; //@line 56127
 $33 = HEAP8[$s2_i] | 0; //@line 56128
 $34 = HEAP8[$s1_i] | 0; //@line 56129
 _e68_cc_set_cmp_8($c, $33 - $34 & 255, $34, $33); //@line 56131
 $36 = $c + 156 | 0; //@line 56132
 $37 = HEAP32[$36 >> 2] | 0; //@line 56133
 if (($37 & 1 | 0) != 0) {
  _e68_exception_address($c, $37, 0, 0); //@line 56138
  STACKTOP = sp; //@line 56140
  return;
 }
 $42 = $c + 164 | 0; //@line 56143
 HEAP16[$c + 162 >> 1] = HEAP16[$42 >> 1] | 0; //@line 56146
 $45 = $37 & 16777215; //@line 56147
 $46 = $45 + 1 | 0; //@line 56148
 if ($46 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $52 = HEAP32[$c + 32 >> 2] | 0; //@line 56155
  $_0_i_i_i = HEAPU8[$52 + $45 | 0] << 8 | HEAPU8[$52 + $46 | 0]; //@line 56165
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $45) | 0; //@line 56173
 }
 HEAP16[$42 >> 1] = $_0_i_i_i; //@line 56176
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$36 >> 2] = (HEAP32[$36 >> 2] | 0) + 2; //@line 56184
  $74 = $c + 152 | 0; //@line 56185
  HEAP32[$74 >> 2] = (HEAP32[$74 >> 2] | 0) + 2; //@line 56188
  STACKTOP = sp; //@line 56190
  return;
 } else {
  _e68_exception_bus($c); //@line 56193
  STACKTOP = sp; //@line 56195
  return;
 }
}
function _opb140($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $1 = 0, $3 = 0, $10 = 0, $23 = 0, $32 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $44 = 0, $47 = 0, $48 = 0, $54 = 0, $_0_i_i_i = 0, $76 = 0, $83 = 0, $84 = 0, $96 = 0, $97 = 0, $100 = 0, $101 = 0, $106 = 0, $109 = 0, $110 = 0, $116 = 0, $_0_i_i = 0, $138 = 0, sp = 0;
 sp = STACKTOP; //@line 56220
 STACKTOP = STACKTOP + 24 | 0; //@line 56220
 $s1_i = sp | 0; //@line 56221
 $s2_i = sp + 8 | 0; //@line 56222
 $s2 = sp + 16 | 0; //@line 56223
 $1 = $c + 160 | 0; //@line 56224
 $3 = HEAPU16[$1 >> 1] | 0; //@line 56226
 if (($3 & 56 | 0) != 8) {
  $83 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 56234
  $84 = $3 & 63; //@line 56235
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($84 << 2) >> 2] & 127]($c, $84, 509, 16) | 0) != 0) {
   STACKTOP = sp; //@line 56242
   return;
  }
  if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 56249
   return;
  }
  $96 = (HEAPU16[$s2 >> 1] ^ $83) & 65535; //@line 56255
  $97 = $c + 372 | 0; //@line 56256
  HEAP32[$97 >> 2] = (HEAP32[$97 >> 2] | 0) + 8; //@line 56259
  _e68_cc_set_nz_16($c, 15, $96); //@line 56260
  $100 = $c + 156 | 0; //@line 56261
  $101 = HEAP32[$100 >> 2] | 0; //@line 56262
  if (($101 & 1 | 0) != 0) {
   _e68_exception_address($c, $101, 0, 0); //@line 56267
   STACKTOP = sp; //@line 56269
   return;
  }
  $106 = $c + 164 | 0; //@line 56272
  HEAP16[$c + 162 >> 1] = HEAP16[$106 >> 1] | 0; //@line 56275
  $109 = $101 & 16777215; //@line 56276
  $110 = $109 + 1 | 0; //@line 56277
  if ($110 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $116 = HEAP32[$c + 32 >> 2] | 0; //@line 56284
   $_0_i_i = HEAPU8[$116 + $109 | 0] << 8 | HEAPU8[$116 + $110 | 0]; //@line 56294
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $109) | 0; //@line 56302
  }
  HEAP16[$106 >> 1] = $_0_i_i; //@line 56305
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$100 >> 2] = (HEAP32[$100 >> 2] | 0) + 2; //@line 56313
   $138 = $c + 152 | 0; //@line 56314
   HEAP32[$138 >> 2] = (HEAP32[$138 >> 2] | 0) + 2; //@line 56317
   _e68_ea_set_val16($c, $96) | 0; //@line 56318
   STACKTOP = sp; //@line 56320
   return;
  } else {
   _e68_exception_bus($c); //@line 56323
   STACKTOP = sp; //@line 56325
   return;
  }
 }
 $10 = $3 & 7 | 24; //@line 56332
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($10 << 2) >> 2] & 127]($c, $10, 8, 16) | 0) != 0) {
  STACKTOP = sp; //@line 56339
  return;
 }
 if ((_e68_ea_get_val16($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 56346
  return;
 }
 $23 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7 | 24; //@line 56353
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($23 << 2) >> 2] & 127]($c, $23, 8, 16) | 0) != 0) {
  STACKTOP = sp; //@line 56360
  return;
 }
 if ((_e68_ea_get_val16($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 56367
  return;
 }
 $32 = $c + 372 | 0; //@line 56370
 HEAP32[$32 >> 2] = (HEAP32[$32 >> 2] | 0) + 12; //@line 56373
 $35 = HEAP16[$s2_i >> 1] | 0; //@line 56374
 $36 = HEAP16[$s1_i >> 1] | 0; //@line 56375
 _e68_cc_set_cmp_16($c, $35 - $36 & 65535, $36, $35); //@line 56377
 $38 = $c + 156 | 0; //@line 56378
 $39 = HEAP32[$38 >> 2] | 0; //@line 56379
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 56384
  STACKTOP = sp; //@line 56386
  return;
 }
 $44 = $c + 164 | 0; //@line 56389
 HEAP16[$c + 162 >> 1] = HEAP16[$44 >> 1] | 0; //@line 56392
 $47 = $39 & 16777215; //@line 56393
 $48 = $47 + 1 | 0; //@line 56394
 if ($48 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $54 = HEAP32[$c + 32 >> 2] | 0; //@line 56401
  $_0_i_i_i = HEAPU8[$54 + $47 | 0] << 8 | HEAPU8[$54 + $48 | 0]; //@line 56411
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $47) | 0; //@line 56419
 }
 HEAP16[$44 >> 1] = $_0_i_i_i; //@line 56422
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$38 >> 2] = (HEAP32[$38 >> 2] | 0) + 2; //@line 56430
  $76 = $c + 152 | 0; //@line 56431
  HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 56434
  STACKTOP = sp; //@line 56436
  return;
 } else {
  _e68_exception_bus($c); //@line 56439
  STACKTOP = sp; //@line 56441
  return;
 }
}
function _opb180($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $1 = 0, $3 = 0, $10 = 0, $23 = 0, $32 = 0, $35 = 0, $36 = 0, $38 = 0, $39 = 0, $44 = 0, $47 = 0, $48 = 0, $54 = 0, $_0_i_i_i = 0, $76 = 0, $83 = 0, $84 = 0, $94 = 0, $95 = 0, $98 = 0, $99 = 0, $104 = 0, $107 = 0, $108 = 0, $114 = 0, $_0_i_i = 0, $136 = 0, sp = 0;
 sp = STACKTOP; //@line 56466
 STACKTOP = STACKTOP + 24 | 0; //@line 56466
 $s1_i = sp | 0; //@line 56467
 $s2_i = sp + 8 | 0; //@line 56468
 $s2 = sp + 16 | 0; //@line 56469
 $1 = $c + 160 | 0; //@line 56470
 $3 = HEAPU16[$1 >> 1] | 0; //@line 56472
 if (($3 & 56 | 0) != 8) {
  $83 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 56480
  $84 = $3 & 63; //@line 56481
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($84 << 2) >> 2] & 127]($c, $84, 509, 32) | 0) != 0) {
   STACKTOP = sp; //@line 56488
   return;
  }
  if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 56495
   return;
  }
  $94 = HEAP32[$s2 >> 2] ^ $83; //@line 56499
  $95 = $c + 372 | 0; //@line 56500
  HEAP32[$95 >> 2] = (HEAP32[$95 >> 2] | 0) + 12; //@line 56503
  _e68_cc_set_nz_32($c, 15, $94); //@line 56504
  $98 = $c + 156 | 0; //@line 56505
  $99 = HEAP32[$98 >> 2] | 0; //@line 56506
  if (($99 & 1 | 0) != 0) {
   _e68_exception_address($c, $99, 0, 0); //@line 56511
   STACKTOP = sp; //@line 56513
   return;
  }
  $104 = $c + 164 | 0; //@line 56516
  HEAP16[$c + 162 >> 1] = HEAP16[$104 >> 1] | 0; //@line 56519
  $107 = $99 & 16777215; //@line 56520
  $108 = $107 + 1 | 0; //@line 56521
  if ($108 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $114 = HEAP32[$c + 32 >> 2] | 0; //@line 56528
   $_0_i_i = HEAPU8[$114 + $107 | 0] << 8 | HEAPU8[$114 + $108 | 0]; //@line 56538
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $107) | 0; //@line 56546
  }
  HEAP16[$104 >> 1] = $_0_i_i; //@line 56549
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$98 >> 2] = (HEAP32[$98 >> 2] | 0) + 2; //@line 56557
   $136 = $c + 152 | 0; //@line 56558
   HEAP32[$136 >> 2] = (HEAP32[$136 >> 2] | 0) + 2; //@line 56561
   _e68_ea_set_val32($c, $94) | 0; //@line 56562
   STACKTOP = sp; //@line 56564
   return;
  } else {
   _e68_exception_bus($c); //@line 56567
   STACKTOP = sp; //@line 56569
   return;
  }
 }
 $10 = $3 & 7 | 24; //@line 56576
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($10 << 2) >> 2] & 127]($c, $10, 8, 32) | 0) != 0) {
  STACKTOP = sp; //@line 56583
  return;
 }
 if ((_e68_ea_get_val32($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 56590
  return;
 }
 $23 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 7 | 24; //@line 56597
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($23 << 2) >> 2] & 127]($c, $23, 8, 32) | 0) != 0) {
  STACKTOP = sp; //@line 56604
  return;
 }
 if ((_e68_ea_get_val32($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 56611
  return;
 }
 $32 = $c + 372 | 0; //@line 56614
 HEAP32[$32 >> 2] = (HEAP32[$32 >> 2] | 0) + 20; //@line 56617
 $35 = HEAP32[$s2_i >> 2] | 0; //@line 56618
 $36 = HEAP32[$s1_i >> 2] | 0; //@line 56619
 _e68_cc_set_cmp_32($c, $35 - $36 | 0, $36, $35); //@line 56621
 $38 = $c + 156 | 0; //@line 56622
 $39 = HEAP32[$38 >> 2] | 0; //@line 56623
 if (($39 & 1 | 0) != 0) {
  _e68_exception_address($c, $39, 0, 0); //@line 56628
  STACKTOP = sp; //@line 56630
  return;
 }
 $44 = $c + 164 | 0; //@line 56633
 HEAP16[$c + 162 >> 1] = HEAP16[$44 >> 1] | 0; //@line 56636
 $47 = $39 & 16777215; //@line 56637
 $48 = $47 + 1 | 0; //@line 56638
 if ($48 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $54 = HEAP32[$c + 32 >> 2] | 0; //@line 56645
  $_0_i_i_i = HEAPU8[$54 + $47 | 0] << 8 | HEAPU8[$54 + $48 | 0]; //@line 56655
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $47) | 0; //@line 56663
 }
 HEAP16[$44 >> 1] = $_0_i_i_i; //@line 56666
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$38 >> 2] = (HEAP32[$38 >> 2] | 0) + 2; //@line 56674
  $76 = $c + 152 | 0; //@line 56675
  HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 56678
  STACKTOP = sp; //@line 56680
  return;
 } else {
  _e68_exception_bus($c); //@line 56683
  STACKTOP = sp; //@line 56685
  return;
 }
}
function _opb1c0($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $4 = 0, $18 = 0, $19 = 0, $22 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 56702
 STACKTOP = STACKTOP + 8 | 0; //@line 56702
 $s1 = sp | 0; //@line 56703
 $1 = $c + 160 | 0; //@line 56704
 $4 = HEAP16[$1 >> 1] & 63; //@line 56707
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 56714
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 56721
  return;
 }
 $18 = HEAP32[$c + 120 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 56729
 $19 = $c + 372 | 0; //@line 56730
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 8; //@line 56733
 $22 = HEAP32[$s1 >> 2] | 0; //@line 56734
 _e68_cc_set_cmp_32($c, $18 - $22 | 0, $22, $18); //@line 56736
 $24 = $c + 156 | 0; //@line 56737
 $25 = HEAP32[$24 >> 2] | 0; //@line 56738
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 56743
  STACKTOP = sp; //@line 56745
  return;
 }
 $30 = $c + 164 | 0; //@line 56748
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 56751
 $33 = $25 & 16777215; //@line 56752
 $34 = $33 + 1 | 0; //@line 56753
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 56760
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 56770
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 56778
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 56781
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 56789
  $62 = $c + 152 | 0; //@line 56790
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 56793
  STACKTOP = sp; //@line 56795
  return;
 } else {
  _e68_exception_bus($c); //@line 56798
  STACKTOP = sp; //@line 56800
  return;
 }
}
function _opc000($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $19 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 56817
 STACKTOP = STACKTOP + 8 | 0; //@line 56817
 $s1 = sp | 0; //@line 56818
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 56821
 $6 = $3 & 63; //@line 56824
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 8) | 0) != 0) {
  STACKTOP = sp; //@line 56831
  return;
 }
 if ((_e68_ea_get_val8($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 56838
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 56841
 $19 = HEAPU8[$s1] & HEAP32[$15 >> 2]; //@line 56845
 $21 = $c + 372 | 0; //@line 56847
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 56850
 _e68_cc_set_nz_8($c, 15, $19 & 255); //@line 56851
 $24 = $c + 156 | 0; //@line 56852
 $25 = HEAP32[$24 >> 2] | 0; //@line 56853
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 56858
  STACKTOP = sp; //@line 56860
  return;
 }
 $30 = $c + 164 | 0; //@line 56863
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 56866
 $33 = $25 & 16777215; //@line 56867
 $34 = $33 + 1 | 0; //@line 56868
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 56875
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 56885
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 56893
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 56896
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 56904
  $62 = $c + 152 | 0; //@line 56905
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 56908
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -256 | $19; //@line 56912
  STACKTOP = sp; //@line 56914
  return;
 } else {
  _e68_exception_bus($c); //@line 56917
  STACKTOP = sp; //@line 56919
  return;
 }
}
function _opc040($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $19 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 56936
 STACKTOP = STACKTOP + 8 | 0; //@line 56936
 $s1 = sp | 0; //@line 56937
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 56940
 $6 = $3 & 63; //@line 56943
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 56950
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 56957
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 56960
 $19 = HEAPU16[$s1 >> 1] & HEAP32[$15 >> 2]; //@line 56964
 $21 = $c + 372 | 0; //@line 56966
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 4; //@line 56969
 _e68_cc_set_nz_16($c, 15, $19 & 65535); //@line 56970
 $24 = $c + 156 | 0; //@line 56971
 $25 = HEAP32[$24 >> 2] | 0; //@line 56972
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 56977
  STACKTOP = sp; //@line 56979
  return;
 }
 $30 = $c + 164 | 0; //@line 56982
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 56985
 $33 = $25 & 16777215; //@line 56986
 $34 = $33 + 1 | 0; //@line 56987
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 56994
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 57004
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 57012
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 57015
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 57023
  $62 = $c + 152 | 0; //@line 57024
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 57027
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -65536 | $19; //@line 57031
  STACKTOP = sp; //@line 57033
  return;
 } else {
  _e68_exception_bus($c); //@line 57036
  STACKTOP = sp; //@line 57038
  return;
 }
}
function _opc080($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 57054
 STACKTOP = STACKTOP + 8 | 0; //@line 57054
 $s1 = sp | 0; //@line 57055
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 57058
 $6 = $3 & 63; //@line 57061
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 32) | 0) != 0) {
  STACKTOP = sp; //@line 57068
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 57075
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 57078
 $18 = HEAP32[$s1 >> 2] & HEAP32[$15 >> 2]; //@line 57081
 $19 = $c + 372 | 0; //@line 57082
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 6; //@line 57085
 _e68_cc_set_nz_32($c, 15, $18); //@line 57086
 $22 = $c + 156 | 0; //@line 57087
 $23 = HEAP32[$22 >> 2] | 0; //@line 57088
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 57093
  STACKTOP = sp; //@line 57095
  return;
 }
 $28 = $c + 164 | 0; //@line 57098
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 57101
 $31 = $23 & 16777215; //@line 57102
 $32 = $31 + 1 | 0; //@line 57103
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 57110
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 57120
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 57128
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 57131
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 57139
  $60 = $c + 152 | 0; //@line 57140
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 57143
  HEAP32[$15 >> 2] = $18; //@line 57144
  STACKTOP = sp; //@line 57146
  return;
 } else {
  _e68_exception_bus($c); //@line 57149
  STACKTOP = sp; //@line 57151
  return;
 }
}
function _opc0c0($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 57168
 STACKTOP = STACKTOP + 8 | 0; //@line 57168
 $s1 = sp | 0; //@line 57169
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 57172
 $6 = $3 & 63; //@line 57175
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 57182
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 57189
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 57192
 $20 = Math_imul(HEAPU16[$s1 >> 1] | 0, HEAP32[$15 >> 2] & 65535) | 0; //@line 57197
 $21 = $c + 372 | 0; //@line 57198
 HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 74; //@line 57201
 _e68_cc_set_nz_32($c, 15, $20); //@line 57202
 $24 = $c + 156 | 0; //@line 57203
 $25 = HEAP32[$24 >> 2] | 0; //@line 57204
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 57209
  STACKTOP = sp; //@line 57211
  return;
 }
 $30 = $c + 164 | 0; //@line 57214
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 57217
 $33 = $25 & 16777215; //@line 57218
 $34 = $33 + 1 | 0; //@line 57219
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 57226
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 57236
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 57244
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 57247
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 57255
  $62 = $c + 152 | 0; //@line 57256
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 57259
  HEAP32[$15 >> 2] = $20; //@line 57260
  STACKTOP = sp; //@line 57262
  return;
 } else {
  _e68_exception_bus($c); //@line 57265
  STACKTOP = sp; //@line 57267
  return;
 }
}
function _opc100($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $7 = 0, $9 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $32 = 0, $34 = 0, $37 = 0, $38 = 0, $40 = 0, $d_0_i = 0, $storemerge_i = 0, $d_1_i = 0, $58 = 0, $61 = 0, $62 = 0, $67 = 0, $70 = 0, $71 = 0, $77 = 0, $_0_i_i_i = 0, $99 = 0, $102 = 0, $108 = 0, $109 = 0, $121 = 0, $122 = 0, $125 = 0, $126 = 0, $131 = 0, $134 = 0, $135 = 0, $141 = 0, $_0_i_i = 0, $163 = 0, sp = 0;
 sp = STACKTOP; //@line 57296
 STACKTOP = STACKTOP + 24 | 0; //@line 57296
 $s1_i = sp | 0; //@line 57297
 $s2_i = sp + 8 | 0; //@line 57298
 $s2 = sp + 16 | 0; //@line 57299
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 57302
 if (($3 & 48 | 0) != 0) {
  $108 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 57310
  $109 = $3 & 63; //@line 57311
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($109 << 2) >> 2] & 127]($c, $109, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 57318
   return;
  }
  if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 57325
   return;
  }
  $121 = HEAPU8[$s2] & $108 & 255; //@line 57331
  $122 = $c + 372 | 0; //@line 57332
  HEAP32[$122 >> 2] = (HEAP32[$122 >> 2] | 0) + 4; //@line 57335
  _e68_cc_set_nz_8($c, 15, $121); //@line 57336
  $125 = $c + 156 | 0; //@line 57337
  $126 = HEAP32[$125 >> 2] | 0; //@line 57338
  if (($126 & 1 | 0) != 0) {
   _e68_exception_address($c, $126, 0, 0); //@line 57343
   STACKTOP = sp; //@line 57345
   return;
  }
  $131 = $c + 164 | 0; //@line 57348
  HEAP16[$c + 162 >> 1] = HEAP16[$131 >> 1] | 0; //@line 57351
  $134 = $126 & 16777215; //@line 57352
  $135 = $134 + 1 | 0; //@line 57353
  if ($135 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $141 = HEAP32[$c + 32 >> 2] | 0; //@line 57360
   $_0_i_i = HEAPU8[$141 + $134 | 0] << 8 | HEAPU8[$141 + $135 | 0]; //@line 57370
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $134) | 0; //@line 57378
  }
  HEAP16[$131 >> 1] = $_0_i_i; //@line 57381
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$125 >> 2] = (HEAP32[$125 >> 2] | 0) + 2; //@line 57389
   $163 = $c + 152 | 0; //@line 57390
   HEAP32[$163 >> 2] = (HEAP32[$163 >> 2] | 0) + 2; //@line 57393
   _e68_ea_set_val8($c, $121) | 0; //@line 57394
   STACKTOP = sp; //@line 57396
   return;
  } else {
   _e68_exception_bus($c); //@line 57399
   STACKTOP = sp; //@line 57401
   return;
  }
 }
 $7 = $3 & 7; //@line 57405
 $9 = $3 >>> 9 & 7; //@line 57407
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $9;
  $ea1_0_i = $7;
 } else {
  $ea2_0_i = $9 | 32;
  $ea1_0_i = $7 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 57427
  return;
 }
 if ((_e68_ea_get_val8($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 57434
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 57443
  return;
 }
 if ((_e68_ea_get_val8($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 57450
  return;
 }
 $32 = HEAP8[$s1_i] | 0; //@line 57453
 $34 = HEAP8[$s2_i] | 0; //@line 57455
 $37 = $c + 166 | 0; //@line 57458
 $38 = HEAP16[$37 >> 1] | 0; //@line 57459
 $40 = (($34 & 255) + ($32 & 255) & 65535) + (($38 & 65535) >>> 4 & 1) & 65535; //@line 57462
 $d_0_i = (($34 & 15) + ($32 & 15) | 0) > 9 ? $40 + 6 & 65535 : $40; //@line 57470
 if (($d_0_i & 65535) > 159) {
  $d_1_i = $d_0_i + 96 & 65535;
  $storemerge_i = $38 | 17;
 } else {
  $d_1_i = $d_0_i;
  $storemerge_i = $38 & -18;
 }
 HEAP16[$37 >> 1] = ($d_1_i & 255) == 0 ? $storemerge_i : $storemerge_i & -5; //@line 57488
 $58 = $c + 372 | 0; //@line 57489
 HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 6; //@line 57492
 $61 = $c + 156 | 0; //@line 57493
 $62 = HEAP32[$61 >> 2] | 0; //@line 57494
 if (($62 & 1 | 0) != 0) {
  _e68_exception_address($c, $62, 0, 0); //@line 57499
  STACKTOP = sp; //@line 57501
  return;
 }
 $67 = $c + 164 | 0; //@line 57504
 HEAP16[$c + 162 >> 1] = HEAP16[$67 >> 1] | 0; //@line 57507
 $70 = $62 & 16777215; //@line 57508
 $71 = $70 + 1 | 0; //@line 57509
 if ($71 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $77 = HEAP32[$c + 32 >> 2] | 0; //@line 57516
  $_0_i_i_i = HEAPU8[$77 + $70 | 0] << 8 | HEAPU8[$77 + $71 | 0]; //@line 57526
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $70) | 0; //@line 57534
 }
 HEAP16[$67 >> 1] = $_0_i_i_i; //@line 57537
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$61 >> 2] = (HEAP32[$61 >> 2] | 0) + 2; //@line 57545
  $99 = $c + 152 | 0; //@line 57546
  HEAP32[$99 >> 2] = (HEAP32[$99 >> 2] | 0) + 2; //@line 57549
  $102 = $d_1_i & 255; //@line 57550
  _e68_ea_set_val8($c, $102) | 0; //@line 57551
  STACKTOP = sp; //@line 57553
  return;
 } else {
  _e68_exception_bus($c); //@line 57556
  STACKTOP = sp; //@line 57558
  return;
 }
}
function _opc140($c) {
 $c = $c | 0;
 var $s2 = 0, $3 = 0, $5 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i_i = 0, $55 = 0, $62 = 0, $63 = 0, $64 = 0, $66 = 0, $69 = 0, $70 = 0, $75 = 0, $78 = 0, $79 = 0, $85 = 0, $_0_i_i_i13 = 0, $107 = 0, $114 = 0, $115 = 0, $127 = 0, $128 = 0, $131 = 0, $132 = 0, $137 = 0, $140 = 0, $141 = 0, $147 = 0, $_0_i_i = 0, $169 = 0, sp = 0;
 sp = STACKTOP; //@line 57587
 STACKTOP = STACKTOP + 8 | 0; //@line 57587
 $s2 = sp | 0; //@line 57588
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 57591
 $5 = $3 >>> 3 & 7; //@line 57593
 if (($5 | 0) == 0) {
  $10 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 57598
  $11 = HEAP32[$10 >> 2] | 0; //@line 57599
  $12 = $c + 88 + (($3 & 7) << 2) | 0; //@line 57600
  HEAP32[$10 >> 2] = HEAP32[$12 >> 2]; //@line 57602
  HEAP32[$12 >> 2] = $11; //@line 57603
  $14 = $c + 372 | 0; //@line 57604
  HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 10; //@line 57607
  $17 = $c + 156 | 0; //@line 57608
  $18 = HEAP32[$17 >> 2] | 0; //@line 57609
  if (($18 & 1 | 0) != 0) {
   _e68_exception_address($c, $18, 0, 0); //@line 57614
   STACKTOP = sp; //@line 57616
   return;
  }
  $23 = $c + 164 | 0; //@line 57619
  HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 57622
  $26 = $18 & 16777215; //@line 57623
  $27 = $26 + 1 | 0; //@line 57624
  if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $33 = HEAP32[$c + 32 >> 2] | 0; //@line 57631
   $_0_i_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 57641
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 57649
  }
  HEAP16[$23 >> 1] = $_0_i_i_i; //@line 57652
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 57660
   $55 = $c + 152 | 0; //@line 57661
   HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 57664
   STACKTOP = sp; //@line 57666
   return;
  } else {
   _e68_exception_bus($c); //@line 57669
   STACKTOP = sp; //@line 57671
   return;
  }
 } else if (($5 | 0) == 1) {
  $62 = $c + 120 + (($3 >>> 9 & 7) << 2) | 0; //@line 57678
  $63 = HEAP32[$62 >> 2] | 0; //@line 57679
  $64 = $c + 120 + (($3 & 7) << 2) | 0; //@line 57680
  HEAP32[$62 >> 2] = HEAP32[$64 >> 2]; //@line 57682
  HEAP32[$64 >> 2] = $63; //@line 57683
  $66 = $c + 372 | 0; //@line 57684
  HEAP32[$66 >> 2] = (HEAP32[$66 >> 2] | 0) + 10; //@line 57687
  $69 = $c + 156 | 0; //@line 57688
  $70 = HEAP32[$69 >> 2] | 0; //@line 57689
  if (($70 & 1 | 0) != 0) {
   _e68_exception_address($c, $70, 0, 0); //@line 57694
   STACKTOP = sp; //@line 57696
   return;
  }
  $75 = $c + 164 | 0; //@line 57699
  HEAP16[$c + 162 >> 1] = HEAP16[$75 >> 1] | 0; //@line 57702
  $78 = $70 & 16777215; //@line 57703
  $79 = $78 + 1 | 0; //@line 57704
  if ($79 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $85 = HEAP32[$c + 32 >> 2] | 0; //@line 57711
   $_0_i_i_i13 = HEAPU8[$85 + $78 | 0] << 8 | HEAPU8[$85 + $79 | 0]; //@line 57721
  } else {
   $_0_i_i_i13 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $78) | 0; //@line 57729
  }
  HEAP16[$75 >> 1] = $_0_i_i_i13; //@line 57732
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$69 >> 2] = (HEAP32[$69 >> 2] | 0) + 2; //@line 57740
   $107 = $c + 152 | 0; //@line 57741
   HEAP32[$107 >> 2] = (HEAP32[$107 >> 2] | 0) + 2; //@line 57744
   STACKTOP = sp; //@line 57746
   return;
  } else {
   _e68_exception_bus($c); //@line 57749
   STACKTOP = sp; //@line 57751
   return;
  }
 } else {
  $114 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 57758
  $115 = $3 & 63; //@line 57759
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($115 << 2) >> 2] & 127]($c, $115, 508, 16) | 0) != 0) {
   STACKTOP = sp; //@line 57766
   return;
  }
  if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 57773
   return;
  }
  $127 = HEAPU16[$s2 >> 1] & $114 & 65535; //@line 57779
  $128 = $c + 372 | 0; //@line 57780
  HEAP32[$128 >> 2] = (HEAP32[$128 >> 2] | 0) + 4; //@line 57783
  _e68_cc_set_nz_16($c, 15, $127); //@line 57784
  $131 = $c + 156 | 0; //@line 57785
  $132 = HEAP32[$131 >> 2] | 0; //@line 57786
  if (($132 & 1 | 0) != 0) {
   _e68_exception_address($c, $132, 0, 0); //@line 57791
   STACKTOP = sp; //@line 57793
   return;
  }
  $137 = $c + 164 | 0; //@line 57796
  HEAP16[$c + 162 >> 1] = HEAP16[$137 >> 1] | 0; //@line 57799
  $140 = $132 & 16777215; //@line 57800
  $141 = $140 + 1 | 0; //@line 57801
  if ($141 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $147 = HEAP32[$c + 32 >> 2] | 0; //@line 57808
   $_0_i_i = HEAPU8[$147 + $140 | 0] << 8 | HEAPU8[$147 + $141 | 0]; //@line 57818
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $140) | 0; //@line 57826
  }
  HEAP16[$137 >> 1] = $_0_i_i; //@line 57829
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$131 >> 2] = (HEAP32[$131 >> 2] | 0) + 2; //@line 57837
   $169 = $c + 152 | 0; //@line 57838
   HEAP32[$169 >> 2] = (HEAP32[$169 >> 2] | 0) + 2; //@line 57841
   _e68_ea_set_val16($c, $127) | 0; //@line 57842
   STACKTOP = sp; //@line 57844
   return;
  } else {
   _e68_exception_bus($c); //@line 57847
   STACKTOP = sp; //@line 57849
   return;
  }
 }
}
function _opc180($c) {
 $c = $c | 0;
 var $s2 = 0, $3 = 0, $7 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i_i = 0, $55 = 0, $60 = 0, $61 = 0, $71 = 0, $72 = 0, $75 = 0, $76 = 0, $81 = 0, $84 = 0, $85 = 0, $91 = 0, $_0_i_i = 0, $113 = 0, sp = 0;
 sp = STACKTOP; //@line 57872
 STACKTOP = STACKTOP + 8 | 0; //@line 57872
 $s2 = sp | 0; //@line 57873
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 57876
 $7 = $3 >>> 9 & 7; //@line 57880
 if (($3 & 56 | 0) == 8) {
  $10 = $c + 88 + ($7 << 2) | 0; //@line 57884
  $11 = HEAP32[$10 >> 2] | 0; //@line 57885
  $12 = $c + 120 + (($3 & 7) << 2) | 0; //@line 57886
  HEAP32[$10 >> 2] = HEAP32[$12 >> 2]; //@line 57888
  HEAP32[$12 >> 2] = $11; //@line 57889
  $14 = $c + 372 | 0; //@line 57890
  HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 10; //@line 57893
  $17 = $c + 156 | 0; //@line 57894
  $18 = HEAP32[$17 >> 2] | 0; //@line 57895
  if (($18 & 1 | 0) != 0) {
   _e68_exception_address($c, $18, 0, 0); //@line 57900
   STACKTOP = sp; //@line 57902
   return;
  }
  $23 = $c + 164 | 0; //@line 57905
  HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 57908
  $26 = $18 & 16777215; //@line 57909
  $27 = $26 + 1 | 0; //@line 57910
  if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $33 = HEAP32[$c + 32 >> 2] | 0; //@line 57917
   $_0_i_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 57927
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 57935
  }
  HEAP16[$23 >> 1] = $_0_i_i_i; //@line 57938
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 57946
   $55 = $c + 152 | 0; //@line 57947
   HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 57950
   STACKTOP = sp; //@line 57952
   return;
  } else {
   _e68_exception_bus($c); //@line 57955
   STACKTOP = sp; //@line 57957
   return;
  }
 }
 $60 = HEAP32[$c + 88 + ($7 << 2) >> 2] | 0; //@line 57962
 $61 = $3 & 63; //@line 57963
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($61 << 2) >> 2] & 127]($c, $61, 508, 32) | 0) != 0) {
  STACKTOP = sp; //@line 57970
  return;
 }
 if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
  STACKTOP = sp; //@line 57977
  return;
 }
 $71 = HEAP32[$s2 >> 2] & $60; //@line 57981
 $72 = $c + 372 | 0; //@line 57982
 HEAP32[$72 >> 2] = (HEAP32[$72 >> 2] | 0) + 6; //@line 57985
 _e68_cc_set_nz_32($c, 15, $71); //@line 57986
 $75 = $c + 156 | 0; //@line 57987
 $76 = HEAP32[$75 >> 2] | 0; //@line 57988
 if (($76 & 1 | 0) != 0) {
  _e68_exception_address($c, $76, 0, 0); //@line 57993
  STACKTOP = sp; //@line 57995
  return;
 }
 $81 = $c + 164 | 0; //@line 57998
 HEAP16[$c + 162 >> 1] = HEAP16[$81 >> 1] | 0; //@line 58001
 $84 = $76 & 16777215; //@line 58002
 $85 = $84 + 1 | 0; //@line 58003
 if ($85 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $91 = HEAP32[$c + 32 >> 2] | 0; //@line 58010
  $_0_i_i = HEAPU8[$91 + $84 | 0] << 8 | HEAPU8[$91 + $85 | 0]; //@line 58020
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $84) | 0; //@line 58028
 }
 HEAP16[$81 >> 1] = $_0_i_i; //@line 58031
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$75 >> 2] = (HEAP32[$75 >> 2] | 0) + 2; //@line 58039
  $113 = $c + 152 | 0; //@line 58040
  HEAP32[$113 >> 2] = (HEAP32[$113 >> 2] | 0) + 2; //@line 58043
  _e68_ea_set_val32($c, $71) | 0; //@line 58044
  STACKTOP = sp; //@line 58046
  return;
 } else {
  _e68_exception_bus($c); //@line 58049
  STACKTOP = sp; //@line 58051
  return;
 }
}
function _opc1c0($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $18 = 0, $21 = 0, $23 = 0, $n1_0 = 0, $n2_0 = 0, $s2_0 = 0, $33 = 0, $d_0 = 0, $36 = 0, $39 = 0, $40 = 0, $45 = 0, $48 = 0, $49 = 0, $55 = 0, $_0_i_i = 0, $77 = 0, sp = 0;
 sp = STACKTOP; //@line 58070
 STACKTOP = STACKTOP + 8 | 0; //@line 58070
 $s1 = sp | 0; //@line 58071
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58074
 $6 = $3 & 63; //@line 58077
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 16) | 0) != 0) {
  STACKTOP = sp; //@line 58084
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 58091
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 58094
 $16 = HEAP32[$15 >> 2] | 0; //@line 58095
 $18 = HEAP16[$s1 >> 1] | 0; //@line 58097
 if ($18 << 16 >> 16 > -1) {
  $n1_0 = 0;
  $23 = $18;
 } else {
  $21 = -$18 & 65535; //@line 58103
  HEAP16[$s1 >> 1] = $21; //@line 58104
  $n1_0 = 1;
  $23 = $21;
 }
 if (($16 & 32768 | 0) == 0) {
  $s2_0 = $16 & 65535;
  $n2_0 = 0;
 } else {
  $s2_0 = ($16 ^ 65535) + 1 & 65535;
  $n2_0 = 1;
 }
 $33 = Math_imul($23 & 65535, $s2_0 & 65535) | 0; //@line 58126
 $d_0 = ($n1_0 | 0) == ($n2_0 | 0) ? $33 : -$33 | 0; //@line 58129
 $36 = $c + 372 | 0; //@line 58130
 HEAP32[$36 >> 2] = (HEAP32[$36 >> 2] | 0) + 74; //@line 58133
 _e68_cc_set_nz_32($c, 15, $d_0); //@line 58134
 $39 = $c + 156 | 0; //@line 58135
 $40 = HEAP32[$39 >> 2] | 0; //@line 58136
 if (($40 & 1 | 0) != 0) {
  _e68_exception_address($c, $40, 0, 0); //@line 58141
  STACKTOP = sp; //@line 58143
  return;
 }
 $45 = $c + 164 | 0; //@line 58146
 HEAP16[$c + 162 >> 1] = HEAP16[$45 >> 1] | 0; //@line 58149
 $48 = $40 & 16777215; //@line 58150
 $49 = $48 + 1 | 0; //@line 58151
 if ($49 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $55 = HEAP32[$c + 32 >> 2] | 0; //@line 58158
  $_0_i_i = HEAPU8[$55 + $48 | 0] << 8 | HEAPU8[$55 + $49 | 0]; //@line 58168
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $48) | 0; //@line 58176
 }
 HEAP16[$45 >> 1] = $_0_i_i; //@line 58179
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 58187
  $77 = $c + 152 | 0; //@line 58188
  HEAP32[$77 >> 2] = (HEAP32[$77 >> 2] | 0) + 2; //@line 58191
  HEAP32[$15 >> 2] = $d_0; //@line 58192
  STACKTOP = sp; //@line 58194
  return;
 } else {
  _e68_exception_bus($c); //@line 58197
  STACKTOP = sp; //@line 58199
  return;
 }
}
function _opd000($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0, sp = 0;
 sp = STACKTOP; //@line 58216
 STACKTOP = STACKTOP + 8 | 0; //@line 58216
 $s1 = sp | 0; //@line 58217
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58220
 $6 = $3 & 63; //@line 58223
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4093, 8) | 0) != 0) {
  STACKTOP = sp; //@line 58230
  return;
 }
 if ((_e68_ea_get_val8($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 58237
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 58240
 $16 = HEAP32[$15 >> 2] | 0; //@line 58241
 $18 = HEAP8[$s1] | 0; //@line 58243
 $20 = ($18 & 255) + $16 | 0; //@line 58245
 $22 = $c + 372 | 0; //@line 58247
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 4; //@line 58250
 _e68_cc_set_add_8($c, $20 & 255, $18, $16 & 255); //@line 58251
 $25 = $c + 156 | 0; //@line 58252
 $26 = HEAP32[$25 >> 2] | 0; //@line 58253
 if (($26 & 1 | 0) != 0) {
  _e68_exception_address($c, $26, 0, 0); //@line 58258
  STACKTOP = sp; //@line 58260
  return;
 }
 $31 = $c + 164 | 0; //@line 58263
 HEAP16[$c + 162 >> 1] = HEAP16[$31 >> 1] | 0; //@line 58266
 $34 = $26 & 16777215; //@line 58267
 $35 = $34 + 1 | 0; //@line 58268
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 58275
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 58285
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 58293
 }
 HEAP16[$31 >> 1] = $_0_i_i; //@line 58296
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 2; //@line 58304
  $63 = $c + 152 | 0; //@line 58305
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 58308
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -256 | $20 & 255; //@line 58313
  STACKTOP = sp; //@line 58315
  return;
 } else {
  _e68_exception_bus($c); //@line 58318
  STACKTOP = sp; //@line 58320
  return;
 }
}
function _opd040($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0, sp = 0;
 sp = STACKTOP; //@line 58337
 STACKTOP = STACKTOP + 8 | 0; //@line 58337
 $s1 = sp | 0; //@line 58338
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58341
 $6 = $3 & 63; //@line 58344
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 58351
  return;
 }
 if ((_e68_ea_get_val16($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 58358
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 58361
 $16 = HEAP32[$15 >> 2] | 0; //@line 58362
 $18 = HEAP16[$s1 >> 1] | 0; //@line 58364
 $20 = ($18 & 65535) + $16 | 0; //@line 58366
 $22 = $c + 372 | 0; //@line 58368
 HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 4; //@line 58371
 _e68_cc_set_add_16($c, $20 & 65535, $18, $16 & 65535); //@line 58372
 $25 = $c + 156 | 0; //@line 58373
 $26 = HEAP32[$25 >> 2] | 0; //@line 58374
 if (($26 & 1 | 0) != 0) {
  _e68_exception_address($c, $26, 0, 0); //@line 58379
  STACKTOP = sp; //@line 58381
  return;
 }
 $31 = $c + 164 | 0; //@line 58384
 HEAP16[$c + 162 >> 1] = HEAP16[$31 >> 1] | 0; //@line 58387
 $34 = $26 & 16777215; //@line 58388
 $35 = $34 + 1 | 0; //@line 58389
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 58396
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 58406
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 58414
 }
 HEAP16[$31 >> 1] = $_0_i_i; //@line 58417
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 2; //@line 58425
  $63 = $c + 152 | 0; //@line 58426
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 58429
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] & -65536 | $20 & 65535; //@line 58434
  STACKTOP = sp; //@line 58436
  return;
 } else {
  _e68_exception_bus($c); //@line 58439
  STACKTOP = sp; //@line 58441
  return;
 }
}
function _opd080($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $32 = 0, $38 = 0, $_0_i_i = 0, $60 = 0, sp = 0;
 sp = STACKTOP; //@line 58457
 STACKTOP = STACKTOP + 8 | 0; //@line 58457
 $s1 = sp | 0; //@line 58458
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58461
 $6 = $3 & 63; //@line 58464
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 58471
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 58478
  return;
 }
 $15 = $c + 88 + (($3 >>> 9 & 7) << 2) | 0; //@line 58481
 $16 = HEAP32[$15 >> 2] | 0; //@line 58482
 $17 = HEAP32[$s1 >> 2] | 0; //@line 58483
 $18 = $17 + $16 | 0; //@line 58484
 $19 = $c + 372 | 0; //@line 58485
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 6; //@line 58488
 _e68_cc_set_add_32($c, $18, $17, $16); //@line 58489
 $22 = $c + 156 | 0; //@line 58490
 $23 = HEAP32[$22 >> 2] | 0; //@line 58491
 if (($23 & 1 | 0) != 0) {
  _e68_exception_address($c, $23, 0, 0); //@line 58496
  STACKTOP = sp; //@line 58498
  return;
 }
 $28 = $c + 164 | 0; //@line 58501
 HEAP16[$c + 162 >> 1] = HEAP16[$28 >> 1] | 0; //@line 58504
 $31 = $23 & 16777215; //@line 58505
 $32 = $31 + 1 | 0; //@line 58506
 if ($32 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $38 = HEAP32[$c + 32 >> 2] | 0; //@line 58513
  $_0_i_i = HEAPU8[$38 + $31 | 0] << 8 | HEAPU8[$38 + $32 | 0]; //@line 58523
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $31) | 0; //@line 58531
 }
 HEAP16[$28 >> 1] = $_0_i_i; //@line 58534
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 2; //@line 58542
  $60 = $c + 152 | 0; //@line 58543
  HEAP32[$60 >> 2] = (HEAP32[$60 >> 2] | 0) + 2; //@line 58546
  HEAP32[$15 >> 2] = $18; //@line 58547
  STACKTOP = sp; //@line 58549
  return;
 } else {
  _e68_exception_bus($c); //@line 58552
  STACKTOP = sp; //@line 58554
  return;
 }
}
function _opd0c0($c) {
 $c = $c | 0;
 var $t = 0, $3 = 0, $6 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $26 = 0, $27 = 0, $32 = 0, $35 = 0, $36 = 0, $42 = 0, $_0_i_i = 0, $64 = 0, sp = 0;
 sp = STACKTOP; //@line 58571
 STACKTOP = STACKTOP + 8 | 0; //@line 58571
 $t = sp | 0; //@line 58572
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58575
 $6 = $3 & 63; //@line 58578
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 58585
  return;
 }
 if ((_e68_ea_get_val16($c, $t) | 0) != 0) {
  STACKTOP = sp; //@line 58592
  return;
 }
 $16 = HEAPU16[$t >> 1] | 0; //@line 58596
 $21 = $c + 120 + (($3 >>> 9 & 7) << 2) | 0; //@line 58601
 $22 = HEAP32[$21 >> 2] | 0; //@line 58602
 $23 = $c + 372 | 0; //@line 58603
 HEAP32[$23 >> 2] = (HEAP32[$23 >> 2] | 0) + 8; //@line 58606
 $26 = $c + 156 | 0; //@line 58607
 $27 = HEAP32[$26 >> 2] | 0; //@line 58608
 if (($27 & 1 | 0) != 0) {
  _e68_exception_address($c, $27, 0, 0); //@line 58613
  STACKTOP = sp; //@line 58615
  return;
 }
 $32 = $c + 164 | 0; //@line 58618
 HEAP16[$c + 162 >> 1] = HEAP16[$32 >> 1] | 0; //@line 58621
 $35 = $27 & 16777215; //@line 58622
 $36 = $35 + 1 | 0; //@line 58623
 if ($36 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $42 = HEAP32[$c + 32 >> 2] | 0; //@line 58630
  $_0_i_i = HEAPU8[$42 + $35 | 0] << 8 | HEAPU8[$42 + $36 | 0]; //@line 58640
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $35) | 0; //@line 58648
 }
 HEAP16[$32 >> 1] = $_0_i_i; //@line 58651
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 2; //@line 58659
  $64 = $c + 152 | 0; //@line 58660
  HEAP32[$64 >> 2] = (HEAP32[$64 >> 2] | 0) + 2; //@line 58663
  HEAP32[$21 >> 2] = (($16 & 32768 | 0) != 0 ? $16 | -65536 : $16) + $22; //@line 58665
  STACKTOP = sp; //@line 58667
  return;
 } else {
  _e68_exception_bus($c); //@line 58670
  STACKTOP = sp; //@line 58672
  return;
 }
}
function _opd100($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $7 = 0, $9 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $32 = 0, $33 = 0, $39 = 0, $40 = 0, $43 = 0, $44 = 0, $49 = 0, $52 = 0, $53 = 0, $59 = 0, $_0_i_i_i = 0, $81 = 0, $89 = 0, $91 = 0, $100 = 0, $103 = 0, $104 = 0, $107 = 0, $108 = 0, $113 = 0, $116 = 0, $117 = 0, $123 = 0, $_0_i_i = 0, $145 = 0, sp = 0;
 sp = STACKTOP; //@line 58698
 STACKTOP = STACKTOP + 24 | 0; //@line 58698
 $s1_i = sp | 0; //@line 58699
 $s2_i = sp + 8 | 0; //@line 58700
 $s2 = sp + 16 | 0; //@line 58701
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58704
 if (($3 & 48 | 0) != 0) {
  $89 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 58712
  $91 = $3 & 63; //@line 58714
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($91 << 2) >> 2] & 127]($c, $91, 508, 8) | 0) != 0) {
   STACKTOP = sp; //@line 58721
   return;
  }
  if ((_e68_ea_get_val8($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 58728
   return;
  }
  $100 = HEAP8[$s2] | 0; //@line 58731
  $103 = ($100 & 255) + $89 & 255; //@line 58734
  $104 = $c + 372 | 0; //@line 58735
  HEAP32[$104 >> 2] = (HEAP32[$104 >> 2] | 0) + 8; //@line 58738
  _e68_cc_set_add_8($c, $103, $89 & 255, $100); //@line 58739
  $107 = $c + 156 | 0; //@line 58740
  $108 = HEAP32[$107 >> 2] | 0; //@line 58741
  if (($108 & 1 | 0) != 0) {
   _e68_exception_address($c, $108, 0, 0); //@line 58746
   STACKTOP = sp; //@line 58748
   return;
  }
  $113 = $c + 164 | 0; //@line 58751
  HEAP16[$c + 162 >> 1] = HEAP16[$113 >> 1] | 0; //@line 58754
  $116 = $108 & 16777215; //@line 58755
  $117 = $116 + 1 | 0; //@line 58756
  if ($117 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $123 = HEAP32[$c + 32 >> 2] | 0; //@line 58763
   $_0_i_i = HEAPU8[$123 + $116 | 0] << 8 | HEAPU8[$123 + $117 | 0]; //@line 58773
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $116) | 0; //@line 58781
  }
  HEAP16[$113 >> 1] = $_0_i_i; //@line 58784
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$107 >> 2] = (HEAP32[$107 >> 2] | 0) + 2; //@line 58792
   $145 = $c + 152 | 0; //@line 58793
   HEAP32[$145 >> 2] = (HEAP32[$145 >> 2] | 0) + 2; //@line 58796
   _e68_ea_set_val8($c, $103) | 0; //@line 58797
   STACKTOP = sp; //@line 58799
   return;
  } else {
   _e68_exception_bus($c); //@line 58802
   STACKTOP = sp; //@line 58804
   return;
  }
 }
 $7 = $3 & 7; //@line 58808
 $9 = $3 >>> 9 & 7; //@line 58810
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $9;
  $ea1_0_i = $7;
 } else {
  $ea2_0_i = $9 | 32;
  $ea1_0_i = $7 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 58830
  return;
 }
 if ((_e68_ea_get_val8($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 58837
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 8) | 0) != 0) {
  STACKTOP = sp; //@line 58846
  return;
 }
 if ((_e68_ea_get_val8($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 58853
  return;
 }
 $32 = HEAP8[$s1_i] | 0; //@line 58856
 $33 = HEAP8[$s2_i] | 0; //@line 58857
 $39 = ($33 + $32 & 255) + ((HEAPU16[$c + 166 >> 1] | 0) >>> 4 & 1) & 255; //@line 58864
 $40 = $c + 372 | 0; //@line 58865
 HEAP32[$40 >> 2] = (HEAP32[$40 >> 2] | 0) + 8; //@line 58868
 _e68_cc_set_addx_8($c, $39, $32, $33); //@line 58869
 $43 = $c + 156 | 0; //@line 58870
 $44 = HEAP32[$43 >> 2] | 0; //@line 58871
 if (($44 & 1 | 0) != 0) {
  _e68_exception_address($c, $44, 0, 0); //@line 58876
  STACKTOP = sp; //@line 58878
  return;
 }
 $49 = $c + 164 | 0; //@line 58881
 HEAP16[$c + 162 >> 1] = HEAP16[$49 >> 1] | 0; //@line 58884
 $52 = $44 & 16777215; //@line 58885
 $53 = $52 + 1 | 0; //@line 58886
 if ($53 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $59 = HEAP32[$c + 32 >> 2] | 0; //@line 58893
  $_0_i_i_i = HEAPU8[$59 + $52 | 0] << 8 | HEAPU8[$59 + $53 | 0]; //@line 58903
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $52) | 0; //@line 58911
 }
 HEAP16[$49 >> 1] = $_0_i_i_i; //@line 58914
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 58922
  $81 = $c + 152 | 0; //@line 58923
  HEAP32[$81 >> 2] = (HEAP32[$81 >> 2] | 0) + 2; //@line 58926
  _e68_ea_set_val8($c, $39) | 0; //@line 58927
  STACKTOP = sp; //@line 58929
  return;
 } else {
  _e68_exception_bus($c); //@line 58932
  STACKTOP = sp; //@line 58934
  return;
 }
}
function _opd140($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $9 = 0, $11 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $34 = 0, $35 = 0, $40 = 0, $41 = 0, $44 = 0, $45 = 0, $50 = 0, $53 = 0, $54 = 0, $60 = 0, $_0_i_i_i = 0, $82 = 0, $90 = 0, $92 = 0, $101 = 0, $104 = 0, $105 = 0, $108 = 0, $109 = 0, $114 = 0, $117 = 0, $118 = 0, $124 = 0, $_0_i_i = 0, $146 = 0, sp = 0;
 sp = STACKTOP; //@line 58960
 STACKTOP = STACKTOP + 24 | 0; //@line 58960
 $s1_i = sp | 0; //@line 58961
 $s2_i = sp + 8 | 0; //@line 58962
 $s2 = sp + 16 | 0; //@line 58963
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 58966
 if (($3 & 48 | 0) != 0) {
  $90 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 58974
  $92 = $3 & 63; //@line 58976
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($92 << 2) >> 2] & 127]($c, $92, 508, 16) | 0) != 0) {
   STACKTOP = sp; //@line 58983
   return;
  }
  if ((_e68_ea_get_val16($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 58990
   return;
  }
  $101 = HEAP16[$s2 >> 1] | 0; //@line 58993
  $104 = ($101 & 65535) + $90 & 65535; //@line 58996
  $105 = $c + 372 | 0; //@line 58997
  HEAP32[$105 >> 2] = (HEAP32[$105 >> 2] | 0) + 8; //@line 59000
  _e68_cc_set_add_16($c, $104, $90 & 65535, $101); //@line 59001
  $108 = $c + 156 | 0; //@line 59002
  $109 = HEAP32[$108 >> 2] | 0; //@line 59003
  if (($109 & 1 | 0) != 0) {
   _e68_exception_address($c, $109, 0, 0); //@line 59008
   STACKTOP = sp; //@line 59010
   return;
  }
  $114 = $c + 164 | 0; //@line 59013
  HEAP16[$c + 162 >> 1] = HEAP16[$114 >> 1] | 0; //@line 59016
  $117 = $109 & 16777215; //@line 59017
  $118 = $117 + 1 | 0; //@line 59018
  if ($118 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $124 = HEAP32[$c + 32 >> 2] | 0; //@line 59025
   $_0_i_i = HEAPU8[$124 + $117 | 0] << 8 | HEAPU8[$124 + $118 | 0]; //@line 59035
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $117) | 0; //@line 59043
  }
  HEAP16[$114 >> 1] = $_0_i_i; //@line 59046
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$108 >> 2] = (HEAP32[$108 >> 2] | 0) + 2; //@line 59054
   $146 = $c + 152 | 0; //@line 59055
   HEAP32[$146 >> 2] = (HEAP32[$146 >> 2] | 0) + 2; //@line 59058
   _e68_ea_set_val16($c, $104) | 0; //@line 59059
   STACKTOP = sp; //@line 59061
   return;
  } else {
   _e68_exception_bus($c); //@line 59064
   STACKTOP = sp; //@line 59066
   return;
  }
 }
 $9 = $3 & 7; //@line 59072
 $11 = $3 >>> 9 & 7; //@line 59074
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $11;
  $ea1_0_i = $9;
 } else {
  $ea2_0_i = $11 | 32;
  $ea1_0_i = $9 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 16) | 0) != 0) {
  STACKTOP = sp; //@line 59094
  return;
 }
 if ((_e68_ea_get_val16($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 59101
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 16) | 0) != 0) {
  STACKTOP = sp; //@line 59110
  return;
 }
 if ((_e68_ea_get_val16($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 59117
  return;
 }
 $34 = HEAP16[$s1_i >> 1] | 0; //@line 59120
 $35 = HEAP16[$s2_i >> 1] | 0; //@line 59121
 $40 = ($35 + $34 & 65535) + ((HEAPU16[$c + 166 >> 1] | 0) >>> 4 & 1) & 65535; //@line 59127
 $41 = $c + 372 | 0; //@line 59128
 HEAP32[$41 >> 2] = (HEAP32[$41 >> 2] | 0) + 8; //@line 59131
 _e68_cc_set_addx_16($c, $40, $34, $35); //@line 59132
 $44 = $c + 156 | 0; //@line 59133
 $45 = HEAP32[$44 >> 2] | 0; //@line 59134
 if (($45 & 1 | 0) != 0) {
  _e68_exception_address($c, $45, 0, 0); //@line 59139
  STACKTOP = sp; //@line 59141
  return;
 }
 $50 = $c + 164 | 0; //@line 59144
 HEAP16[$c + 162 >> 1] = HEAP16[$50 >> 1] | 0; //@line 59147
 $53 = $45 & 16777215; //@line 59148
 $54 = $53 + 1 | 0; //@line 59149
 if ($54 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $60 = HEAP32[$c + 32 >> 2] | 0; //@line 59156
  $_0_i_i_i = HEAPU8[$60 + $53 | 0] << 8 | HEAPU8[$60 + $54 | 0]; //@line 59166
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $53) | 0; //@line 59174
 }
 HEAP16[$50 >> 1] = $_0_i_i_i; //@line 59177
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 59185
  $82 = $c + 152 | 0; //@line 59186
  HEAP32[$82 >> 2] = (HEAP32[$82 >> 2] | 0) + 2; //@line 59189
  _e68_ea_set_val16($c, $40) | 0; //@line 59190
  STACKTOP = sp; //@line 59192
  return;
 } else {
  _e68_exception_bus($c); //@line 59195
  STACKTOP = sp; //@line 59197
  return;
 }
}
function _opd180($c) {
 $c = $c | 0;
 var $s1_i = 0, $s2_i = 0, $s2 = 0, $3 = 0, $9 = 0, $11 = 0, $ea1_0_i = 0, $ea2_0_i = 0, $34 = 0, $35 = 0, $41 = 0, $42 = 0, $45 = 0, $46 = 0, $51 = 0, $54 = 0, $55 = 0, $61 = 0, $_0_i_i_i = 0, $83 = 0, $91 = 0, $92 = 0, $101 = 0, $102 = 0, $103 = 0, $106 = 0, $107 = 0, $112 = 0, $115 = 0, $116 = 0, $122 = 0, $_0_i_i = 0, $144 = 0, sp = 0;
 sp = STACKTOP; //@line 59223
 STACKTOP = STACKTOP + 24 | 0; //@line 59223
 $s1_i = sp | 0; //@line 59224
 $s2_i = sp + 8 | 0; //@line 59225
 $s2 = sp + 16 | 0; //@line 59226
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 59229
 if (($3 & 48 | 0) != 0) {
  $91 = HEAP32[$c + 88 + (($3 >>> 9 & 7) << 2) >> 2] | 0; //@line 59237
  $92 = $3 & 63; //@line 59238
  if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($92 << 2) >> 2] & 127]($c, $92, 508, 32) | 0) != 0) {
   STACKTOP = sp; //@line 59245
   return;
  }
  if ((_e68_ea_get_val32($c, $s2) | 0) != 0) {
   STACKTOP = sp; //@line 59252
   return;
  }
  $101 = HEAP32[$s2 >> 2] | 0; //@line 59255
  $102 = $101 + $91 | 0; //@line 59256
  $103 = $c + 372 | 0; //@line 59257
  HEAP32[$103 >> 2] = (HEAP32[$103 >> 2] | 0) + 12; //@line 59260
  _e68_cc_set_add_32($c, $102, $91, $101); //@line 59261
  $106 = $c + 156 | 0; //@line 59262
  $107 = HEAP32[$106 >> 2] | 0; //@line 59263
  if (($107 & 1 | 0) != 0) {
   _e68_exception_address($c, $107, 0, 0); //@line 59268
   STACKTOP = sp; //@line 59270
   return;
  }
  $112 = $c + 164 | 0; //@line 59273
  HEAP16[$c + 162 >> 1] = HEAP16[$112 >> 1] | 0; //@line 59276
  $115 = $107 & 16777215; //@line 59277
  $116 = $115 + 1 | 0; //@line 59278
  if ($116 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $122 = HEAP32[$c + 32 >> 2] | 0; //@line 59285
   $_0_i_i = HEAPU8[$122 + $115 | 0] << 8 | HEAPU8[$122 + $116 | 0]; //@line 59295
  } else {
   $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $115) | 0; //@line 59303
  }
  HEAP16[$112 >> 1] = $_0_i_i; //@line 59306
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$106 >> 2] = (HEAP32[$106 >> 2] | 0) + 2; //@line 59314
   $144 = $c + 152 | 0; //@line 59315
   HEAP32[$144 >> 2] = (HEAP32[$144 >> 2] | 0) + 2; //@line 59318
   _e68_ea_set_val32($c, $102) | 0; //@line 59319
   STACKTOP = sp; //@line 59321
   return;
  } else {
   _e68_exception_bus($c); //@line 59324
   STACKTOP = sp; //@line 59326
   return;
  }
 }
 $9 = $3 & 7; //@line 59332
 $11 = $3 >>> 9 & 7; //@line 59334
 if (($3 & 8 | 0) == 0) {
  $ea2_0_i = $11;
  $ea1_0_i = $9;
 } else {
  $ea2_0_i = $11 | 32;
  $ea1_0_i = $9 | 32;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea1_0_i << 2) >> 2] & 127]($c, $ea1_0_i, 17, 32) | 0) != 0) {
  STACKTOP = sp; //@line 59354
  return;
 }
 if ((_e68_ea_get_val32($c, $s1_i) | 0) != 0) {
  STACKTOP = sp; //@line 59361
  return;
 }
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($ea2_0_i << 2) >> 2] & 127]($c, $ea2_0_i, 17, 32) | 0) != 0) {
  STACKTOP = sp; //@line 59370
  return;
 }
 if ((_e68_ea_get_val32($c, $s2_i) | 0) != 0) {
  STACKTOP = sp; //@line 59377
  return;
 }
 $34 = HEAP32[$s1_i >> 2] | 0; //@line 59380
 $35 = HEAP32[$s2_i >> 2] | 0; //@line 59381
 $41 = $35 + $34 + ((HEAPU16[$c + 166 >> 1] | 0) >>> 4 & 1) | 0; //@line 59388
 $42 = $c + 372 | 0; //@line 59389
 HEAP32[$42 >> 2] = (HEAP32[$42 >> 2] | 0) + 12; //@line 59392
 _e68_cc_set_addx_32($c, $41, $34, $35); //@line 59393
 $45 = $c + 156 | 0; //@line 59394
 $46 = HEAP32[$45 >> 2] | 0; //@line 59395
 if (($46 & 1 | 0) != 0) {
  _e68_exception_address($c, $46, 0, 0); //@line 59400
  STACKTOP = sp; //@line 59402
  return;
 }
 $51 = $c + 164 | 0; //@line 59405
 HEAP16[$c + 162 >> 1] = HEAP16[$51 >> 1] | 0; //@line 59408
 $54 = $46 & 16777215; //@line 59409
 $55 = $54 + 1 | 0; //@line 59410
 if ($55 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $61 = HEAP32[$c + 32 >> 2] | 0; //@line 59417
  $_0_i_i_i = HEAPU8[$61 + $54 | 0] << 8 | HEAPU8[$61 + $55 | 0]; //@line 59427
 } else {
  $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $54) | 0; //@line 59435
 }
 HEAP16[$51 >> 1] = $_0_i_i_i; //@line 59438
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$45 >> 2] = (HEAP32[$45 >> 2] | 0) + 2; //@line 59446
  $83 = $c + 152 | 0; //@line 59447
  HEAP32[$83 >> 2] = (HEAP32[$83 >> 2] | 0) + 2; //@line 59450
  _e68_ea_set_val32($c, $41) | 0; //@line 59451
  STACKTOP = sp; //@line 59453
  return;
 } else {
  _e68_exception_bus($c); //@line 59456
  STACKTOP = sp; //@line 59458
  return;
 }
}
function _opd1c0($c) {
 $c = $c | 0;
 var $s1 = 0, $3 = 0, $6 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $31 = 0, $37 = 0, $_0_i_i = 0, $59 = 0, sp = 0;
 sp = STACKTOP; //@line 59474
 STACKTOP = STACKTOP + 8 | 0; //@line 59474
 $s1 = sp | 0; //@line 59475
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 59478
 $6 = $3 & 63; //@line 59481
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($6 << 2) >> 2] & 127]($c, $6, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 59488
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 59495
  return;
 }
 $15 = $c + 120 + (($3 >>> 9 & 7) << 2) | 0; //@line 59498
 $16 = HEAP32[$15 >> 2] | 0; //@line 59499
 $17 = HEAP32[$s1 >> 2] | 0; //@line 59500
 $18 = $c + 372 | 0; //@line 59501
 HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 6; //@line 59504
 $21 = $c + 156 | 0; //@line 59505
 $22 = HEAP32[$21 >> 2] | 0; //@line 59506
 if (($22 & 1 | 0) != 0) {
  _e68_exception_address($c, $22, 0, 0); //@line 59511
  STACKTOP = sp; //@line 59513
  return;
 }
 $27 = $c + 164 | 0; //@line 59516
 HEAP16[$c + 162 >> 1] = HEAP16[$27 >> 1] | 0; //@line 59519
 $30 = $22 & 16777215; //@line 59520
 $31 = $30 + 1 | 0; //@line 59521
 if ($31 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $37 = HEAP32[$c + 32 >> 2] | 0; //@line 59528
  $_0_i_i = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 59538
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 59546
 }
 HEAP16[$27 >> 1] = $_0_i_i; //@line 59549
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 59557
  $59 = $c + 152 | 0; //@line 59558
  HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 59561
  HEAP32[$15 >> 2] = $17 + $16; //@line 59563
  STACKTOP = sp; //@line 59565
  return;
 } else {
  _e68_exception_bus($c); //@line 59568
  STACKTOP = sp; //@line 59570
  return;
 }
}
function _ope000($c) {
 $c = $c | 0;
 var $3 = 0, $5 = 0, $7 = 0, $9 = 0, $13 = 0, $17 = 0, $18 = 0, $19 = 0, $23 = 0, $27 = 0, $28 = 0, $_0_i23_i = 0, $30 = 0, $32 = 0, $36 = 0, $41 = 0, $42 = 0, $48 = 0, $49 = 0, $55 = 0, $_0_i24_i = 0, $d_1_i = 0, $58 = 0, $61 = 0, $62 = 0, $67 = 0, $70 = 0, $71 = 0, $77 = 0, $_0_i_i_i = 0, $99 = 0, $108 = 0, $109 = 0, $111 = 0, $117 = 0, $121 = 0, $_0_i22_i = 0, $127 = 0, $129 = 0, $134 = 0, $135 = 0, $146 = 0, $150 = 0, $_0_i23_i9 = 0, $d_0_i = 0, $156 = 0, $159 = 0, $160 = 0, $165 = 0, $168 = 0, $169 = 0, $175 = 0, $_0_i_i_i10 = 0, $197 = 0, $206 = 0, $208 = 0, $209 = 0, $211 = 0, $213 = 0, $219 = 0, $x_017_i = 0, $x_01726_i = 0, $_0_i24_i15 = 0, $x_020_i = 0, $v_019_i = 0, $i_018_i = 0, $224 = 0, $225 = 0, $x_0_i = 0, $_0_i25_i = 0, $x_0_lcssa_i = 0, $v_0_lcssa_i = 0, $229 = 0, $234 = 0, $237 = 0, $238 = 0, $243 = 0, $246 = 0, $247 = 0, $253 = 0, $_0_i_i_i16 = 0, $275 = 0, $284 = 0, $285 = 0, $286 = 0, $288 = 0, $_0_i_i = 0, $297 = 0, $300 = 0, $304 = 0, $305 = 0, $308 = 0, $309 = 0, $320 = 0, $324 = 0, $d_0_i20 = 0, $330 = 0, $333 = 0, $334 = 0, $339 = 0, $342 = 0, $343 = 0, $349 = 0, $_0_i_i_i21 = 0, $371 = 0, $379 = 0, label = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 59627
 $5 = $3 >>> 3 & 3; //@line 59629
 if (($5 | 0) == 0) {
  $7 = $3 & 7; //@line 59631
  $9 = $3 >>> 9 & 7; //@line 59633
  do {
   if (($3 & 32 | 0) == 0) {
    $13 = $c + 88 + ($7 << 2) | 0; //@line 59641
    $_0_i23_i = ($9 | 0) == 0 ? 8 : $9;
    $28 = $13;
    $27 = HEAP32[$13 >> 2] | 0;
    label = 7411; //@line 59645
   } else {
    $17 = HEAP32[$c + 88 + ($9 << 2) >> 2] & 63; //@line 59649
    $18 = $c + 88 + ($7 << 2) | 0; //@line 59650
    $19 = HEAP32[$18 >> 2] | 0; //@line 59651
    if (($17 | 0) != 0) {
     $_0_i23_i = $17;
     $28 = $18;
     $27 = $19;
     label = 7411; //@line 59656
     break;
    }
    $23 = $c + 166 | 0; //@line 59660
    HEAP16[$23 >> 1] = HEAP16[$23 >> 1] & -2; //@line 59663
    $d_1_i = $19 & 255;
    $_0_i24_i = 0;
    $55 = $18;
   }
  } while (0);
  do {
   if ((label | 0) == 7411) {
    $30 = $27 & 255; //@line 59674
    $32 = ($27 & 128 | 0) != 0; //@line 59676
    if ($_0_i23_i >>> 0 < 8) {
     $36 = ($32 ? $30 | 65280 : $30) >>> ($_0_i23_i >>> 0) & 255; //@line 59682
     $41 = $c + 166 | 0; //@line 59687
     $42 = HEAP16[$41 >> 1] | 0; //@line 59688
     if ((1 << $_0_i23_i - 1 & $30 | 0) == 0) {
      HEAP16[$41 >> 1] = $42 & -18; //@line 59692
      $d_1_i = $36;
      $_0_i24_i = $_0_i23_i;
      $55 = $28;
      break;
     } else {
      HEAP16[$41 >> 1] = $42 | 17; //@line 59697
      $d_1_i = $36;
      $_0_i24_i = $_0_i23_i;
      $55 = $28;
      break;
     }
    } else {
     $48 = $c + 166 | 0; //@line 59703
     $49 = HEAP16[$48 >> 1] | 0; //@line 59704
     if ($32) {
      HEAP16[$48 >> 1] = $49 | 17; //@line 59708
      $d_1_i = -1;
      $_0_i24_i = $_0_i23_i;
      $55 = $28;
      break;
     } else {
      HEAP16[$48 >> 1] = $49 & -18; //@line 59714
      $d_1_i = 0;
      $_0_i24_i = $_0_i23_i;
      $55 = $28;
      break;
     }
    }
   }
  } while (0);
  $58 = $c + 372 | 0; //@line 59726
  HEAP32[$58 >> 2] = ($_0_i24_i << 1) + 6 + (HEAP32[$58 >> 2] | 0); //@line 59729
  _e68_cc_set_nz_8($c, 14, $d_1_i); //@line 59730
  $61 = $c + 156 | 0; //@line 59731
  $62 = HEAP32[$61 >> 2] | 0; //@line 59732
  if (($62 & 1 | 0) != 0) {
   _e68_exception_address($c, $62, 0, 0); //@line 59737
   return;
  }
  $67 = $c + 164 | 0; //@line 59742
  HEAP16[$c + 162 >> 1] = HEAP16[$67 >> 1] | 0; //@line 59745
  $70 = $62 & 16777215; //@line 59746
  $71 = $70 + 1 | 0; //@line 59747
  if ($71 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $77 = HEAP32[$c + 32 >> 2] | 0; //@line 59754
   $_0_i_i_i = HEAPU8[$77 + $70 | 0] << 8 | HEAPU8[$77 + $71 | 0]; //@line 59764
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $70) | 0; //@line 59772
  }
  HEAP16[$67 >> 1] = $_0_i_i_i; //@line 59775
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$61 >> 2] = (HEAP32[$61 >> 2] | 0) + 2; //@line 59783
   $99 = $c + 152 | 0; //@line 59784
   HEAP32[$99 >> 2] = (HEAP32[$99 >> 2] | 0) + 2; //@line 59787
   HEAP32[$55 >> 2] = HEAP32[$55 >> 2] & -256 | $d_1_i & 255; //@line 59792
   return;
  } else {
   _e68_exception_bus($c); //@line 59797
   return;
  }
 } else if (($5 | 0) == 3) {
  $284 = $c + 88 + (($3 & 7) << 2) | 0; //@line 59804
  $285 = HEAP32[$284 >> 2] | 0; //@line 59805
  $286 = $285 & 255; //@line 59806
  $288 = $3 >>> 9 & 7; //@line 59808
  if (($3 & 32 | 0) == 0) {
   $_0_i_i = ($288 | 0) == 0 ? 8 : $288; //@line 59816
  } else {
   $_0_i_i = HEAP32[$c + 88 + ($288 << 2) >> 2] & 63; //@line 59822
  }
  $297 = $_0_i_i & 7; //@line 59825
  L9300 : do {
   if (($297 | 0) == 0) {
    do {
     if (($_0_i_i | 0) != 0) {
      if (($285 & 128 | 0) == 0) {
       break;
      }
      $320 = $c + 166 | 0; //@line 59840
      HEAP16[$320 >> 1] = HEAP16[$320 >> 1] | 1; //@line 59843
      $d_0_i20 = $286; //@line 59845
      break L9300;
     }
    } while (0);
    $324 = $c + 166 | 0; //@line 59849
    HEAP16[$324 >> 1] = HEAP16[$324 >> 1] & -2; //@line 59852
    $d_0_i20 = $286; //@line 59853
   } else {
    $300 = $285 & 255; //@line 59855
    $304 = $300 << 8 - $297 | $300 >>> ($297 >>> 0); //@line 59859
    $305 = $304 & 255; //@line 59860
    $308 = $c + 166 | 0; //@line 59863
    $309 = HEAP16[$308 >> 1] | 0; //@line 59864
    if (($304 & 128 | 0) == 0) {
     HEAP16[$308 >> 1] = $309 & -2; //@line 59868
     $d_0_i20 = $305; //@line 59869
     break;
    } else {
     HEAP16[$308 >> 1] = $309 | 1; //@line 59873
     $d_0_i20 = $305; //@line 59875
     break;
    }
   }
  } while (0);
  $330 = $c + 372 | 0; //@line 59883
  HEAP32[$330 >> 2] = ($_0_i_i << 1) + 6 + (HEAP32[$330 >> 2] | 0); //@line 59886
  _e68_cc_set_nz_8($c, 14, $d_0_i20); //@line 59887
  $333 = $c + 156 | 0; //@line 59888
  $334 = HEAP32[$333 >> 2] | 0; //@line 59889
  if (($334 & 1 | 0) != 0) {
   _e68_exception_address($c, $334, 0, 0); //@line 59894
   return;
  }
  $339 = $c + 164 | 0; //@line 59899
  HEAP16[$c + 162 >> 1] = HEAP16[$339 >> 1] | 0; //@line 59902
  $342 = $334 & 16777215; //@line 59903
  $343 = $342 + 1 | 0; //@line 59904
  if ($343 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $349 = HEAP32[$c + 32 >> 2] | 0; //@line 59911
   $_0_i_i_i21 = HEAPU8[$349 + $342 | 0] << 8 | HEAPU8[$349 + $343 | 0]; //@line 59921
  } else {
   $_0_i_i_i21 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $342) | 0; //@line 59929
  }
  HEAP16[$339 >> 1] = $_0_i_i_i21; //@line 59932
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$333 >> 2] = (HEAP32[$333 >> 2] | 0) + 2; //@line 59940
   $371 = $c + 152 | 0; //@line 59941
   HEAP32[$371 >> 2] = (HEAP32[$371 >> 2] | 0) + 2; //@line 59944
   HEAP32[$284 >> 2] = HEAP32[$284 >> 2] & -256 | $d_0_i20 & 255; //@line 59949
   return;
  } else {
   _e68_exception_bus($c); //@line 59954
   return;
  }
 } else if (($5 | 0) == 2) {
  $206 = $c + 88 + (($3 & 7) << 2) | 0; //@line 59961
  $208 = HEAP32[$206 >> 2] & 255; //@line 59964
  $209 = $c + 166 | 0; //@line 59965
  $211 = (HEAPU16[$209 >> 1] | 0) >>> 4; //@line 59967
  $213 = $3 >>> 9 & 7; //@line 59969
  if (($3 & 32 | 0) == 0) {
   $_0_i24_i15 = ($213 | 0) == 0 ? 8 : $213;
   $x_01726_i = $211 & 1;
   label = 7449; //@line 59979
  } else {
   $219 = HEAP32[$c + 88 + ($213 << 2) >> 2] & 63; //@line 59983
   $x_017_i = $211 & 1; //@line 59984
   if (($219 | 0) == 0) {
    $v_0_lcssa_i = $208;
    $x_0_lcssa_i = $x_017_i;
    $_0_i25_i = 0;
   } else {
    $_0_i24_i15 = $219;
    $x_01726_i = $x_017_i;
    label = 7449; //@line 59991
   }
  }
  if ((label | 0) == 7449) {
   $i_018_i = 0;
   $v_019_i = $208;
   $x_020_i = $x_01726_i;
   while (1) {
    $224 = ($v_019_i & 65535) >>> 1 | $x_020_i << 7; //@line 60005
    $225 = $i_018_i + 1 | 0; //@line 60006
    $x_0_i = $v_019_i & 1; //@line 60007
    if ($225 >>> 0 < $_0_i24_i15 >>> 0) {
     $i_018_i = $225;
     $v_019_i = $224;
     $x_020_i = $x_0_i;
    } else {
     $v_0_lcssa_i = $224;
     $x_0_lcssa_i = $x_0_i;
     $_0_i25_i = $_0_i24_i15;
     break;
    }
   }
  }
  $229 = $c + 372 | 0; //@line 60023
  HEAP32[$229 >> 2] = ($_0_i25_i << 1) + 6 + (HEAP32[$229 >> 2] | 0); //@line 60026
  _e68_cc_set_nz_8($c, 14, $v_0_lcssa_i & 255); //@line 60028
  $234 = HEAP16[$209 >> 1] | 0; //@line 60030
  HEAP16[$209 >> 1] = $x_0_lcssa_i << 16 >> 16 == 0 ? $234 & -18 : $234 | 17; //@line 60034
  $237 = $c + 156 | 0; //@line 60035
  $238 = HEAP32[$237 >> 2] | 0; //@line 60036
  if (($238 & 1 | 0) != 0) {
   _e68_exception_address($c, $238, 0, 0); //@line 60041
   return;
  }
  $243 = $c + 164 | 0; //@line 60046
  HEAP16[$c + 162 >> 1] = HEAP16[$243 >> 1] | 0; //@line 60049
  $246 = $238 & 16777215; //@line 60050
  $247 = $246 + 1 | 0; //@line 60051
  if ($247 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $253 = HEAP32[$c + 32 >> 2] | 0; //@line 60058
   $_0_i_i_i16 = HEAPU8[$253 + $246 | 0] << 8 | HEAPU8[$253 + $247 | 0]; //@line 60068
  } else {
   $_0_i_i_i16 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $246) | 0; //@line 60076
  }
  HEAP16[$243 >> 1] = $_0_i_i_i16; //@line 60079
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$237 >> 2] = (HEAP32[$237 >> 2] | 0) + 2; //@line 60087
   $275 = $c + 152 | 0; //@line 60088
   HEAP32[$275 >> 2] = (HEAP32[$275 >> 2] | 0) + 2; //@line 60091
   HEAP32[$206 >> 2] = HEAP32[$206 >> 2] & -256 | $v_0_lcssa_i & 255; //@line 60097
   return;
  } else {
   _e68_exception_bus($c); //@line 60102
   return;
  }
 } else if (($5 | 0) == 1) {
  $108 = $c + 88 + (($3 & 7) << 2) | 0; //@line 60109
  $109 = HEAP32[$108 >> 2] | 0; //@line 60110
  $111 = $3 >>> 9 & 7; //@line 60112
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i22_i = ($111 | 0) == 0 ? 8 : $111; //@line 60121
    label = 7430; //@line 60122
   } else {
    $117 = HEAP32[$c + 88 + ($111 << 2) >> 2] & 63; //@line 60126
    if (($117 | 0) != 0) {
     $_0_i22_i = $117; //@line 60130
     label = 7430; //@line 60131
     break;
    }
    $121 = $c + 166 | 0; //@line 60135
    HEAP16[$121 >> 1] = HEAP16[$121 >> 1] & -2; //@line 60138
    $d_0_i = $109 & 255;
    $_0_i23_i9 = 0;
   }
  } while (0);
  L9353 : do {
   if ((label | 0) == 7430) {
    if ($_0_i22_i >>> 0 < 8) {
     $127 = $109 & 255; //@line 60149
     $129 = $127 >>> ($_0_i22_i >>> 0) & 255; //@line 60151
     $134 = $c + 166 | 0; //@line 60156
     $135 = HEAP16[$134 >> 1] | 0; //@line 60157
     if ((1 << $_0_i22_i - 1 & $127 | 0) == 0) {
      HEAP16[$134 >> 1] = $135 & -18; //@line 60161
      $d_0_i = $129;
      $_0_i23_i9 = $_0_i22_i;
      break;
     } else {
      HEAP16[$134 >> 1] = $135 | 17; //@line 60166
      $d_0_i = $129;
      $_0_i23_i9 = $_0_i22_i;
      break;
     }
    }
    do {
     if (($_0_i22_i | 0) == 8) {
      if (($109 & 128 | 0) == 0) {
       break;
      }
      $146 = $c + 166 | 0; //@line 60182
      HEAP16[$146 >> 1] = HEAP16[$146 >> 1] | 17; //@line 60185
      $d_0_i = 0;
      $_0_i23_i9 = 8;
      break L9353;
     }
    } while (0);
    $150 = $c + 166 | 0; //@line 60191
    HEAP16[$150 >> 1] = HEAP16[$150 >> 1] & -18; //@line 60194
    $d_0_i = 0;
    $_0_i23_i9 = $_0_i22_i;
   }
  } while (0);
  $156 = $c + 372 | 0; //@line 60202
  HEAP32[$156 >> 2] = ($_0_i23_i9 << 1) + 6 + (HEAP32[$156 >> 2] | 0); //@line 60205
  _e68_cc_set_nz_8($c, 14, $d_0_i); //@line 60206
  $159 = $c + 156 | 0; //@line 60207
  $160 = HEAP32[$159 >> 2] | 0; //@line 60208
  if (($160 & 1 | 0) != 0) {
   _e68_exception_address($c, $160, 0, 0); //@line 60213
   return;
  }
  $165 = $c + 164 | 0; //@line 60218
  HEAP16[$c + 162 >> 1] = HEAP16[$165 >> 1] | 0; //@line 60221
  $168 = $160 & 16777215; //@line 60222
  $169 = $168 + 1 | 0; //@line 60223
  if ($169 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $175 = HEAP32[$c + 32 >> 2] | 0; //@line 60230
   $_0_i_i_i10 = HEAPU8[$175 + $168 | 0] << 8 | HEAPU8[$175 + $169 | 0]; //@line 60240
  } else {
   $_0_i_i_i10 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $168) | 0; //@line 60248
  }
  HEAP16[$165 >> 1] = $_0_i_i_i10; //@line 60251
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$159 >> 2] = (HEAP32[$159 >> 2] | 0) + 2; //@line 60259
   $197 = $c + 152 | 0; //@line 60260
   HEAP32[$197 >> 2] = (HEAP32[$197 >> 2] | 0) + 2; //@line 60263
   HEAP32[$108 >> 2] = HEAP32[$108 >> 2] & -256 | $d_0_i & 255; //@line 60268
   return;
  } else {
   _e68_exception_bus($c); //@line 60273
   return;
  }
 } else {
  _e68_exception_illegal($c); //@line 60279
  $379 = $c + 372 | 0; //@line 60280
  HEAP32[$379 >> 2] = (HEAP32[$379 >> 2] | 0) + 2; //@line 60283
  return;
 }
}
function _ope040($c) {
 $c = $c | 0;
 var $3 = 0, $5 = 0, $8 = 0, $9 = 0, $11 = 0, $19 = 0, $23 = 0, $29 = 0, $31 = 0, $_0_i2325_i = 0, $32 = 0, $35 = 0, $40 = 0, $41 = 0, $47 = 0, $48 = 0, $_0_i24_i = 0, $d_1_i = 0, $56 = 0, $59 = 0, $60 = 0, $65 = 0, $68 = 0, $69 = 0, $75 = 0, $_0_i_i_i = 0, $97 = 0, $106 = 0, $107 = 0, $109 = 0, $115 = 0, $119 = 0, $_0_i2224_i = 0, $125 = 0, $127 = 0, $132 = 0, $133 = 0, $144 = 0, $148 = 0, $_0_i23_i = 0, $d_0_i = 0, $154 = 0, $157 = 0, $158 = 0, $163 = 0, $166 = 0, $167 = 0, $173 = 0, $_0_i_i_i9 = 0, $195 = 0, $204 = 0, $206 = 0, $208 = 0, $212 = 0, $217 = 0, $218 = 0, $220 = 0, $222 = 0, $223 = 0, $_0_i21_i = 0, $d_019_i = 0, $i_018_i = 0, $x_0_in17_i = 0, $227 = 0, $228 = 0, $230 = 0, $_0_i22_i = 0, $d_0_lcssa_i = 0, $x_0_in_lcssa_i = 0, $233 = 0, $237 = 0, $240 = 0, $241 = 0, $246 = 0, $249 = 0, $250 = 0, $256 = 0, $_0_i_i_i13 = 0, $278 = 0, $287 = 0, $288 = 0, $289 = 0, $291 = 0, $_0_i_i = 0, $303 = 0, $307 = 0, $308 = 0, $311 = 0, $312 = 0, $323 = 0, $327 = 0, $d_0_i17 = 0, $333 = 0, $336 = 0, $337 = 0, $342 = 0, $345 = 0, $346 = 0, $352 = 0, $_0_i_i_i18 = 0, $374 = 0, $382 = 0, label = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 60341
 $5 = $3 >>> 3 & 3; //@line 60343
 if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 60346
  $9 = HEAP32[$8 >> 2] | 0; //@line 60347
  $11 = $3 >>> 9 & 7; //@line 60349
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i2325_i = ($11 | 0) == 0 ? 8 : $11;
    $31 = ($9 & 32768 | 0) != 0;
    label = 7499; //@line 60361
   } else {
    $19 = HEAP32[$c + 88 + ($11 << 2) >> 2] & 63; //@line 60365
    if (($19 | 0) == 0) {
     $23 = $c + 166 | 0; //@line 60370
     HEAP16[$23 >> 1] = HEAP16[$23 >> 1] & -2; //@line 60373
     $d_1_i = $9 & 65535;
     $_0_i24_i = 0;
     break;
    }
    $29 = ($9 & 32768 | 0) != 0; //@line 60380
    if ($19 >>> 0 < 16) {
     $_0_i2325_i = $19;
     $31 = $29;
     label = 7499; //@line 60384
     break;
    }
    $47 = $c + 166 | 0; //@line 60387
    $48 = HEAP16[$47 >> 1] | 0; //@line 60388
    if ($29) {
     HEAP16[$47 >> 1] = $48 | 17; //@line 60392
     $d_1_i = -1;
     $_0_i24_i = $19;
     break;
    } else {
     HEAP16[$47 >> 1] = $48 & -18; //@line 60398
     $d_1_i = 0;
     $_0_i24_i = $19;
     break;
    }
   }
  } while (0);
  do {
   if ((label | 0) == 7499) {
    $32 = $9 & 65535; //@line 60408
    $35 = ($31 ? $9 | -65536 : $32) >>> ($_0_i2325_i >>> 0) & 65535; //@line 60412
    $40 = $c + 166 | 0; //@line 60417
    $41 = HEAP16[$40 >> 1] | 0; //@line 60418
    if ((1 << $_0_i2325_i - 1 & $32 | 0) == 0) {
     HEAP16[$40 >> 1] = $41 & -18; //@line 60422
     $d_1_i = $35;
     $_0_i24_i = $_0_i2325_i;
     break;
    } else {
     HEAP16[$40 >> 1] = $41 | 17; //@line 60427
     $d_1_i = $35;
     $_0_i24_i = $_0_i2325_i;
     break;
    }
   }
  } while (0);
  $56 = $c + 372 | 0; //@line 60438
  HEAP32[$56 >> 2] = ($_0_i24_i << 1) + 6 + (HEAP32[$56 >> 2] | 0); //@line 60441
  _e68_cc_set_nz_16($c, 14, $d_1_i); //@line 60442
  $59 = $c + 156 | 0; //@line 60443
  $60 = HEAP32[$59 >> 2] | 0; //@line 60444
  if (($60 & 1 | 0) != 0) {
   _e68_exception_address($c, $60, 0, 0); //@line 60449
   return;
  }
  $65 = $c + 164 | 0; //@line 60454
  HEAP16[$c + 162 >> 1] = HEAP16[$65 >> 1] | 0; //@line 60457
  $68 = $60 & 16777215; //@line 60458
  $69 = $68 + 1 | 0; //@line 60459
  if ($69 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $75 = HEAP32[$c + 32 >> 2] | 0; //@line 60466
   $_0_i_i_i = HEAPU8[$75 + $68 | 0] << 8 | HEAPU8[$75 + $69 | 0]; //@line 60476
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $68) | 0; //@line 60484
  }
  HEAP16[$65 >> 1] = $_0_i_i_i; //@line 60487
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 60495
   $97 = $c + 152 | 0; //@line 60496
   HEAP32[$97 >> 2] = (HEAP32[$97 >> 2] | 0) + 2; //@line 60499
   HEAP32[$8 >> 2] = HEAP32[$8 >> 2] & -65536 | $d_1_i & 65535; //@line 60504
   return;
  } else {
   _e68_exception_bus($c); //@line 60509
   return;
  }
 } else if (($5 | 0) == 1) {
  $106 = $c + 88 + (($3 & 7) << 2) | 0; //@line 60516
  $107 = HEAP32[$106 >> 2] | 0; //@line 60517
  $109 = $3 >>> 9 & 7; //@line 60519
  L9412 : do {
   if (($3 & 32 | 0) == 0) {
    $_0_i2224_i = ($109 | 0) == 0 ? 8 : $109; //@line 60528
    label = 7518; //@line 60529
   } else {
    $115 = HEAP32[$c + 88 + ($109 << 2) >> 2] & 63; //@line 60533
    if (($115 | 0) == 0) {
     $119 = $c + 166 | 0; //@line 60538
     HEAP16[$119 >> 1] = HEAP16[$119 >> 1] & -2; //@line 60541
     $d_0_i = $107 & 65535;
     $_0_i23_i = 0;
     break;
    }
    if ($115 >>> 0 < 16) {
     $_0_i2224_i = $115; //@line 60549
     label = 7518; //@line 60550
     break;
    }
    do {
     if (($115 | 0) == 16) {
      if (($107 & 32768 | 0) == 0) {
       break;
      }
      $144 = $c + 166 | 0; //@line 60563
      HEAP16[$144 >> 1] = HEAP16[$144 >> 1] | 17; //@line 60566
      $d_0_i = 0;
      $_0_i23_i = 16;
      break L9412;
     }
    } while (0);
    $148 = $c + 166 | 0; //@line 60572
    HEAP16[$148 >> 1] = HEAP16[$148 >> 1] & -18; //@line 60575
    $d_0_i = 0;
    $_0_i23_i = $115;
   }
  } while (0);
  do {
   if ((label | 0) == 7518) {
    $125 = $107 & 65535; //@line 60582
    $127 = $125 >>> ($_0_i2224_i >>> 0) & 65535; //@line 60584
    $132 = $c + 166 | 0; //@line 60589
    $133 = HEAP16[$132 >> 1] | 0; //@line 60590
    if ((1 << $_0_i2224_i - 1 & $125 | 0) == 0) {
     HEAP16[$132 >> 1] = $133 & -18; //@line 60594
     $d_0_i = $127;
     $_0_i23_i = $_0_i2224_i;
     break;
    } else {
     HEAP16[$132 >> 1] = $133 | 17; //@line 60599
     $d_0_i = $127;
     $_0_i23_i = $_0_i2224_i;
     break;
    }
   }
  } while (0);
  $154 = $c + 372 | 0; //@line 60610
  HEAP32[$154 >> 2] = ($_0_i23_i << 1) + 6 + (HEAP32[$154 >> 2] | 0); //@line 60613
  _e68_cc_set_nz_16($c, 14, $d_0_i); //@line 60614
  $157 = $c + 156 | 0; //@line 60615
  $158 = HEAP32[$157 >> 2] | 0; //@line 60616
  if (($158 & 1 | 0) != 0) {
   _e68_exception_address($c, $158, 0, 0); //@line 60621
   return;
  }
  $163 = $c + 164 | 0; //@line 60626
  HEAP16[$c + 162 >> 1] = HEAP16[$163 >> 1] | 0; //@line 60629
  $166 = $158 & 16777215; //@line 60630
  $167 = $166 + 1 | 0; //@line 60631
  if ($167 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $173 = HEAP32[$c + 32 >> 2] | 0; //@line 60638
   $_0_i_i_i9 = HEAPU8[$173 + $166 | 0] << 8 | HEAPU8[$173 + $167 | 0]; //@line 60648
  } else {
   $_0_i_i_i9 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $166) | 0; //@line 60656
  }
  HEAP16[$163 >> 1] = $_0_i_i_i9; //@line 60659
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$157 >> 2] = (HEAP32[$157 >> 2] | 0) + 2; //@line 60667
   $195 = $c + 152 | 0; //@line 60668
   HEAP32[$195 >> 2] = (HEAP32[$195 >> 2] | 0) + 2; //@line 60671
   HEAP32[$106 >> 2] = HEAP32[$106 >> 2] & -65536 | $d_0_i & 65535; //@line 60676
   return;
  } else {
   _e68_exception_bus($c); //@line 60681
   return;
  }
 } else if (($5 | 0) == 3) {
  $287 = $c + 88 + (($3 & 7) << 2) | 0; //@line 60688
  $288 = HEAP32[$287 >> 2] | 0; //@line 60689
  $289 = $288 & 65535; //@line 60690
  $291 = $3 >>> 9 & 7; //@line 60692
  if (($3 & 32 | 0) == 0) {
   $_0_i_i = ($291 | 0) == 0 ? 8 : $291; //@line 60700
  } else {
   $_0_i_i = HEAP32[$c + 88 + ($291 << 2) >> 2] & 63; //@line 60706
  }
  L9449 : do {
   if (($_0_i_i & 15 | 0) == 0) {
    do {
     if (($_0_i_i | 0) != 0) {
      if (($288 & 32768 | 0) == 0) {
       break;
      }
      $323 = $c + 166 | 0; //@line 60724
      HEAP16[$323 >> 1] = HEAP16[$323 >> 1] | 1; //@line 60727
      $d_0_i17 = $289; //@line 60729
      break L9449;
     }
    } while (0);
    $327 = $c + 166 | 0; //@line 60733
    HEAP16[$327 >> 1] = HEAP16[$327 >> 1] & -2; //@line 60736
    $d_0_i17 = $289; //@line 60737
   } else {
    $303 = $288 & 65535; //@line 60739
    $307 = $303 << 16 - $_0_i_i | $303 >>> ($_0_i_i >>> 0); //@line 60743
    $308 = $307 & 65535; //@line 60744
    $311 = $c + 166 | 0; //@line 60747
    $312 = HEAP16[$311 >> 1] | 0; //@line 60748
    if (($307 & 32768 | 0) == 0) {
     HEAP16[$311 >> 1] = $312 & -2; //@line 60752
     $d_0_i17 = $308; //@line 60753
     break;
    } else {
     HEAP16[$311 >> 1] = $312 | 1; //@line 60757
     $d_0_i17 = $308; //@line 60759
     break;
    }
   }
  } while (0);
  $333 = $c + 372 | 0; //@line 60767
  HEAP32[$333 >> 2] = ($_0_i_i << 1) + 6 + (HEAP32[$333 >> 2] | 0); //@line 60770
  _e68_cc_set_nz_16($c, 14, $d_0_i17); //@line 60771
  $336 = $c + 156 | 0; //@line 60772
  $337 = HEAP32[$336 >> 2] | 0; //@line 60773
  if (($337 & 1 | 0) != 0) {
   _e68_exception_address($c, $337, 0, 0); //@line 60778
   return;
  }
  $342 = $c + 164 | 0; //@line 60783
  HEAP16[$c + 162 >> 1] = HEAP16[$342 >> 1] | 0; //@line 60786
  $345 = $337 & 16777215; //@line 60787
  $346 = $345 + 1 | 0; //@line 60788
  if ($346 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $352 = HEAP32[$c + 32 >> 2] | 0; //@line 60795
   $_0_i_i_i18 = HEAPU8[$352 + $345 | 0] << 8 | HEAPU8[$352 + $346 | 0]; //@line 60805
  } else {
   $_0_i_i_i18 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $345) | 0; //@line 60813
  }
  HEAP16[$342 >> 1] = $_0_i_i_i18; //@line 60816
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$336 >> 2] = (HEAP32[$336 >> 2] | 0) + 2; //@line 60824
   $374 = $c + 152 | 0; //@line 60825
   HEAP32[$374 >> 2] = (HEAP32[$374 >> 2] | 0) + 2; //@line 60828
   HEAP32[$287 >> 2] = HEAP32[$287 >> 2] & -65536 | $d_0_i17 & 65535; //@line 60833
   return;
  } else {
   _e68_exception_bus($c); //@line 60838
   return;
  }
 } else if (($5 | 0) == 2) {
  $204 = $c + 88 + (($3 & 7) << 2) | 0; //@line 60845
  $206 = HEAP32[$204 >> 2] & 65535; //@line 60847
  $208 = $3 >>> 9 & 7; //@line 60849
  if (($3 & 32 | 0) == 0) {
   $212 = $c + 166 | 0; //@line 60856
   $_0_i21_i = ($208 | 0) == 0 ? 8 : $208;
   $223 = $212;
   $222 = (HEAPU16[$212 >> 1] | 0) >>> 4;
   label = 7536; //@line 60861
  } else {
   $217 = HEAP32[$c + 88 + ($208 << 2) >> 2] & 63; //@line 60865
   $218 = $c + 166 | 0; //@line 60866
   $220 = (HEAPU16[$218 >> 1] | 0) >>> 4; //@line 60868
   if (($217 | 0) == 0) {
    $x_0_in_lcssa_i = $220;
    $d_0_lcssa_i = $206;
    $_0_i22_i = 0;
    $230 = $218;
   } else {
    $_0_i21_i = $217;
    $223 = $218;
    $222 = $220;
    label = 7536; //@line 60875
   }
  }
  if ((label | 0) == 7536) {
   $x_0_in17_i = $222;
   $i_018_i = 0;
   $d_019_i = $206;
   while (1) {
    $227 = $x_0_in17_i << 15 | ($d_019_i & 65535) >>> 1; //@line 60890
    $228 = $i_018_i + 1 | 0; //@line 60891
    if ($228 >>> 0 < $_0_i21_i >>> 0) {
     $x_0_in17_i = $d_019_i;
     $i_018_i = $228;
     $d_019_i = $227;
    } else {
     $x_0_in_lcssa_i = $d_019_i;
     $d_0_lcssa_i = $227;
     $_0_i22_i = $_0_i21_i;
     $230 = $223;
     break;
    }
   }
  }
  $233 = $c + 372 | 0; //@line 60909
  HEAP32[$233 >> 2] = ($_0_i22_i << 1) + 6 + (HEAP32[$233 >> 2] | 0); //@line 60912
  _e68_cc_set_nz_16($c, 14, $d_0_lcssa_i); //@line 60913
  $237 = HEAP16[$230 >> 1] | 0; //@line 60915
  HEAP16[$230 >> 1] = ($x_0_in_lcssa_i & 1) == 0 ? $237 & -18 : $237 | 17; //@line 60919
  $240 = $c + 156 | 0; //@line 60920
  $241 = HEAP32[$240 >> 2] | 0; //@line 60921
  if (($241 & 1 | 0) != 0) {
   _e68_exception_address($c, $241, 0, 0); //@line 60926
   return;
  }
  $246 = $c + 164 | 0; //@line 60931
  HEAP16[$c + 162 >> 1] = HEAP16[$246 >> 1] | 0; //@line 60934
  $249 = $241 & 16777215; //@line 60935
  $250 = $249 + 1 | 0; //@line 60936
  if ($250 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $256 = HEAP32[$c + 32 >> 2] | 0; //@line 60943
   $_0_i_i_i13 = HEAPU8[$256 + $249 | 0] << 8 | HEAPU8[$256 + $250 | 0]; //@line 60953
  } else {
   $_0_i_i_i13 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $249) | 0; //@line 60961
  }
  HEAP16[$246 >> 1] = $_0_i_i_i13; //@line 60964
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$240 >> 2] = (HEAP32[$240 >> 2] | 0) + 2; //@line 60972
   $278 = $c + 152 | 0; //@line 60973
   HEAP32[$278 >> 2] = (HEAP32[$278 >> 2] | 0) + 2; //@line 60976
   HEAP32[$204 >> 2] = HEAP32[$204 >> 2] & -65536 | $d_0_lcssa_i & 65535; //@line 60981
   return;
  } else {
   _e68_exception_bus($c); //@line 60986
   return;
  }
 } else {
  _e68_exception_illegal($c); //@line 60992
  $382 = $c + 372 | 0; //@line 60993
  HEAP32[$382 >> 2] = (HEAP32[$382 >> 2] | 0) + 2; //@line 60996
  return;
 }
}
function _ope080($c) {
 $c = $c | 0;
 var $3 = 0, $5 = 0, $8 = 0, $9 = 0, $11 = 0, $__i_i = 0, $16 = 0, $19 = 0, $22 = 0, $27 = 0, $29 = 0, $31 = 0, $_0_i222426_i = 0, $_0_i222425_i = 0, $d_0_i = 0, $40 = 0, $41 = 0, $47 = 0, $48 = 0, $_0_i23_i = 0, $d_1_i = 0, $56 = 0, $59 = 0, $60 = 0, $65 = 0, $68 = 0, $69 = 0, $75 = 0, $_0_i_i_i = 0, $97 = 0, $102 = 0, $103 = 0, $105 = 0, $111 = 0, $114 = 0, $_0_i2224_i = 0, $120 = 0, $125 = 0, $126 = 0, $134 = 0, $135 = 0, $_0_i23_i9 = 0, $d_0_i10 = 0, $143 = 0, $146 = 0, $147 = 0, $152 = 0, $155 = 0, $156 = 0, $162 = 0, $_0_i_i_i11 = 0, $184 = 0, $189 = 0, $190 = 0, $192 = 0, $196 = 0, $202 = 0, $203 = 0, $206 = 0, $208 = 0, $209 = 0, $_0_i23_i15 = 0, $d_019_i = 0, $i_018_i = 0, $x_017_i = 0, $211 = 0, $214 = 0, $215 = 0, $217 = 0, $_0_i24_i = 0, $d_0_lcssa_i = 0, $x_0_lcssa_i = 0, $220 = 0, $224 = 0, $227 = 0, $228 = 0, $233 = 0, $236 = 0, $237 = 0, $243 = 0, $_0_i_i_i16 = 0, $265 = 0, $270 = 0, $271 = 0, $273 = 0, $_0_i_i = 0, $282 = 0, $288 = 0, $290 = 0, $291 = 0, $299 = 0, $300 = 0, $d_0_i21 = 0, $308 = 0, $311 = 0, $312 = 0, $317 = 0, $320 = 0, $321 = 0, $327 = 0, $_0_i_i_i22 = 0, $349 = 0, $353 = 0, label = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 61051
 $5 = $3 >>> 3 & 3; //@line 61053
 if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 61056
  $9 = HEAP32[$8 >> 2] | 0; //@line 61057
  $11 = $3 >>> 9 & 7; //@line 61059
  do {
   if (($3 & 32 | 0) == 0) {
    $__i_i = ($11 | 0) == 0 ? 8 : $11; //@line 61066
    $16 = $9 >>> ($__i_i >>> 0); //@line 61068
    if (($9 | 0) < 0) {
     $_0_i222426_i = $__i_i;
     $31 = $16;
     label = 7587; //@line 61072
    } else {
     $d_0_i = $16;
     $_0_i222425_i = $__i_i;
     label = 7588; //@line 61075
    }
   } else {
    $19 = HEAP32[$c + 88 + ($11 << 2) >> 2] & 63; //@line 61080
    if (($19 | 0) == 0) {
     $22 = $c + 166 | 0; //@line 61084
     HEAP16[$22 >> 1] = HEAP16[$22 >> 1] & -2; //@line 61087
     $d_1_i = $9;
     $_0_i23_i = 0;
     break;
    }
    $27 = ($9 | 0) < 0; //@line 61093
    if ($19 >>> 0 < 32) {
     $29 = $9 >>> ($19 >>> 0); //@line 61096
     if ($27) {
      $_0_i222426_i = $19;
      $31 = $29;
      label = 7587; //@line 61100
      break;
     } else {
      $d_0_i = $29;
      $_0_i222425_i = $19;
      label = 7588; //@line 61104
      break;
     }
    }
    $47 = $c + 166 | 0; //@line 61108
    $48 = HEAP16[$47 >> 1] | 0; //@line 61109
    if ($27) {
     HEAP16[$47 >> 1] = $48 | 17; //@line 61113
     $d_1_i = -1;
     $_0_i23_i = $19;
     break;
    } else {
     HEAP16[$47 >> 1] = $48 & -18; //@line 61119
     $d_1_i = 0;
     $_0_i23_i = $19;
     break;
    }
   }
  } while (0);
  if ((label | 0) == 7587) {
   $d_0_i = -1 << 32 - $_0_i222426_i | $31;
   $_0_i222425_i = $_0_i222426_i;
   label = 7588; //@line 61133
  }
  do {
   if ((label | 0) == 7588) {
    $40 = $c + 166 | 0; //@line 61143
    $41 = HEAP16[$40 >> 1] | 0; //@line 61144
    if ((1 << $_0_i222425_i - 1 & $9 | 0) == 0) {
     HEAP16[$40 >> 1] = $41 & -18; //@line 61148
     $d_1_i = $d_0_i;
     $_0_i23_i = $_0_i222425_i;
     break;
    } else {
     HEAP16[$40 >> 1] = $41 | 17; //@line 61153
     $d_1_i = $d_0_i;
     $_0_i23_i = $_0_i222425_i;
     break;
    }
   }
  } while (0);
  $56 = $c + 372 | 0; //@line 61164
  HEAP32[$56 >> 2] = ($_0_i23_i << 1) + 8 + (HEAP32[$56 >> 2] | 0); //@line 61167
  _e68_cc_set_nz_32($c, 14, $d_1_i); //@line 61168
  $59 = $c + 156 | 0; //@line 61169
  $60 = HEAP32[$59 >> 2] | 0; //@line 61170
  if (($60 & 1 | 0) != 0) {
   _e68_exception_address($c, $60, 0, 0); //@line 61175
   return;
  }
  $65 = $c + 164 | 0; //@line 61180
  HEAP16[$c + 162 >> 1] = HEAP16[$65 >> 1] | 0; //@line 61183
  $68 = $60 & 16777215; //@line 61184
  $69 = $68 + 1 | 0; //@line 61185
  if ($69 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $75 = HEAP32[$c + 32 >> 2] | 0; //@line 61192
   $_0_i_i_i = HEAPU8[$75 + $68 | 0] << 8 | HEAPU8[$75 + $69 | 0]; //@line 61202
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $68) | 0; //@line 61210
  }
  HEAP16[$65 >> 1] = $_0_i_i_i; //@line 61213
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 61221
   $97 = $c + 152 | 0; //@line 61222
   HEAP32[$97 >> 2] = (HEAP32[$97 >> 2] | 0) + 2; //@line 61225
   HEAP32[$8 >> 2] = $d_1_i; //@line 61226
   return;
  } else {
   _e68_exception_bus($c); //@line 61231
   return;
  }
 } else if (($5 | 0) == 2) {
  $189 = $c + 88 + (($3 & 7) << 2) | 0; //@line 61238
  $190 = HEAP32[$189 >> 2] | 0; //@line 61239
  $192 = $3 >>> 9 & 7; //@line 61241
  if (($3 & 32 | 0) == 0) {
   $196 = $c + 166 | 0; //@line 61248
   $_0_i23_i15 = ($192 | 0) == 0 ? 8 : $192;
   $209 = $196;
   $208 = (HEAPU16[$196 >> 1] | 0) >>> 4 & 1;
   label = 7624; //@line 61255
  } else {
   $202 = HEAP32[$c + 88 + ($192 << 2) >> 2] & 63; //@line 61259
   $203 = $c + 166 | 0; //@line 61260
   $206 = (HEAPU16[$203 >> 1] | 0) >>> 4 & 1; //@line 61264
   if (($202 | 0) == 0) {
    $x_0_lcssa_i = $206;
    $d_0_lcssa_i = $190;
    $_0_i24_i = 0;
    $217 = $203;
   } else {
    $_0_i23_i15 = $202;
    $209 = $203;
    $208 = $206;
    label = 7624; //@line 61271
   }
  }
  if ((label | 0) == 7624) {
   $x_017_i = $208;
   $i_018_i = 0;
   $d_019_i = $190;
   while (1) {
    $211 = $d_019_i & 1; //@line 61284
    $214 = $x_017_i << 31 | $d_019_i >>> 1; //@line 61287
    $215 = $i_018_i + 1 | 0; //@line 61288
    if ($215 >>> 0 < $_0_i23_i15 >>> 0) {
     $x_017_i = $211;
     $i_018_i = $215;
     $d_019_i = $214;
    } else {
     $x_0_lcssa_i = $211;
     $d_0_lcssa_i = $214;
     $_0_i24_i = $_0_i23_i15;
     $217 = $209;
     break;
    }
   }
  }
  $220 = $c + 372 | 0; //@line 61305
  HEAP32[$220 >> 2] = ($_0_i24_i << 1) + 8 + (HEAP32[$220 >> 2] | 0); //@line 61308
  _e68_cc_set_nz_32($c, 14, $d_0_lcssa_i); //@line 61309
  $224 = HEAP16[$217 >> 1] | 0; //@line 61311
  HEAP16[$217 >> 1] = ($x_0_lcssa_i | 0) == 0 ? $224 & -18 : $224 | 17; //@line 61315
  $227 = $c + 156 | 0; //@line 61316
  $228 = HEAP32[$227 >> 2] | 0; //@line 61317
  if (($228 & 1 | 0) != 0) {
   _e68_exception_address($c, $228, 0, 0); //@line 61322
   return;
  }
  $233 = $c + 164 | 0; //@line 61327
  HEAP16[$c + 162 >> 1] = HEAP16[$233 >> 1] | 0; //@line 61330
  $236 = $228 & 16777215; //@line 61331
  $237 = $236 + 1 | 0; //@line 61332
  if ($237 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $243 = HEAP32[$c + 32 >> 2] | 0; //@line 61339
   $_0_i_i_i16 = HEAPU8[$243 + $236 | 0] << 8 | HEAPU8[$243 + $237 | 0]; //@line 61349
  } else {
   $_0_i_i_i16 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $236) | 0; //@line 61357
  }
  HEAP16[$233 >> 1] = $_0_i_i_i16; //@line 61360
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$227 >> 2] = (HEAP32[$227 >> 2] | 0) + 2; //@line 61368
   $265 = $c + 152 | 0; //@line 61369
   HEAP32[$265 >> 2] = (HEAP32[$265 >> 2] | 0) + 2; //@line 61372
   HEAP32[$189 >> 2] = $d_0_lcssa_i; //@line 61373
   return;
  } else {
   _e68_exception_bus($c); //@line 61378
   return;
  }
 } else if (($5 | 0) == 1) {
  $102 = $c + 88 + (($3 & 7) << 2) | 0; //@line 61385
  $103 = HEAP32[$102 >> 2] | 0; //@line 61386
  $105 = $3 >>> 9 & 7; //@line 61388
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i2224_i = ($105 | 0) == 0 ? 8 : $105; //@line 61397
    label = 7607; //@line 61398
   } else {
    $111 = HEAP32[$c + 88 + ($105 << 2) >> 2] & 63; //@line 61402
    if (($111 | 0) == 0) {
     $114 = $c + 166 | 0; //@line 61406
     HEAP16[$114 >> 1] = HEAP16[$114 >> 1] & -2; //@line 61409
     $d_0_i10 = $103;
     $_0_i23_i9 = 0;
     break;
    }
    if ($111 >>> 0 < 32) {
     $_0_i2224_i = $111; //@line 61417
     label = 7607; //@line 61418
     break;
    }
    $134 = $c + 166 | 0; //@line 61424
    $135 = HEAP16[$134 >> 1] | 0; //@line 61425
    if (($111 | 0) == 32 & ($103 | 0) < 0) {
     HEAP16[$134 >> 1] = $135 | 17; //@line 61429
     $d_0_i10 = 0;
     $_0_i23_i9 = 32;
     break;
    } else {
     HEAP16[$134 >> 1] = $135 & -18; //@line 61435
     $d_0_i10 = 0;
     $_0_i23_i9 = $111;
     break;
    }
   }
  } while (0);
  do {
   if ((label | 0) == 7607) {
    $120 = $103 >>> ($_0_i2224_i >>> 0); //@line 61444
    $125 = $c + 166 | 0; //@line 61449
    $126 = HEAP16[$125 >> 1] | 0; //@line 61450
    if ((1 << $_0_i2224_i - 1 & $103 | 0) == 0) {
     HEAP16[$125 >> 1] = $126 & -18; //@line 61454
     $d_0_i10 = $120;
     $_0_i23_i9 = $_0_i2224_i;
     break;
    } else {
     HEAP16[$125 >> 1] = $126 | 17; //@line 61459
     $d_0_i10 = $120;
     $_0_i23_i9 = $_0_i2224_i;
     break;
    }
   }
  } while (0);
  $143 = $c + 372 | 0; //@line 61470
  HEAP32[$143 >> 2] = ($_0_i23_i9 << 1) + 8 + (HEAP32[$143 >> 2] | 0); //@line 61473
  _e68_cc_set_nz_32($c, 14, $d_0_i10); //@line 61474
  $146 = $c + 156 | 0; //@line 61475
  $147 = HEAP32[$146 >> 2] | 0; //@line 61476
  if (($147 & 1 | 0) != 0) {
   _e68_exception_address($c, $147, 0, 0); //@line 61481
   return;
  }
  $152 = $c + 164 | 0; //@line 61486
  HEAP16[$c + 162 >> 1] = HEAP16[$152 >> 1] | 0; //@line 61489
  $155 = $147 & 16777215; //@line 61490
  $156 = $155 + 1 | 0; //@line 61491
  if ($156 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $162 = HEAP32[$c + 32 >> 2] | 0; //@line 61498
   $_0_i_i_i11 = HEAPU8[$162 + $155 | 0] << 8 | HEAPU8[$162 + $156 | 0]; //@line 61508
  } else {
   $_0_i_i_i11 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $155) | 0; //@line 61516
  }
  HEAP16[$152 >> 1] = $_0_i_i_i11; //@line 61519
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$146 >> 2] = (HEAP32[$146 >> 2] | 0) + 2; //@line 61527
   $184 = $c + 152 | 0; //@line 61528
   HEAP32[$184 >> 2] = (HEAP32[$184 >> 2] | 0) + 2; //@line 61531
   HEAP32[$102 >> 2] = $d_0_i10; //@line 61532
   return;
  } else {
   _e68_exception_bus($c); //@line 61537
   return;
  }
 } else if (($5 | 0) == 3) {
  $270 = $c + 88 + (($3 & 7) << 2) | 0; //@line 61544
  $271 = HEAP32[$270 >> 2] | 0; //@line 61545
  $273 = $3 >>> 9 & 7; //@line 61547
  if (($3 & 32 | 0) == 0) {
   $_0_i_i = ($273 | 0) == 0 ? 8 : $273; //@line 61555
  } else {
   $_0_i_i = HEAP32[$c + 88 + ($273 << 2) >> 2] & 63; //@line 61561
  }
  $282 = $_0_i_i & 31; //@line 61564
  do {
   if (($282 | 0) == 0) {
    $299 = $c + 166 | 0; //@line 61572
    $300 = HEAP16[$299 >> 1] | 0; //@line 61573
    if (($_0_i_i | 0) != 0 & ($271 | 0) < 0) {
     HEAP16[$299 >> 1] = $300 | 1; //@line 61577
     $d_0_i21 = $271; //@line 61579
     break;
    } else {
     HEAP16[$299 >> 1] = $300 & -2; //@line 61583
     $d_0_i21 = $271; //@line 61584
     break;
    }
   } else {
    $288 = $271 << 32 - $282 | $271 >>> ($282 >>> 0); //@line 61591
    $290 = $c + 166 | 0; //@line 61593
    $291 = HEAP16[$290 >> 1] | 0; //@line 61594
    if (($288 | 0) < 0) {
     HEAP16[$290 >> 1] = $291 | 1; //@line 61598
     $d_0_i21 = $288; //@line 61600
     break;
    } else {
     HEAP16[$290 >> 1] = $291 & -2; //@line 61604
     $d_0_i21 = $288; //@line 61605
     break;
    }
   }
  } while (0);
  $308 = $c + 372 | 0; //@line 61613
  HEAP32[$308 >> 2] = ($_0_i_i << 1) + 8 + (HEAP32[$308 >> 2] | 0); //@line 61616
  _e68_cc_set_nz_32($c, 14, $d_0_i21); //@line 61617
  $311 = $c + 156 | 0; //@line 61618
  $312 = HEAP32[$311 >> 2] | 0; //@line 61619
  if (($312 & 1 | 0) != 0) {
   _e68_exception_address($c, $312, 0, 0); //@line 61624
   return;
  }
  $317 = $c + 164 | 0; //@line 61629
  HEAP16[$c + 162 >> 1] = HEAP16[$317 >> 1] | 0; //@line 61632
  $320 = $312 & 16777215; //@line 61633
  $321 = $320 + 1 | 0; //@line 61634
  if ($321 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $327 = HEAP32[$c + 32 >> 2] | 0; //@line 61641
   $_0_i_i_i22 = HEAPU8[$327 + $320 | 0] << 8 | HEAPU8[$327 + $321 | 0]; //@line 61651
  } else {
   $_0_i_i_i22 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $320) | 0; //@line 61659
  }
  HEAP16[$317 >> 1] = $_0_i_i_i22; //@line 61662
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$311 >> 2] = (HEAP32[$311 >> 2] | 0) + 2; //@line 61670
   $349 = $c + 152 | 0; //@line 61671
   HEAP32[$349 >> 2] = (HEAP32[$349 >> 2] | 0) + 2; //@line 61674
   HEAP32[$270 >> 2] = $d_0_i21; //@line 61675
   return;
  } else {
   _e68_exception_bus($c); //@line 61680
   return;
  }
 } else {
  _e68_exception_illegal($c); //@line 61686
  $353 = $c + 372 | 0; //@line 61687
  HEAP32[$353 >> 2] = (HEAP32[$353 >> 2] | 0) + 2; //@line 61690
  return;
 }
}
function _ope0c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $16 = 0, $17 = 0, $23 = 0, $24 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 61709
 STACKTOP = STACKTOP + 8 | 0; //@line 61709
 $s = sp | 0; //@line 61710
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 61714
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 61721
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 61728
  return;
 }
 $13 = HEAP16[$s >> 1] | 0; //@line 61731
 $16 = ($13 & 65535) >>> 1 | $13 & -32768; //@line 61734
 $17 = $c + 372 | 0; //@line 61735
 HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 8; //@line 61738
 _e68_cc_set_nz_16($c, 14, $16); //@line 61739
 $23 = $c + 166 | 0; //@line 61743
 $24 = HEAP16[$23 >> 1] | 0; //@line 61744
 HEAP16[$23 >> 1] = (HEAP16[$s >> 1] & 1) == 0 ? $24 & -18 : $24 | 17; //@line 61748
 $27 = $c + 156 | 0; //@line 61749
 $28 = HEAP32[$27 >> 2] | 0; //@line 61750
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 61755
  STACKTOP = sp; //@line 61757
  return;
 }
 $33 = $c + 164 | 0; //@line 61760
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 61763
 $36 = $28 & 16777215; //@line 61764
 $37 = $36 + 1 | 0; //@line 61765
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 61772
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 61782
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 61790
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 61793
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 61801
  $65 = $c + 152 | 0; //@line 61802
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 61805
  _e68_ea_set_val16($c, $16) | 0; //@line 61806
  STACKTOP = sp; //@line 61808
  return;
 } else {
  _e68_exception_bus($c); //@line 61811
  STACKTOP = sp; //@line 61813
  return;
 }
}
function _ope100($c) {
 $c = $c | 0;
 var $3 = 0, $5 = 0, $8 = 0, $9 = 0, $11 = 0, $17 = 0, $21 = 0, $_0_i32_i = 0, $27 = 0, $29 = 0, $36 = 0, $37 = 0, $storemerge_i = 0, $40 = 0, $41 = 0, $54 = 0, $56 = 0, $58 = 0, $60 = 0, $62 = 0, $65 = 0, $_0_i31_i = 0, $d_0_i = 0, $73 = 0, $76 = 0, $77 = 0, $82 = 0, $85 = 0, $86 = 0, $92 = 0, $_0_i_i_i = 0, $114 = 0, $123 = 0, $124 = 0, $126 = 0, $132 = 0, $136 = 0, $_0_i23_i = 0, $142 = 0, $144 = 0, $149 = 0, $150 = 0, $161 = 0, $165 = 0, $_0_i22_i = 0, $d_0_i9 = 0, $171 = 0, $174 = 0, $175 = 0, $180 = 0, $183 = 0, $184 = 0, $190 = 0, $_0_i_i_i10 = 0, $212 = 0, $221 = 0, $223 = 0, $225 = 0, $229 = 0, $234 = 0, $235 = 0, $x_017_i = 0, $x_01726_i = 0, $239 = 0, $_0_i24_i = 0, $x_020_i = 0, $d_019_i = 0, $i_018_i = 0, $243 = 0, $244 = 0, $x_0_i = 0, $246 = 0, $_0_i25_i = 0, $x_0_lcssa_i = 0, $d_0_lcssa_i = 0, $249 = 0, $254 = 0, $257 = 0, $258 = 0, $263 = 0, $266 = 0, $267 = 0, $273 = 0, $_0_i_i_i16 = 0, $295 = 0, $304 = 0, $305 = 0, $306 = 0, $308 = 0, $_0_i_i = 0, $317 = 0, $320 = 0, $324 = 0, $325 = 0, $328 = 0, $329 = 0, $340 = 0, $344 = 0, $d_0_i20 = 0, $350 = 0, $353 = 0, $354 = 0, $359 = 0, $362 = 0, $363 = 0, $369 = 0, $_0_i_i_i21 = 0, $391 = 0, $399 = 0, label = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 61872
 $5 = $3 >>> 3 & 3; //@line 61874
 if (($5 | 0) == 1) {
  $123 = $c + 88 + (($3 & 7) << 2) | 0; //@line 61877
  $124 = HEAP32[$123 >> 2] | 0; //@line 61878
  $126 = $3 >>> 9 & 7; //@line 61880
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i23_i = ($126 | 0) == 0 ? 8 : $126; //@line 61889
    label = 7711; //@line 61890
   } else {
    $132 = HEAP32[$c + 88 + ($126 << 2) >> 2] & 63; //@line 61894
    if (($132 | 0) != 0) {
     $_0_i23_i = $132; //@line 61898
     label = 7711; //@line 61899
     break;
    }
    $136 = $c + 166 | 0; //@line 61903
    HEAP16[$136 >> 1] = HEAP16[$136 >> 1] & -2; //@line 61906
    $d_0_i9 = $124 & 255;
    $_0_i22_i = 0;
   }
  } while (0);
  L9642 : do {
   if ((label | 0) == 7711) {
    if ($_0_i23_i >>> 0 < 8) {
     $142 = $124 & 255; //@line 61917
     $144 = $142 << $_0_i23_i & 255; //@line 61919
     $149 = $c + 166 | 0; //@line 61924
     $150 = HEAP16[$149 >> 1] | 0; //@line 61925
     if ((1 << 8 - $_0_i23_i & $142 | 0) == 0) {
      HEAP16[$149 >> 1] = $150 & -18; //@line 61929
      $d_0_i9 = $144;
      $_0_i22_i = $_0_i23_i;
      break;
     } else {
      HEAP16[$149 >> 1] = $150 | 17; //@line 61934
      $d_0_i9 = $144;
      $_0_i22_i = $_0_i23_i;
      break;
     }
    }
    do {
     if (($_0_i23_i | 0) == 8) {
      if (($124 & 1 | 0) == 0) {
       break;
      }
      $161 = $c + 166 | 0; //@line 61950
      HEAP16[$161 >> 1] = HEAP16[$161 >> 1] | 17; //@line 61953
      $d_0_i9 = 0;
      $_0_i22_i = 8;
      break L9642;
     }
    } while (0);
    $165 = $c + 166 | 0; //@line 61959
    HEAP16[$165 >> 1] = HEAP16[$165 >> 1] & -18; //@line 61962
    $d_0_i9 = 0;
    $_0_i22_i = $_0_i23_i;
   }
  } while (0);
  $171 = $c + 372 | 0; //@line 61970
  HEAP32[$171 >> 2] = ($_0_i22_i << 1) + 6 + (HEAP32[$171 >> 2] | 0); //@line 61973
  _e68_cc_set_nz_8($c, 14, $d_0_i9); //@line 61974
  $174 = $c + 156 | 0; //@line 61975
  $175 = HEAP32[$174 >> 2] | 0; //@line 61976
  if (($175 & 1 | 0) != 0) {
   _e68_exception_address($c, $175, 0, 0); //@line 61981
   return;
  }
  $180 = $c + 164 | 0; //@line 61986
  HEAP16[$c + 162 >> 1] = HEAP16[$180 >> 1] | 0; //@line 61989
  $183 = $175 & 16777215; //@line 61990
  $184 = $183 + 1 | 0; //@line 61991
  if ($184 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $190 = HEAP32[$c + 32 >> 2] | 0; //@line 61998
   $_0_i_i_i10 = HEAPU8[$190 + $183 | 0] << 8 | HEAPU8[$190 + $184 | 0]; //@line 62008
  } else {
   $_0_i_i_i10 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $183) | 0; //@line 62016
  }
  HEAP16[$180 >> 1] = $_0_i_i_i10; //@line 62019
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$174 >> 2] = (HEAP32[$174 >> 2] | 0) + 2; //@line 62027
   $212 = $c + 152 | 0; //@line 62028
   HEAP32[$212 >> 2] = (HEAP32[$212 >> 2] | 0) + 2; //@line 62031
   HEAP32[$123 >> 2] = HEAP32[$123 >> 2] & -256 | $d_0_i9 & 255; //@line 62036
   return;
  } else {
   _e68_exception_bus($c); //@line 62041
   return;
  }
 } else if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 62048
  $9 = HEAP32[$8 >> 2] | 0; //@line 62049
  $11 = $3 >>> 9 & 7; //@line 62051
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i32_i = ($11 | 0) == 0 ? 8 : $11; //@line 62060
    label = 7688; //@line 62061
   } else {
    $17 = HEAP32[$c + 88 + ($11 << 2) >> 2] & 63; //@line 62065
    if (($17 | 0) != 0) {
     $_0_i32_i = $17; //@line 62069
     label = 7688; //@line 62070
     break;
    }
    $21 = $c + 166 | 0; //@line 62074
    HEAP16[$21 >> 1] = HEAP16[$21 >> 1] & -4; //@line 62077
    $d_0_i = $9 & 255;
    $_0_i31_i = 0;
   }
  } while (0);
  do {
   if ((label | 0) == 7688) {
    if ($_0_i32_i >>> 0 < 8) {
     $27 = $9 & 255; //@line 62088
     $29 = $27 << $_0_i32_i & 255; //@line 62090
     $36 = $c + 166 | 0; //@line 62097
     $37 = HEAP16[$36 >> 1] | 0; //@line 62098
     $storemerge_i = (1 << 8 - $_0_i32_i & $27 | 0) == 0 ? $37 & -18 : $37 | 17; //@line 62101
     HEAP16[$36 >> 1] = $storemerge_i; //@line 62102
     $40 = 255 << 7 - $_0_i32_i & 255; //@line 62103
     $41 = $40 & $9; //@line 62104
     if (($41 | 0) == 0 | ($41 | 0) == ($40 | 0)) {
      HEAP16[$36 >> 1] = $storemerge_i & -3; //@line 62111
      $d_0_i = $29;
      $_0_i31_i = $_0_i32_i;
      break;
     } else {
      HEAP16[$36 >> 1] = $storemerge_i | 2; //@line 62116
      $d_0_i = $29;
      $_0_i31_i = $_0_i32_i;
      break;
     }
    }
    do {
     if (($_0_i32_i | 0) == 8) {
      if (($9 & 1 | 0) == 0) {
       label = 7695; //@line 62130
       break;
      }
      $54 = $c + 166 | 0; //@line 62133
      $56 = HEAP16[$54 >> 1] | 17; //@line 62135
      HEAP16[$54 >> 1] = $56; //@line 62136
      $62 = $56; //@line 62138
     } else {
      label = 7695; //@line 62140
     }
    } while (0);
    if ((label | 0) == 7695) {
     $58 = $c + 166 | 0; //@line 62144
     $60 = HEAP16[$58 >> 1] & -18; //@line 62146
     HEAP16[$58 >> 1] = $60; //@line 62147
     $62 = $60; //@line 62148
    }
    $65 = $c + 166 | 0; //@line 62153
    if (($9 & 255 | 0) == 0) {
     HEAP16[$65 >> 1] = $62 & -3; //@line 62157
     $d_0_i = 0;
     $_0_i31_i = $_0_i32_i;
     break;
    } else {
     HEAP16[$65 >> 1] = $62 | 2; //@line 62162
     $d_0_i = 0;
     $_0_i31_i = $_0_i32_i;
     break;
    }
   }
  } while (0);
  $73 = $c + 372 | 0; //@line 62173
  HEAP32[$73 >> 2] = ($_0_i31_i << 1) + 6 + (HEAP32[$73 >> 2] | 0); //@line 62176
  _e68_cc_set_nz_8($c, 12, $d_0_i); //@line 62177
  $76 = $c + 156 | 0; //@line 62178
  $77 = HEAP32[$76 >> 2] | 0; //@line 62179
  if (($77 & 1 | 0) != 0) {
   _e68_exception_address($c, $77, 0, 0); //@line 62184
   return;
  }
  $82 = $c + 164 | 0; //@line 62189
  HEAP16[$c + 162 >> 1] = HEAP16[$82 >> 1] | 0; //@line 62192
  $85 = $77 & 16777215; //@line 62193
  $86 = $85 + 1 | 0; //@line 62194
  if ($86 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $92 = HEAP32[$c + 32 >> 2] | 0; //@line 62201
   $_0_i_i_i = HEAPU8[$92 + $85 | 0] << 8 | HEAPU8[$92 + $86 | 0]; //@line 62211
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $85) | 0; //@line 62219
  }
  HEAP16[$82 >> 1] = $_0_i_i_i; //@line 62222
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 62230
   $114 = $c + 152 | 0; //@line 62231
   HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 2; //@line 62234
   HEAP32[$8 >> 2] = HEAP32[$8 >> 2] & -256 | $d_0_i & 255; //@line 62239
   return;
  } else {
   _e68_exception_bus($c); //@line 62244
   return;
  }
 } else if (($5 | 0) == 3) {
  $304 = $c + 88 + (($3 & 7) << 2) | 0; //@line 62251
  $305 = HEAP32[$304 >> 2] | 0; //@line 62252
  $306 = $305 & 255; //@line 62253
  $308 = $3 >>> 9 & 7; //@line 62255
  if (($3 & 32 | 0) == 0) {
   $_0_i_i = ($308 | 0) == 0 ? 8 : $308; //@line 62263
  } else {
   $_0_i_i = HEAP32[$c + 88 + ($308 << 2) >> 2] & 63; //@line 62269
  }
  $317 = $_0_i_i & 7; //@line 62272
  L9709 : do {
   if (($317 | 0) == 0) {
    do {
     if (($_0_i_i | 0) != 0) {
      if (($305 & 1 | 0) == 0) {
       break;
      }
      $340 = $c + 166 | 0; //@line 62287
      HEAP16[$340 >> 1] = HEAP16[$340 >> 1] | 1; //@line 62290
      $d_0_i20 = $306; //@line 62292
      break L9709;
     }
    } while (0);
    $344 = $c + 166 | 0; //@line 62296
    HEAP16[$344 >> 1] = HEAP16[$344 >> 1] & -2; //@line 62299
    $d_0_i20 = $306; //@line 62300
   } else {
    $320 = $305 & 255; //@line 62302
    $324 = $320 >>> ((8 - $317 | 0) >>> 0) | $320 << $317; //@line 62306
    $325 = $324 & 255; //@line 62307
    $328 = $c + 166 | 0; //@line 62310
    $329 = HEAP16[$328 >> 1] | 0; //@line 62311
    if (($324 & 1 | 0) == 0) {
     HEAP16[$328 >> 1] = $329 & -2; //@line 62315
     $d_0_i20 = $325; //@line 62316
     break;
    } else {
     HEAP16[$328 >> 1] = $329 | 1; //@line 62320
     $d_0_i20 = $325; //@line 62322
     break;
    }
   }
  } while (0);
  $350 = $c + 372 | 0; //@line 62330
  HEAP32[$350 >> 2] = ($_0_i_i << 1) + 6 + (HEAP32[$350 >> 2] | 0); //@line 62333
  _e68_cc_set_nz_8($c, 14, $d_0_i20); //@line 62334
  $353 = $c + 156 | 0; //@line 62335
  $354 = HEAP32[$353 >> 2] | 0; //@line 62336
  if (($354 & 1 | 0) != 0) {
   _e68_exception_address($c, $354, 0, 0); //@line 62341
   return;
  }
  $359 = $c + 164 | 0; //@line 62346
  HEAP16[$c + 162 >> 1] = HEAP16[$359 >> 1] | 0; //@line 62349
  $362 = $354 & 16777215; //@line 62350
  $363 = $362 + 1 | 0; //@line 62351
  if ($363 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $369 = HEAP32[$c + 32 >> 2] | 0; //@line 62358
   $_0_i_i_i21 = HEAPU8[$369 + $362 | 0] << 8 | HEAPU8[$369 + $363 | 0]; //@line 62368
  } else {
   $_0_i_i_i21 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $362) | 0; //@line 62376
  }
  HEAP16[$359 >> 1] = $_0_i_i_i21; //@line 62379
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$353 >> 2] = (HEAP32[$353 >> 2] | 0) + 2; //@line 62387
   $391 = $c + 152 | 0; //@line 62388
   HEAP32[$391 >> 2] = (HEAP32[$391 >> 2] | 0) + 2; //@line 62391
   HEAP32[$304 >> 2] = HEAP32[$304 >> 2] & -256 | $d_0_i20 & 255; //@line 62396
   return;
  } else {
   _e68_exception_bus($c); //@line 62401
   return;
  }
 } else if (($5 | 0) == 2) {
  $221 = $c + 88 + (($3 & 7) << 2) | 0; //@line 62408
  $223 = HEAP32[$221 >> 2] & 255; //@line 62411
  $225 = $3 >>> 9 & 7; //@line 62413
  if (($3 & 32 | 0) == 0) {
   $229 = $c + 166 | 0; //@line 62420
   $_0_i24_i = ($225 | 0) == 0 ? 8 : $225;
   $239 = $229;
   $x_01726_i = (HEAPU16[$229 >> 1] | 0) >>> 4 & 1;
   label = 7730; //@line 62426
  } else {
   $234 = HEAP32[$c + 88 + ($225 << 2) >> 2] & 63; //@line 62430
   $235 = $c + 166 | 0; //@line 62431
   $x_017_i = (HEAPU16[$235 >> 1] | 0) >>> 4 & 1; //@line 62434
   if (($234 | 0) == 0) {
    $d_0_lcssa_i = $223;
    $x_0_lcssa_i = $x_017_i;
    $_0_i25_i = 0;
    $246 = $235;
   } else {
    $_0_i24_i = $234;
    $239 = $235;
    $x_01726_i = $x_017_i;
    label = 7730; //@line 62441
   }
  }
  if ((label | 0) == 7730) {
   $i_018_i = 0;
   $d_019_i = $223;
   $x_020_i = $x_01726_i;
   while (1) {
    $243 = $d_019_i << 1 | $x_020_i; //@line 62456
    $244 = $i_018_i + 1 | 0; //@line 62457
    $x_0_i = ($d_019_i & 65535) >>> 7 & 1; //@line 62458
    if ($244 >>> 0 < $_0_i24_i >>> 0) {
     $i_018_i = $244;
     $d_019_i = $243;
     $x_020_i = $x_0_i;
    } else {
     $d_0_lcssa_i = $243;
     $x_0_lcssa_i = $x_0_i;
     $_0_i25_i = $_0_i24_i;
     $246 = $239;
     break;
    }
   }
  }
  $249 = $c + 372 | 0; //@line 62475
  HEAP32[$249 >> 2] = ($_0_i25_i << 1) + 6 + (HEAP32[$249 >> 2] | 0); //@line 62478
  _e68_cc_set_nz_8($c, 14, $d_0_lcssa_i & 255); //@line 62480
  $254 = HEAP16[$246 >> 1] | 0; //@line 62482
  HEAP16[$246 >> 1] = $x_0_lcssa_i << 16 >> 16 == 0 ? $254 & -18 : $254 | 17; //@line 62486
  $257 = $c + 156 | 0; //@line 62487
  $258 = HEAP32[$257 >> 2] | 0; //@line 62488
  if (($258 & 1 | 0) != 0) {
   _e68_exception_address($c, $258, 0, 0); //@line 62493
   return;
  }
  $263 = $c + 164 | 0; //@line 62498
  HEAP16[$c + 162 >> 1] = HEAP16[$263 >> 1] | 0; //@line 62501
  $266 = $258 & 16777215; //@line 62502
  $267 = $266 + 1 | 0; //@line 62503
  if ($267 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $273 = HEAP32[$c + 32 >> 2] | 0; //@line 62510
   $_0_i_i_i16 = HEAPU8[$273 + $266 | 0] << 8 | HEAPU8[$273 + $267 | 0]; //@line 62520
  } else {
   $_0_i_i_i16 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $266) | 0; //@line 62528
  }
  HEAP16[$263 >> 1] = $_0_i_i_i16; //@line 62531
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$257 >> 2] = (HEAP32[$257 >> 2] | 0) + 2; //@line 62539
   $295 = $c + 152 | 0; //@line 62540
   HEAP32[$295 >> 2] = (HEAP32[$295 >> 2] | 0) + 2; //@line 62543
   HEAP32[$221 >> 2] = HEAP32[$221 >> 2] & -256 | $d_0_lcssa_i & 255; //@line 62549
   return;
  } else {
   _e68_exception_bus($c); //@line 62554
   return;
  }
 } else {
  _e68_exception_illegal($c); //@line 62560
  $399 = $c + 372 | 0; //@line 62561
  HEAP32[$399 >> 2] = (HEAP32[$399 >> 2] | 0) + 2; //@line 62564
  return;
 }
}
function _ope140($c) {
 $c = $c | 0;
 var $3 = 0, $5 = 0, $8 = 0, $9 = 0, $11 = 0, $17 = 0, $21 = 0, $_0_i3233_i = 0, $27 = 0, $29 = 0, $36 = 0, $37 = 0, $storemerge_i = 0, $40 = 0, $41 = 0, $54 = 0, $56 = 0, $58 = 0, $60 = 0, $62 = 0, $65 = 0, $_0_i31_i = 0, $d_0_i = 0, $73 = 0, $76 = 0, $77 = 0, $82 = 0, $85 = 0, $86 = 0, $92 = 0, $_0_i_i_i = 0, $114 = 0, $123 = 0, $124 = 0, $126 = 0, $132 = 0, $136 = 0, $_0_i2324_i = 0, $142 = 0, $144 = 0, $149 = 0, $150 = 0, $161 = 0, $165 = 0, $_0_i22_i = 0, $d_0_i9 = 0, $171 = 0, $174 = 0, $175 = 0, $180 = 0, $183 = 0, $184 = 0, $190 = 0, $_0_i_i_i10 = 0, $212 = 0, $221 = 0, $223 = 0, $225 = 0, $229 = 0, $234 = 0, $235 = 0, $_lobit_i = 0, $_lobit25_i = 0, $239 = 0, $_0_i23_i = 0, $d_019_i = 0, $i_018_i = 0, $x_017_i = 0, $241 = 0, $243 = 0, $244 = 0, $246 = 0, $_0_i24_i = 0, $d_0_lcssa_i = 0, $x_0_lcssa_i = 0, $249 = 0, $253 = 0, $256 = 0, $257 = 0, $262 = 0, $265 = 0, $266 = 0, $272 = 0, $_0_i_i_i15 = 0, $294 = 0, $303 = 0, $304 = 0, $305 = 0, $307 = 0, $_0_i_i = 0, $316 = 0, $319 = 0, $323 = 0, $324 = 0, $327 = 0, $328 = 0, $339 = 0, $343 = 0, $d_0_i19 = 0, $349 = 0, $352 = 0, $353 = 0, $358 = 0, $361 = 0, $362 = 0, $368 = 0, $_0_i_i_i20 = 0, $390 = 0, $398 = 0, label = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 62624
 $5 = $3 >>> 3 & 3; //@line 62626
 if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 62629
  $9 = HEAP32[$8 >> 2] | 0; //@line 62630
  $11 = $3 >>> 9 & 7; //@line 62632
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i3233_i = ($11 | 0) == 0 ? 8 : $11; //@line 62641
    label = 7780; //@line 62642
   } else {
    $17 = HEAP32[$c + 88 + ($11 << 2) >> 2] & 63; //@line 62646
    if (($17 | 0) == 0) {
     $21 = $c + 166 | 0; //@line 62651
     HEAP16[$21 >> 1] = HEAP16[$21 >> 1] & -4; //@line 62654
     $d_0_i = $9 & 65535;
     $_0_i31_i = 0;
     break;
    }
    if ($17 >>> 0 < 16) {
     $_0_i3233_i = $17; //@line 62662
     label = 7780; //@line 62663
     break;
    }
    do {
     if (($17 | 0) == 16) {
      if (($9 & 1 | 0) == 0) {
       label = 7786; //@line 62674
       break;
      }
      $54 = $c + 166 | 0; //@line 62677
      $56 = HEAP16[$54 >> 1] | 17; //@line 62679
      HEAP16[$54 >> 1] = $56; //@line 62680
      $62 = $56; //@line 62682
     } else {
      label = 7786; //@line 62684
     }
    } while (0);
    if ((label | 0) == 7786) {
     $58 = $c + 166 | 0; //@line 62688
     $60 = HEAP16[$58 >> 1] & -18; //@line 62690
     HEAP16[$58 >> 1] = $60; //@line 62691
     $62 = $60; //@line 62692
    }
    $65 = $c + 166 | 0; //@line 62697
    if (($9 & 65535 | 0) == 0) {
     HEAP16[$65 >> 1] = $62 & -3; //@line 62701
     $d_0_i = 0;
     $_0_i31_i = $17;
     break;
    } else {
     HEAP16[$65 >> 1] = $62 | 2; //@line 62706
     $d_0_i = 0;
     $_0_i31_i = $17;
     break;
    }
   }
  } while (0);
  do {
   if ((label | 0) == 7780) {
    $27 = $9 & 65535; //@line 62716
    $29 = $27 << $_0_i3233_i & 65535; //@line 62718
    $36 = $c + 166 | 0; //@line 62725
    $37 = HEAP16[$36 >> 1] | 0; //@line 62726
    $storemerge_i = (1 << 16 - $_0_i3233_i & $27 | 0) == 0 ? $37 & -18 : $37 | 17; //@line 62729
    HEAP16[$36 >> 1] = $storemerge_i; //@line 62730
    $40 = 65535 << 15 - $_0_i3233_i & 65535; //@line 62731
    $41 = $40 & $9; //@line 62732
    if (($41 | 0) == 0 | ($41 | 0) == ($40 | 0)) {
     HEAP16[$36 >> 1] = $storemerge_i & -3; //@line 62739
     $d_0_i = $29;
     $_0_i31_i = $_0_i3233_i;
     break;
    } else {
     HEAP16[$36 >> 1] = $storemerge_i | 2; //@line 62744
     $d_0_i = $29;
     $_0_i31_i = $_0_i3233_i;
     break;
    }
   }
  } while (0);
  $73 = $c + 372 | 0; //@line 62755
  HEAP32[$73 >> 2] = ($_0_i31_i << 1) + 6 + (HEAP32[$73 >> 2] | 0); //@line 62758
  _e68_cc_set_nz_16($c, 12, $d_0_i); //@line 62759
  $76 = $c + 156 | 0; //@line 62760
  $77 = HEAP32[$76 >> 2] | 0; //@line 62761
  if (($77 & 1 | 0) != 0) {
   _e68_exception_address($c, $77, 0, 0); //@line 62766
   return;
  }
  $82 = $c + 164 | 0; //@line 62771
  HEAP16[$c + 162 >> 1] = HEAP16[$82 >> 1] | 0; //@line 62774
  $85 = $77 & 16777215; //@line 62775
  $86 = $85 + 1 | 0; //@line 62776
  if ($86 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $92 = HEAP32[$c + 32 >> 2] | 0; //@line 62783
   $_0_i_i_i = HEAPU8[$92 + $85 | 0] << 8 | HEAPU8[$92 + $86 | 0]; //@line 62793
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $85) | 0; //@line 62801
  }
  HEAP16[$82 >> 1] = $_0_i_i_i; //@line 62804
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$76 >> 2] = (HEAP32[$76 >> 2] | 0) + 2; //@line 62812
   $114 = $c + 152 | 0; //@line 62813
   HEAP32[$114 >> 2] = (HEAP32[$114 >> 2] | 0) + 2; //@line 62816
   HEAP32[$8 >> 2] = HEAP32[$8 >> 2] & -65536 | $d_0_i & 65535; //@line 62821
   return;
  } else {
   _e68_exception_bus($c); //@line 62826
   return;
  }
 } else if (($5 | 0) == 1) {
  $123 = $c + 88 + (($3 & 7) << 2) | 0; //@line 62833
  $124 = HEAP32[$123 >> 2] | 0; //@line 62834
  $126 = $3 >>> 9 & 7; //@line 62836
  L9794 : do {
   if (($3 & 32 | 0) == 0) {
    $_0_i2324_i = ($126 | 0) == 0 ? 8 : $126; //@line 62845
    label = 7803; //@line 62846
   } else {
    $132 = HEAP32[$c + 88 + ($126 << 2) >> 2] & 63; //@line 62850
    if (($132 | 0) == 0) {
     $136 = $c + 166 | 0; //@line 62855
     HEAP16[$136 >> 1] = HEAP16[$136 >> 1] & -2; //@line 62858
     $d_0_i9 = $124 & 65535;
     $_0_i22_i = 0;
     break;
    }
    if ($132 >>> 0 < 16) {
     $_0_i2324_i = $132; //@line 62866
     label = 7803; //@line 62867
     break;
    }
    do {
     if (($132 | 0) == 16) {
      if (($124 & 1 | 0) == 0) {
       break;
      }
      $161 = $c + 166 | 0; //@line 62880
      HEAP16[$161 >> 1] = HEAP16[$161 >> 1] | 17; //@line 62883
      $d_0_i9 = 0;
      $_0_i22_i = 16;
      break L9794;
     }
    } while (0);
    $165 = $c + 166 | 0; //@line 62889
    HEAP16[$165 >> 1] = HEAP16[$165 >> 1] & -18; //@line 62892
    $d_0_i9 = 0;
    $_0_i22_i = $132;
   }
  } while (0);
  do {
   if ((label | 0) == 7803) {
    $142 = $124 & 65535; //@line 62899
    $144 = $142 << $_0_i2324_i & 65535; //@line 62901
    $149 = $c + 166 | 0; //@line 62906
    $150 = HEAP16[$149 >> 1] | 0; //@line 62907
    if ((1 << 16 - $_0_i2324_i & $142 | 0) == 0) {
     HEAP16[$149 >> 1] = $150 & -18; //@line 62911
     $d_0_i9 = $144;
     $_0_i22_i = $_0_i2324_i;
     break;
    } else {
     HEAP16[$149 >> 1] = $150 | 17; //@line 62916
     $d_0_i9 = $144;
     $_0_i22_i = $_0_i2324_i;
     break;
    }
   }
  } while (0);
  $171 = $c + 372 | 0; //@line 62927
  HEAP32[$171 >> 2] = ($_0_i22_i << 1) + 6 + (HEAP32[$171 >> 2] | 0); //@line 62930
  _e68_cc_set_nz_16($c, 14, $d_0_i9); //@line 62931
  $174 = $c + 156 | 0; //@line 62932
  $175 = HEAP32[$174 >> 2] | 0; //@line 62933
  if (($175 & 1 | 0) != 0) {
   _e68_exception_address($c, $175, 0, 0); //@line 62938
   return;
  }
  $180 = $c + 164 | 0; //@line 62943
  HEAP16[$c + 162 >> 1] = HEAP16[$180 >> 1] | 0; //@line 62946
  $183 = $175 & 16777215; //@line 62947
  $184 = $183 + 1 | 0; //@line 62948
  if ($184 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $190 = HEAP32[$c + 32 >> 2] | 0; //@line 62955
   $_0_i_i_i10 = HEAPU8[$190 + $183 | 0] << 8 | HEAPU8[$190 + $184 | 0]; //@line 62965
  } else {
   $_0_i_i_i10 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $183) | 0; //@line 62973
  }
  HEAP16[$180 >> 1] = $_0_i_i_i10; //@line 62976
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$174 >> 2] = (HEAP32[$174 >> 2] | 0) + 2; //@line 62984
   $212 = $c + 152 | 0; //@line 62985
   HEAP32[$212 >> 2] = (HEAP32[$212 >> 2] | 0) + 2; //@line 62988
   HEAP32[$123 >> 2] = HEAP32[$123 >> 2] & -65536 | $d_0_i9 & 65535; //@line 62993
   return;
  } else {
   _e68_exception_bus($c); //@line 62998
   return;
  }
 } else if (($5 | 0) == 2) {
  $221 = $c + 88 + (($3 & 7) << 2) | 0; //@line 63005
  $223 = HEAP32[$221 >> 2] & 65535; //@line 63007
  $225 = $3 >>> 9 & 7; //@line 63009
  if (($3 & 32 | 0) == 0) {
   $229 = $c + 166 | 0; //@line 63016
   $_0_i23_i = ($225 | 0) == 0 ? 8 : $225;
   $239 = $229;
   $_lobit25_i = (HEAPU16[$229 >> 1] | 0) >>> 4 & 1;
   label = 7821; //@line 63022
  } else {
   $234 = HEAP32[$c + 88 + ($225 << 2) >> 2] & 63; //@line 63026
   $235 = $c + 166 | 0; //@line 63027
   $_lobit_i = (HEAPU16[$235 >> 1] | 0) >>> 4 & 1; //@line 63030
   if (($234 | 0) == 0) {
    $x_0_lcssa_i = $_lobit_i;
    $d_0_lcssa_i = $223;
    $_0_i24_i = 0;
    $246 = $235;
   } else {
    $_0_i23_i = $234;
    $239 = $235;
    $_lobit25_i = $_lobit_i;
    label = 7821; //@line 63037
   }
  }
  if ((label | 0) == 7821) {
   $x_017_i = $_lobit25_i;
   $i_018_i = 0;
   $d_019_i = $223;
   while (1) {
    $241 = ($d_019_i & 65535) >>> 15; //@line 63050
    $243 = $x_017_i | $d_019_i << 1; //@line 63052
    $244 = $i_018_i + 1 | 0; //@line 63053
    if ($244 >>> 0 < $_0_i23_i >>> 0) {
     $x_017_i = $241;
     $i_018_i = $244;
     $d_019_i = $243;
    } else {
     $x_0_lcssa_i = $241;
     $d_0_lcssa_i = $243;
     $_0_i24_i = $_0_i23_i;
     $246 = $239;
     break;
    }
   }
  }
  $249 = $c + 372 | 0; //@line 63070
  HEAP32[$249 >> 2] = ($_0_i24_i << 1) + 6 + (HEAP32[$249 >> 2] | 0); //@line 63073
  _e68_cc_set_nz_16($c, 14, $d_0_lcssa_i); //@line 63074
  $253 = HEAP16[$246 >> 1] | 0; //@line 63076
  HEAP16[$246 >> 1] = $x_0_lcssa_i << 16 >> 16 == 0 ? $253 & -18 : $253 | 17; //@line 63080
  $256 = $c + 156 | 0; //@line 63081
  $257 = HEAP32[$256 >> 2] | 0; //@line 63082
  if (($257 & 1 | 0) != 0) {
   _e68_exception_address($c, $257, 0, 0); //@line 63087
   return;
  }
  $262 = $c + 164 | 0; //@line 63092
  HEAP16[$c + 162 >> 1] = HEAP16[$262 >> 1] | 0; //@line 63095
  $265 = $257 & 16777215; //@line 63096
  $266 = $265 + 1 | 0; //@line 63097
  if ($266 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $272 = HEAP32[$c + 32 >> 2] | 0; //@line 63104
   $_0_i_i_i15 = HEAPU8[$272 + $265 | 0] << 8 | HEAPU8[$272 + $266 | 0]; //@line 63114
  } else {
   $_0_i_i_i15 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $265) | 0; //@line 63122
  }
  HEAP16[$262 >> 1] = $_0_i_i_i15; //@line 63125
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$256 >> 2] = (HEAP32[$256 >> 2] | 0) + 2; //@line 63133
   $294 = $c + 152 | 0; //@line 63134
   HEAP32[$294 >> 2] = (HEAP32[$294 >> 2] | 0) + 2; //@line 63137
   HEAP32[$221 >> 2] = HEAP32[$221 >> 2] & -65536 | $d_0_lcssa_i & 65535; //@line 63142
   return;
  } else {
   _e68_exception_bus($c); //@line 63147
   return;
  }
 } else if (($5 | 0) == 3) {
  $303 = $c + 88 + (($3 & 7) << 2) | 0; //@line 63154
  $304 = HEAP32[$303 >> 2] | 0; //@line 63155
  $305 = $304 & 65535; //@line 63156
  $307 = $3 >>> 9 & 7; //@line 63158
  if (($3 & 32 | 0) == 0) {
   $_0_i_i = ($307 | 0) == 0 ? 8 : $307; //@line 63166
  } else {
   $_0_i_i = HEAP32[$c + 88 + ($307 << 2) >> 2] & 63; //@line 63172
  }
  $316 = $_0_i_i & 15; //@line 63175
  L9853 : do {
   if (($316 | 0) == 0) {
    do {
     if (($_0_i_i | 0) != 0) {
      if (($304 & 1 | 0) == 0) {
       break;
      }
      $339 = $c + 166 | 0; //@line 63190
      HEAP16[$339 >> 1] = HEAP16[$339 >> 1] | 1; //@line 63193
      $d_0_i19 = $305; //@line 63195
      break L9853;
     }
    } while (0);
    $343 = $c + 166 | 0; //@line 63199
    HEAP16[$343 >> 1] = HEAP16[$343 >> 1] & -2; //@line 63202
    $d_0_i19 = $305; //@line 63203
   } else {
    $319 = $304 & 65535; //@line 63205
    $323 = $319 >>> ((16 - $316 | 0) >>> 0) | $319 << $316; //@line 63209
    $324 = $323 & 65535; //@line 63210
    $327 = $c + 166 | 0; //@line 63213
    $328 = HEAP16[$327 >> 1] | 0; //@line 63214
    if (($323 & 1 | 0) == 0) {
     HEAP16[$327 >> 1] = $328 & -2; //@line 63218
     $d_0_i19 = $324; //@line 63219
     break;
    } else {
     HEAP16[$327 >> 1] = $328 | 1; //@line 63223
     $d_0_i19 = $324; //@line 63225
     break;
    }
   }
  } while (0);
  $349 = $c + 372 | 0; //@line 63233
  HEAP32[$349 >> 2] = ($_0_i_i << 1) + 6 + (HEAP32[$349 >> 2] | 0); //@line 63236
  _e68_cc_set_nz_16($c, 14, $d_0_i19); //@line 63237
  $352 = $c + 156 | 0; //@line 63238
  $353 = HEAP32[$352 >> 2] | 0; //@line 63239
  if (($353 & 1 | 0) != 0) {
   _e68_exception_address($c, $353, 0, 0); //@line 63244
   return;
  }
  $358 = $c + 164 | 0; //@line 63249
  HEAP16[$c + 162 >> 1] = HEAP16[$358 >> 1] | 0; //@line 63252
  $361 = $353 & 16777215; //@line 63253
  $362 = $361 + 1 | 0; //@line 63254
  if ($362 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $368 = HEAP32[$c + 32 >> 2] | 0; //@line 63261
   $_0_i_i_i20 = HEAPU8[$368 + $361 | 0] << 8 | HEAPU8[$368 + $362 | 0]; //@line 63271
  } else {
   $_0_i_i_i20 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $361) | 0; //@line 63279
  }
  HEAP16[$358 >> 1] = $_0_i_i_i20; //@line 63282
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$352 >> 2] = (HEAP32[$352 >> 2] | 0) + 2; //@line 63290
   $390 = $c + 152 | 0; //@line 63291
   HEAP32[$390 >> 2] = (HEAP32[$390 >> 2] | 0) + 2; //@line 63294
   HEAP32[$303 >> 2] = HEAP32[$303 >> 2] & -65536 | $d_0_i19 & 65535; //@line 63299
   return;
  } else {
   _e68_exception_bus($c); //@line 63304
   return;
  }
 } else {
  _e68_exception_illegal($c); //@line 63310
  $398 = $c + 372 | 0; //@line 63311
  HEAP32[$398 >> 2] = (HEAP32[$398 >> 2] | 0) + 2; //@line 63314
  return;
 }
}
function _ope180($c) {
 $c = $c | 0;
 var $3 = 0, $5 = 0, $8 = 0, $9 = 0, $11 = 0, $17 = 0, $20 = 0, $_0_i3233_i = 0, $26 = 0, $28 = 0, $33 = 0, $34 = 0, $storemerge_i = 0, $37 = 0, $50 = 0, $52 = 0, $54 = 0, $56 = 0, $58 = 0, $60 = 0, $_0_i31_i = 0, $d_0_i = 0, $68 = 0, $71 = 0, $72 = 0, $77 = 0, $80 = 0, $81 = 0, $87 = 0, $_0_i_i_i = 0, $109 = 0, $114 = 0, $115 = 0, $117 = 0, $123 = 0, $126 = 0, $_0_i2324_i = 0, $132 = 0, $137 = 0, $138 = 0, $149 = 0, $153 = 0, $_0_i22_i = 0, $d_0_i9 = 0, $159 = 0, $162 = 0, $163 = 0, $168 = 0, $171 = 0, $172 = 0, $178 = 0, $_0_i_i_i10 = 0, $200 = 0, $206 = 0, $_0_i_i = 0, $215 = 0, $216 = 0, $217 = 0, $220 = 0, $d_019_i = 0, $i_018_i = 0, $x_017_i = 0, $222 = 0, $224 = 0, $225 = 0, $d_0_lcssa_i = 0, $x_0_lcssa_i = 0, $229 = 0, $233 = 0, $236 = 0, $237 = 0, $242 = 0, $245 = 0, $246 = 0, $252 = 0, $_0_i_i_i15 = 0, $274 = 0, $279 = 0, $280 = 0, $282 = 0, $_0_i_i18 = 0, $291 = 0, $297 = 0, $300 = 0, $301 = 0, $312 = 0, $316 = 0, $d_0_i20 = 0, $322 = 0, $325 = 0, $326 = 0, $331 = 0, $334 = 0, $335 = 0, $341 = 0, $_0_i_i_i21 = 0, $363 = 0, $367 = 0, label = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 63370
 $5 = $3 >>> 3 & 3; //@line 63372
 if (($5 | 0) == 3) {
  $279 = $c + 88 + (($3 & 7) << 2) | 0; //@line 63375
  $280 = HEAP32[$279 >> 2] | 0; //@line 63376
  $282 = $3 >>> 9 & 7; //@line 63378
  if (($3 & 32 | 0) == 0) {
   $_0_i_i18 = ($282 | 0) == 0 ? 8 : $282; //@line 63386
  } else {
   $_0_i_i18 = HEAP32[$c + 88 + ($282 << 2) >> 2] & 63; //@line 63392
  }
  $291 = $_0_i_i18 & 31; //@line 63395
  L9884 : do {
   if (($291 | 0) == 0) {
    do {
     if (($_0_i_i18 | 0) != 0) {
      if (($280 & 1 | 0) == 0) {
       break;
      }
      $312 = $c + 166 | 0; //@line 63410
      HEAP16[$312 >> 1] = HEAP16[$312 >> 1] | 1; //@line 63413
      $d_0_i20 = $280; //@line 63415
      break L9884;
     }
    } while (0);
    $316 = $c + 166 | 0; //@line 63419
    HEAP16[$316 >> 1] = HEAP16[$316 >> 1] & -2; //@line 63422
    $d_0_i20 = $280; //@line 63423
   } else {
    $297 = $280 >>> ((32 - $291 | 0) >>> 0) | $280 << $291; //@line 63428
    $300 = $c + 166 | 0; //@line 63431
    $301 = HEAP16[$300 >> 1] | 0; //@line 63432
    if (($297 & 1 | 0) == 0) {
     HEAP16[$300 >> 1] = $301 & -2; //@line 63436
     $d_0_i20 = $297; //@line 63437
     break;
    } else {
     HEAP16[$300 >> 1] = $301 | 1; //@line 63441
     $d_0_i20 = $297; //@line 63443
     break;
    }
   }
  } while (0);
  $322 = $c + 372 | 0; //@line 63451
  HEAP32[$322 >> 2] = ($_0_i_i18 << 1) + 8 + (HEAP32[$322 >> 2] | 0); //@line 63454
  _e68_cc_set_nz_32($c, 14, $d_0_i20); //@line 63455
  $325 = $c + 156 | 0; //@line 63456
  $326 = HEAP32[$325 >> 2] | 0; //@line 63457
  if (($326 & 1 | 0) != 0) {
   _e68_exception_address($c, $326, 0, 0); //@line 63462
   return;
  }
  $331 = $c + 164 | 0; //@line 63467
  HEAP16[$c + 162 >> 1] = HEAP16[$331 >> 1] | 0; //@line 63470
  $334 = $326 & 16777215; //@line 63471
  $335 = $334 + 1 | 0; //@line 63472
  if ($335 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $341 = HEAP32[$c + 32 >> 2] | 0; //@line 63479
   $_0_i_i_i21 = HEAPU8[$341 + $334 | 0] << 8 | HEAPU8[$341 + $335 | 0]; //@line 63489
  } else {
   $_0_i_i_i21 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $334) | 0; //@line 63497
  }
  HEAP16[$331 >> 1] = $_0_i_i_i21; //@line 63500
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$325 >> 2] = (HEAP32[$325 >> 2] | 0) + 2; //@line 63508
   $363 = $c + 152 | 0; //@line 63509
   HEAP32[$363 >> 2] = (HEAP32[$363 >> 2] | 0) + 2; //@line 63512
   HEAP32[$279 >> 2] = $d_0_i20; //@line 63513
   return;
  } else {
   _e68_exception_bus($c); //@line 63518
   return;
  }
 } else if (($5 | 0) == 2) {
  $206 = $3 >>> 9 & 7; //@line 63526
  if (($3 & 32 | 0) == 0) {
   $_0_i_i = ($206 | 0) == 0 ? 8 : $206; //@line 63534
  } else {
   $_0_i_i = HEAP32[$c + 88 + ($206 << 2) >> 2] & 63; //@line 63540
  }
  $215 = $c + 88 + (($3 & 7) << 2) | 0; //@line 63543
  $216 = HEAP32[$215 >> 2] | 0; //@line 63544
  $217 = $c + 166 | 0; //@line 63545
  $220 = (HEAPU16[$217 >> 1] | 0) >>> 4 & 1; //@line 63549
  if (($_0_i_i | 0) == 0) {
   $x_0_lcssa_i = $220;
   $d_0_lcssa_i = $216;
  } else {
   $x_017_i = $220;
   $i_018_i = 0;
   $d_019_i = $216;
   while (1) {
    $222 = $d_019_i >>> 31; //@line 63560
    $224 = $x_017_i | $d_019_i << 1; //@line 63562
    $225 = $i_018_i + 1 | 0; //@line 63563
    if ($225 >>> 0 < $_0_i_i >>> 0) {
     $x_017_i = $222;
     $i_018_i = $225;
     $d_019_i = $224;
    } else {
     $x_0_lcssa_i = $222;
     $d_0_lcssa_i = $224;
     break;
    }
   }
  }
  $229 = $c + 372 | 0; //@line 63578
  HEAP32[$229 >> 2] = ($_0_i_i << 1) + 8 + (HEAP32[$229 >> 2] | 0); //@line 63581
  _e68_cc_set_nz_32($c, 14, $d_0_lcssa_i); //@line 63582
  $233 = HEAP16[$217 >> 1] | 0; //@line 63584
  HEAP16[$217 >> 1] = ($x_0_lcssa_i | 0) == 0 ? $233 & -18 : $233 | 17; //@line 63588
  $236 = $c + 156 | 0; //@line 63589
  $237 = HEAP32[$236 >> 2] | 0; //@line 63590
  if (($237 & 1 | 0) != 0) {
   _e68_exception_address($c, $237, 0, 0); //@line 63595
   return;
  }
  $242 = $c + 164 | 0; //@line 63600
  HEAP16[$c + 162 >> 1] = HEAP16[$242 >> 1] | 0; //@line 63603
  $245 = $237 & 16777215; //@line 63604
  $246 = $245 + 1 | 0; //@line 63605
  if ($246 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $252 = HEAP32[$c + 32 >> 2] | 0; //@line 63612
   $_0_i_i_i15 = HEAPU8[$252 + $245 | 0] << 8 | HEAPU8[$252 + $246 | 0]; //@line 63622
  } else {
   $_0_i_i_i15 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $245) | 0; //@line 63630
  }
  HEAP16[$242 >> 1] = $_0_i_i_i15; //@line 63633
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$236 >> 2] = (HEAP32[$236 >> 2] | 0) + 2; //@line 63641
   $274 = $c + 152 | 0; //@line 63642
   HEAP32[$274 >> 2] = (HEAP32[$274 >> 2] | 0) + 2; //@line 63645
   HEAP32[$215 >> 2] = $d_0_lcssa_i; //@line 63646
   return;
  } else {
   _e68_exception_bus($c); //@line 63651
   return;
  }
 } else if (($5 | 0) == 0) {
  $8 = $c + 88 + (($3 & 7) << 2) | 0; //@line 63658
  $9 = HEAP32[$8 >> 2] | 0; //@line 63659
  $11 = $3 >>> 9 & 7; //@line 63661
  do {
   if (($3 & 32 | 0) == 0) {
    $_0_i3233_i = ($11 | 0) == 0 ? 8 : $11; //@line 63670
    label = 7871; //@line 63671
   } else {
    $17 = HEAP32[$c + 88 + ($11 << 2) >> 2] & 63; //@line 63675
    if (($17 | 0) == 0) {
     $20 = $c + 166 | 0; //@line 63679
     HEAP16[$20 >> 1] = HEAP16[$20 >> 1] & -4; //@line 63682
     $d_0_i = $9;
     $_0_i31_i = 0;
     break;
    }
    if ($17 >>> 0 < 32) {
     $_0_i3233_i = $17; //@line 63690
     label = 7871; //@line 63691
     break;
    }
    do {
     if (($17 | 0) == 32) {
      if (($9 & 1 | 0) == 0) {
       label = 7877; //@line 63702
       break;
      }
      $50 = $c + 166 | 0; //@line 63705
      $52 = HEAP16[$50 >> 1] | 17; //@line 63707
      HEAP16[$50 >> 1] = $52; //@line 63708
      $58 = $52; //@line 63710
     } else {
      label = 7877; //@line 63712
     }
    } while (0);
    if ((label | 0) == 7877) {
     $54 = $c + 166 | 0; //@line 63716
     $56 = HEAP16[$54 >> 1] & -18; //@line 63718
     HEAP16[$54 >> 1] = $56; //@line 63719
     $58 = $56; //@line 63720
    }
    $60 = $c + 166 | 0; //@line 63724
    if (($9 | 0) == 0) {
     HEAP16[$60 >> 1] = $58 & -3; //@line 63728
     $d_0_i = 0;
     $_0_i31_i = $17;
     break;
    } else {
     HEAP16[$60 >> 1] = $58 | 2; //@line 63733
     $d_0_i = 0;
     $_0_i31_i = $17;
     break;
    }
   }
  } while (0);
  do {
   if ((label | 0) == 7871) {
    $26 = $9 << $_0_i3233_i; //@line 63743
    $28 = -1 << 31 - $_0_i3233_i; //@line 63745
    $33 = $c + 166 | 0; //@line 63750
    $34 = HEAP16[$33 >> 1] | 0; //@line 63751
    $storemerge_i = (1 << 32 - $_0_i3233_i & $9 | 0) == 0 ? $34 & -18 : $34 | 17; //@line 63754
    HEAP16[$33 >> 1] = $storemerge_i; //@line 63755
    $37 = $28 & $9; //@line 63756
    if (($37 | 0) == 0 | ($37 | 0) == ($28 | 0)) {
     HEAP16[$33 >> 1] = $storemerge_i & -3; //@line 63763
     $d_0_i = $26;
     $_0_i31_i = $_0_i3233_i;
     break;
    } else {
     HEAP16[$33 >> 1] = $storemerge_i | 2; //@line 63768
     $d_0_i = $26;
     $_0_i31_i = $_0_i3233_i;
     break;
    }
   }
  } while (0);
  $68 = $c + 372 | 0; //@line 63779
  HEAP32[$68 >> 2] = ($_0_i31_i << 1) + 8 + (HEAP32[$68 >> 2] | 0); //@line 63782
  _e68_cc_set_nz_32($c, 12, $d_0_i); //@line 63783
  $71 = $c + 156 | 0; //@line 63784
  $72 = HEAP32[$71 >> 2] | 0; //@line 63785
  if (($72 & 1 | 0) != 0) {
   _e68_exception_address($c, $72, 0, 0); //@line 63790
   return;
  }
  $77 = $c + 164 | 0; //@line 63795
  HEAP16[$c + 162 >> 1] = HEAP16[$77 >> 1] | 0; //@line 63798
  $80 = $72 & 16777215; //@line 63799
  $81 = $80 + 1 | 0; //@line 63800
  if ($81 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $87 = HEAP32[$c + 32 >> 2] | 0; //@line 63807
   $_0_i_i_i = HEAPU8[$87 + $80 | 0] << 8 | HEAPU8[$87 + $81 | 0]; //@line 63817
  } else {
   $_0_i_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $80) | 0; //@line 63825
  }
  HEAP16[$77 >> 1] = $_0_i_i_i; //@line 63828
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$71 >> 2] = (HEAP32[$71 >> 2] | 0) + 2; //@line 63836
   $109 = $c + 152 | 0; //@line 63837
   HEAP32[$109 >> 2] = (HEAP32[$109 >> 2] | 0) + 2; //@line 63840
   HEAP32[$8 >> 2] = $d_0_i; //@line 63841
   return;
  } else {
   _e68_exception_bus($c); //@line 63846
   return;
  }
 } else if (($5 | 0) == 1) {
  $114 = $c + 88 + (($3 & 7) << 2) | 0; //@line 63853
  $115 = HEAP32[$114 >> 2] | 0; //@line 63854
  $117 = $3 >>> 9 & 7; //@line 63856
  L9969 : do {
   if (($3 & 32 | 0) == 0) {
    $_0_i2324_i = ($117 | 0) == 0 ? 8 : $117; //@line 63865
    label = 7894; //@line 63866
   } else {
    $123 = HEAP32[$c + 88 + ($117 << 2) >> 2] & 63; //@line 63870
    if (($123 | 0) == 0) {
     $126 = $c + 166 | 0; //@line 63874
     HEAP16[$126 >> 1] = HEAP16[$126 >> 1] & -2; //@line 63877
     $d_0_i9 = $115;
     $_0_i22_i = 0;
     break;
    }
    if ($123 >>> 0 < 32) {
     $_0_i2324_i = $123; //@line 63885
     label = 7894; //@line 63886
     break;
    }
    do {
     if (($123 | 0) == 32) {
      if (($115 & 1 | 0) == 0) {
       break;
      }
      $149 = $c + 166 | 0; //@line 63899
      HEAP16[$149 >> 1] = HEAP16[$149 >> 1] | 17; //@line 63902
      $d_0_i9 = 0;
      $_0_i22_i = 32;
      break L9969;
     }
    } while (0);
    $153 = $c + 166 | 0; //@line 63908
    HEAP16[$153 >> 1] = HEAP16[$153 >> 1] & -18; //@line 63911
    $d_0_i9 = 0;
    $_0_i22_i = $123;
   }
  } while (0);
  do {
   if ((label | 0) == 7894) {
    $132 = $115 << $_0_i2324_i; //@line 63918
    $137 = $c + 166 | 0; //@line 63923
    $138 = HEAP16[$137 >> 1] | 0; //@line 63924
    if ((1 << 32 - $_0_i2324_i & $115 | 0) == 0) {
     HEAP16[$137 >> 1] = $138 & -18; //@line 63928
     $d_0_i9 = $132;
     $_0_i22_i = $_0_i2324_i;
     break;
    } else {
     HEAP16[$137 >> 1] = $138 | 17; //@line 63933
     $d_0_i9 = $132;
     $_0_i22_i = $_0_i2324_i;
     break;
    }
   }
  } while (0);
  $159 = $c + 372 | 0; //@line 63944
  HEAP32[$159 >> 2] = ($_0_i22_i << 1) + 8 + (HEAP32[$159 >> 2] | 0); //@line 63947
  _e68_cc_set_nz_32($c, 14, $d_0_i9); //@line 63948
  $162 = $c + 156 | 0; //@line 63949
  $163 = HEAP32[$162 >> 2] | 0; //@line 63950
  if (($163 & 1 | 0) != 0) {
   _e68_exception_address($c, $163, 0, 0); //@line 63955
   return;
  }
  $168 = $c + 164 | 0; //@line 63960
  HEAP16[$c + 162 >> 1] = HEAP16[$168 >> 1] | 0; //@line 63963
  $171 = $163 & 16777215; //@line 63964
  $172 = $171 + 1 | 0; //@line 63965
  if ($172 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $178 = HEAP32[$c + 32 >> 2] | 0; //@line 63972
   $_0_i_i_i10 = HEAPU8[$178 + $171 | 0] << 8 | HEAPU8[$178 + $172 | 0]; //@line 63982
  } else {
   $_0_i_i_i10 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $171) | 0; //@line 63990
  }
  HEAP16[$168 >> 1] = $_0_i_i_i10; //@line 63993
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   HEAP32[$162 >> 2] = (HEAP32[$162 >> 2] | 0) + 2; //@line 64001
   $200 = $c + 152 | 0; //@line 64002
   HEAP32[$200 >> 2] = (HEAP32[$200 >> 2] | 0) + 2; //@line 64005
   HEAP32[$114 >> 2] = $d_0_i9; //@line 64006
   return;
  } else {
   _e68_exception_bus($c); //@line 64011
   return;
  }
 } else {
  _e68_exception_illegal($c); //@line 64017
  $367 = $c + 372 | 0; //@line 64018
  HEAP32[$367 >> 2] = (HEAP32[$367 >> 2] | 0) + 2; //@line 64021
  return;
 }
}
function _ope1c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $15 = 0, $16 = 0, $17 = 0, $20 = 0, $22 = 0, $23 = 0, $storemerge = 0, $32 = 0, $33 = 0, $38 = 0, $41 = 0, $42 = 0, $48 = 0, $_0_i_i = 0, $70 = 0, sp = 0;
 sp = STACKTOP; //@line 64041
 STACKTOP = STACKTOP + 8 | 0; //@line 64041
 $s = sp | 0; //@line 64042
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64046
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64053
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64060
  return;
 }
 $15 = HEAPU16[$s >> 1] << 1; //@line 64065
 $16 = $15 & 65535; //@line 64066
 $17 = $c + 372 | 0; //@line 64067
 HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 8; //@line 64070
 _e68_cc_set_nz_16($c, 12, $16); //@line 64071
 $20 = HEAP16[$s >> 1] | 0; //@line 64072
 $22 = $c + 166 | 0; //@line 64074
 $23 = HEAP16[$22 >> 1] | 0; //@line 64075
 $storemerge = $20 << 16 >> 16 < 0 ? $23 | 17 : $23 & -18; //@line 64078
 HEAP16[$22 >> 1] = (($20 & 65535 ^ $15) & 32768 | 0) == 0 ? $storemerge & -3 : $storemerge | 2; //@line 64086
 $32 = $c + 156 | 0; //@line 64087
 $33 = HEAP32[$32 >> 2] | 0; //@line 64088
 if (($33 & 1 | 0) != 0) {
  _e68_exception_address($c, $33, 0, 0); //@line 64093
  STACKTOP = sp; //@line 64095
  return;
 }
 $38 = $c + 164 | 0; //@line 64098
 HEAP16[$c + 162 >> 1] = HEAP16[$38 >> 1] | 0; //@line 64101
 $41 = $33 & 16777215; //@line 64102
 $42 = $41 + 1 | 0; //@line 64103
 if ($42 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $48 = HEAP32[$c + 32 >> 2] | 0; //@line 64110
  $_0_i_i = HEAPU8[$48 + $41 | 0] << 8 | HEAPU8[$48 + $42 | 0]; //@line 64120
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $41) | 0; //@line 64128
 }
 HEAP16[$38 >> 1] = $_0_i_i; //@line 64131
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$32 >> 2] = (HEAP32[$32 >> 2] | 0) + 2; //@line 64139
  $70 = $c + 152 | 0; //@line 64140
  HEAP32[$70 >> 2] = (HEAP32[$70 >> 2] | 0) + 2; //@line 64143
  _e68_ea_set_val16($c, $16) | 0; //@line 64144
  STACKTOP = sp; //@line 64146
  return;
 } else {
  _e68_exception_bus($c); //@line 64149
  STACKTOP = sp; //@line 64151
  return;
 }
}
function _ope2c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $21 = 0, $22 = 0, $25 = 0, $26 = 0, $31 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0, sp = 0;
 sp = STACKTOP; //@line 64168
 STACKTOP = STACKTOP + 8 | 0; //@line 64168
 $s = sp | 0; //@line 64169
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64173
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64180
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64187
  return;
 }
 $14 = (HEAPU16[$s >> 1] | 0) >>> 1; //@line 64191
 $15 = $c + 372 | 0; //@line 64192
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 8; //@line 64195
 _e68_cc_set_nz_16($c, 14, $14); //@line 64196
 $21 = $c + 166 | 0; //@line 64200
 $22 = HEAP16[$21 >> 1] | 0; //@line 64201
 HEAP16[$21 >> 1] = (HEAP16[$s >> 1] & 1) == 0 ? $22 & -18 : $22 | 17; //@line 64205
 $25 = $c + 156 | 0; //@line 64206
 $26 = HEAP32[$25 >> 2] | 0; //@line 64207
 if (($26 & 1 | 0) != 0) {
  _e68_exception_address($c, $26, 0, 0); //@line 64212
  STACKTOP = sp; //@line 64214
  return;
 }
 $31 = $c + 164 | 0; //@line 64217
 HEAP16[$c + 162 >> 1] = HEAP16[$31 >> 1] | 0; //@line 64220
 $34 = $26 & 16777215; //@line 64221
 $35 = $34 + 1 | 0; //@line 64222
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 64229
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 64239
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 64247
 }
 HEAP16[$31 >> 1] = $_0_i_i; //@line 64250
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$25 >> 2] = (HEAP32[$25 >> 2] | 0) + 2; //@line 64258
  $63 = $c + 152 | 0; //@line 64259
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 64262
  _e68_ea_set_val16($c, $14) | 0; //@line 64263
  STACKTOP = sp; //@line 64265
  return;
 } else {
  _e68_exception_bus($c); //@line 64268
  STACKTOP = sp; //@line 64270
  return;
 }
}
function _ope3c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $15 = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $30 = 0, $33 = 0, $34 = 0, $40 = 0, $_0_i_i = 0, $62 = 0, sp = 0;
 sp = STACKTOP; //@line 64287
 STACKTOP = STACKTOP + 8 | 0; //@line 64287
 $s = sp | 0; //@line 64288
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64292
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64299
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64306
  return;
 }
 $14 = HEAP16[$s >> 1] << 1; //@line 64310
 $15 = $c + 372 | 0; //@line 64311
 HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 8; //@line 64314
 _e68_cc_set_nz_16($c, 14, $14); //@line 64315
 $20 = $c + 166 | 0; //@line 64318
 $21 = HEAP16[$20 >> 1] | 0; //@line 64319
 HEAP16[$20 >> 1] = (HEAP16[$s >> 1] | 0) < 0 ? $21 | 17 : $21 & -18; //@line 64323
 $24 = $c + 156 | 0; //@line 64324
 $25 = HEAP32[$24 >> 2] | 0; //@line 64325
 if (($25 & 1 | 0) != 0) {
  _e68_exception_address($c, $25, 0, 0); //@line 64330
  STACKTOP = sp; //@line 64332
  return;
 }
 $30 = $c + 164 | 0; //@line 64335
 HEAP16[$c + 162 >> 1] = HEAP16[$30 >> 1] | 0; //@line 64338
 $33 = $25 & 16777215; //@line 64339
 $34 = $33 + 1 | 0; //@line 64340
 if ($34 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $40 = HEAP32[$c + 32 >> 2] | 0; //@line 64347
  $_0_i_i = HEAPU8[$40 + $33 | 0] << 8 | HEAPU8[$40 + $34 | 0]; //@line 64357
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $33) | 0; //@line 64365
 }
 HEAP16[$30 >> 1] = $_0_i_i; //@line 64368
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$24 >> 2] = (HEAP32[$24 >> 2] | 0) + 2; //@line 64376
  $62 = $c + 152 | 0; //@line 64377
  HEAP32[$62 >> 2] = (HEAP32[$62 >> 2] | 0) + 2; //@line 64380
  _e68_ea_set_val16($c, $14) | 0; //@line 64381
  STACKTOP = sp; //@line 64383
  return;
 } else {
  _e68_exception_bus($c); //@line 64386
  STACKTOP = sp; //@line 64388
  return;
 }
}
function _ope4c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $19 = 0, $20 = 0, $26 = 0, $29 = 0, $30 = 0, $35 = 0, $38 = 0, $39 = 0, $45 = 0, $_0_i_i = 0, $67 = 0, sp = 0;
 sp = STACKTOP; //@line 64406
 STACKTOP = STACKTOP + 8 | 0; //@line 64406
 $s = sp | 0; //@line 64407
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64411
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64418
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64425
  return;
 }
 $13 = $c + 166 | 0; //@line 64428
 $19 = (HEAPU16[$s >> 1] | 0) >>> 1 | (HEAPU16[$13 >> 1] | 0) >>> 4 << 15; //@line 64434
 $20 = $c + 372 | 0; //@line 64435
 HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 8; //@line 64438
 _e68_cc_set_nz_16($c, 14, $19); //@line 64439
 $26 = HEAP16[$13 >> 1] | 0; //@line 64443
 HEAP16[$13 >> 1] = (HEAP16[$s >> 1] & 1) == 0 ? $26 & -18 : $26 | 17; //@line 64447
 $29 = $c + 156 | 0; //@line 64448
 $30 = HEAP32[$29 >> 2] | 0; //@line 64449
 if (($30 & 1 | 0) != 0) {
  _e68_exception_address($c, $30, 0, 0); //@line 64454
  STACKTOP = sp; //@line 64456
  return;
 }
 $35 = $c + 164 | 0; //@line 64459
 HEAP16[$c + 162 >> 1] = HEAP16[$35 >> 1] | 0; //@line 64462
 $38 = $30 & 16777215; //@line 64463
 $39 = $38 + 1 | 0; //@line 64464
 if ($39 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $45 = HEAP32[$c + 32 >> 2] | 0; //@line 64471
  $_0_i_i = HEAPU8[$45 + $38 | 0] << 8 | HEAPU8[$45 + $39 | 0]; //@line 64481
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $38) | 0; //@line 64489
 }
 HEAP16[$35 >> 1] = $_0_i_i; //@line 64492
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 2; //@line 64500
  $67 = $c + 152 | 0; //@line 64501
  HEAP32[$67 >> 2] = (HEAP32[$67 >> 2] | 0) + 2; //@line 64504
  _e68_ea_set_val16($c, $19) | 0; //@line 64505
  STACKTOP = sp; //@line 64507
  return;
 } else {
  _e68_exception_bus($c); //@line 64510
  STACKTOP = sp; //@line 64512
  return;
 }
}
function _ope5c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $18 = 0, $19 = 0, $24 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 64529
 STACKTOP = STACKTOP + 8 | 0; //@line 64529
 $s = sp | 0; //@line 64530
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64534
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64541
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64548
  return;
 }
 $13 = $c + 166 | 0; //@line 64551
 $18 = HEAP16[$s >> 1] << 1 | (HEAPU16[$13 >> 1] | 0) >>> 4 & 1; //@line 64557
 $19 = $c + 372 | 0; //@line 64558
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 8; //@line 64561
 _e68_cc_set_nz_16($c, 14, $18); //@line 64562
 $24 = HEAP16[$13 >> 1] | 0; //@line 64565
 HEAP16[$13 >> 1] = (HEAP16[$s >> 1] | 0) < 0 ? $24 | 17 : $24 & -18; //@line 64569
 $27 = $c + 156 | 0; //@line 64570
 $28 = HEAP32[$27 >> 2] | 0; //@line 64571
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 64576
  STACKTOP = sp; //@line 64578
  return;
 }
 $33 = $c + 164 | 0; //@line 64581
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 64584
 $36 = $28 & 16777215; //@line 64585
 $37 = $36 + 1 | 0; //@line 64586
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 64593
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 64603
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 64611
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 64614
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 64622
  $65 = $c + 152 | 0; //@line 64623
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 64626
  _e68_ea_set_val16($c, $18) | 0; //@line 64627
  STACKTOP = sp; //@line 64629
  return;
 } else {
  _e68_exception_bus($c); //@line 64632
  STACKTOP = sp; //@line 64634
  return;
 }
}
function _ope6c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $16 = 0, $17 = 0, $23 = 0, $24 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 64651
 STACKTOP = STACKTOP + 8 | 0; //@line 64651
 $s = sp | 0; //@line 64652
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64656
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64663
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64670
  return;
 }
 $13 = HEAP16[$s >> 1] | 0; //@line 64673
 $16 = ($13 & 65535) >>> 1 | $13 << 15; //@line 64676
 $17 = $c + 372 | 0; //@line 64677
 HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 8; //@line 64680
 _e68_cc_set_nz_16($c, 14, $16); //@line 64681
 $23 = $c + 166 | 0; //@line 64685
 $24 = HEAP16[$23 >> 1] | 0; //@line 64686
 HEAP16[$23 >> 1] = (HEAP16[$s >> 1] & 1) == 0 ? $24 & -2 : $24 | 1; //@line 64690
 $27 = $c + 156 | 0; //@line 64691
 $28 = HEAP32[$27 >> 2] | 0; //@line 64692
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 64697
  STACKTOP = sp; //@line 64699
  return;
 }
 $33 = $c + 164 | 0; //@line 64702
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 64705
 $36 = $28 & 16777215; //@line 64706
 $37 = $36 + 1 | 0; //@line 64707
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 64714
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 64724
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 64732
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 64735
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 64743
  $65 = $c + 152 | 0; //@line 64744
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 64747
  _e68_ea_set_val16($c, $16) | 0; //@line 64748
  STACKTOP = sp; //@line 64750
  return;
 } else {
  _e68_exception_bus($c); //@line 64753
  STACKTOP = sp; //@line 64755
  return;
 }
}
function _ope7c0($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $14 = 0, $16 = 0, $18 = 0, $19 = 0, $23 = 0, $24 = 0, $27 = 0, $28 = 0, $33 = 0, $36 = 0, $37 = 0, $43 = 0, $_0_i_i = 0, $65 = 0, sp = 0;
 sp = STACKTOP; //@line 64772
 STACKTOP = STACKTOP + 8 | 0; //@line 64772
 $s = sp | 0; //@line 64773
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 64777
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 508, 16) | 0) != 0) {
  STACKTOP = sp; //@line 64784
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 64791
  return;
 }
 $14 = HEAPU16[$s >> 1] | 0; //@line 64795
 $16 = $14 >>> 15; //@line 64797
 $18 = ($14 << 1 | $16) & 65535; //@line 64799
 $19 = $c + 372 | 0; //@line 64800
 HEAP32[$19 >> 2] = (HEAP32[$19 >> 2] | 0) + 8; //@line 64803
 _e68_cc_set_nz_16($c, 14, $18); //@line 64804
 $23 = $c + 166 | 0; //@line 64806
 $24 = HEAP16[$23 >> 1] | 0; //@line 64807
 HEAP16[$23 >> 1] = ($16 | 0) == 0 ? $24 & -2 : $24 | 1; //@line 64811
 $27 = $c + 156 | 0; //@line 64812
 $28 = HEAP32[$27 >> 2] | 0; //@line 64813
 if (($28 & 1 | 0) != 0) {
  _e68_exception_address($c, $28, 0, 0); //@line 64818
  STACKTOP = sp; //@line 64820
  return;
 }
 $33 = $c + 164 | 0; //@line 64823
 HEAP16[$c + 162 >> 1] = HEAP16[$33 >> 1] | 0; //@line 64826
 $36 = $28 & 16777215; //@line 64827
 $37 = $36 + 1 | 0; //@line 64828
 if ($37 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $43 = HEAP32[$c + 32 >> 2] | 0; //@line 64835
  $_0_i_i = HEAPU8[$43 + $36 | 0] << 8 | HEAPU8[$43 + $37 | 0]; //@line 64845
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $36) | 0; //@line 64853
 }
 HEAP16[$33 >> 1] = $_0_i_i; //@line 64856
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$27 >> 2] = (HEAP32[$27 >> 2] | 0) + 2; //@line 64864
  $65 = $c + 152 | 0; //@line 64865
  HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 2; //@line 64868
  _e68_ea_set_val16($c, $18) | 0; //@line 64869
  STACKTOP = sp; //@line 64871
  return;
 } else {
  _e68_exception_bus($c); //@line 64874
  STACKTOP = sp; //@line 64876
  return;
 }
}
function _opf000($c) {
 $c = $c | 0;
 HEAP16[$c + 330 >> 1] = HEAP16[$c + 160 >> 1] | 0; //@line 64890
 _e68_exception_fxxx($c); //@line 64891
 return;
}
function _e68_op_bcc($c, $cond) {
 $c = $c | 0;
 $cond = $cond | 0;
 var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $11 = 0, $14 = 0, $15 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $30 = 0, $_0_i_i13 = 0, $55 = 0, $dist_0 = 0, $63 = 0, $66 = 0, $67 = 0, $72 = 0, $75 = 0, $76 = 0, $82 = 0, $_0_i_i17 = 0, $102 = 0, $110 = 0, $114 = 0, $115 = 0, $120 = 0, $123 = 0, $124 = 0, $130 = 0, $_0_i_i = 0, $150 = 0;
 $1 = $c + 152 | 0; //@line 64919
 $3 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 64921
 $4 = $c + 160 | 0; //@line 64922
 $6 = HEAPU16[$4 >> 1] | 0; //@line 64924
 $11 = ($6 & 128 | 0) != 0 ? $6 | -256 : $6 & 255; //@line 64929
 do {
  if (($11 | 0) == 0) {
   $14 = $c + 156 | 0; //@line 64934
   $15 = HEAP32[$14 >> 2] | 0; //@line 64935
   if (($15 & 1 | 0) != 0) {
    _e68_exception_address($c, $15, 0, 0); //@line 64940
    return;
   }
   $20 = $c + 164 | 0; //@line 64945
   $22 = $c + 162 | 0; //@line 64947
   HEAP16[$22 >> 1] = HEAP16[$20 >> 1] | 0; //@line 64948
   $23 = $15 & 16777215; //@line 64949
   $24 = $23 + 1 | 0; //@line 64950
   if ($24 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $30 = HEAP32[$c + 32 >> 2] | 0; //@line 64957
    $_0_i_i13 = HEAPU8[$30 + $23 | 0] << 8 | HEAPU8[$30 + $24 | 0]; //@line 64967
   } else {
    $_0_i_i13 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $23) | 0; //@line 64975
   }
   HEAP16[$20 >> 1] = $_0_i_i13; //@line 64978
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 2; //@line 64986
    HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 64989
    $55 = HEAPU16[$22 >> 1] | 0; //@line 64991
    $dist_0 = ($55 & 32768 | 0) != 0 ? $55 | -65536 : $55; //@line 64997
    break;
   }
   _e68_exception_bus($c); //@line 65000
   return;
  } else {
   $dist_0 = $11; //@line 65005
  }
 } while (0);
 do {
  if (($cond | 0) == 0) {
   $110 = $c + 372 | 0; //@line 65017
   HEAP32[$110 >> 2] = ((HEAP16[$4 >> 1] & 255) == 0 ? 12 : 8) + (HEAP32[$110 >> 2] | 0); //@line 65020
   $114 = HEAP32[$c + 156 >> 2] | 0; //@line 65023
  } else {
   $63 = $c + 372 | 0; //@line 65025
   HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 10; //@line 65028
   $66 = $3 + $dist_0 | 0; //@line 65029
   $67 = $c + 156 | 0; //@line 65030
   HEAP32[$67 >> 2] = $66; //@line 65031
   if (($66 & 1 | 0) != 0) {
    _e68_exception_address($c, $66, 0, 0); //@line 65036
    return;
   }
   $72 = $c + 164 | 0; //@line 65041
   HEAP16[$c + 162 >> 1] = HEAP16[$72 >> 1] | 0; //@line 65044
   $75 = $66 & 16777215; //@line 65045
   $76 = $75 + 1 | 0; //@line 65046
   if ($76 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $82 = HEAP32[$c + 32 >> 2] | 0; //@line 65053
    $_0_i_i17 = HEAPU8[$82 + $75 | 0] << 8 | HEAPU8[$82 + $76 | 0]; //@line 65063
   } else {
    $_0_i_i17 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $75) | 0; //@line 65071
   }
   HEAP16[$72 >> 1] = $_0_i_i17; //@line 65074
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    $102 = (HEAP32[$67 >> 2] | 0) + 2 | 0; //@line 65081
    HEAP32[$67 >> 2] = $102; //@line 65082
    HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 65085
    $114 = $102; //@line 65087
    break;
   }
   _e68_exception_bus($c); //@line 65090
   return;
  }
 } while (0);
 $115 = $c + 156 | 0; //@line 65097
 if (($114 & 1 | 0) != 0) {
  _e68_exception_address($c, $114, 0, 0); //@line 65102
  return;
 }
 $120 = $c + 164 | 0; //@line 65107
 HEAP16[$c + 162 >> 1] = HEAP16[$120 >> 1] | 0; //@line 65110
 $123 = $114 & 16777215; //@line 65111
 $124 = $123 + 1 | 0; //@line 65112
 if ($124 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $130 = HEAP32[$c + 32 >> 2] | 0; //@line 65119
  $_0_i_i = HEAPU8[$130 + $123 | 0] << 8 | HEAPU8[$130 + $124 | 0]; //@line 65129
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $123) | 0; //@line 65137
 }
 HEAP16[$120 >> 1] = $_0_i_i; //@line 65140
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  $150 = HEAP32[$115 >> 2] | 0; //@line 65146
  HEAP32[$115 >> 2] = $150 + 2; //@line 65148
  HEAP32[$1 >> 2] = $150 - 2; //@line 65150
  return;
 } else {
  _e68_exception_bus($c); //@line 65155
  return;
 }
}
function _e68_op_trapcc($c, $cond) {
 $c = $c | 0;
 $cond = $cond | 0;
 var $4 = 0, $6 = 0, $7 = 0, $12 = 0, $15 = 0, $16 = 0, $22 = 0, $_0_i_i = 0, $42 = 0, $43 = 0, $47 = 0, $48 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $63 = 0, $78 = 0, $79 = 0, $85 = 0, $86 = 0, $93 = 0, $94 = 0, $98 = 0, $111 = 0, $phitmp = 0, $114 = 0, $118 = 0, $122 = 0, $123 = 0, $128 = 0, $131 = 0, $132 = 0, $138 = 0, $_0_i_i16 = 0, $160 = 0, $166 = 0;
 $4 = HEAP16[$c + 160 >> 1] & 7; //@line 65190
 do {
  if (($4 | 0) == 4) {
   $122 = HEAP32[$c + 156 >> 2] | 0; //@line 65196
  } else if (($4 | 0) == 3) {
   $47 = $c + 156 | 0; //@line 65198
   $48 = HEAP32[$47 >> 2] | 0; //@line 65199
   if (($48 & 1 | 0) != 0) {
    _e68_exception_address($c, $48, 0, 0); //@line 65204
    return;
   }
   $53 = $c + 164 | 0; //@line 65209
   $55 = $c + 162 | 0; //@line 65211
   HEAP16[$55 >> 1] = HEAP16[$53 >> 1] | 0; //@line 65212
   $56 = $48 & 16777215; //@line 65213
   $57 = $56 + 1 | 0; //@line 65214
   $58 = $c + 36 | 0; //@line 65215
   if ($57 >>> 0 < (HEAP32[$58 >> 2] | 0) >>> 0) {
    $63 = HEAP32[$c + 32 >> 2] | 0; //@line 65221
    $78 = HEAPU8[$63 + $56 | 0] << 8 | HEAPU8[$63 + $57 | 0]; //@line 65231
   } else {
    $78 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $56) | 0; //@line 65239
   }
   HEAP16[$53 >> 1] = $78; //@line 65242
   $79 = $c + 336 | 0; //@line 65243
   if ((HEAP8[$79] | 0) != 0) {
    _e68_exception_bus($c); //@line 65248
    return;
   }
   $85 = (HEAP32[$47 >> 2] | 0) + 2 | 0; //@line 65254
   HEAP32[$47 >> 2] = $85; //@line 65255
   $86 = $c + 152 | 0; //@line 65256
   HEAP32[$86 >> 2] = (HEAP32[$86 >> 2] | 0) + 2; //@line 65259
   if (($85 & 1 | 0) != 0) {
    _e68_exception_address($c, $85, 0, 0); //@line 65264
    return;
   }
   HEAP16[$55 >> 1] = $78; //@line 65269
   $93 = $85 & 16777215; //@line 65270
   $94 = $93 + 1 | 0; //@line 65271
   do {
    if ($94 >>> 0 < (HEAP32[$58 >> 2] | 0) >>> 0) {
     $98 = HEAP32[$c + 32 >> 2] | 0; //@line 65278
     HEAP16[$53 >> 1] = HEAPU8[$98 + $93 | 0] << 8 | HEAPU8[$98 + $94 | 0]; //@line 65287
    } else {
     $111 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $93) | 0; //@line 65294
     $phitmp = (HEAP8[$79] | 0) == 0; //@line 65296
     HEAP16[$53 >> 1] = $111; //@line 65297
     if ($phitmp) {
      break;
     }
     _e68_exception_bus($c); //@line 65302
     return;
    }
   } while (0);
   $114 = (HEAP32[$47 >> 2] | 0) + 2 | 0; //@line 65309
   HEAP32[$47 >> 2] = $114; //@line 65310
   HEAP32[$86 >> 2] = (HEAP32[$86 >> 2] | 0) + 2; //@line 65313
   $122 = $114; //@line 65315
  } else if (($4 | 0) == 2) {
   $6 = $c + 156 | 0; //@line 65317
   $7 = HEAP32[$6 >> 2] | 0; //@line 65318
   if (($7 & 1 | 0) != 0) {
    _e68_exception_address($c, $7, 0, 0); //@line 65323
    return;
   }
   $12 = $c + 164 | 0; //@line 65328
   HEAP16[$c + 162 >> 1] = HEAP16[$12 >> 1] | 0; //@line 65331
   $15 = $7 & 16777215; //@line 65332
   $16 = $15 + 1 | 0; //@line 65333
   if ($16 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $22 = HEAP32[$c + 32 >> 2] | 0; //@line 65340
    $_0_i_i = HEAPU8[$22 + $15 | 0] << 8 | HEAPU8[$22 + $16 | 0]; //@line 65350
   } else {
    $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $15) | 0; //@line 65358
   }
   HEAP16[$12 >> 1] = $_0_i_i; //@line 65361
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    $42 = (HEAP32[$6 >> 2] | 0) + 2 | 0; //@line 65368
    HEAP32[$6 >> 2] = $42; //@line 65369
    $43 = $c + 152 | 0; //@line 65370
    HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 65373
    $122 = $42; //@line 65375
    break;
   }
   _e68_exception_bus($c); //@line 65378
   return;
  } else {
   $118 = $c + 372 | 0; //@line 65383
   HEAP32[$118 >> 2] = (HEAP32[$118 >> 2] | 0) + 2; //@line 65386
   _e68_exception_illegal($c); //@line 65387
   return;
  }
 } while (0);
 $123 = $c + 156 | 0; //@line 65394
 if (($122 & 1 | 0) != 0) {
  _e68_exception_address($c, $122, 0, 0); //@line 65399
  return;
 }
 $128 = $c + 164 | 0; //@line 65404
 HEAP16[$c + 162 >> 1] = HEAP16[$128 >> 1] | 0; //@line 65407
 $131 = $122 & 16777215; //@line 65408
 $132 = $131 + 1 | 0; //@line 65409
 if ($132 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $138 = HEAP32[$c + 32 >> 2] | 0; //@line 65416
  $_0_i_i16 = HEAPU8[$138 + $131 | 0] << 8 | HEAPU8[$138 + $132 | 0]; //@line 65426
 } else {
  $_0_i_i16 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $131) | 0; //@line 65434
 }
 HEAP16[$128 >> 1] = $_0_i_i16; //@line 65437
 if ((HEAP8[$c + 336 | 0] | 0) != 0) {
  _e68_exception_bus($c); //@line 65443
  return;
 }
 HEAP32[$123 >> 2] = (HEAP32[$123 >> 2] | 0) + 2; //@line 65450
 $160 = $c + 152 | 0; //@line 65451
 HEAP32[$160 >> 2] = (HEAP32[$160 >> 2] | 0) + 2; //@line 65454
 if (($cond | 0) == 0) {
  $166 = $c + 372 | 0; //@line 65458
  HEAP32[$166 >> 2] = (HEAP32[$166 >> 2] | 0) + 4; //@line 65461
  return;
 } else {
  _e68_exception_overflow($c); //@line 65465
  return;
 }
}
function _e68_set_opcodes_020($c) {
 $c = $c | 0;
 var $i_013 = 0, $3 = 0;
 _e68_set_opcodes($c); //@line 65478
 $i_013 = 0; //@line 65480
 do {
  $3 = HEAP32[24920 + ($i_013 << 2) >> 2] | 0; //@line 65484
  if (($3 | 0) != 0) {
   HEAP32[$c + 400 + ($i_013 << 2) >> 2] = $3; //@line 65489
  }
  $i_013 = $i_013 + 1 | 0; //@line 65492
 } while ($i_013 >>> 0 < 1024);
 HEAP32[$c + 4496 >> 2] = 496; //@line 65502
 return;
}
function _op49c0_00($c) {
 $c = $c | 0;
 var $5 = 0, $6 = 0, $11 = 0, $12 = 0, $15 = 0, $16 = 0, $21 = 0, $24 = 0, $25 = 0, $31 = 0, $_0_i_i = 0, $53 = 0;
 $5 = $c + 88 + ((HEAP16[$c + 160 >> 1] & 7) << 2) | 0; //@line 65523
 $6 = HEAP32[$5 >> 2] | 0; //@line 65524
 $11 = ($6 & 128 | 0) != 0 ? $6 | -256 : $6 & 255; //@line 65529
 $12 = $c + 372 | 0; //@line 65530
 HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 4; //@line 65533
 _e68_cc_set_nz_32($c, 15, $11); //@line 65534
 $15 = $c + 156 | 0; //@line 65535
 $16 = HEAP32[$15 >> 2] | 0; //@line 65536
 if (($16 & 1 | 0) != 0) {
  _e68_exception_address($c, $16, 0, 0); //@line 65541
  return;
 }
 $21 = $c + 164 | 0; //@line 65546
 HEAP16[$c + 162 >> 1] = HEAP16[$21 >> 1] | 0; //@line 65549
 $24 = $16 & 16777215; //@line 65550
 $25 = $24 + 1 | 0; //@line 65551
 if ($25 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $31 = HEAP32[$c + 32 >> 2] | 0; //@line 65558
  $_0_i_i = HEAPU8[$31 + $24 | 0] << 8 | HEAPU8[$31 + $25 | 0]; //@line 65568
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $24) | 0; //@line 65576
 }
 HEAP16[$21 >> 1] = $_0_i_i; //@line 65579
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$15 >> 2] = (HEAP32[$15 >> 2] | 0) + 2; //@line 65587
  $53 = $c + 152 | 0; //@line 65588
  HEAP32[$53 >> 2] = (HEAP32[$53 >> 2] | 0) + 2; //@line 65591
  HEAP32[$5 >> 2] = $11; //@line 65592
  return;
 } else {
  _e68_exception_bus($c); //@line 65597
  return;
 }
}
function _op00c0($c) {
 $c = $c | 0;
 var $1 = 0, $5 = 0, $6 = 0, $7 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $22 = 0, $_0_i_i = 0, $37 = 0, $44 = 0, $51 = 0, $57 = 0, $67 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $84 = 0, $85 = 0, $86 = 0, $_0_i41 = 0, $87 = 0, $93 = 0, $_0_i42 = 0, $106 = 0, $113 = 0, $114 = 0, $115 = 0, $117 = 0, $118 = 0, $122 = 0, $136 = 0, $137 = 0, $138 = 0, $_0_i44 = 0, $139 = 0, $145 = 0, $146 = 0, $150 = 0, $_0_i49 = 0, $165 = 0, $171 = 0, $172 = 0, $176 = 0, $202 = 0, $203 = 0, $204 = 0, $_0_i51 = 0, $206 = 0, $207 = 0, $211 = 0, $239 = 0, $b1_0 = 0, $b2_0 = 0, $242 = 0, $243 = 0, $247 = 0, $253 = 0, $s2_0 = 0, $270 = 0, $276 = 0, $279 = 0, $280 = 0, $storemerge54 = 0, $285 = 0, $292 = 0, $298 = 0, $299 = 0, $304 = 0, $_0_i_i45 = 0;
 $1 = $c + 160 | 0; //@line 65647
 $5 = (HEAPU16[$1 >> 1] | 0) >>> 9 & 3; //@line 65651
 $6 = $c + 156 | 0; //@line 65652
 $7 = HEAP32[$6 >> 2] | 0; //@line 65653
 if (($7 & 1 | 0) != 0) {
  _e68_exception_address($c, $7, 0, 0); //@line 65658
  return;
 }
 $12 = $c + 164 | 0; //@line 65663
 $14 = $c + 162 | 0; //@line 65665
 HEAP16[$14 >> 1] = HEAP16[$12 >> 1] | 0; //@line 65666
 $15 = $7 & 16777215; //@line 65667
 $16 = $15 + 1 | 0; //@line 65668
 $17 = $c + 36 | 0; //@line 65669
 if ($16 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
  $22 = HEAP32[$c + 32 >> 2] | 0; //@line 65675
  $_0_i_i = HEAPU8[$22 + $15 | 0] << 8 | HEAPU8[$22 + $16 | 0]; //@line 65685
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $15) | 0; //@line 65693
 }
 HEAP16[$12 >> 1] = $_0_i_i; //@line 65696
 $37 = $c + 336 | 0; //@line 65697
 if ((HEAP8[$37] | 0) != 0) {
  _e68_exception_bus($c); //@line 65702
  return;
 }
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 65709
 $44 = $c + 152 | 0; //@line 65710
 HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 65713
 if ((HEAP16[$14 >> 1] & 2047) != 0) {
  $51 = $c + 372 | 0; //@line 65719
  HEAP32[$51 >> 2] = (HEAP32[$51 >> 2] | 0) + 2; //@line 65722
  _e68_exception_illegal($c); //@line 65723
  return;
 }
 $57 = HEAP16[$1 >> 1] & 63; //@line 65730
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($57 << 2) >> 2] & 127]($c, $57, 2020, 8) | 0) != 0) {
  return;
 }
 if ((HEAP32[$c + 340 >> 2] | 0) != 2) {
  $239 = $c + 372 | 0; //@line 65745
  HEAP32[$239 >> 2] = (HEAP32[$239 >> 2] | 0) + 2; //@line 65748
  _e68_exception_illegal($c); //@line 65749
  return;
 }
 $67 = ($5 | 0) == 0; //@line 65754
 do {
  if ($67) {
   $69 = $c + 344 | 0; //@line 65758
   $70 = HEAP32[$69 >> 2] | 0; //@line 65759
   $71 = $70 & 16777215; //@line 65760
   $72 = HEAP32[$17 >> 2] | 0; //@line 65761
   if ($71 >>> 0 < $72 >>> 0) {
    $_0_i41 = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $71 | 0] | 0;
    $86 = $70;
    $85 = $72;
   } else {
    $84 = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $71) | 0; //@line 65776
    $_0_i41 = $84;
    $86 = HEAP32[$69 >> 2] | 0;
    $85 = HEAP32[$17 >> 2] | 0;
   }
   $87 = $_0_i41 & 255; //@line 65785
   $93 = $86 + 1 & 16777215; //@line 65791
   if ($93 >>> 0 < $85 >>> 0) {
    $_0_i42 = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $93 | 0] | 0; //@line 65800
   } else {
    $_0_i42 = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $93) | 0; //@line 65808
   }
   $106 = $_0_i42 & 255; //@line 65811
   $b2_0 = ($106 & 128 | 0) != 0 ? $106 | -256 : $106;
   $b1_0 = ($87 & 128 | 0) != 0 ? $87 | -256 : $87;
  } else {
   $113 = $c + 344 | 0; //@line 65820
   $114 = HEAP32[$113 >> 2] | 0; //@line 65821
   $115 = $114 & 16777215; //@line 65822
   if (($5 | 0) != 1) {
    $171 = $115 + 3 | 0; //@line 65825
    $172 = HEAP32[$17 >> 2] | 0; //@line 65826
    if ($171 >>> 0 < $172 >>> 0) {
     $176 = HEAP32[$c + 32 >> 2] | 0; //@line 65831
     $_0_i51 = ((HEAPU8[$176 + $115 | 0] << 8 | HEAPU8[$176 + ($115 + 1) | 0]) << 8 | HEAPU8[$176 + ($115 + 2) | 0]) << 8 | HEAPU8[$176 + $171 | 0];
     $204 = $114;
     $203 = $172;
    } else {
     $202 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $115) | 0; //@line 65859
     $_0_i51 = $202;
     $204 = HEAP32[$113 >> 2] | 0;
     $203 = HEAP32[$17 >> 2] | 0;
    }
    $206 = $204 + 4 & 16777215; //@line 65869
    $207 = $206 + 3 | 0; //@line 65870
    if ($207 >>> 0 < $203 >>> 0) {
     $211 = HEAP32[$c + 32 >> 2] | 0; //@line 65875
     $b2_0 = ((HEAPU8[$211 + $206 | 0] << 8 | HEAPU8[$211 + ($206 + 1) | 0]) << 8 | HEAPU8[$211 + ($206 + 2) | 0]) << 8 | HEAPU8[$211 + $207 | 0];
     $b1_0 = $_0_i51;
     break;
    } else {
     $b2_0 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $206) | 0;
     $b1_0 = $_0_i51;
     break;
    }
   }
   $117 = $115 + 1 | 0; //@line 65910
   $118 = HEAP32[$17 >> 2] | 0; //@line 65911
   if ($117 >>> 0 < $118 >>> 0) {
    $122 = HEAP32[$c + 32 >> 2] | 0; //@line 65916
    $_0_i44 = HEAPU8[$122 + $115 | 0] << 8 | HEAPU8[$122 + $117 | 0];
    $138 = $114;
    $137 = $118;
   } else {
    $136 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $115) | 0; //@line 65932
    $_0_i44 = $136;
    $138 = HEAP32[$113 >> 2] | 0;
    $137 = HEAP32[$17 >> 2] | 0;
   }
   $139 = $_0_i44 & 65535; //@line 65941
   $145 = $138 + 2 & 16777215; //@line 65947
   $146 = $145 + 1 | 0; //@line 65948
   if ($146 >>> 0 < $137 >>> 0) {
    $150 = HEAP32[$c + 32 >> 2] | 0; //@line 65953
    $_0_i49 = HEAPU8[$150 + $145 | 0] << 8 | HEAPU8[$150 + $146 | 0]; //@line 65963
   } else {
    $_0_i49 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $145) | 0; //@line 65971
   }
   $165 = $_0_i49 & 65535; //@line 65974
   $b2_0 = ($165 & 32768 | 0) != 0 ? $165 | -65536 : $165;
   $b1_0 = ($139 & 32768 | 0) != 0 ? $139 | -65536 : $139;
  }
 } while (0);
 $242 = HEAP16[$14 >> 1] | 0; //@line 65985
 $243 = $242 & 65535; //@line 65986
 $247 = $243 >>> 12 & 7; //@line 65990
 do {
  if (($243 & 32768 | 0) == 0) {
   $253 = HEAP32[$c + 88 + ($247 << 2) >> 2] | 0; //@line 65995
   if ($67) {
    $s2_0 = ($253 & 128 | 0) != 0 ? $253 | -256 : $253 & 255; //@line 66004
    break;
   }
   if (($5 | 0) != 1) {
    $s2_0 = $253; //@line 66010
    break;
   }
   $s2_0 = ($253 & 32768 | 0) != 0 ? $253 | -65536 : $253 & 65535; //@line 66019
  } else {
   $s2_0 = HEAP32[$c + 120 + ($247 << 2) >> 2] | 0; //@line 66024
  }
 } while (0);
 $270 = $s2_0 ^ -2147483648; //@line 66029
 if ($270 >>> 0 < ($b1_0 ^ -2147483648) >>> 0) {
  $276 = 1; //@line 66033
 } else {
  $276 = $270 >>> 0 > ($b2_0 ^ -2147483648) >>> 0; //@line 66038
 }
 $279 = $c + 166 | 0; //@line 66044
 $280 = HEAP16[$279 >> 1] | 0; //@line 66045
 $storemerge54 = ($s2_0 | 0) == ($b1_0 | 0) | ($s2_0 | 0) == ($b2_0 | 0) ? $280 | 4 : $280 & -5; //@line 66048
 HEAP16[$279 >> 1] = $276 ? $storemerge54 | 1 : $storemerge54 & -2; //@line 66052
 $285 = $c + 372 | 0; //@line 66053
 HEAP32[$285 >> 2] = (HEAP32[$285 >> 2] | 0) + 14; //@line 66056
 if (!(($242 & 2048) == 0 | $276 ^ 1)) {
  _e68_exception_check($c); //@line 66063
  return;
 }
 $292 = HEAP32[$6 >> 2] | 0; //@line 66068
 if (($292 & 1 | 0) != 0) {
  _e68_exception_address($c, $292, 0, 0); //@line 66073
  return;
 }
 HEAP16[$14 >> 1] = HEAP16[$12 >> 1] | 0; //@line 66079
 $298 = $292 & 16777215; //@line 66080
 $299 = $298 + 1 | 0; //@line 66081
 if ($299 >>> 0 < (HEAP32[$17 >> 2] | 0) >>> 0) {
  $304 = HEAP32[$c + 32 >> 2] | 0; //@line 66087
  $_0_i_i45 = HEAPU8[$304 + $298 | 0] << 8 | HEAPU8[$304 + $299 | 0]; //@line 66097
 } else {
  $_0_i_i45 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $298) | 0; //@line 66105
 }
 HEAP16[$12 >> 1] = $_0_i_i45; //@line 66108
 if ((HEAP8[$37] | 0) == 0) {
  HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 66115
  HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 66118
  return;
 } else {
  _e68_exception_bus($c); //@line 66123
  return;
 }
}
function _op4100($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $4 = 0, $18 = 0, $20 = 0, $24 = 0, $27 = 0, $32 = 0, $35 = 0, $36 = 0, $41 = 0, $44 = 0, $45 = 0, $51 = 0, $_0_i_i = 0, $73 = 0, sp = 0;
 sp = STACKTOP; //@line 66143
 STACKTOP = STACKTOP + 8 | 0; //@line 66143
 $s1 = sp | 0; //@line 66144
 $1 = $c + 160 | 0; //@line 66145
 $4 = HEAP16[$1 >> 1] & 63; //@line 66148
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4093, 32) | 0) != 0) {
  STACKTOP = sp; //@line 66155
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 66162
  return;
 }
 $18 = HEAP32[$c + 88 + (((HEAPU16[$1 >> 1] | 0) >>> 9 & 7) << 2) >> 2] | 0; //@line 66170
 do {
  if (($18 | 0) < 0) {
   $20 = $c + 166 | 0; //@line 66175
   HEAP16[$20 >> 1] = HEAP16[$20 >> 1] | 8; //@line 66178
  } else {
   $24 = HEAP32[$s1 >> 2] | 0; //@line 66180
   if (($24 | 0) < 0 | $18 >>> 0 > $24 >>> 0) {
    $27 = $c + 166 | 0; //@line 66186
    HEAP16[$27 >> 1] = HEAP16[$27 >> 1] & -9; //@line 66189
    break;
   }
   $32 = $c + 372 | 0; //@line 66192
   HEAP32[$32 >> 2] = (HEAP32[$32 >> 2] | 0) + 14; //@line 66195
   $35 = $c + 156 | 0; //@line 66196
   $36 = HEAP32[$35 >> 2] | 0; //@line 66197
   if (($36 & 1 | 0) != 0) {
    _e68_exception_address($c, $36, 0, 0); //@line 66202
    STACKTOP = sp; //@line 66204
    return;
   }
   $41 = $c + 164 | 0; //@line 66207
   HEAP16[$c + 162 >> 1] = HEAP16[$41 >> 1] | 0; //@line 66210
   $44 = $36 & 16777215; //@line 66211
   $45 = $44 + 1 | 0; //@line 66212
   if ($45 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $51 = HEAP32[$c + 32 >> 2] | 0; //@line 66219
    $_0_i_i = HEAPU8[$51 + $44 | 0] << 8 | HEAPU8[$51 + $45 | 0]; //@line 66229
   } else {
    $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $44) | 0; //@line 66237
   }
   HEAP16[$41 >> 1] = $_0_i_i; //@line 66240
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$35 >> 2] = (HEAP32[$35 >> 2] | 0) + 2; //@line 66248
    $73 = $c + 152 | 0; //@line 66249
    HEAP32[$73 >> 2] = (HEAP32[$73 >> 2] | 0) + 2; //@line 66252
    STACKTOP = sp; //@line 66254
    return;
   } else {
    _e68_exception_bus($c); //@line 66257
    STACKTOP = sp; //@line 66259
    return;
   }
  }
 } while (0);
 _e68_exception_check($c); //@line 66264
 STACKTOP = sp; //@line 66266
 return;
}
function _op4a001068($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0, sp = 0;
 sp = STACKTOP; //@line 66281
 STACKTOP = STACKTOP + 8 | 0; //@line 66281
 $s = sp | 0; //@line 66282
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 66286
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4093, 8) | 0) != 0) {
  STACKTOP = sp; //@line 66293
  return;
 }
 if ((_e68_ea_get_val8($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 66300
  return;
 }
 $13 = $c + 372 | 0; //@line 66303
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 66306
 _e68_cc_set_nz_8($c, 15, HEAP8[$s] | 0); //@line 66308
 $17 = $c + 156 | 0; //@line 66309
 $18 = HEAP32[$17 >> 2] | 0; //@line 66310
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 66315
  STACKTOP = sp; //@line 66317
  return;
 }
 $23 = $c + 164 | 0; //@line 66320
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 66323
 $26 = $18 & 16777215; //@line 66324
 $27 = $26 + 1 | 0; //@line 66325
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 66332
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 66342
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 66350
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 66353
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 66361
  $55 = $c + 152 | 0; //@line 66362
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 66365
  STACKTOP = sp; //@line 66367
  return;
 } else {
  _e68_exception_bus($c); //@line 66370
  STACKTOP = sp; //@line 66372
  return;
 }
}
function _op4a401069($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0, sp = 0;
 sp = STACKTOP; //@line 66388
 STACKTOP = STACKTOP + 8 | 0; //@line 66388
 $s = sp | 0; //@line 66389
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 66393
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 16) | 0) != 0) {
  STACKTOP = sp; //@line 66400
  return;
 }
 if ((_e68_ea_get_val16($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 66407
  return;
 }
 $13 = $c + 372 | 0; //@line 66410
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 66413
 _e68_cc_set_nz_16($c, 15, HEAP16[$s >> 1] | 0); //@line 66415
 $17 = $c + 156 | 0; //@line 66416
 $18 = HEAP32[$17 >> 2] | 0; //@line 66417
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 66422
  STACKTOP = sp; //@line 66424
  return;
 }
 $23 = $c + 164 | 0; //@line 66427
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 66430
 $26 = $18 & 16777215; //@line 66431
 $27 = $26 + 1 | 0; //@line 66432
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 66439
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 66449
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 66457
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 66460
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 66468
  $55 = $c + 152 | 0; //@line 66469
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 66472
  STACKTOP = sp; //@line 66474
  return;
 } else {
  _e68_exception_bus($c); //@line 66477
  STACKTOP = sp; //@line 66479
  return;
 }
}
function _op4a801070($c) {
 $c = $c | 0;
 var $s = 0, $4 = 0, $13 = 0, $17 = 0, $18 = 0, $23 = 0, $26 = 0, $27 = 0, $33 = 0, $_0_i_i = 0, $55 = 0, sp = 0;
 sp = STACKTOP; //@line 66495
 STACKTOP = STACKTOP + 8 | 0; //@line 66495
 $s = sp | 0; //@line 66496
 $4 = HEAP16[$c + 160 >> 1] & 63; //@line 66500
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($4 << 2) >> 2] & 127]($c, $4, 4095, 32) | 0) != 0) {
  STACKTOP = sp; //@line 66507
  return;
 }
 if ((_e68_ea_get_val32($c, $s) | 0) != 0) {
  STACKTOP = sp; //@line 66514
  return;
 }
 $13 = $c + 372 | 0; //@line 66517
 HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 8; //@line 66520
 _e68_cc_set_nz_32($c, 15, HEAP32[$s >> 2] | 0); //@line 66522
 $17 = $c + 156 | 0; //@line 66523
 $18 = HEAP32[$17 >> 2] | 0; //@line 66524
 if (($18 & 1 | 0) != 0) {
  _e68_exception_address($c, $18, 0, 0); //@line 66529
  STACKTOP = sp; //@line 66531
  return;
 }
 $23 = $c + 164 | 0; //@line 66534
 HEAP16[$c + 162 >> 1] = HEAP16[$23 >> 1] | 0; //@line 66537
 $26 = $18 & 16777215; //@line 66538
 $27 = $26 + 1 | 0; //@line 66539
 if ($27 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $33 = HEAP32[$c + 32 >> 2] | 0; //@line 66546
  $_0_i_i = HEAPU8[$33 + $26 | 0] << 8 | HEAPU8[$33 + $27 | 0]; //@line 66556
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $26) | 0; //@line 66564
 }
 HEAP16[$23 >> 1] = $_0_i_i; //@line 66567
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 2; //@line 66575
  $55 = $c + 152 | 0; //@line 66576
  HEAP32[$55 >> 2] = (HEAP32[$55 >> 2] | 0) + 2; //@line 66579
  STACKTOP = sp; //@line 66581
  return;
 } else {
  _e68_exception_bus($c); //@line 66584
  STACKTOP = sp; //@line 66586
  return;
 }
}
function _op4c00($c) {
 $c = $c | 0;
 var $st = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $43 = 0, $47 = 0, $52 = 0, $55 = 0, $59 = 0, $69$0 = 0, $69$1 = 0, $70 = 0, $72$0 = 0, $72$1 = 0, $75 = 0, $78 = 0, $s1_1$0 = 0, $s1_1$1 = 0, $s2_0$0 = 0, $s2_0$1 = 0, $81$0 = 0, $82 = 0, $83$0 = 0, $84 = 0, $90 = 0, $91 = 0, $storemerge39 = 0, $99 = 0, $102 = 0, $103 = 0, $storemerge = 0, $storemerge38 = 0, $115 = 0, $117 = 0, $119 = 0, $120 = 0, $125 = 0, $131 = 0, $132 = 0, $137 = 0, $_0_i_i42 = 0, sp = 0;
 sp = STACKTOP; //@line 66618
 STACKTOP = STACKTOP + 8 | 0; //@line 66618
 $st = sp | 0; //@line 66619
 $1 = $c + 156 | 0; //@line 66620
 $2 = HEAP32[$1 >> 2] | 0; //@line 66621
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 66626
  STACKTOP = sp; //@line 66628
  return;
 }
 $7 = $c + 164 | 0; //@line 66631
 $9 = $c + 162 | 0; //@line 66633
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 66634
 $10 = $2 & 16777215; //@line 66635
 $11 = $10 + 1 | 0; //@line 66636
 $12 = $c + 36 | 0; //@line 66637
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 66643
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 66653
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 66661
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 66664
 $32 = $c + 336 | 0; //@line 66665
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 66670
  STACKTOP = sp; //@line 66672
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 66677
 $39 = $c + 152 | 0; //@line 66678
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 66681
 $43 = HEAPU16[$9 >> 1] | 0; //@line 66683
 if (($43 & 33544 | 0) != 0) {
  $47 = $c + 372 | 0; //@line 66688
  HEAP32[$47 >> 2] = (HEAP32[$47 >> 2] | 0) + 2; //@line 66691
  _e68_exception_illegal($c); //@line 66692
  STACKTOP = sp; //@line 66694
  return;
 }
 $52 = ($43 & 2048 | 0) != 0; //@line 66698
 $55 = $43 & 7; //@line 66701
 $59 = HEAP16[$c + 160 >> 1] & 63; //@line 66705
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($59 << 2) >> 2] & 127]($c, $59, 4093, 32) | 0) != 0) {
  STACKTOP = sp; //@line 66712
  return;
 }
 if ((_e68_ea_get_val32($c, $st) | 0) != 0) {
  STACKTOP = sp; //@line 66719
  return;
 }
 $69$0 = HEAP32[$st >> 2] | 0; //@line 66723
 $69$1 = 0; //@line 66724
 $70 = $c + 88 + (($43 >>> 12 & 7) << 2) | 0; //@line 66725
 $72$0 = HEAP32[$70 >> 2] | 0; //@line 66727
 $72$1 = 0; //@line 66728
 if ($52) {
  $75 = ($69$0 & -2147483648 | 0) == 0 & ($69$1 & 0 | 0) == 0; //@line 66737
  $78 = ($72$0 & -2147483648 | 0) == 0 & ($72$1 & 0 | 0) == 0; //@line 66750
  $s2_0$1 = $78 ? $72$1 : $72$1 | -1;
  $s2_0$0 = $78 ? $72$0 : $72$0 | 0;
  $s1_1$1 = $75 ? $69$1 : $69$1 | -1;
  $s1_1$0 = $75 ? $69$0 : $69$0 | 0;
 } else {
  $s2_0$1 = $72$1;
  $s2_0$0 = $72$0;
  $s1_1$1 = $69$1;
  $s1_1$0 = $69$0;
 }
 $81$0 = ___muldi3($s2_0$0, $s2_0$1, $s1_1$0, $s1_1$1) | 0;
 $82 = $81$0; //@line 66768
 $83$0 = tempRet0; //@line 66769
 $84 = $83$0; //@line 66772
 HEAP32[$70 >> 2] = $82; //@line 66773
 do {
  if (($43 & 1024 | 0) == 0) {
   $102 = $c + 166 | 0; //@line 66780
   $103 = HEAP16[$102 >> 1] | 0; //@line 66781
   $storemerge = ($84 | 0) < 0 ? $103 | 8 : $103 & -9; //@line 66784
   $storemerge38 = ($83$0 | $81$0 | 0) == 0 ? $storemerge | 4 : $storemerge & -5; //@line 66792
   HEAP16[$102 >> 1] = $storemerge38; //@line 66793
   if (($84 | 0) == (($52 & ($82 | 0) < 0) << 31 >> 31 | 0)) {
    $117 = $storemerge38 & -3; //@line 66800
    HEAP16[$102 >> 1] = $117; //@line 66801
    $119 = $117; //@line 66802
    break;
   } else {
    $115 = $storemerge38 | 2; //@line 66805
    HEAP16[$102 >> 1] = $115; //@line 66806
    $119 = $115; //@line 66808
    break;
   }
  } else {
   HEAP32[$c + 88 + ($55 << 2) >> 2] = $84; //@line 66813
   $90 = $c + 166 | 0; //@line 66815
   $91 = HEAP16[$90 >> 1] | 0; //@line 66816
   $storemerge39 = ($84 | 0) < 0 ? $91 | 8 : $91 & -9; //@line 66819
   $99 = (($83$0 | $81$0 | 0) == 0 ? $storemerge39 | 4 : $storemerge39 & -7) & -3; //@line 66828
   HEAP16[$90 >> 1] = $99; //@line 66829
   $119 = $99; //@line 66831
  }
 } while (0);
 $120 = $c + 372 | 0; //@line 66835
 HEAP32[$120 >> 2] = (HEAP32[$120 >> 2] | 0) + 74; //@line 66838
 HEAP16[$c + 166 >> 1] = $119 & -2; //@line 66841
 $125 = HEAP32[$1 >> 2] | 0; //@line 66842
 if (($125 & 1 | 0) != 0) {
  _e68_exception_address($c, $125, 0, 0); //@line 66847
  STACKTOP = sp; //@line 66849
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 66853
 $131 = $125 & 16777215; //@line 66854
 $132 = $131 + 1 | 0; //@line 66855
 if ($132 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $137 = HEAP32[$c + 32 >> 2] | 0; //@line 66861
  $_0_i_i42 = HEAPU8[$137 + $131 | 0] << 8 | HEAPU8[$137 + $132 | 0]; //@line 66871
 } else {
  $_0_i_i42 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $131) | 0; //@line 66879
 }
 HEAP16[$7 >> 1] = $_0_i_i42; //@line 66882
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 66889
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 66892
  STACKTOP = sp; //@line 66894
  return;
 } else {
  _e68_exception_bus($c); //@line 66897
  STACKTOP = sp; //@line 66899
  return;
 }
}
function _op4c40($c) {
 $c = $c | 0;
 var $s1 = 0, $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $32 = 0, $39 = 0, $43 = 0, $47 = 0, $52 = 0, $54 = 0, $55 = 0, $59 = 0, $68 = 0, $69 = 0, $70 = 0, $78 = 0, $80 = 0, $83 = 0, $s2_0 = 0, $neg2_0 = 0, $neg1_0 = 0, $88 = 0, $_lobit = 0, $s2_1 = 0, $s3_0 = 0, $neg2_1 = 0, $101$0 = 0, $101$1 = 0, $102$0 = 0, $102$1 = 0, $103$0 = 0, $103$1 = 0, $104 = 0, $105$0 = 0, $106 = 0, $$etemp$0$1 = 0, $$etemp$2$1 = 0, $neg2_256 = 0, $d2_055 = 0, $d1_054 = 0, $d1_0_ = 0, $124 = 0, $128 = 0, $131 = 0, $137 = 0, $138 = 0, $143 = 0, $_0_i_i50 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 66929
 STACKTOP = STACKTOP + 8 | 0; //@line 66929
 $s1 = sp | 0; //@line 66930
 $1 = $c + 156 | 0; //@line 66931
 $2 = HEAP32[$1 >> 2] | 0; //@line 66932
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 66937
  STACKTOP = sp; //@line 66939
  return;
 }
 $7 = $c + 164 | 0; //@line 66942
 $9 = $c + 162 | 0; //@line 66944
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 66945
 $10 = $2 & 16777215; //@line 66946
 $11 = $10 + 1 | 0; //@line 66947
 $12 = $c + 36 | 0; //@line 66948
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 66954
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 66964
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 66972
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 66975
 $32 = $c + 336 | 0; //@line 66976
 if ((HEAP8[$32] | 0) != 0) {
  _e68_exception_bus($c); //@line 66981
  STACKTOP = sp; //@line 66983
  return;
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 66988
 $39 = $c + 152 | 0; //@line 66989
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 66992
 $43 = HEAPU16[$9 >> 1] | 0; //@line 66994
 if (($43 & 33544 | 0) != 0) {
  $47 = $c + 372 | 0; //@line 66999
  HEAP32[$47 >> 2] = (HEAP32[$47 >> 2] | 0) + 2; //@line 67002
  _e68_exception_illegal($c); //@line 67003
  STACKTOP = sp; //@line 67005
  return;
 }
 $52 = ($43 & 2048 | 0) != 0; //@line 67009
 $54 = $43 >>> 12 & 7; //@line 67011
 $55 = $43 & 7; //@line 67012
 $59 = HEAP16[$c + 160 >> 1] & 63; //@line 67016
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($59 << 2) >> 2] & 127]($c, $59, 4093, 32) | 0) != 0) {
  STACKTOP = sp; //@line 67023
  return;
 }
 if ((_e68_ea_get_val32($c, $s1) | 0) != 0) {
  STACKTOP = sp; //@line 67030
  return;
 }
 $68 = $c + 88 + ($54 << 2) | 0; //@line 67033
 $69 = HEAP32[$68 >> 2] | 0; //@line 67034
 $70 = HEAP32[$s1 >> 2] | 0; //@line 67035
 if (($70 | 0) == 0) {
  _e68_exception_divzero($c); //@line 67039
  STACKTOP = sp; //@line 67041
  return;
 }
 if ($52) {
  if (($70 | 0) < 0) {
   $78 = -$70 | 0; //@line 67052
   HEAP32[$s1 >> 2] = $78; //@line 67053
   $80 = $78; //@line 67055
  } else {
   $80 = $70; //@line 67057
  }
  $neg1_0 = $70 >>> 31;
  $neg2_0 = $69 >>> 31;
  $s2_0 = ($69 | 0) < 0 ? -$69 | 0 : $69;
  $83 = $80;
 } else {
  $neg1_0 = 0;
  $neg2_0 = 0;
  $s2_0 = $69;
  $83 = $70;
 }
 L10514 : do {
  if (($43 & 1024 | 0) == 0) {
   $d1_054 = ($s2_0 >>> 0) / ($83 >>> 0) | 0;
   $d2_055 = ($s2_0 >>> 0) % ($83 >>> 0) | 0;
   $neg2_256 = $neg2_0;
   label = 8361; //@line 67079
  } else {
   $88 = HEAP32[$c + 88 + ($55 << 2) >> 2] | 0; //@line 67082
   do {
    if ($52) {
     $_lobit = $88 >>> 31; //@line 67087
     if (($88 | 0) >= 0) {
      $neg2_1 = $_lobit;
      $s3_0 = $88;
      $s2_1 = $69;
      break;
     }
     $neg2_1 = $_lobit;
     $s3_0 = (($69 | 0) == 0) + ~$88 | 0;
     $s2_1 = -$69 | 0;
    } else {
     $neg2_1 = $neg2_0;
     $s3_0 = $88;
     $s2_1 = $69;
    }
   } while (0);
   $101$0 = $s2_1 | 0; //@line 67113
   $101$1 = $s3_0 | 0; //@line 67114
   $102$0 = $83; //@line 67115
   $102$1 = 0; //@line 67116
   $103$0 = ___udivdi3($101$0, $101$1, $102$0, $102$1) | 0;
   $103$1 = tempRet0;
   $104 = $103$0; //@line 67119
   $105$0 = ___uremdi3($101$0, $101$1, $102$0, $102$1) | 0;
   $106 = $105$0; //@line 67122
   do {
    if ($52) {
     $$etemp$0$1 = 0; //@line 67127
     if ($103$1 >>> 0 > $$etemp$0$1 >>> 0 | $103$1 >>> 0 == $$etemp$0$1 >>> 0 & $103$0 >>> 0 > -2147483648 >>> 0) {
      break;
     }
     if (!(($103$0 | 0) == (-2147483648 | 0) & ($103$1 | 0) == 0 & ($neg1_0 | 0) == ($neg2_1 | 0))) {
      $d1_054 = $104;
      $d2_055 = $106;
      $neg2_256 = $neg2_1;
      label = 8361; //@line 67141
      break L10514;
     }
    } else {
     $$etemp$2$1 = 1; //@line 67146
     if ($103$1 >>> 0 < $$etemp$2$1 >>> 0 | $103$1 >>> 0 == $$etemp$2$1 >>> 0 & $103$0 >>> 0 < 0 >>> 0) {
      $d1_054 = $104;
      $d2_055 = $106;
      $neg2_256 = $neg2_1;
      label = 8361; //@line 67151
      break L10514;
     }
    }
   } while (0);
   $124 = $c + 166 | 0; //@line 67156
   HEAP16[$124 >> 1] = HEAP16[$124 >> 1] | 2; //@line 67159
  }
 } while (0);
 if ((label | 0) == 8361) {
  $d1_0_ = ($neg1_0 | 0) == ($neg2_256 | 0) ? $d1_054 : -$d1_054 | 0; //@line 67168
  HEAP32[$68 >> 2] = $d1_0_; //@line 67169
  if (($55 | 0) != ($54 | 0)) {
   HEAP32[$c + 88 + ($55 << 2) >> 2] = ($neg2_256 | 0) == 0 ? $d2_055 : -$d2_055 | 0; //@line 67177
  }
  _e68_cc_set_nz_32($c, 15, $d1_0_); //@line 67180
 }
 $128 = $c + 372 | 0; //@line 67183
 HEAP32[$128 >> 2] = (HEAP32[$128 >> 2] | 0) + 144; //@line 67186
 $131 = HEAP32[$1 >> 2] | 0; //@line 67187
 if (($131 & 1 | 0) != 0) {
  _e68_exception_address($c, $131, 0, 0); //@line 67192
  STACKTOP = sp; //@line 67194
  return;
 }
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 67198
 $137 = $131 & 16777215; //@line 67199
 $138 = $137 + 1 | 0; //@line 67200
 if ($138 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $143 = HEAP32[$c + 32 >> 2] | 0; //@line 67206
  $_0_i_i50 = HEAPU8[$143 + $137 | 0] << 8 | HEAPU8[$143 + $138 | 0]; //@line 67216
 } else {
  $_0_i_i50 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $137) | 0; //@line 67224
 }
 HEAP16[$7 >> 1] = $_0_i_i50; //@line 67227
 if ((HEAP8[$32] | 0) == 0) {
  HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 67234
  HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 67237
  STACKTOP = sp; //@line 67239
  return;
 } else {
  _e68_exception_bus($c); //@line 67242
  STACKTOP = sp; //@line 67244
  return;
 }
}
function _op50c01071($c) {
 $c = $c | 0;
 var $3 = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 67257
 if ((($3 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, 1); //@line 67263
  return;
 }
 if (($3 & 56 | 0) == 8) {
  _e68_op_dbcc($c, 1); //@line 67272
  return;
 } else {
  _e68_op_scc($c, 1); //@line 67277
  return;
 }
}
function _op51c01072($c) {
 $c = $c | 0;
 var $3 = 0;
 $3 = HEAPU16[$c + 160 >> 1] | 0; //@line 67291
 if ((($3 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, 0); //@line 67297
  return;
 }
 if (($3 & 56 | 0) == 8) {
  _e68_op_dbcc($c, 0); //@line 67306
  return;
 } else {
  _e68_op_scc($c, 0); //@line 67311
  return;
 }
}
function _op52c01073($c) {
 $c = $c | 0;
 var $3 = 0, $10 = 0, $13 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 67327
 if (($3 & 1 | 0) == 0) {
  $10 = $3 >>> 2 & 1 ^ 1; //@line 67335
 } else {
  $10 = 0; //@line 67337
 }
 $13 = HEAPU16[$c + 160 >> 1] | 0; //@line 67342
 if ((($13 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $10); //@line 67348
  return;
 }
 if (($13 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $10); //@line 67357
  return;
 } else {
  _e68_op_scc($c, $10); //@line 67362
  return;
 }
}
function _op53c01074($c) {
 $c = $c | 0;
 var $3 = 0, $9 = 0, $12 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 67377
 if (($3 & 1 | 0) == 0) {
  $9 = $3 >>> 2 & 1; //@line 67385
 } else {
  $9 = 1; //@line 67387
 }
 $12 = HEAPU16[$c + 160 >> 1] | 0; //@line 67392
 if ((($12 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $9); //@line 67398
  return;
 }
 if (($12 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $9); //@line 67407
  return;
 } else {
  _e68_op_scc($c, $9); //@line 67412
  return;
 }
}
function _op54c01075($c) {
 $c = $c | 0;
 var $5 = 0, $8 = 0;
 $5 = (HEAP16[$c + 166 >> 1] & 1 ^ 1) & 65535; //@line 67429
 $8 = HEAPU16[$c + 160 >> 1] | 0; //@line 67432
 if ((($8 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $5); //@line 67438
  return;
 }
 if (($8 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $5); //@line 67447
  return;
 } else {
  _e68_op_scc($c, $5); //@line 67452
  return;
 }
}
function _op55c01076($c) {
 $c = $c | 0;
 var $4 = 0, $7 = 0;
 $4 = HEAP16[$c + 166 >> 1] & 1; //@line 67468
 $7 = HEAPU16[$c + 160 >> 1] | 0; //@line 67471
 if ((($7 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $4); //@line 67477
  return;
 }
 if (($7 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $4); //@line 67486
  return;
 } else {
  _e68_op_scc($c, $4); //@line 67491
  return;
 }
}
function _op56c01077($c) {
 $c = $c | 0;
 var $5 = 0, $8 = 0;
 $5 = ((HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1 ^ 1) & 65535; //@line 67509
 $8 = HEAPU16[$c + 160 >> 1] | 0; //@line 67512
 if ((($8 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $5); //@line 67518
  return;
 }
 if (($8 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $5); //@line 67527
  return;
 } else {
  _e68_op_scc($c, $5); //@line 67532
  return;
 }
}
function _op57c01078($c) {
 $c = $c | 0;
 var $4 = 0, $7 = 0;
 $4 = (HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1; //@line 67549
 $7 = HEAPU16[$c + 160 >> 1] | 0; //@line 67552
 if ((($7 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $4); //@line 67558
  return;
 }
 if (($7 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $4); //@line 67567
  return;
 } else {
  _e68_op_scc($c, $4); //@line 67572
  return;
 }
}
function _op58c01079($c) {
 $c = $c | 0;
 var $5 = 0, $8 = 0;
 $5 = ((HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1 ^ 1) & 65535; //@line 67590
 $8 = HEAPU16[$c + 160 >> 1] | 0; //@line 67593
 if ((($8 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $5); //@line 67599
  return;
 }
 if (($8 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $5); //@line 67608
  return;
 } else {
  _e68_op_scc($c, $5); //@line 67613
  return;
 }
}
function _op59c01080($c) {
 $c = $c | 0;
 var $4 = 0, $7 = 0;
 $4 = (HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1; //@line 67630
 $7 = HEAPU16[$c + 160 >> 1] | 0; //@line 67633
 if ((($7 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $4); //@line 67639
  return;
 }
 if (($7 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $4); //@line 67648
  return;
 } else {
  _e68_op_scc($c, $4); //@line 67653
  return;
 }
}
function _op5ac01081($c) {
 $c = $c | 0;
 var $5 = 0, $8 = 0;
 $5 = ((HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1 ^ 1) & 65535; //@line 67671
 $8 = HEAPU16[$c + 160 >> 1] | 0; //@line 67674
 if ((($8 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $5); //@line 67680
  return;
 }
 if (($8 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $5); //@line 67689
  return;
 } else {
  _e68_op_scc($c, $5); //@line 67694
  return;
 }
}
function _op5bc01082($c) {
 $c = $c | 0;
 var $4 = 0, $7 = 0;
 $4 = (HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1; //@line 67711
 $7 = HEAPU16[$c + 160 >> 1] | 0; //@line 67714
 if ((($7 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $4); //@line 67720
  return;
 }
 if (($7 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $4); //@line 67729
  return;
 } else {
  _e68_op_scc($c, $4); //@line 67734
  return;
 }
}
function _op5cc01083($c) {
 $c = $c | 0;
 var $3 = 0, $8 = 0, $11 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 67749
 $8 = ($3 >>> 3 ^ $3 >>> 1) & 1 ^ 1; //@line 67754
 $11 = HEAPU16[$c + 160 >> 1] | 0; //@line 67757
 if ((($11 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $8); //@line 67763
  return;
 }
 if (($11 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $8); //@line 67772
  return;
 } else {
  _e68_op_scc($c, $8); //@line 67777
  return;
 }
}
function _op5dc01084($c) {
 $c = $c | 0;
 var $3 = 0, $7 = 0, $10 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 67792
 $7 = ($3 >>> 3 ^ $3 >>> 1) & 1; //@line 67796
 $10 = HEAPU16[$c + 160 >> 1] | 0; //@line 67799
 if ((($10 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $7); //@line 67805
  return;
 }
 if (($10 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $7); //@line 67814
  return;
 } else {
  _e68_op_scc($c, $7); //@line 67819
  return;
 }
}
function _op5ec01085($c) {
 $c = $c | 0;
 var $3 = 0, $13 = 0, $16 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 67835
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) == 0) {
  $13 = $3 >>> 2 & 1 ^ 1; //@line 67846
 } else {
  $13 = 0; //@line 67848
 }
 $16 = HEAPU16[$c + 160 >> 1] | 0; //@line 67853
 if ((($16 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $13); //@line 67859
  return;
 }
 if (($16 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $13); //@line 67868
  return;
 } else {
  _e68_op_scc($c, $13); //@line 67873
  return;
 }
}
function _op5fc01086($c) {
 $c = $c | 0;
 var $3 = 0, $12 = 0, $15 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 67889
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) == 0) {
  $12 = $3 >>> 2 & 1; //@line 67900
 } else {
  $12 = 1; //@line 67902
 }
 $15 = HEAPU16[$c + 160 >> 1] | 0; //@line 67907
 if ((($15 & 63) - 58 | 0) >>> 0 < 3) {
  _e68_op_trapcc($c, $12); //@line 67913
  return;
 }
 if (($15 & 56 | 0) == 8) {
  _e68_op_dbcc($c, $12); //@line 67922
  return;
 } else {
  _e68_op_scc($c, $12); //@line 67927
  return;
 }
}
function _op60001087($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, 1); //@line 67938
 return;
}
function _op61001088($c) {
 $c = $c | 0;
 var $4 = 0, $addr_0 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $29 = 0;
 $4 = HEAP16[$c + 160 >> 1] & 255; //@line 67957
 if (($4 | 0) == 0) {
  $addr_0 = (HEAP32[$c + 152 >> 2] | 0) + 4 | 0; //@line 67963
 } else if (($4 | 0) == 255) {
  $addr_0 = (HEAP32[$c + 152 >> 2] | 0) + 6 | 0; //@line 67969
 } else {
  $addr_0 = (HEAP32[$c + 152 >> 2] | 0) + 2 | 0; //@line 67975
 }
 $18 = $c + 148 | 0; //@line 67978
 $20 = (HEAP32[$18 >> 2] | 0) - 4 | 0; //@line 67980
 $21 = $20 & 16777215; //@line 67981
 $22 = $21 + 3 | 0; //@line 67982
 if ($22 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $29 = $c + 32 | 0; //@line 67990
  HEAP8[(HEAP32[$29 >> 2] | 0) + $21 | 0] = $addr_0 >>> 24 & 255; //@line 67993
  HEAP8[(HEAP32[$29 >> 2] | 0) + ($21 + 1) | 0] = $addr_0 >>> 16 & 255; //@line 67999
  HEAP8[(HEAP32[$29 >> 2] | 0) + ($21 + 2) | 0] = $addr_0 >>> 8 & 255; //@line 68005
  HEAP8[(HEAP32[$29 >> 2] | 0) + $22 | 0] = $addr_0 & 255; //@line 68009
  HEAP32[$18 >> 2] = $20; //@line 68011
  _e68020_op_bcc($c, 1); //@line 68012
  return;
 } else {
  FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $21, $addr_0); //@line 68020
  HEAP32[$18 >> 2] = $20; //@line 68021
  _e68020_op_bcc($c, 1); //@line 68022
  return;
 }
}
function _op62001089($c) {
 $c = $c | 0;
 var $3 = 0, $10 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 68037
 if (($3 & 1 | 0) != 0) {
  $10 = 0; //@line 68042
  _e68020_op_bcc($c, $10); //@line 68044
  return;
 }
 $10 = $3 >>> 2 & 1 ^ 1; //@line 68051
 _e68020_op_bcc($c, $10); //@line 68053
 return;
}
function _op63001090($c) {
 $c = $c | 0;
 var $3 = 0, $9 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 68066
 if (($3 & 1 | 0) != 0) {
  $9 = 1; //@line 68071
  _e68020_op_bcc($c, $9); //@line 68073
  return;
 }
 $9 = $3 >>> 2 & 1; //@line 68080
 _e68020_op_bcc($c, $9); //@line 68082
 return;
}
function _op64001091($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, (HEAP16[$c + 166 >> 1] & 1 ^ 1) & 65535); //@line 68098
 return;
}
function _op65001092($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, HEAP16[$c + 166 >> 1] & 1); //@line 68113
 return;
}
function _op66001093($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, ((HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1 ^ 1) & 65535); //@line 68130
 return;
}
function _op67001094($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, (HEAPU16[$c + 166 >> 1] | 0) >>> 2 & 1); //@line 68146
 return;
}
function _op68001095($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, ((HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1 ^ 1) & 65535); //@line 68163
 return;
}
function _op69001096($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, (HEAPU16[$c + 166 >> 1] | 0) >>> 1 & 1); //@line 68179
 return;
}
function _op6a001097($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, ((HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1 ^ 1) & 65535); //@line 68196
 return;
}
function _op6b001098($c) {
 $c = $c | 0;
 _e68020_op_bcc($c, (HEAPU16[$c + 166 >> 1] | 0) >>> 3 & 1); //@line 68212
 return;
}
function _op6c001099($c) {
 $c = $c | 0;
 var $3 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 68225
 _e68020_op_bcc($c, ($3 >>> 3 ^ $3 >>> 1) & 1 ^ 1); //@line 68231
 return;
}
function _op6d001100($c) {
 $c = $c | 0;
 var $3 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 68244
 _e68020_op_bcc($c, ($3 >>> 3 ^ $3 >>> 1) & 1); //@line 68249
 return;
}
function _op6e001101($c) {
 $c = $c | 0;
 var $3 = 0, $13 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 68263
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) != 0) {
  $13 = 0; //@line 68271
  _e68020_op_bcc($c, $13); //@line 68273
  return;
 }
 $13 = $3 >>> 2 & 1 ^ 1; //@line 68280
 _e68020_op_bcc($c, $13); //@line 68282
 return;
}
function _op6f001102($c) {
 $c = $c | 0;
 var $3 = 0, $12 = 0;
 $3 = HEAPU16[$c + 166 >> 1] | 0; //@line 68296
 if ((($3 >>> 3 ^ $3 >>> 1) & 1 | 0) != 0) {
  $12 = 1; //@line 68304
  _e68020_op_bcc($c, $12); //@line 68306
  return;
 }
 $12 = $3 >>> 2 & 1; //@line 68313
 _e68020_op_bcc($c, $12); //@line 68315
 return;
}
function _ope8c0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $13 = 0, $14 = 0, $19 = 0, $22 = 0, $23 = 0, $29 = 0, $_0_i_i = 0, $51 = 0, sp = 0;
 sp = STACKTOP; //@line 68330
 STACKTOP = STACKTOP + 8 | 0; //@line 68330
 $val = sp | 0; //@line 68331
 if ((_e68_get_ea_bf($c, $val, 2021) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 68336
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 68339
  _e68_exception_illegal($c); //@line 68340
  STACKTOP = sp; //@line 68341
  return;
 }
 _e68_cc_set_nz_32($c, 15, HEAP32[$val >> 2] << 32 - (HEAP32[$c + 352 >> 2] | 0)); //@line 68349
 $13 = $c + 156 | 0; //@line 68350
 $14 = HEAP32[$13 >> 2] | 0; //@line 68351
 if (($14 & 1 | 0) != 0) {
  _e68_exception_address($c, $14, 0, 0); //@line 68356
  STACKTOP = sp; //@line 68358
  return;
 }
 $19 = $c + 164 | 0; //@line 68361
 HEAP16[$c + 162 >> 1] = HEAP16[$19 >> 1] | 0; //@line 68364
 $22 = $14 & 16777215; //@line 68365
 $23 = $22 + 1 | 0; //@line 68366
 if ($23 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $29 = HEAP32[$c + 32 >> 2] | 0; //@line 68373
  $_0_i_i = HEAPU8[$29 + $22 | 0] << 8 | HEAPU8[$29 + $23 | 0]; //@line 68383
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $22) | 0; //@line 68391
 }
 HEAP16[$19 >> 1] = $_0_i_i; //@line 68394
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 2; //@line 68402
  $51 = $c + 152 | 0; //@line 68403
  HEAP32[$51 >> 2] = (HEAP32[$51 >> 2] | 0) + 2; //@line 68406
  STACKTOP = sp; //@line 68408
  return;
 } else {
  _e68_exception_bus($c); //@line 68411
  STACKTOP = sp; //@line 68413
  return;
 }
}
function _ope9c0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $8 = 0, $12 = 0, $15 = 0, $18 = 0, $21 = 0, $22 = 0, $27 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, sp = 0;
 sp = STACKTOP; //@line 68429
 STACKTOP = STACKTOP + 8 | 0; //@line 68429
 $val = sp | 0; //@line 68430
 if ((_e68_get_ea_bf($c, $val, 2021) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 68435
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 68438
  _e68_exception_illegal($c); //@line 68439
  STACKTOP = sp; //@line 68440
  return;
 }
 $8 = $c + 162 | 0; //@line 68443
 $12 = (HEAPU16[$8 >> 1] | 0) >>> 12 & 7; //@line 68447
 $15 = 32 - (HEAP32[$c + 352 >> 2] | 0) | 0; //@line 68450
 $18 = -1 >>> ($15 >>> 0) & HEAP32[$val >> 2]; //@line 68453
 HEAP32[$val >> 2] = $18; //@line 68454
 _e68_cc_set_nz_32($c, 15, $18 << $15); //@line 68456
 HEAP32[$c + 88 + ($12 << 2) >> 2] = $18; //@line 68458
 $21 = $c + 156 | 0; //@line 68459
 $22 = HEAP32[$21 >> 2] | 0; //@line 68460
 if (($22 & 1 | 0) != 0) {
  _e68_exception_address($c, $22, 0, 0); //@line 68465
  STACKTOP = sp; //@line 68467
  return;
 }
 $27 = $c + 164 | 0; //@line 68470
 HEAP16[$8 >> 1] = HEAP16[$27 >> 1] | 0; //@line 68472
 $29 = $22 & 16777215; //@line 68473
 $30 = $29 + 1 | 0; //@line 68474
 if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 68481
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 68491
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 68499
 }
 HEAP16[$27 >> 1] = $_0_i_i; //@line 68502
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 68510
  $58 = $c + 152 | 0; //@line 68511
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 68514
  STACKTOP = sp; //@line 68516
  return;
 } else {
  _e68_exception_bus($c); //@line 68519
  STACKTOP = sp; //@line 68521
  return;
 }
}
function _opeac0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $8 = 0, $13 = 0, $21 = 0, $22 = 0, $27 = 0, $30 = 0, $31 = 0, $37 = 0, $_0_i_i = 0, $59 = 0, sp = 0;
 sp = STACKTOP; //@line 68537
 STACKTOP = STACKTOP + 8 | 0; //@line 68537
 $val = sp | 0; //@line 68538
 if ((_e68_get_ea_bf($c, $val, 485) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 68543
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 68546
  _e68_exception_illegal($c); //@line 68547
  STACKTOP = sp; //@line 68549
  return;
 }
 $8 = HEAP32[$val >> 2] | 0; //@line 68552
 if ((_e68_set_ea_bf($c, ~$8) | 0) != 0) {
  $13 = $c + 372 | 0; //@line 68558
  HEAP32[$13 >> 2] = (HEAP32[$13 >> 2] | 0) + 2; //@line 68561
  _e68_exception_illegal($c); //@line 68562
  STACKTOP = sp; //@line 68564
  return;
 }
 _e68_cc_set_nz_32($c, 15, $8 << 32 - (HEAP32[$c + 352 >> 2] | 0)); //@line 68571
 $21 = $c + 156 | 0; //@line 68572
 $22 = HEAP32[$21 >> 2] | 0; //@line 68573
 if (($22 & 1 | 0) != 0) {
  _e68_exception_address($c, $22, 0, 0); //@line 68578
  STACKTOP = sp; //@line 68580
  return;
 }
 $27 = $c + 164 | 0; //@line 68583
 HEAP16[$c + 162 >> 1] = HEAP16[$27 >> 1] | 0; //@line 68586
 $30 = $22 & 16777215; //@line 68587
 $31 = $30 + 1 | 0; //@line 68588
 if ($31 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $37 = HEAP32[$c + 32 >> 2] | 0; //@line 68595
  $_0_i_i = HEAPU8[$37 + $30 | 0] << 8 | HEAPU8[$37 + $31 | 0]; //@line 68605
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $30) | 0; //@line 68613
 }
 HEAP16[$27 >> 1] = $_0_i_i; //@line 68616
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$21 >> 2] = (HEAP32[$21 >> 2] | 0) + 2; //@line 68624
  $59 = $c + 152 | 0; //@line 68625
  HEAP32[$59 >> 2] = (HEAP32[$59 >> 2] | 0) + 2; //@line 68628
  STACKTOP = sp; //@line 68630
  return;
 } else {
  _e68_exception_bus($c); //@line 68633
  STACKTOP = sp; //@line 68635
  return;
 }
}
function _opebc0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $8 = 0, $12 = 0, $15 = 0, $16 = 0, $18 = 0, $storemerge = 0, $29 = 0, $30 = 0, $35 = 0, $37 = 0, $38 = 0, $44 = 0, $_0_i_i = 0, $66 = 0, sp = 0;
 sp = STACKTOP; //@line 68652
 STACKTOP = STACKTOP + 8 | 0; //@line 68652
 $val = sp | 0; //@line 68653
 if ((_e68_get_ea_bf($c, $val, 2021) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 68658
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 68661
  _e68_exception_illegal($c); //@line 68662
  STACKTOP = sp; //@line 68663
  return;
 }
 $8 = $c + 162 | 0; //@line 68666
 $12 = (HEAPU16[$8 >> 1] | 0) >>> 12 & 7; //@line 68670
 $15 = 32 - (HEAP32[$c + 352 >> 2] | 0) | 0; //@line 68673
 $16 = -1 >>> ($15 >>> 0); //@line 68674
 $18 = HEAP32[$val >> 2] | 0; //@line 68676
 if ((-2147483648 >>> ($15 >>> 0) & $18 | 0) == 0) {
  $storemerge = $16 & $18; //@line 68682
 } else {
  $storemerge = $18 | ~$16; //@line 68687
 }
 HEAP32[$val >> 2] = $storemerge; //@line 68690
 _e68_cc_set_nz_32($c, 15, $storemerge << $15); //@line 68692
 HEAP32[$c + 88 + ($12 << 2) >> 2] = $storemerge; //@line 68694
 $29 = $c + 156 | 0; //@line 68695
 $30 = HEAP32[$29 >> 2] | 0; //@line 68696
 if (($30 & 1 | 0) != 0) {
  _e68_exception_address($c, $30, 0, 0); //@line 68701
  STACKTOP = sp; //@line 68703
  return;
 }
 $35 = $c + 164 | 0; //@line 68706
 HEAP16[$8 >> 1] = HEAP16[$35 >> 1] | 0; //@line 68708
 $37 = $30 & 16777215; //@line 68709
 $38 = $37 + 1 | 0; //@line 68710
 if ($38 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $44 = HEAP32[$c + 32 >> 2] | 0; //@line 68717
  $_0_i_i = HEAPU8[$44 + $37 | 0] << 8 | HEAPU8[$44 + $38 | 0]; //@line 68727
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $37) | 0; //@line 68735
 }
 HEAP16[$35 >> 1] = $_0_i_i; //@line 68738
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$29 >> 2] = (HEAP32[$29 >> 2] | 0) + 2; //@line 68746
  $66 = $c + 152 | 0; //@line 68747
  HEAP32[$66 >> 2] = (HEAP32[$66 >> 2] | 0) + 2; //@line 68750
  STACKTOP = sp; //@line 68752
  return;
 } else {
  _e68_exception_bus($c); //@line 68755
  STACKTOP = sp; //@line 68757
  return;
 }
}
function _opecc0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $11 = 0, $20 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, sp = 0;
 sp = STACKTOP; //@line 68773
 STACKTOP = STACKTOP + 8 | 0; //@line 68773
 $val = sp | 0; //@line 68774
 if ((_e68_get_ea_bf($c, $val, 485) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 68779
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 68782
  _e68_exception_illegal($c); //@line 68783
  STACKTOP = sp; //@line 68785
  return;
 }
 if ((_e68_set_ea_bf($c, 0) | 0) != 0) {
  $11 = $c + 372 | 0; //@line 68792
  HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 68795
  _e68_exception_illegal($c); //@line 68796
  STACKTOP = sp; //@line 68798
  return;
 }
 _e68_cc_set_nz_32($c, 15, HEAP32[$val >> 2] << 32 - (HEAP32[$c + 352 >> 2] | 0)); //@line 68806
 $20 = $c + 156 | 0; //@line 68807
 $21 = HEAP32[$20 >> 2] | 0; //@line 68808
 if (($21 & 1 | 0) != 0) {
  _e68_exception_address($c, $21, 0, 0); //@line 68813
  STACKTOP = sp; //@line 68815
  return;
 }
 $26 = $c + 164 | 0; //@line 68818
 HEAP16[$c + 162 >> 1] = HEAP16[$26 >> 1] | 0; //@line 68821
 $29 = $21 & 16777215; //@line 68822
 $30 = $29 + 1 | 0; //@line 68823
 if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 68830
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 68840
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 68848
 }
 HEAP16[$26 >> 1] = $_0_i_i; //@line 68851
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 68859
  $58 = $c + 152 | 0; //@line 68860
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 68863
  STACKTOP = sp; //@line 68865
  return;
 } else {
  _e68_exception_bus($c); //@line 68868
  STACKTOP = sp; //@line 68870
  return;
 }
}
function _opeec0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $11 = 0, $20 = 0, $21 = 0, $26 = 0, $29 = 0, $30 = 0, $36 = 0, $_0_i_i = 0, $58 = 0, sp = 0;
 sp = STACKTOP; //@line 68886
 STACKTOP = STACKTOP + 8 | 0; //@line 68886
 $val = sp | 0; //@line 68887
 if ((_e68_get_ea_bf($c, $val, 485) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 68892
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 68895
  _e68_exception_illegal($c); //@line 68896
  STACKTOP = sp; //@line 68898
  return;
 }
 if ((_e68_set_ea_bf($c, -1) | 0) != 0) {
  $11 = $c + 372 | 0; //@line 68905
  HEAP32[$11 >> 2] = (HEAP32[$11 >> 2] | 0) + 2; //@line 68908
  _e68_exception_illegal($c); //@line 68909
  STACKTOP = sp; //@line 68911
  return;
 }
 _e68_cc_set_nz_32($c, 15, HEAP32[$val >> 2] << 32 - (HEAP32[$c + 352 >> 2] | 0)); //@line 68919
 $20 = $c + 156 | 0; //@line 68920
 $21 = HEAP32[$20 >> 2] | 0; //@line 68921
 if (($21 & 1 | 0) != 0) {
  _e68_exception_address($c, $21, 0, 0); //@line 68926
  STACKTOP = sp; //@line 68928
  return;
 }
 $26 = $c + 164 | 0; //@line 68931
 HEAP16[$c + 162 >> 1] = HEAP16[$26 >> 1] | 0; //@line 68934
 $29 = $21 & 16777215; //@line 68935
 $30 = $29 + 1 | 0; //@line 68936
 if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $36 = HEAP32[$c + 32 >> 2] | 0; //@line 68943
  $_0_i_i = HEAPU8[$36 + $29 | 0] << 8 | HEAPU8[$36 + $30 | 0]; //@line 68953
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29) | 0; //@line 68961
 }
 HEAP16[$26 >> 1] = $_0_i_i; //@line 68964
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + 2; //@line 68972
  $58 = $c + 152 | 0; //@line 68973
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 2; //@line 68976
  STACKTOP = sp; //@line 68978
  return;
 } else {
  _e68_exception_bus($c); //@line 68981
  STACKTOP = sp; //@line 68983
  return;
 }
}
function _e68_cc_set_nz_8($c, $msk, $val) {
 $c = $c | 0;
 $msk = $msk | 0;
 $val = $val | 0;
 var $set_0 = 0, $5 = 0, $7 = 0;
 if ($val << 24 >> 24 == 0) {
  $set_0 = 4; //@line 69000
 } else {
  $set_0 = $val << 24 >> 24 < 0 ? 8 : 0; //@line 69005
 }
 $5 = $msk & 255; //@line 69008
 $7 = $c + 166 | 0; //@line 69010
 HEAP16[$7 >> 1] = ((HEAPU16[$7 >> 1] | 0) & ($5 ^ 65535) | $set_0 & $5) & 65535; //@line 69017
 return;
}
function _e68_cc_set_nz_16($c, $msk, $val) {
 $c = $c | 0;
 $msk = $msk | 0;
 $val = $val | 0;
 var $set_0 = 0, $5 = 0, $7 = 0;
 if ($val << 16 >> 16 == 0) {
  $set_0 = 4; //@line 69034
 } else {
  $set_0 = $val << 16 >> 16 < 0 ? 8 : 0; //@line 69039
 }
 $5 = $msk & 255; //@line 69042
 $7 = $c + 166 | 0; //@line 69044
 HEAP16[$7 >> 1] = ((HEAPU16[$7 >> 1] | 0) & ($5 ^ 65535) | $set_0 & $5) & 65535; //@line 69051
 return;
}
function _e68_cc_set_nz_32($c, $msk, $val) {
 $c = $c | 0;
 $msk = $msk | 0;
 $val = $val | 0;
 var $set_0 = 0, $6 = 0, $8 = 0;
 if (($val | 0) == 0) {
  $set_0 = 4; //@line 69068
 } else {
  $set_0 = $val >> 31 & 8; //@line 69073
 }
 $6 = $msk & 255; //@line 69076
 $8 = $c + 166 | 0; //@line 69078
 HEAP16[$8 >> 1] = ((HEAPU16[$8 >> 1] | 0) & ($6 ^ 65535) | $set_0 & $6) & 65535; //@line 69085
 return;
}
function _opefc0($c) {
 $c = $c | 0;
 var $val = 0, $4 = 0, $8 = 0, $14 = 0, $18 = 0, $26 = 0, $27 = 0, $32 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i_i = 0, $63 = 0, sp = 0;
 sp = STACKTOP; //@line 69102
 STACKTOP = STACKTOP + 8 | 0; //@line 69102
 $val = sp | 0; //@line 69103
 if ((_e68_get_ea_bf($c, $val, 2021) | 0) != 0) {
  $4 = $c + 372 | 0; //@line 69108
  HEAP32[$4 >> 2] = (HEAP32[$4 >> 2] | 0) + 2; //@line 69111
  _e68_exception_illegal($c); //@line 69112
  STACKTOP = sp; //@line 69114
  return;
 }
 $8 = $c + 162 | 0; //@line 69117
 $14 = HEAP32[$c + 88 + (((HEAPU16[$8 >> 1] | 0) >>> 12 & 7) << 2) >> 2] | 0; //@line 69123
 HEAP32[$val >> 2] = $14; //@line 69124
 if ((_e68_set_ea_bf($c, $14) | 0) != 0) {
  $18 = $c + 372 | 0; //@line 69129
  HEAP32[$18 >> 2] = (HEAP32[$18 >> 2] | 0) + 2; //@line 69132
  _e68_exception_illegal($c); //@line 69133
  STACKTOP = sp; //@line 69135
  return;
 }
 _e68_cc_set_nz_32($c, 15, $14 << 32 - (HEAP32[$c + 352 >> 2] | 0)); //@line 69142
 $26 = $c + 156 | 0; //@line 69143
 $27 = HEAP32[$26 >> 2] | 0; //@line 69144
 if (($27 & 1 | 0) != 0) {
  _e68_exception_address($c, $27, 0, 0); //@line 69149
  STACKTOP = sp; //@line 69151
  return;
 }
 $32 = $c + 164 | 0; //@line 69154
 HEAP16[$8 >> 1] = HEAP16[$32 >> 1] | 0; //@line 69156
 $34 = $27 & 16777215; //@line 69157
 $35 = $34 + 1 | 0; //@line 69158
 if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $41 = HEAP32[$c + 32 >> 2] | 0; //@line 69165
  $_0_i_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 69175
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 69183
 }
 HEAP16[$32 >> 1] = $_0_i_i; //@line 69186
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$26 >> 2] = (HEAP32[$26 >> 2] | 0) + 2; //@line 69194
  $63 = $c + 152 | 0; //@line 69195
  HEAP32[$63 >> 2] = (HEAP32[$63 >> 2] | 0) + 2; //@line 69198
  STACKTOP = sp; //@line 69200
  return;
 } else {
  _e68_exception_bus($c); //@line 69203
  STACKTOP = sp; //@line 69205
  return;
 }
}
function _e68_get_ea_bf($c, $bf, $mask) {
 $c = $c | 0;
 $bf = $bf | 0;
 $mask = $mask | 0;
 var $1 = 0, $2 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $17 = 0, $_0_i_i = 0, $39 = 0, $42 = 0, $43 = 0, $44 = 0, $53 = 0, $wth_0_in = 0, $wth_0 = 0, $_wth_0 = 0, $65 = 0, $71 = 0, $72 = 0, $74 = 0, $80 = 0, $82 = 0, $val_0_i = 0, $91 = 0, $92 = 0, $93 = 0, $99 = 0, $100 = 0, $101 = 0, $n1_027_in_i = 0, $adr_126_i = 0, $buf_025_i = 0, $cnt_024_i = 0, $n1_027_i = 0, $103 = 0, $cnt_0__i = 0, $105 = 0, $108 = 0, $_0_i_i22 = 0, $131 = 0, $_0 = 0;
 $1 = $c + 156 | 0; //@line 69234
 $2 = HEAP32[$1 >> 2] | 0; //@line 69235
 if (($2 & 1 | 0) != 0) {
  _e68_exception_address($c, $2, 0, 0); //@line 69240
  $_0 = 1; //@line 69242
  return $_0 | 0; //@line 69245
 }
 $7 = $c + 164 | 0; //@line 69247
 $9 = $c + 162 | 0; //@line 69249
 HEAP16[$9 >> 1] = HEAP16[$7 >> 1] | 0; //@line 69250
 $10 = $2 & 16777215; //@line 69251
 $11 = $10 + 1 | 0; //@line 69252
 $12 = $c + 36 | 0; //@line 69253
 if ($11 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
  $17 = HEAP32[$c + 32 >> 2] | 0; //@line 69259
  $_0_i_i = HEAPU8[$17 + $10 | 0] << 8 | HEAPU8[$17 + $11 | 0]; //@line 69269
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $10) | 0; //@line 69277
 }
 HEAP16[$7 >> 1] = $_0_i_i; //@line 69280
 if ((HEAP8[$c + 336 | 0] | 0) != 0) {
  _e68_exception_bus($c); //@line 69286
  $_0 = 1; //@line 69288
  return $_0 | 0; //@line 69291
 }
 HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 69295
 $39 = $c + 152 | 0; //@line 69296
 HEAP32[$39 >> 2] = (HEAP32[$39 >> 2] | 0) + 2; //@line 69299
 $42 = HEAP16[$9 >> 1] | 0; //@line 69300
 $43 = $42 & 65535; //@line 69301
 $44 = $43 >>> 6; //@line 69302
 if (($43 & 2048 | 0) == 0) {
  $53 = $44 & 31; //@line 69308
 } else {
  $53 = HEAP32[$c + 88 + (($44 & 7) << 2) >> 2] | 0; //@line 69314
 }
 if (($42 & 32) == 0) {
  $wth_0_in = $43; //@line 69321
 } else {
  $wth_0_in = HEAP32[$c + 88 + (($43 & 7) << 2) >> 2] | 0; //@line 69327
 }
 $wth_0 = $wth_0_in & 31; //@line 69330
 $_wth_0 = ($wth_0 | 0) == 0 ? 32 : $wth_0; //@line 69332
 $65 = HEAP16[$c + 160 >> 1] & 63; //@line 69336
 if ((FUNCTION_TABLE_iiiii[HEAP32[20568 + ($65 << 2) >> 2] & 127]($c, $65, $mask, 8) | 0) != 0) {
  $_0 = 1; //@line 69343
  return $_0 | 0; //@line 69346
 }
 $71 = $c + 348 | 0; //@line 69348
 HEAP32[$71 >> 2] = $53; //@line 69349
 $72 = $c + 352 | 0; //@line 69350
 HEAP32[$72 >> 2] = $_wth_0; //@line 69351
 $74 = HEAP32[$c + 340 >> 2] | 0; //@line 69353
 do {
  if (($74 | 0) == 1) {
   $80 = HEAP32[$c + 88 + ((HEAP32[$c + 344 >> 2] & 7) << 2) >> 2] | 0; //@line 69360
   $82 = $53 + $_wth_0 & 31; //@line 69362
   if (($82 | 0) == 0) {
    $val_0_i = $80; //@line 69366
   } else {
    $val_0_i = $80 >>> ((32 - $82 | 0) >>> 0) | $80 << $82; //@line 69373
   }
   HEAP32[$bf >> 2] = $val_0_i; //@line 69376
  } else if (($74 | 0) == 2) {
   $91 = HEAP32[$c + 344 >> 2] | 0; //@line 69380
   $92 = $53 >>> 3; //@line 69381
   HEAP32[$bf >> 2] = 0; //@line 69382
   $93 = HEAP32[$72 >> 2] | 0; //@line 69383
   if (($93 | 0) == 0) {
    break;
   }
   $99 = $c + 32 | 0; //@line 69395
   $100 = $c + 8 | 0; //@line 69396
   $101 = $c + 4 | 0; //@line 69397
   $cnt_024_i = $93;
   $buf_025_i = $c + 356 | 0;
   $adr_126_i = (($53 | 0) < 0 ? $92 | -536870912 : $92) + $91 | 0;
   $n1_027_in_i = HEAP32[$71 >> 2] | 0;
   while (1) {
    $n1_027_i = $n1_027_in_i & 7; //@line 69405
    $103 = 8 - $n1_027_i | 0; //@line 69406
    $cnt_0__i = $103 >>> 0 > $cnt_024_i >>> 0 ? $cnt_024_i : $103; //@line 69408
    $105 = $103 - $cnt_0__i | 0; //@line 69409
    $108 = $adr_126_i & 16777215; //@line 69412
    if ($108 >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
     $_0_i_i22 = HEAP8[(HEAP32[$99 >> 2] | 0) + $108 | 0] | 0; //@line 69421
    } else {
     $_0_i_i22 = FUNCTION_TABLE_iii[HEAP32[$100 >> 2] & 63](HEAP32[$101 >> 2] | 0, $108) | 0; //@line 69427
    }
    HEAP8[$buf_025_i] = $_0_i_i22; //@line 69431
    HEAP32[$bf >> 2] = (255 << $105 & 255 >>> ($n1_027_i >>> 0) & ($_0_i_i22 & 255)) >>> ($105 >>> 0) | HEAP32[$bf >> 2] << $cnt_0__i; //@line 69439
    if (($cnt_024_i | 0) == ($cnt_0__i | 0)) {
     break;
    } else {
     $cnt_024_i = $cnt_024_i - $cnt_0__i | 0;
     $buf_025_i = $buf_025_i + 1 | 0;
     $adr_126_i = $adr_126_i + 1 | 0;
     $n1_027_in_i = $cnt_0__i + $n1_027_i | 0;
    }
   }
  } else {
   $_0 = 1; //@line 69452
   return $_0 | 0; //@line 69455
  }
 } while (0);
 $131 = $c + 372 | 0; //@line 69458
 HEAP32[$131 >> 2] = (HEAP32[$131 >> 2] | 0) + 18; //@line 69461
 $_0 = 0; //@line 69463
 return $_0 | 0; //@line 69466
}
function _e68_set_ea_bf($c, $bf) {
 $c = $c | 0;
 $bf = $bf | 0;
 var $2 = 0, $7 = 0, $11 = 0, $12 = 0, $16 = 0, $20 = 0, $_0_i = 0, $msk_0_i = 0, $32 = 0, $33 = 0, $35 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $n1_027_in_i = 0, $adr_126_i = 0, $buf_025_i = 0, $cnt_024_i = 0, $n1_027_i = 0, $47 = 0, $cnt_0__i = 0, $49 = 0, $52 = 0, $58 = 0, $63 = 0, $64 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 69486
 if (($2 | 0) == 1) {
  $7 = $c + 88 + ((HEAP32[$c + 344 >> 2] & 7) << 2) | 0; //@line 69491
  $11 = 32 - (HEAP32[$c + 352 >> 2] | 0) | 0; //@line 69495
  $12 = -1 >>> ($11 >>> 0); //@line 69496
  $16 = $11 - (HEAP32[$c + 348 >> 2] | 0) & 31; //@line 69500
  if (($16 | 0) == 0) {
   $msk_0_i = $12;
   $_0_i = $bf;
  } else {
   $20 = 32 - $16 | 0; //@line 69507
   $msk_0_i = $12 >>> ($20 >>> 0) | $12 << $16;
   $_0_i = $bf >>> ($20 >>> 0) | $bf << $16;
  }
  HEAP32[$7 >> 2] = HEAP32[$7 >> 2] & ~$msk_0_i | $msk_0_i & $_0_i; //@line 69522
  $_0 = 0; //@line 69524
  return $_0 | 0; //@line 69527
 } else if (($2 | 0) == 2) {
  $32 = HEAP32[$c + 348 >> 2] | 0; //@line 69530
  $33 = $32 >>> 3; //@line 69531
  $35 = HEAP32[$c + 352 >> 2] | 0; //@line 69533
  if (($35 | 0) == 0) {
   $_0 = 0; //@line 69537
   return $_0 | 0; //@line 69540
  }
  $42 = $c + 36 | 0; //@line 69549
  $43 = $c + 32 | 0; //@line 69550
  $44 = $c + 20 | 0; //@line 69551
  $45 = $c + 4 | 0; //@line 69552
  $cnt_024_i = $35;
  $buf_025_i = $c + 356 | 0;
  $adr_126_i = (HEAP32[$c + 344 >> 2] | 0) + (($32 | 0) < 0 ? $33 | -536870912 : $33) | 0;
  $n1_027_in_i = $32;
  while (1) {
   $n1_027_i = $n1_027_in_i & 7; //@line 69560
   $47 = 8 - $n1_027_i | 0; //@line 69561
   $cnt_0__i = $47 >>> 0 > $cnt_024_i >>> 0 ? $cnt_024_i : $47; //@line 69563
   $49 = $47 - $cnt_0__i | 0; //@line 69564
   $52 = 255 << $49 & 255 >>> ($n1_027_i >>> 0); //@line 69567
   $58 = $cnt_024_i - $cnt_0__i | 0; //@line 69573
   $63 = (($52 ^ 255) & (HEAPU8[$buf_025_i] | 0) | $bf >>> (($58 - $49 | 0) >>> 0) & $52) & 255; //@line 69578
   $64 = $adr_126_i & 16777215; //@line 69579
   if ($64 >>> 0 < (HEAP32[$42 >> 2] | 0) >>> 0) {
    HEAP8[(HEAP32[$43 >> 2] | 0) + $64 | 0] = $63; //@line 69586
   } else {
    FUNCTION_TABLE_viii[HEAP32[$44 >> 2] & 63](HEAP32[$45 >> 2] | 0, $64, $63); //@line 69591
   }
   if (($cnt_024_i | 0) == ($cnt_0__i | 0)) {
    $_0 = 0; //@line 69598
    break;
   } else {
    $cnt_024_i = $58;
    $buf_025_i = $buf_025_i + 1 | 0;
    $adr_126_i = $adr_126_i + 1 | 0;
    $n1_027_in_i = $cnt_0__i + $n1_027_i | 0;
   }
  }
  return $_0 | 0; //@line 69606
 } else {
  $_0 = 1; //@line 69608
  return $_0 | 0; //@line 69611
 }
 return 0;
}
function _e68020_op_bcc($c, $cond) {
 $c = $c | 0;
 $cond = $cond | 0;
 var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $11 = 0, $14 = 0, $15 = 0, $20 = 0, $22 = 0, $23 = 0, $24 = 0, $30 = 0, $_0_i_i19 = 0, $55 = 0, $64 = 0, $65 = 0, $70 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $80 = 0, $95 = 0, $96 = 0, $102 = 0, $105 = 0, $110 = 0, $111 = 0, $115 = 0, $128 = 0, $phitmp = 0, $dist_0 = 0, $143 = 0, $146 = 0, $147 = 0, $152 = 0, $155 = 0, $156 = 0, $162 = 0, $_0_i_i31 = 0, $182 = 0, $190 = 0, $194 = 0, $195 = 0, $200 = 0, $203 = 0, $204 = 0, $210 = 0, $_0_i_i = 0, $230 = 0;
 $1 = $c + 152 | 0; //@line 69647
 $3 = (HEAP32[$1 >> 2] | 0) + 2 | 0; //@line 69649
 $4 = $c + 160 | 0; //@line 69650
 $6 = HEAPU16[$4 >> 1] | 0; //@line 69652
 $11 = ($6 & 128 | 0) != 0 ? $6 | -256 : $6 & 255; //@line 69657
 do {
  if (($11 | 0) == 0) {
   $14 = $c + 156 | 0; //@line 69662
   $15 = HEAP32[$14 >> 2] | 0; //@line 69663
   if (($15 & 1 | 0) != 0) {
    _e68_exception_address($c, $15, 0, 0); //@line 69668
    return;
   }
   $20 = $c + 164 | 0; //@line 69673
   $22 = $c + 162 | 0; //@line 69675
   HEAP16[$22 >> 1] = HEAP16[$20 >> 1] | 0; //@line 69676
   $23 = $15 & 16777215; //@line 69677
   $24 = $23 + 1 | 0; //@line 69678
   if ($24 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $30 = HEAP32[$c + 32 >> 2] | 0; //@line 69685
    $_0_i_i19 = HEAPU8[$30 + $23 | 0] << 8 | HEAPU8[$30 + $24 | 0]; //@line 69695
   } else {
    $_0_i_i19 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $23) | 0; //@line 69703
   }
   HEAP16[$20 >> 1] = $_0_i_i19; //@line 69706
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$14 >> 2] = (HEAP32[$14 >> 2] | 0) + 2; //@line 69714
    HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 69717
    $55 = HEAPU16[$22 >> 1] | 0; //@line 69719
    $dist_0 = ($55 & 32768 | 0) != 0 ? $55 | -65536 : $55; //@line 69725
    break;
   }
   _e68_exception_bus($c); //@line 69728
   return;
  } else {
   if (($11 & 255 | 0) != 255) {
    $dist_0 = $11; //@line 69737
    break;
   }
   $64 = $c + 156 | 0; //@line 69740
   $65 = HEAP32[$64 >> 2] | 0; //@line 69741
   if (($65 & 1 | 0) != 0) {
    _e68_exception_address($c, $65, 0, 0); //@line 69746
    return;
   }
   $70 = $c + 164 | 0; //@line 69751
   $72 = $c + 162 | 0; //@line 69753
   HEAP16[$72 >> 1] = HEAP16[$70 >> 1] | 0; //@line 69754
   $73 = $65 & 16777215; //@line 69755
   $74 = $73 + 1 | 0; //@line 69756
   $75 = $c + 36 | 0; //@line 69757
   if ($74 >>> 0 < (HEAP32[$75 >> 2] | 0) >>> 0) {
    $80 = HEAP32[$c + 32 >> 2] | 0; //@line 69763
    $95 = HEAPU8[$80 + $73 | 0] << 8 | HEAPU8[$80 + $74 | 0]; //@line 69773
   } else {
    $95 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $73) | 0; //@line 69781
   }
   HEAP16[$70 >> 1] = $95; //@line 69784
   $96 = $c + 336 | 0; //@line 69785
   if ((HEAP8[$96] | 0) != 0) {
    _e68_exception_bus($c); //@line 69790
    return;
   }
   $102 = (HEAP32[$64 >> 2] | 0) + 2 | 0; //@line 69796
   HEAP32[$64 >> 2] = $102; //@line 69797
   HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 69800
   $105 = HEAP16[$72 >> 1] | 0; //@line 69801
   if (($102 & 1 | 0) != 0) {
    _e68_exception_address($c, $102, 0, 0); //@line 69806
    return;
   }
   HEAP16[$72 >> 1] = $95; //@line 69811
   $110 = $102 & 16777215; //@line 69812
   $111 = $110 + 1 | 0; //@line 69813
   do {
    if ($111 >>> 0 < (HEAP32[$75 >> 2] | 0) >>> 0) {
     $115 = HEAP32[$c + 32 >> 2] | 0; //@line 69820
     HEAP16[$70 >> 1] = HEAPU8[$115 + $110 | 0] << 8 | HEAPU8[$115 + $111 | 0]; //@line 69829
    } else {
     $128 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $110) | 0; //@line 69836
     $phitmp = (HEAP8[$96] | 0) == 0; //@line 69838
     HEAP16[$70 >> 1] = $128; //@line 69839
     if ($phitmp) {
      break;
     }
     _e68_exception_bus($c); //@line 69844
     return;
    }
   } while (0);
   HEAP32[$64 >> 2] = (HEAP32[$64 >> 2] | 0) + 2; //@line 69852
   HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 69855
   $dist_0 = HEAPU16[$72 >> 1] | ($105 & 65535) << 16; //@line 69862
  }
 } while (0);
 do {
  if (($cond | 0) == 0) {
   $190 = $c + 372 | 0; //@line 69874
   HEAP32[$190 >> 2] = ((HEAP16[$4 >> 1] & 255) == 0 ? 12 : 8) + (HEAP32[$190 >> 2] | 0); //@line 69877
   $194 = HEAP32[$c + 156 >> 2] | 0; //@line 69880
  } else {
   $143 = $c + 372 | 0; //@line 69882
   HEAP32[$143 >> 2] = (HEAP32[$143 >> 2] | 0) + 10; //@line 69885
   $146 = $3 + $dist_0 | 0; //@line 69886
   $147 = $c + 156 | 0; //@line 69887
   HEAP32[$147 >> 2] = $146; //@line 69888
   if (($146 & 1 | 0) != 0) {
    _e68_exception_address($c, $146, 0, 0); //@line 69893
    return;
   }
   $152 = $c + 164 | 0; //@line 69898
   HEAP16[$c + 162 >> 1] = HEAP16[$152 >> 1] | 0; //@line 69901
   $155 = $146 & 16777215; //@line 69902
   $156 = $155 + 1 | 0; //@line 69903
   if ($156 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $162 = HEAP32[$c + 32 >> 2] | 0; //@line 69910
    $_0_i_i31 = HEAPU8[$162 + $155 | 0] << 8 | HEAPU8[$162 + $156 | 0]; //@line 69920
   } else {
    $_0_i_i31 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $155) | 0; //@line 69928
   }
   HEAP16[$152 >> 1] = $_0_i_i31; //@line 69931
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    $182 = (HEAP32[$147 >> 2] | 0) + 2 | 0; //@line 69938
    HEAP32[$147 >> 2] = $182; //@line 69939
    HEAP32[$1 >> 2] = (HEAP32[$1 >> 2] | 0) + 2; //@line 69942
    $194 = $182; //@line 69944
    break;
   }
   _e68_exception_bus($c); //@line 69947
   return;
  }
 } while (0);
 $195 = $c + 156 | 0; //@line 69954
 if (($194 & 1 | 0) != 0) {
  _e68_exception_address($c, $194, 0, 0); //@line 69959
  return;
 }
 $200 = $c + 164 | 0; //@line 69964
 HEAP16[$c + 162 >> 1] = HEAP16[$200 >> 1] | 0; //@line 69967
 $203 = $194 & 16777215; //@line 69968
 $204 = $203 + 1 | 0; //@line 69969
 if ($204 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $210 = HEAP32[$c + 32 >> 2] | 0; //@line 69976
  $_0_i_i = HEAPU8[$210 + $203 | 0] << 8 | HEAPU8[$210 + $204 | 0]; //@line 69986
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $203) | 0; //@line 69994
 }
 HEAP16[$200 >> 1] = $_0_i_i; //@line 69997
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  $230 = HEAP32[$195 >> 2] | 0; //@line 70003
  HEAP32[$195 >> 2] = $230 + 2; //@line 70005
  HEAP32[$1 >> 2] = $230 - 2; //@line 70007
  return;
 } else {
  _e68_exception_bus($c); //@line 70012
  return;
 }
}
function _e68_cc_set_add_8($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $storemerge = 0, $7 = 0, $9 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0;
 $2 = $c + 166 | 0; //@line 70032
 $3 = HEAP16[$2 >> 1] | 0; //@line 70033
 $storemerge = $d << 24 >> 24 == 0 ? $3 | 4 : $3 & -5; //@line 70036
 HEAP16[$2 >> 1] = $storemerge; //@line 70037
 $7 = ($s1 & 255) >>> 7; //@line 70039
 $9 = ($s2 & 255) >>> 7; //@line 70041
 do {
  if ($d << 24 >> 24 > -1) {
   $set_1_i = ($9 | $7 | 0) == 0 ? 0 : 17; //@line 70048
   if (($9 & $7 | 0) == 0) {
    $set_2_i = $set_1_i; //@line 70053
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70058
  } else {
   $set_0_i = ($9 & $7 | 0) == 0 ? 8 : 25; //@line 70062
   if (($9 | $7 | 0) != 0) {
    $set_2_i = $set_0_i; //@line 70067
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70072
  }
 } while (0);
 HEAP16[$2 >> 1] = $storemerge & -28 | $set_2_i; //@line 70078
 return;
}
function _e68_cc_set_add_16($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $storemerge = 0, $7 = 0, $9 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0;
 $2 = $c + 166 | 0; //@line 70096
 $3 = HEAP16[$2 >> 1] | 0; //@line 70097
 $storemerge = $d << 16 >> 16 == 0 ? $3 | 4 : $3 & -5; //@line 70100
 HEAP16[$2 >> 1] = $storemerge; //@line 70101
 $7 = ($s1 & 65535) >>> 15; //@line 70103
 $9 = ($s2 & 65535) >>> 15; //@line 70105
 do {
  if ($d << 16 >> 16 > -1) {
   $set_1_i = ($9 | $7 | 0) == 0 ? 0 : 17; //@line 70112
   if (($9 & $7 | 0) == 0) {
    $set_2_i = $set_1_i; //@line 70117
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70122
  } else {
   $set_0_i = ($9 & $7 | 0) == 0 ? 8 : 25; //@line 70126
   if (($9 | $7 | 0) != 0) {
    $set_2_i = $set_0_i; //@line 70131
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70136
  }
 } while (0);
 HEAP16[$2 >> 1] = $storemerge & -28 | $set_2_i; //@line 70142
 return;
}
function _e68_cc_set_add_32($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $storemerge = 0, $6 = 0, $7 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0;
 $2 = $c + 166 | 0; //@line 70159
 $3 = HEAP16[$2 >> 1] | 0; //@line 70160
 $storemerge = ($d | 0) == 0 ? $3 | 4 : $3 & -5; //@line 70163
 HEAP16[$2 >> 1] = $storemerge; //@line 70164
 $6 = $s1 >>> 31; //@line 70165
 $7 = $s2 >>> 31; //@line 70166
 do {
  if (($d | 0) > -1) {
   $set_1_i = ($7 | $6 | 0) == 0 ? 0 : 17; //@line 70173
   if (($7 & $6 | 0) == 0) {
    $set_2_i = $set_1_i; //@line 70178
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70183
  } else {
   $set_0_i = ($7 & $6 | 0) == 0 ? 8 : 25; //@line 70187
   if (($7 | $6 | 0) != 0) {
    $set_2_i = $set_0_i; //@line 70192
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70197
  }
 } while (0);
 HEAP16[$2 >> 1] = $storemerge & -28 | $set_2_i; //@line 70203
 return;
}
function _e68_cc_set_addx_8($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $4 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $20 = 0, $23 = 0;
 $2 = ($s1 & 255) >>> 7; //@line 70221
 $4 = ($s2 & 255) >>> 7; //@line 70223
 do {
  if ($d << 24 >> 24 > -1) {
   $set_1_i = ($4 | $2 | 0) == 0 ? 0 : 17; //@line 70230
   if (($4 & $2 | 0) == 0) {
    $set_2_i = $set_1_i; //@line 70235
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70240
  } else {
   $set_0_i = ($4 & $2 | 0) == 0 ? 8 : 25; //@line 70244
   if (($4 | $2 | 0) != 0) {
    $set_2_i = $set_0_i; //@line 70249
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70254
  }
 } while (0);
 $20 = $c + 166 | 0; //@line 70258
 $23 = HEAP16[$20 >> 1] & -28 | $set_2_i; //@line 70261
 HEAP16[$20 >> 1] = $d << 24 >> 24 == 0 ? $23 : $23 & -5; //@line 70265
 return;
}
function _e68_cc_set_addx_16($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $4 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $20 = 0, $23 = 0;
 $2 = ($s1 & 65535) >>> 15; //@line 70283
 $4 = ($s2 & 65535) >>> 15; //@line 70285
 do {
  if ($d << 16 >> 16 > -1) {
   $set_1_i = ($4 | $2 | 0) == 0 ? 0 : 17; //@line 70292
   if (($4 & $2 | 0) == 0) {
    $set_2_i = $set_1_i; //@line 70297
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70302
  } else {
   $set_0_i = ($4 & $2 | 0) == 0 ? 8 : 25; //@line 70306
   if (($4 | $2 | 0) != 0) {
    $set_2_i = $set_0_i; //@line 70311
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70316
  }
 } while (0);
 $20 = $c + 166 | 0; //@line 70320
 $23 = HEAP16[$20 >> 1] & -28 | $set_2_i; //@line 70323
 HEAP16[$20 >> 1] = $d << 16 >> 16 == 0 ? $23 : $23 & -5; //@line 70327
 return;
}
function _e68_cc_set_addx_32($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $1 = 0, $2 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $18 = 0, $21 = 0;
 $1 = $s1 >>> 31; //@line 70343
 $2 = $s2 >>> 31; //@line 70344
 do {
  if (($d | 0) > -1) {
   $set_1_i = ($2 | $1 | 0) == 0 ? 0 : 17; //@line 70351
   if (($2 & $1 | 0) == 0) {
    $set_2_i = $set_1_i; //@line 70356
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70361
  } else {
   $set_0_i = ($2 & $1 | 0) == 0 ? 8 : 25; //@line 70365
   if (($2 | $1 | 0) != 0) {
    $set_2_i = $set_0_i; //@line 70370
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70375
  }
 } while (0);
 $18 = $c + 166 | 0; //@line 70379
 $21 = HEAP16[$18 >> 1] & -28 | $set_2_i; //@line 70382
 HEAP16[$18 >> 1] = ($d | 0) == 0 ? $21 : $21 & -5; //@line 70386
 return;
}
function _e68_cc_set_cmp_8($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = $s1 << 24 >> 24 < 0; //@line 70403
 $3 = $s2 << 24 >> 24 > -1; //@line 70404
 do {
  if ($d << 24 >> 24 > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70409
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70413
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70418
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70421
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70425
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70430
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70434
 $14 = HEAP16[$10 >> 1] & -16 | $set_2_i & 15; //@line 70438
 HEAP16[$10 >> 1] = $d << 24 >> 24 == 0 ? $14 | 4 : $14; //@line 70442
 return;
}
function _e68_cc_set_cmp_16($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = $s1 << 16 >> 16 < 0; //@line 70459
 $3 = $s2 << 16 >> 16 > -1; //@line 70460
 do {
  if ($d << 16 >> 16 > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70465
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70469
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70474
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70477
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70481
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70486
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70490
 $14 = HEAP16[$10 >> 1] & -16 | $set_2_i & 15; //@line 70494
 HEAP16[$10 >> 1] = $d << 16 >> 16 == 0 ? $14 | 4 : $14; //@line 70498
 return;
}
function _e68_cc_set_cmp_32($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = ($s1 | 0) < 0; //@line 70515
 $3 = ($s2 | 0) > -1; //@line 70516
 do {
  if (($d | 0) > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70521
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70525
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70530
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70533
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70537
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70542
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70546
 $14 = HEAP16[$10 >> 1] & -16 | $set_2_i & 15; //@line 70550
 HEAP16[$10 >> 1] = ($d | 0) == 0 ? $14 | 4 : $14; //@line 70554
 return;
}
function _e68_cc_set_sub_8($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = $s1 << 24 >> 24 < 0; //@line 70571
 $3 = $s2 << 24 >> 24 > -1; //@line 70572
 do {
  if ($d << 24 >> 24 > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70577
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70581
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70586
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70589
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70593
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70598
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70602
 $14 = HEAP16[$10 >> 1] & -32 | $set_2_i & 31; //@line 70606
 HEAP16[$10 >> 1] = $d << 24 >> 24 == 0 ? $14 | 4 : $14; //@line 70610
 return;
}
function _e68_cc_set_sub_16($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = $s1 << 16 >> 16 < 0; //@line 70627
 $3 = $s2 << 16 >> 16 > -1; //@line 70628
 do {
  if ($d << 16 >> 16 > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70633
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70637
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70642
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70645
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70649
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70654
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70658
 $14 = HEAP16[$10 >> 1] & -32 | $set_2_i & 31; //@line 70662
 HEAP16[$10 >> 1] = $d << 16 >> 16 == 0 ? $14 | 4 : $14; //@line 70666
 return;
}
function _e68_cc_set_sub_32($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = ($s1 | 0) < 0; //@line 70683
 $3 = ($s2 | 0) > -1; //@line 70684
 do {
  if (($d | 0) > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70689
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70693
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70698
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70701
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70705
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70710
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70714
 $14 = HEAP16[$10 >> 1] & -32 | $set_2_i & 31; //@line 70718
 HEAP16[$10 >> 1] = ($d | 0) == 0 ? $14 | 4 : $14; //@line 70722
 return;
}
function _e68_cc_set_subx_8($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = $s1 << 24 >> 24 < 0; //@line 70739
 $3 = $s2 << 24 >> 24 > -1; //@line 70740
 do {
  if ($d << 24 >> 24 > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70745
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70749
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70754
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70757
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70761
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70766
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70770
 $14 = HEAP16[$10 >> 1] & -28 | $set_2_i & 27; //@line 70774
 HEAP16[$10 >> 1] = $d << 24 >> 24 == 0 ? $14 : $14 & -5; //@line 70778
 return;
}
function _e68_cc_set_subx_16($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = $s1 << 16 >> 16 < 0; //@line 70795
 $3 = $s2 << 16 >> 16 > -1; //@line 70796
 do {
  if ($d << 16 >> 16 > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70801
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70805
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70810
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70813
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70817
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70822
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70826
 $14 = HEAP16[$10 >> 1] & -28 | $set_2_i & 27; //@line 70830
 HEAP16[$10 >> 1] = $d << 16 >> 16 == 0 ? $14 : $14 & -5; //@line 70834
 return;
}
function _e68_cc_set_subx_32($c, $d, $s1, $s2) {
 $c = $c | 0;
 $d = $d | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 var $2 = 0, $3 = 0, $set_0_i = 0, $set_1_i = 0, $set_2_i = 0, $10 = 0, $14 = 0;
 $2 = ($s1 | 0) < 0; //@line 70851
 $3 = ($s2 | 0) > -1; //@line 70852
 do {
  if (($d | 0) > -1) {
   $set_1_i = $2 & $3 ? 17 : 0; //@line 70857
   if ($2 | $3) {
    $set_2_i = $set_1_i; //@line 70861
    break;
   }
   $set_2_i = $set_1_i | 2; //@line 70866
  } else {
   $set_0_i = $2 | $3 ? 25 : 8; //@line 70869
   if (!($2 & $3)) {
    $set_2_i = $set_0_i; //@line 70873
    break;
   }
   $set_2_i = $set_0_i | 2; //@line 70878
  }
 } while (0);
 $10 = $c + 166 | 0; //@line 70882
 $14 = HEAP16[$10 >> 1] & -28 | $set_2_i & 27; //@line 70886
 HEAP16[$10 >> 1] = ($d | 0) == 0 ? $14 : $14 & -5; //@line 70890
 return;
}
function _e68_ea_000_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $_0 = 0;
 if (($mask & 1 | 0) == 0) {
  _e68_exception_illegal($c); //@line 70908
  $_0 = 1; //@line 70910
  return $_0 | 0; //@line 70913
 } else {
  HEAP32[$c + 340 >> 2] = 1; //@line 70916
  HEAP32[$c + 344 >> 2] = $ea & 7; //@line 70919
  $_0 = 0; //@line 70921
  return $_0 | 0; //@line 70924
 }
 return 0;
}
function _e68_ea_001_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $_0 = 0;
 if (($mask & 2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 70941
  $_0 = 1; //@line 70943
  return $_0 | 0; //@line 70946
 } else {
  HEAP32[$c + 340 >> 2] = 1; //@line 70949
  HEAP32[$c + 344 >> 2] = $ea & 7 | 8; //@line 70953
  $_0 = 0; //@line 70955
  return $_0 | 0; //@line 70958
 }
 return 0;
}
function _e68_ea_010_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $_0 = 0;
 if (($mask & 4 | 0) == 0) {
  _e68_exception_illegal($c); //@line 70975
  $_0 = 1; //@line 70977
  return $_0 | 0; //@line 70980
 } else {
  HEAP32[$c + 340 >> 2] = 2; //@line 70983
  HEAP32[$c + 344 >> 2] = HEAP32[$c + 120 + (($ea & 7) << 2) >> 2]; //@line 70988
  $_0 = 0; //@line 70990
  return $_0 | 0; //@line 70993
 }
 return 0;
}
function _e68_ea_011_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $7 = 0, $8 = 0, $_0 = 0;
 if (($mask & 8 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71011
  $_0 = 1; //@line 71013
  return $_0 | 0; //@line 71016
 } else {
  HEAP32[$c + 340 >> 2] = 2; //@line 71020
  $7 = $c + 120 + (($ea & 7) << 2) | 0; //@line 71021
  $8 = HEAP32[$7 >> 2] | 0; //@line 71022
  HEAP32[$c + 344 >> 2] = $8; //@line 71024
  HEAP32[$7 >> 2] = $8 + ($size >>> 3); //@line 71027
  $_0 = 0; //@line 71029
  return $_0 | 0; //@line 71032
 }
 return 0;
}
function _e68_ea_011_111($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $7 = 0, $8 = 0, $_010 = 0;
 if (($mask & 8 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71050
  $_010 = 1; //@line 71052
  return $_010 | 0; //@line 71055
 } else {
  HEAP32[$c + 340 >> 2] = 2; //@line 71059
  $7 = $c + 148 | 0; //@line 71060
  $8 = HEAP32[$7 >> 2] | 0; //@line 71061
  HEAP32[$c + 344 >> 2] = $8; //@line 71063
  HEAP32[$7 >> 2] = $8 + (($size | 0) == 8 ? 2 : $size >>> 3); //@line 71067
  $_010 = 0; //@line 71069
  return $_010 | 0; //@line 71072
 }
 return 0;
}
function _e68_ea_100_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $7 = 0, $10 = 0, $12 = 0, $_0 = 0;
 if (($mask & 16 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71090
  $_0 = 1; //@line 71092
  return $_0 | 0; //@line 71095
 } else {
  HEAP32[$c + 340 >> 2] = 2; //@line 71099
  $7 = $c + 120 + (($ea & 7) << 2) | 0; //@line 71100
  $10 = (HEAP32[$7 >> 2] | 0) - ($size >>> 3) | 0; //@line 71103
  HEAP32[$c + 344 >> 2] = $10; //@line 71105
  HEAP32[$7 >> 2] = $10; //@line 71106
  $12 = $c + 372 | 0; //@line 71107
  HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 2; //@line 71110
  $_0 = 0; //@line 71112
  return $_0 | 0; //@line 71115
 }
 return 0;
}
function _e68_ea_100_111($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $7 = 0, $10 = 0, $12 = 0, $_011 = 0;
 if (($mask & 16 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71133
  $_011 = 1; //@line 71135
  return $_011 | 0; //@line 71138
 } else {
  HEAP32[$c + 340 >> 2] = 2; //@line 71142
  $7 = $c + 148 | 0; //@line 71143
  $10 = (HEAP32[$7 >> 2] | 0) - (($size | 0) == 8 ? 2 : $size >>> 3) | 0; //@line 71147
  HEAP32[$c + 344 >> 2] = $10; //@line 71149
  HEAP32[$7 >> 2] = $10; //@line 71150
  $12 = $c + 372 | 0; //@line 71151
  HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 2; //@line 71154
  $_011 = 0; //@line 71156
  return $_011 | 0; //@line 71159
 }
 return 0;
}
function _e68_ea_101_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $5 = 0, $6 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $21 = 0, $_0_i_i = 0, $43 = 0, $51 = 0, $58 = 0, $_0 = 0;
 if (($mask & 32 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71182
  $_0 = 1; //@line 71184
  return $_0 | 0; //@line 71187
 }
 $5 = $c + 156 | 0; //@line 71189
 $6 = HEAP32[$5 >> 2] | 0; //@line 71190
 if (($6 & 1 | 0) != 0) {
  _e68_exception_address($c, $6, 0, 0); //@line 71195
  $_0 = 1; //@line 71197
  return $_0 | 0; //@line 71200
 }
 $11 = $c + 164 | 0; //@line 71202
 $13 = $c + 162 | 0; //@line 71204
 HEAP16[$13 >> 1] = HEAP16[$11 >> 1] | 0; //@line 71205
 $14 = $6 & 16777215; //@line 71206
 $15 = $14 + 1 | 0; //@line 71207
 if ($15 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $21 = HEAP32[$c + 32 >> 2] | 0; //@line 71214
  $_0_i_i = HEAPU8[$21 + $14 | 0] << 8 | HEAPU8[$21 + $15 | 0]; //@line 71224
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $14) | 0; //@line 71232
 }
 HEAP16[$11 >> 1] = $_0_i_i; //@line 71235
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 71243
  $43 = $c + 152 | 0; //@line 71244
  HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 71247
  HEAP32[$c + 340 >> 2] = 2; //@line 71249
  $51 = HEAPU16[$13 >> 1] | 0; //@line 71254
  HEAP32[$c + 344 >> 2] = (($51 & 32768 | 0) != 0 ? $51 | -65536 : $51) + (HEAP32[$c + 120 + (($ea & 7) << 2) >> 2] | 0); //@line 71261
  $58 = $c + 372 | 0; //@line 71262
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 4; //@line 71265
  $_0 = 0; //@line 71267
  return $_0 | 0; //@line 71270
 } else {
  _e68_exception_bus($c); //@line 71272
  $_0 = 1; //@line 71274
  return $_0 | 0; //@line 71277
 }
 return 0;
}
function _e68_ea_110_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $5 = 0, $6 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $21 = 0, $_0_i_i = 0, $43 = 0, $49 = 0, $50 = 0, $_pre = 0, $56 = 0, $scale_0 = 0, $64 = 0, $70 = 0, $74 = 0, $idx_0_in = 0, $idx_0 = 0, $idx_1 = 0, $91 = 0, $_0 = 0;
 if (($mask & 64 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71304
  $_0 = 1; //@line 71306
  return $_0 | 0; //@line 71309
 }
 $5 = $c + 156 | 0; //@line 71311
 $6 = HEAP32[$5 >> 2] | 0; //@line 71312
 if (($6 & 1 | 0) != 0) {
  _e68_exception_address($c, $6, 0, 0); //@line 71317
  $_0 = 1; //@line 71319
  return $_0 | 0; //@line 71322
 }
 $11 = $c + 164 | 0; //@line 71324
 $13 = $c + 162 | 0; //@line 71326
 HEAP16[$13 >> 1] = HEAP16[$11 >> 1] | 0; //@line 71327
 $14 = $6 & 16777215; //@line 71328
 $15 = $14 + 1 | 0; //@line 71329
 if ($15 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $21 = HEAP32[$c + 32 >> 2] | 0; //@line 71336
  $_0_i_i = HEAPU8[$21 + $14 | 0] << 8 | HEAPU8[$21 + $15 | 0]; //@line 71346
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $14) | 0; //@line 71354
 }
 HEAP16[$11 >> 1] = $_0_i_i; //@line 71357
 if ((HEAP8[$c + 336 | 0] | 0) != 0) {
  _e68_exception_bus($c); //@line 71363
  $_0 = 1; //@line 71365
  return $_0 | 0; //@line 71368
 }
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 71372
 $43 = $c + 152 | 0; //@line 71373
 HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 71376
 HEAP32[$c + 340 >> 2] = 2; //@line 71378
 $49 = HEAP32[$c + 120 + (($ea & 7) << 2) >> 2] | 0; //@line 71381
 $50 = $c + 344 | 0; //@line 71382
 HEAP32[$50 >> 2] = $49; //@line 71383
 $_pre = HEAP16[$13 >> 1] | 0; //@line 71388
 do {
  if ((HEAP32[$c >> 2] & 4 | 0) == 0) {
   $scale_0 = 0; //@line 71392
  } else {
   $56 = $_pre & 65535; //@line 71394
   if (($56 & 256 | 0) == 0) {
    $scale_0 = $56 >>> 9 & 3; //@line 71402
    break;
   }
   $_0 = _e68_ea_full($c, $56) | 0; //@line 71407
   return $_0 | 0; //@line 71410
  }
 } while (0);
 $64 = $_pre & 65535; //@line 71414
 $70 = (($64 & 128 | 0) != 0 ? $64 | -256 : $64 & 255) + $49 | 0; //@line 71420
 HEAP32[$50 >> 2] = $70; //@line 71421
 $74 = $64 >>> 12 & 7; //@line 71425
 if (($64 & 32768 | 0) == 0) {
  $idx_0_in = $c + 88 + ($74 << 2) | 0; //@line 71429
 } else {
  $idx_0_in = $c + 120 + ($74 << 2) | 0; //@line 71433
 }
 $idx_0 = HEAP32[$idx_0_in >> 2] | 0; //@line 71436
 if (($_pre & 2048) == 0) {
  $idx_1 = ($idx_0 & 32768 | 0) != 0 ? $idx_0 | -65536 : $idx_0 & 65535; //@line 71447
 } else {
  $idx_1 = $idx_0; //@line 71449
 }
 HEAP32[$50 >> 2] = $70 + ($idx_1 << $scale_0); //@line 71454
 $91 = $c + 372 | 0; //@line 71455
 HEAP32[$91 >> 2] = (HEAP32[$91 >> 2] | 0) + 6; //@line 71458
 $_0 = 0; //@line 71460
 return $_0 | 0; //@line 71463
}
function _e68_ea_111_000($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $5 = 0, $6 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $21 = 0, $_0_i_i = 0, $43 = 0, $48 = 0, $54 = 0, $_0 = 0;
 if (($mask & 128 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71485
  $_0 = 1; //@line 71487
  return $_0 | 0; //@line 71490
 }
 $5 = $c + 156 | 0; //@line 71492
 $6 = HEAP32[$5 >> 2] | 0; //@line 71493
 if (($6 & 1 | 0) != 0) {
  _e68_exception_address($c, $6, 0, 0); //@line 71498
  $_0 = 1; //@line 71500
  return $_0 | 0; //@line 71503
 }
 $11 = $c + 164 | 0; //@line 71505
 $13 = $c + 162 | 0; //@line 71507
 HEAP16[$13 >> 1] = HEAP16[$11 >> 1] | 0; //@line 71508
 $14 = $6 & 16777215; //@line 71509
 $15 = $14 + 1 | 0; //@line 71510
 if ($15 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $21 = HEAP32[$c + 32 >> 2] | 0; //@line 71517
  $_0_i_i = HEAPU8[$21 + $14 | 0] << 8 | HEAPU8[$21 + $15 | 0]; //@line 71527
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $14) | 0; //@line 71535
 }
 HEAP16[$11 >> 1] = $_0_i_i; //@line 71538
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 71546
  $43 = $c + 152 | 0; //@line 71547
  HEAP32[$43 >> 2] = (HEAP32[$43 >> 2] | 0) + 2; //@line 71550
  HEAP32[$c + 340 >> 2] = 2; //@line 71552
  $48 = HEAPU16[$13 >> 1] | 0; //@line 71554
  HEAP32[$c + 344 >> 2] = ($48 & 32768 | 0) != 0 ? $48 | -65536 : $48; //@line 71560
  $54 = $c + 372 | 0; //@line 71561
  HEAP32[$54 >> 2] = (HEAP32[$54 >> 2] | 0) + 4; //@line 71564
  $_0 = 0; //@line 71566
  return $_0 | 0; //@line 71569
 } else {
  _e68_exception_bus($c); //@line 71571
  $_0 = 1; //@line 71573
  return $_0 | 0; //@line 71576
 }
 return 0;
}
function _e68_ea_111_001($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $5 = 0, $6 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $21 = 0, $36 = 0, $37 = 0, $43 = 0, $44 = 0, $50 = 0, $55 = 0, $56 = 0, $60 = 0, $73 = 0, $phitmp = 0, $85 = 0, $_0 = 0;
 if (($mask & 256 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71602
  $_0 = 1; //@line 71604
  return $_0 | 0; //@line 71607
 }
 $5 = $c + 156 | 0; //@line 71609
 $6 = HEAP32[$5 >> 2] | 0; //@line 71610
 if (($6 & 1 | 0) != 0) {
  _e68_exception_address($c, $6, 0, 0); //@line 71615
  $_0 = 1; //@line 71617
  return $_0 | 0; //@line 71620
 }
 $11 = $c + 164 | 0; //@line 71622
 $13 = $c + 162 | 0; //@line 71624
 HEAP16[$13 >> 1] = HEAP16[$11 >> 1] | 0; //@line 71625
 $14 = $6 & 16777215; //@line 71626
 $15 = $14 + 1 | 0; //@line 71627
 $16 = $c + 36 | 0; //@line 71628
 if ($15 >>> 0 < (HEAP32[$16 >> 2] | 0) >>> 0) {
  $21 = HEAP32[$c + 32 >> 2] | 0; //@line 71634
  $36 = HEAPU8[$21 + $14 | 0] << 8 | HEAPU8[$21 + $15 | 0]; //@line 71644
 } else {
  $36 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $14) | 0; //@line 71652
 }
 HEAP16[$11 >> 1] = $36; //@line 71655
 $37 = $c + 336 | 0; //@line 71656
 if ((HEAP8[$37] | 0) != 0) {
  _e68_exception_bus($c); //@line 71661
  $_0 = 1; //@line 71663
  return $_0 | 0; //@line 71666
 }
 $43 = (HEAP32[$5 >> 2] | 0) + 2 | 0; //@line 71669
 HEAP32[$5 >> 2] = $43; //@line 71670
 $44 = $c + 152 | 0; //@line 71671
 HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 71674
 HEAP32[$c + 340 >> 2] = 2; //@line 71676
 $50 = $c + 344 | 0; //@line 71679
 HEAP32[$50 >> 2] = HEAPU16[$13 >> 1] | 0; //@line 71680
 if (($43 & 1 | 0) != 0) {
  _e68_exception_address($c, $43, 0, 0); //@line 71685
  $_0 = 1; //@line 71687
  return $_0 | 0; //@line 71690
 }
 HEAP16[$13 >> 1] = $36; //@line 71692
 $55 = $43 & 16777215; //@line 71693
 $56 = $55 + 1 | 0; //@line 71694
 do {
  if ($56 >>> 0 < (HEAP32[$16 >> 2] | 0) >>> 0) {
   $60 = HEAP32[$c + 32 >> 2] | 0; //@line 71701
   HEAP16[$11 >> 1] = HEAPU8[$60 + $55 | 0] << 8 | HEAPU8[$60 + $56 | 0]; //@line 71710
  } else {
   $73 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $55) | 0; //@line 71717
   $phitmp = (HEAP8[$37] | 0) == 0; //@line 71719
   HEAP16[$11 >> 1] = $73; //@line 71720
   if ($phitmp) {
    break;
   }
   _e68_exception_bus($c); //@line 71725
   $_0 = 1; //@line 71727
   return $_0 | 0; //@line 71730
  }
 } while (0);
 HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 71735
 HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 71738
 HEAP32[$50 >> 2] = HEAPU16[$13 >> 1] | HEAP32[$50 >> 2] << 16; //@line 71744
 $85 = $c + 372 | 0; //@line 71745
 HEAP32[$85 >> 2] = (HEAP32[$85 >> 2] | 0) + 8; //@line 71748
 $_0 = 0; //@line 71750
 return $_0 | 0; //@line 71753
}
function _e68_ea_111_010($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $6 = 0, $7 = 0, $9 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $24 = 0, $_0_i_i = 0, $46 = 0, $50 = 0, $57 = 0, $_0 = 0;
 if (($mask & 512 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71775
  $_0 = 1; //@line 71777
  return $_0 | 0; //@line 71780
 }
 HEAP32[$c + 340 >> 2] = 2; //@line 71783
 $6 = $c + 156 | 0; //@line 71784
 $7 = HEAP32[$6 >> 2] | 0; //@line 71785
 $9 = $c + 344 | 0; //@line 71787
 HEAP32[$9 >> 2] = $7 - 2; //@line 71788
 if (($7 & 1 | 0) != 0) {
  _e68_exception_address($c, $7, 0, 0); //@line 71793
  $_0 = 1; //@line 71795
  return $_0 | 0; //@line 71798
 }
 $14 = $c + 164 | 0; //@line 71800
 $16 = $c + 162 | 0; //@line 71802
 HEAP16[$16 >> 1] = HEAP16[$14 >> 1] | 0; //@line 71803
 $17 = $7 & 16777215; //@line 71804
 $18 = $17 + 1 | 0; //@line 71805
 if ($18 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $24 = HEAP32[$c + 32 >> 2] | 0; //@line 71812
  $_0_i_i = HEAPU8[$24 + $17 | 0] << 8 | HEAPU8[$24 + $18 | 0]; //@line 71822
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $17) | 0; //@line 71830
 }
 HEAP16[$14 >> 1] = $_0_i_i; //@line 71833
 if ((HEAP8[$c + 336 | 0] | 0) == 0) {
  HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 71841
  $46 = $c + 152 | 0; //@line 71842
  HEAP32[$46 >> 2] = (HEAP32[$46 >> 2] | 0) + 2; //@line 71845
  $50 = HEAPU16[$16 >> 1] | 0; //@line 71847
  HEAP32[$9 >> 2] = (($50 & 32768 | 0) != 0 ? $50 | -65536 : $50) + (HEAP32[$9 >> 2] | 0); //@line 71854
  $57 = $c + 372 | 0; //@line 71855
  HEAP32[$57 >> 2] = (HEAP32[$57 >> 2] | 0) + 4; //@line 71858
  $_0 = 0; //@line 71860
  return $_0 | 0; //@line 71863
 } else {
  _e68_exception_bus($c); //@line 71865
  $_0 = 1; //@line 71867
  return $_0 | 0; //@line 71870
 }
 return 0;
}
function _e68_ea_111_011($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $6 = 0, $7 = 0, $9 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $24 = 0, $_0_i_i = 0, $46 = 0, $_pre = 0, $54 = 0, $scale_0 = 0, $62 = 0, $69 = 0, $73 = 0, $idx_0_in = 0, $idx_0 = 0, $idx_1 = 0, $90 = 0, $_0 = 0;
 if (($mask & 1024 | 0) == 0) {
  _e68_exception_illegal($c); //@line 71897
  $_0 = 1; //@line 71899
  return $_0 | 0; //@line 71902
 }
 HEAP32[$c + 340 >> 2] = 2; //@line 71905
 $6 = $c + 156 | 0; //@line 71906
 $7 = HEAP32[$6 >> 2] | 0; //@line 71907
 $9 = $c + 344 | 0; //@line 71909
 HEAP32[$9 >> 2] = $7 - 2; //@line 71910
 if (($7 & 1 | 0) != 0) {
  _e68_exception_address($c, $7, 0, 0); //@line 71915
  $_0 = 1; //@line 71917
  return $_0 | 0; //@line 71920
 }
 $14 = $c + 164 | 0; //@line 71922
 $16 = $c + 162 | 0; //@line 71924
 HEAP16[$16 >> 1] = HEAP16[$14 >> 1] | 0; //@line 71925
 $17 = $7 & 16777215; //@line 71926
 $18 = $17 + 1 | 0; //@line 71927
 if ($18 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $24 = HEAP32[$c + 32 >> 2] | 0; //@line 71934
  $_0_i_i = HEAPU8[$24 + $17 | 0] << 8 | HEAPU8[$24 + $18 | 0]; //@line 71944
 } else {
  $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $17) | 0; //@line 71952
 }
 HEAP16[$14 >> 1] = $_0_i_i; //@line 71955
 if ((HEAP8[$c + 336 | 0] | 0) != 0) {
  _e68_exception_bus($c); //@line 71961
  $_0 = 1; //@line 71963
  return $_0 | 0; //@line 71966
 }
 HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 2; //@line 71970
 $46 = $c + 152 | 0; //@line 71971
 HEAP32[$46 >> 2] = (HEAP32[$46 >> 2] | 0) + 2; //@line 71974
 $_pre = HEAP16[$16 >> 1] | 0; //@line 71979
 do {
  if ((HEAP32[$c >> 2] & 4 | 0) == 0) {
   $scale_0 = 0; //@line 71983
  } else {
   $54 = $_pre & 65535; //@line 71985
   if (($54 & 256 | 0) == 0) {
    $scale_0 = $54 >>> 9 & 3; //@line 71993
    break;
   }
   $_0 = _e68_ea_full($c, $54) | 0; //@line 71998
   return $_0 | 0; //@line 72001
  }
 } while (0);
 $62 = $_pre & 65535; //@line 72005
 $69 = (($62 & 128 | 0) != 0 ? $62 | -256 : $62 & 255) + (HEAP32[$9 >> 2] | 0) | 0; //@line 72012
 HEAP32[$9 >> 2] = $69; //@line 72013
 $73 = $62 >>> 12 & 7; //@line 72017
 if (($62 & 32768 | 0) == 0) {
  $idx_0_in = $c + 88 + ($73 << 2) | 0; //@line 72021
 } else {
  $idx_0_in = $c + 120 + ($73 << 2) | 0; //@line 72025
 }
 $idx_0 = HEAP32[$idx_0_in >> 2] | 0; //@line 72028
 if (($_pre & 2048) == 0) {
  $idx_1 = ($idx_0 & 32768 | 0) != 0 ? $idx_0 | -65536 : $idx_0 & 65535; //@line 72039
 } else {
  $idx_1 = $idx_0; //@line 72041
 }
 HEAP32[$9 >> 2] = $69 + ($idx_1 << $scale_0); //@line 72046
 $90 = $c + 372 | 0; //@line 72047
 HEAP32[$90 >> 2] = (HEAP32[$90 >> 2] | 0) + 6; //@line 72050
 $_0 = 0; //@line 72052
 return $_0 | 0; //@line 72055
}
function _e68_ea_111_100($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 var $5 = 0, $6 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $21 = 0, $36 = 0, $37 = 0, $43 = 0, $44 = 0, $49 = 0, $50 = 0, $56 = 0, $57 = 0, $61 = 0, $74 = 0, $phitmp = 0, $86 = 0, $90 = 0, $95 = 0, $_0 = 0;
 if (($mask & 2048 | 0) == 0) {
  _e68_exception_illegal($c); //@line 72081
  $_0 = 1; //@line 72083
  return $_0 | 0; //@line 72086
 }
 $5 = $c + 156 | 0; //@line 72088
 $6 = HEAP32[$5 >> 2] | 0; //@line 72089
 if (($6 & 1 | 0) != 0) {
  _e68_exception_address($c, $6, 0, 0); //@line 72094
  $_0 = 1; //@line 72096
  return $_0 | 0; //@line 72099
 }
 $11 = $c + 164 | 0; //@line 72101
 $13 = $c + 162 | 0; //@line 72103
 HEAP16[$13 >> 1] = HEAP16[$11 >> 1] | 0; //@line 72104
 $14 = $6 & 16777215; //@line 72105
 $15 = $14 + 1 | 0; //@line 72106
 $16 = $c + 36 | 0; //@line 72107
 if ($15 >>> 0 < (HEAP32[$16 >> 2] | 0) >>> 0) {
  $21 = HEAP32[$c + 32 >> 2] | 0; //@line 72113
  $36 = HEAPU8[$21 + $14 | 0] << 8 | HEAPU8[$21 + $15 | 0]; //@line 72123
 } else {
  $36 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $14) | 0; //@line 72131
 }
 HEAP16[$11 >> 1] = $36; //@line 72134
 $37 = $c + 336 | 0; //@line 72135
 if ((HEAP8[$37] | 0) != 0) {
  _e68_exception_bus($c); //@line 72140
  $_0 = 1; //@line 72142
  return $_0 | 0; //@line 72145
 }
 $43 = (HEAP32[$5 >> 2] | 0) + 2 | 0; //@line 72148
 HEAP32[$5 >> 2] = $43; //@line 72149
 $44 = $c + 152 | 0; //@line 72150
 HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 72153
 HEAP32[$c + 340 >> 2] = 0; //@line 72155
 $49 = HEAPU16[$13 >> 1] | 0; //@line 72157
 $50 = $c + 344 | 0; //@line 72158
 HEAP32[$50 >> 2] = $49; //@line 72159
 if (($size | 0) == 32) {
  if (($43 & 1 | 0) != 0) {
   _e68_exception_address($c, $43, 0, 0); //@line 72165
   $_0 = 1; //@line 72167
   return $_0 | 0; //@line 72170
  }
  HEAP16[$13 >> 1] = $36; //@line 72172
  $56 = $43 & 16777215; //@line 72173
  $57 = $56 + 1 | 0; //@line 72174
  do {
   if ($57 >>> 0 < (HEAP32[$16 >> 2] | 0) >>> 0) {
    $61 = HEAP32[$c + 32 >> 2] | 0; //@line 72181
    HEAP16[$11 >> 1] = HEAPU8[$61 + $56 | 0] << 8 | HEAPU8[$61 + $57 | 0]; //@line 72190
   } else {
    $74 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $56) | 0; //@line 72197
    $phitmp = (HEAP8[$37] | 0) == 0; //@line 72199
    HEAP16[$11 >> 1] = $74; //@line 72200
    if ($phitmp) {
     break;
    }
    _e68_exception_bus($c); //@line 72205
    $_0 = 1; //@line 72207
    return $_0 | 0; //@line 72210
   }
  } while (0);
  HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 2; //@line 72215
  HEAP32[$44 >> 2] = (HEAP32[$44 >> 2] | 0) + 2; //@line 72218
  HEAP32[$50 >> 2] = HEAPU16[$13 >> 1] | HEAP32[$50 >> 2] << 16; //@line 72224
  $86 = $c + 372 | 0; //@line 72225
  HEAP32[$86 >> 2] = (HEAP32[$86 >> 2] | 0) + 8; //@line 72228
  $_0 = 0; //@line 72230
  return $_0 | 0; //@line 72233
 } else if (($size | 0) == 16) {
  $90 = $c + 372 | 0; //@line 72235
  HEAP32[$90 >> 2] = (HEAP32[$90 >> 2] | 0) + 4; //@line 72238
  $_0 = 0; //@line 72240
  return $_0 | 0; //@line 72243
 } else {
  HEAP32[$50 >> 2] = $49 & 255; //@line 72246
  $95 = $c + 372 | 0; //@line 72247
  HEAP32[$95 >> 2] = (HEAP32[$95 >> 2] | 0) + 4; //@line 72250
  $_0 = 0; //@line 72251
  return $_0 | 0; //@line 72254
 }
 return 0;
}
function _e68_ea_111_xxx($c, $ea, $mask, $size) {
 $c = $c | 0;
 $ea = $ea | 0;
 $mask = $mask | 0;
 $size = $size | 0;
 _e68_exception_illegal($c); //@line 72266
 return 1; //@line 72268
}
function _e68_ea_get_val8($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $2 = 0, $9 = 0, $20 = 0, $_0_i = 0, $35 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 72283
 if (($2 | 0) == 1) {
  $9 = HEAP32[$c + 344 >> 2] | 0; //@line 72286
  if ($9 >>> 0 < 8) {
   HEAP8[$val] = HEAP32[$c + 88 + (($9 & 7) << 2) >> 2] & 255; //@line 72294
   $_0 = 0; //@line 72296
   return $_0 | 0; //@line 72299
  } else {
   _e68_exception_illegal($c); //@line 72301
   $_0 = 1; //@line 72303
   return $_0 | 0; //@line 72306
  }
 } else if (($2 | 0) == 0) {
  HEAP8[$val] = HEAP32[$c + 344 >> 2] & 255; //@line 72312
  $_0 = 0; //@line 72314
  return $_0 | 0; //@line 72317
 } else if (($2 | 0) == 2) {
  $20 = HEAP32[$c + 344 >> 2] & 16777215; //@line 72321
  if ($20 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $_0_i = HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $20 | 0] | 0; //@line 72332
  } else {
   $_0_i = FUNCTION_TABLE_iii[HEAP32[$c + 8 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $20) | 0; //@line 72340
  }
  HEAP8[$val] = $_0_i; //@line 72343
  $35 = $c + 372 | 0; //@line 72344
  HEAP32[$35 >> 2] = (HEAP32[$35 >> 2] | 0) + 4; //@line 72347
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   $_0 = 0; //@line 72353
   return $_0 | 0; //@line 72356
  }
  _e68_exception_bus($c); //@line 72358
  $_0 = 1; //@line 72360
  return $_0 | 0; //@line 72363
 } else {
  _e68_exception_illegal($c); //@line 72365
  $_0 = 1; //@line 72367
  return $_0 | 0; //@line 72370
 }
 return 0;
}
function _e68_ea_get_val16($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $2 = 0, $9 = 0, $_sink_in = 0, $24 = 0, $34 = 0, $35 = 0, $41 = 0, $_0_i = 0, $56 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 72388
 if (($2 | 0) == 0) {
  HEAP16[$val >> 1] = HEAP32[$c + 344 >> 2] & 65535; //@line 72393
  $_0 = 0; //@line 72395
  return $_0 | 0; //@line 72398
 } else if (($2 | 0) == 1) {
  $9 = HEAP32[$c + 344 >> 2] | 0; //@line 72401
  do {
   if ($9 >>> 0 < 8) {
    $_sink_in = $c + 88 + (($9 & 7) << 2) | 0; //@line 72409
   } else {
    if ($9 >>> 0 < 16) {
     $_sink_in = $c + 120 + (($9 & 7) << 2) | 0; //@line 72416
     break;
    }
    _e68_exception_illegal($c); //@line 72419
    $_0 = 1; //@line 72421
    return $_0 | 0; //@line 72424
   }
  } while (0);
  HEAP16[$val >> 1] = HEAP32[$_sink_in >> 2] & 65535; //@line 72430
  $_0 = 0; //@line 72432
  return $_0 | 0; //@line 72435
 } else if (($2 | 0) == 2) {
  $24 = HEAP32[$c + 344 >> 2] | 0; //@line 72438
  do {
   if (($24 & 1 | 0) != 0) {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     break;
    }
    _e68_exception_address($c, $24, 1, 0); //@line 72452
    $_0 = 1; //@line 72454
    return $_0 | 0; //@line 72457
   }
  } while (0);
  $34 = $24 & 16777215; //@line 72460
  $35 = $34 + 1 | 0; //@line 72461
  if ($35 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $41 = HEAP32[$c + 32 >> 2] | 0; //@line 72468
   $_0_i = HEAPU8[$41 + $34 | 0] << 8 | HEAPU8[$41 + $35 | 0]; //@line 72478
  } else {
   $_0_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $34) | 0; //@line 72486
  }
  HEAP16[$val >> 1] = $_0_i; //@line 72489
  $56 = $c + 372 | 0; //@line 72490
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 4; //@line 72493
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   $_0 = 0; //@line 72499
   return $_0 | 0; //@line 72502
  }
  _e68_exception_bus($c); //@line 72504
  $_0 = 1; //@line 72506
  return $_0 | 0; //@line 72509
 } else {
  _e68_exception_illegal($c); //@line 72511
  $_0 = 1; //@line 72513
  return $_0 | 0; //@line 72516
 }
 return 0;
}
function _e68_ea_get_val32($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $2 = 0, $8 = 0, $storemerge_in = 0, $22 = 0, $32 = 0, $33 = 0, $39 = 0, $_0_i = 0, $66 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 72535
 if (($2 | 0) == 2) {
  $22 = HEAP32[$c + 344 >> 2] | 0; //@line 72538
  do {
   if (($22 & 1 | 0) != 0) {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     break;
    }
    _e68_exception_address($c, $22, 1, 0); //@line 72552
    $_0 = 1; //@line 72554
    return $_0 | 0; //@line 72557
   }
  } while (0);
  $32 = $22 & 16777215; //@line 72560
  $33 = $32 + 3 | 0; //@line 72561
  if ($33 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $39 = HEAP32[$c + 32 >> 2] | 0; //@line 72568
   $_0_i = ((HEAPU8[$39 + $32 | 0] << 8 | HEAPU8[$39 + ($32 + 1) | 0]) << 8 | HEAPU8[$39 + ($32 + 2) | 0]) << 8 | HEAPU8[$39 + $33 | 0]; //@line 72590
  } else {
   $_0_i = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $32) | 0; //@line 72598
  }
  HEAP32[$val >> 2] = $_0_i; //@line 72601
  $66 = $c + 372 | 0; //@line 72602
  HEAP32[$66 >> 2] = (HEAP32[$66 >> 2] | 0) + 8; //@line 72605
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   $_0 = 0; //@line 72611
   return $_0 | 0; //@line 72614
  }
  _e68_exception_bus($c); //@line 72616
  $_0 = 1; //@line 72618
  return $_0 | 0; //@line 72621
 } else if (($2 | 0) == 0) {
  HEAP32[$val >> 2] = HEAP32[$c + 344 >> 2]; //@line 72625
  $_0 = 0; //@line 72627
  return $_0 | 0; //@line 72630
 } else if (($2 | 0) == 1) {
  $8 = HEAP32[$c + 344 >> 2] | 0; //@line 72633
  do {
   if ($8 >>> 0 < 8) {
    $storemerge_in = $c + 88 + (($8 & 7) << 2) | 0; //@line 72641
   } else {
    if ($8 >>> 0 < 16) {
     $storemerge_in = $c + 120 + (($8 & 7) << 2) | 0; //@line 72648
     break;
    }
    _e68_exception_illegal($c); //@line 72651
    $_0 = 1; //@line 72653
    return $_0 | 0; //@line 72656
   }
  } while (0);
  HEAP32[$val >> 2] = HEAP32[$storemerge_in >> 2]; //@line 72661
  $_0 = 0; //@line 72663
  return $_0 | 0; //@line 72666
 } else {
  _e68_exception_illegal($c); //@line 72668
  $_0 = 1; //@line 72670
  return $_0 | 0; //@line 72673
 }
 return 0;
}
function _e68_ea_set_val8($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $2 = 0, $6 = 0, $10 = 0, $19 = 0, $32 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 72688
 if (($2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 72690
  $_0 = 1; //@line 72692
  return $_0 | 0; //@line 72695
 } else if (($2 | 0) == 2) {
  $19 = HEAP32[$c + 344 >> 2] & 16777215; //@line 72699
  if ($19 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   HEAP8[(HEAP32[$c + 32 >> 2] | 0) + $19 | 0] = $val; //@line 72708
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 20 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $19, $val); //@line 72715
  }
  $32 = $c + 372 | 0; //@line 72717
  HEAP32[$32 >> 2] = (HEAP32[$32 >> 2] | 0) + 4; //@line 72720
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   $_0 = 0; //@line 72726
   return $_0 | 0; //@line 72729
  }
  _e68_exception_bus($c); //@line 72731
  $_0 = 1; //@line 72733
  return $_0 | 0; //@line 72736
 } else if (($2 | 0) == 1) {
  $6 = HEAP32[$c + 344 >> 2] | 0; //@line 72739
  if ($6 >>> 0 < 8) {
   $10 = $c + 88 + (($6 & 7) << 2) | 0; //@line 72744
   HEAP32[$10 >> 2] = HEAP32[$10 >> 2] & -256 | $val & 255; //@line 72749
   $_0 = 0; //@line 72751
   return $_0 | 0; //@line 72754
  } else {
   _e68_exception_illegal($c); //@line 72756
   $_0 = 1; //@line 72758
   return $_0 | 0; //@line 72761
  }
 } else {
  _e68_exception_illegal($c); //@line 72764
  $_0 = 1; //@line 72766
  return $_0 | 0; //@line 72769
 }
 return 0;
}
function _e68_ea_set_val16($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $2 = 0, $6 = 0, $10 = 0, $19 = 0, $27 = 0, $37 = 0, $38 = 0, $45 = 0, $56 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 72787
 if (($2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 72789
  $_0 = 1; //@line 72791
  return $_0 | 0; //@line 72794
 } else if (($2 | 0) == 1) {
  $6 = HEAP32[$c + 344 >> 2] | 0; //@line 72797
  if ($6 >>> 0 < 8) {
   $10 = $c + 88 + (($6 & 7) << 2) | 0; //@line 72802
   HEAP32[$10 >> 2] = HEAP32[$10 >> 2] & -65536 | $val & 65535; //@line 72807
   $_0 = 0; //@line 72809
   return $_0 | 0; //@line 72812
  }
  if ($6 >>> 0 < 16) {
   $19 = $val & 65535; //@line 72818
   HEAP32[$c + 120 + (($6 & 7) << 2) >> 2] = ($19 & 32768 | 0) == 0 ? $19 : $19 | -65536; //@line 72824
   $_0 = 0; //@line 72825
   return $_0 | 0; //@line 72828
  } else {
   _e68_exception_illegal($c); //@line 72830
   $_0 = 1; //@line 72832
   return $_0 | 0; //@line 72835
  }
 } else if (($2 | 0) == 2) {
  $27 = HEAP32[$c + 344 >> 2] | 0; //@line 72839
  do {
   if (($27 & 1 | 0) != 0) {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     break;
    }
    _e68_exception_address($c, $27, 1, 1); //@line 72853
    $_0 = 1; //@line 72855
    return $_0 | 0; //@line 72858
   }
  } while (0);
  $37 = $27 & 16777215; //@line 72861
  $38 = $37 + 1 | 0; //@line 72862
  if ($38 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $45 = $c + 32 | 0; //@line 72870
   HEAP8[(HEAP32[$45 >> 2] | 0) + $37 | 0] = ($val & 65535) >>> 8 & 255; //@line 72873
   HEAP8[(HEAP32[$45 >> 2] | 0) + $38 | 0] = $val & 255; //@line 72877
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 24 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $37, $val); //@line 72884
  }
  $56 = $c + 372 | 0; //@line 72886
  HEAP32[$56 >> 2] = (HEAP32[$56 >> 2] | 0) + 4; //@line 72889
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   $_0 = 0; //@line 72895
   return $_0 | 0; //@line 72898
  }
  _e68_exception_bus($c); //@line 72900
  $_0 = 1; //@line 72902
  return $_0 | 0; //@line 72905
 } else {
  _e68_exception_illegal($c); //@line 72907
  $_0 = 1; //@line 72909
  return $_0 | 0; //@line 72912
 }
 return 0;
}
function _e68_ea_set_val32($c, $val) {
 $c = $c | 0;
 $val = $val | 0;
 var $2 = 0, $6 = 0, $19 = 0, $29 = 0, $30 = 0, $37 = 0, $58 = 0, $_0 = 0;
 $2 = HEAP32[$c + 340 >> 2] | 0; //@line 72930
 if (($2 | 0) == 0) {
  _e68_exception_illegal($c); //@line 72932
  $_0 = 1; //@line 72934
  return $_0 | 0; //@line 72937
 } else if (($2 | 0) == 1) {
  $6 = HEAP32[$c + 344 >> 2] | 0; //@line 72940
  if ($6 >>> 0 < 8) {
   HEAP32[$c + 88 + (($6 & 7) << 2) >> 2] = $val; //@line 72946
   $_0 = 0; //@line 72948
   return $_0 | 0; //@line 72951
  }
  if ($6 >>> 0 < 16) {
   HEAP32[$c + 120 + (($6 & 7) << 2) >> 2] = $val; //@line 72958
   $_0 = 0; //@line 72959
   return $_0 | 0; //@line 72962
  } else {
   _e68_exception_illegal($c); //@line 72964
   $_0 = 1; //@line 72966
   return $_0 | 0; //@line 72969
  }
 } else if (($2 | 0) == 2) {
  $19 = HEAP32[$c + 344 >> 2] | 0; //@line 72973
  do {
   if (($19 & 1 | 0) != 0) {
    if ((HEAP32[$c >> 2] & 1 | 0) != 0) {
     break;
    }
    _e68_exception_address($c, $19, 1, 1); //@line 72987
    $_0 = 1; //@line 72989
    return $_0 | 0; //@line 72992
   }
  } while (0);
  $29 = $19 & 16777215; //@line 72995
  $30 = $29 + 3 | 0; //@line 72996
  if ($30 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $37 = $c + 32 | 0; //@line 73004
   HEAP8[(HEAP32[$37 >> 2] | 0) + $29 | 0] = $val >>> 24 & 255; //@line 73007
   HEAP8[(HEAP32[$37 >> 2] | 0) + ($29 + 1) | 0] = $val >>> 16 & 255; //@line 73013
   HEAP8[(HEAP32[$37 >> 2] | 0) + ($29 + 2) | 0] = $val >>> 8 & 255; //@line 73019
   HEAP8[(HEAP32[$37 >> 2] | 0) + $30 | 0] = $val & 255; //@line 73023
  } else {
   FUNCTION_TABLE_viii[HEAP32[$c + 28 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $29, $val); //@line 73030
  }
  $58 = $c + 372 | 0; //@line 73032
  HEAP32[$58 >> 2] = (HEAP32[$58 >> 2] | 0) + 8; //@line 73035
  if ((HEAP8[$c + 336 | 0] | 0) == 0) {
   $_0 = 0; //@line 73041
   return $_0 | 0; //@line 73044
  }
  _e68_exception_bus($c); //@line 73046
  $_0 = 1; //@line 73048
  return $_0 | 0; //@line 73051
 } else {
  _e68_exception_illegal($c); //@line 73053
  $_0 = 1; //@line 73055
  return $_0 | 0; //@line 73058
 }
 return 0;
}
function _e6522_set_ora_fct($via, $ext, $fct) {
 $via = $via | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$via + 36 >> 2] = $ext; //@line 73071
 HEAP32[$via + 40 >> 2] = $fct; //@line 73074
 return;
}
function _e6522_set_orb_fct($via, $ext, $fct) {
 $via = $via | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$via + 48 >> 2] = $ext; //@line 73088
 HEAP32[$via + 52 >> 2] = $fct; //@line 73091
 return;
}
function _e6522_set_cb2_fct($via, $ext, $fct) {
 $via = $via | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$via + 60 >> 2] = $ext; //@line 73105
 HEAP32[$via + 64 >> 2] = $fct; //@line 73108
 return;
}
function _e6522_set_shift_out_fct($via, $ext, $fct) {
 $via = $via | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$via + 72 >> 2] = $ext; //@line 73122
 HEAP32[$via + 76 >> 2] = $fct; //@line 73125
 return;
}
function _e6522_set_irq_fct($via, $ext, $fct) {
 $via = $via | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$via + 80 >> 2] = $ext; //@line 73139
 HEAP32[$via + 84 >> 2] = $fct; //@line 73142
 return;
}
function _e68_ea_full($c, $ext) {
 $c = $c | 0;
 $ext = $ext | 0;
 var $4 = 0, $9 = 0, $14 = 0, $ix_0_in = 0, $ix_0 = 0, $ix_1 = 0, $30 = 0, $33 = 0, $34 = 0, $39 = 0, $41 = 0, $42 = 0, $43 = 0, $49 = 0, $_0_i_i = 0, $71 = 0, $75 = 0, $81 = 0, $82 = 0, $87 = 0, $89 = 0, $90 = 0, $91 = 0, $92 = 0, $97 = 0, $112 = 0, $113 = 0, $119 = 0, $120 = 0, $123 = 0, $128 = 0, $129 = 0, $133 = 0, $146 = 0, $phitmp25 = 0, $bd_0 = 0, $164 = 0, $168 = 0, $171 = 0, $172 = 0, $177 = 0, $179 = 0, $180 = 0, $181 = 0, $187 = 0, $_0_i_i10 = 0, $209 = 0, $213 = 0, $219 = 0, $220 = 0, $225 = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $235 = 0, $250 = 0, $251 = 0, $257 = 0, $258 = 0, $261 = 0, $266 = 0, $267 = 0, $271 = 0, $284 = 0, $phitmp = 0, $od_0 = 0, $302 = 0, $305 = 0, $306 = 0, $312 = 0, $_0_i22 = 0, $343 = 0, $348 = 0, $349 = 0, $355 = 0, $_0_i = 0, $_0 = 0;
 $4 = ($ext & 64 | 0) != 0; //@line 73199
 if (($ext & 128 | 0) != 0) {
  HEAP32[$c + 344 >> 2] = 0; //@line 73203
 }
 $9 = $ext >>> 9 & 3; //@line 73207
 do {
  if ($4) {
   $ix_1 = 0; //@line 73211
  } else {
   $14 = $ext >>> 12 & 7; //@line 73216
   if (($ext & 32768 | 0) == 0) {
    $ix_0_in = $c + 88 + ($14 << 2) | 0; //@line 73220
   } else {
    $ix_0_in = $c + 120 + ($14 << 2) | 0; //@line 73224
   }
   $ix_0 = HEAP32[$ix_0_in >> 2] | 0; //@line 73227
   if (($ext & 2048 | 0) != 0) {
    $ix_1 = $ix_0; //@line 73232
    break;
   }
   $ix_1 = ($ix_0 & 32768 | 0) != 0 ? $ix_0 | -65536 : $ix_0 & 65535; //@line 73241
  }
 } while (0);
 $30 = $ext >>> 4 & 3; //@line 73246
 do {
  if (($30 | 0) == 0) {
   _e68_exception_illegal($c); //@line 73249
   $_0 = 1; //@line 73251
   return $_0 | 0; //@line 73254
  } else if (($30 | 0) == 2) {
   $33 = $c + 156 | 0; //@line 73256
   $34 = HEAP32[$33 >> 2] | 0; //@line 73257
   if (($34 & 1 | 0) != 0) {
    _e68_exception_address($c, $34, 0, 0); //@line 73262
    $_0 = 1; //@line 73264
    return $_0 | 0; //@line 73267
   }
   $39 = $c + 164 | 0; //@line 73269
   $41 = $c + 162 | 0; //@line 73271
   HEAP16[$41 >> 1] = HEAP16[$39 >> 1] | 0; //@line 73272
   $42 = $34 & 16777215; //@line 73273
   $43 = $42 + 1 | 0; //@line 73274
   if ($43 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $49 = HEAP32[$c + 32 >> 2] | 0; //@line 73281
    $_0_i_i = HEAPU8[$49 + $42 | 0] << 8 | HEAPU8[$49 + $43 | 0]; //@line 73291
   } else {
    $_0_i_i = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $42) | 0; //@line 73299
   }
   HEAP16[$39 >> 1] = $_0_i_i; //@line 73302
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$33 >> 2] = (HEAP32[$33 >> 2] | 0) + 2; //@line 73310
    $71 = $c + 152 | 0; //@line 73311
    HEAP32[$71 >> 2] = (HEAP32[$71 >> 2] | 0) + 2; //@line 73314
    $75 = HEAPU16[$41 >> 1] | 0; //@line 73316
    $bd_0 = ($75 & 32768 | 0) != 0 ? $75 | -65536 : $75; //@line 73322
    break;
   }
   _e68_exception_bus($c); //@line 73325
   $_0 = 1; //@line 73327
   return $_0 | 0; //@line 73330
  } else if (($30 | 0) == 3) {
   $81 = $c + 156 | 0; //@line 73332
   $82 = HEAP32[$81 >> 2] | 0; //@line 73333
   if (($82 & 1 | 0) != 0) {
    _e68_exception_address($c, $82, 0, 0); //@line 73338
    $_0 = 1; //@line 73340
    return $_0 | 0; //@line 73343
   }
   $87 = $c + 164 | 0; //@line 73345
   $89 = $c + 162 | 0; //@line 73347
   HEAP16[$89 >> 1] = HEAP16[$87 >> 1] | 0; //@line 73348
   $90 = $82 & 16777215; //@line 73349
   $91 = $90 + 1 | 0; //@line 73350
   $92 = $c + 36 | 0; //@line 73351
   if ($91 >>> 0 < (HEAP32[$92 >> 2] | 0) >>> 0) {
    $97 = HEAP32[$c + 32 >> 2] | 0; //@line 73357
    $112 = HEAPU8[$97 + $90 | 0] << 8 | HEAPU8[$97 + $91 | 0]; //@line 73367
   } else {
    $112 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $90) | 0; //@line 73375
   }
   HEAP16[$87 >> 1] = $112; //@line 73378
   $113 = $c + 336 | 0; //@line 73379
   if ((HEAP8[$113] | 0) != 0) {
    _e68_exception_bus($c); //@line 73384
    $_0 = 1; //@line 73386
    return $_0 | 0; //@line 73389
   }
   $119 = (HEAP32[$81 >> 2] | 0) + 2 | 0; //@line 73392
   HEAP32[$81 >> 2] = $119; //@line 73393
   $120 = $c + 152 | 0; //@line 73394
   HEAP32[$120 >> 2] = (HEAP32[$120 >> 2] | 0) + 2; //@line 73397
   $123 = HEAP16[$89 >> 1] | 0; //@line 73398
   if (($119 & 1 | 0) != 0) {
    _e68_exception_address($c, $119, 0, 0); //@line 73403
    $_0 = 1; //@line 73405
    return $_0 | 0; //@line 73408
   }
   HEAP16[$89 >> 1] = $112; //@line 73410
   $128 = $119 & 16777215; //@line 73411
   $129 = $128 + 1 | 0; //@line 73412
   do {
    if ($129 >>> 0 < (HEAP32[$92 >> 2] | 0) >>> 0) {
     $133 = HEAP32[$c + 32 >> 2] | 0; //@line 73419
     HEAP16[$87 >> 1] = HEAPU8[$133 + $128 | 0] << 8 | HEAPU8[$133 + $129 | 0]; //@line 73428
    } else {
     $146 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $128) | 0; //@line 73435
     $phitmp25 = (HEAP8[$113] | 0) == 0; //@line 73437
     HEAP16[$87 >> 1] = $146; //@line 73438
     if ($phitmp25) {
      break;
     }
     _e68_exception_bus($c); //@line 73443
     $_0 = 1; //@line 73445
     return $_0 | 0; //@line 73448
    }
   } while (0);
   HEAP32[$81 >> 2] = (HEAP32[$81 >> 2] | 0) + 2; //@line 73453
   HEAP32[$120 >> 2] = (HEAP32[$120 >> 2] | 0) + 2; //@line 73456
   $bd_0 = HEAPU16[$89 >> 1] | ($123 & 65535) << 16; //@line 73463
  } else {
   $bd_0 = 0; //@line 73465
  }
 } while (0);
 if (($ext & 7 | 0) == 0) {
  $164 = $c + 344 | 0; //@line 73475
  HEAP32[$164 >> 2] = $bd_0 + ($ix_1 << $9) + (HEAP32[$164 >> 2] | 0); //@line 73478
  $_0 = 0; //@line 73480
  return $_0 | 0; //@line 73483
 }
 $168 = $ext & 3; //@line 73485
 do {
  if (($168 | 0) == 2) {
   $171 = $c + 156 | 0; //@line 73488
   $172 = HEAP32[$171 >> 2] | 0; //@line 73489
   if (($172 & 1 | 0) != 0) {
    _e68_exception_address($c, $172, 0, 0); //@line 73494
    $_0 = 1; //@line 73496
    return $_0 | 0; //@line 73499
   }
   $177 = $c + 164 | 0; //@line 73501
   $179 = $c + 162 | 0; //@line 73503
   HEAP16[$179 >> 1] = HEAP16[$177 >> 1] | 0; //@line 73504
   $180 = $172 & 16777215; //@line 73505
   $181 = $180 + 1 | 0; //@line 73506
   if ($181 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
    $187 = HEAP32[$c + 32 >> 2] | 0; //@line 73513
    $_0_i_i10 = HEAPU8[$187 + $180 | 0] << 8 | HEAPU8[$187 + $181 | 0]; //@line 73523
   } else {
    $_0_i_i10 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $180) | 0; //@line 73531
   }
   HEAP16[$177 >> 1] = $_0_i_i10; //@line 73534
   if ((HEAP8[$c + 336 | 0] | 0) == 0) {
    HEAP32[$171 >> 2] = (HEAP32[$171 >> 2] | 0) + 2; //@line 73542
    $209 = $c + 152 | 0; //@line 73543
    HEAP32[$209 >> 2] = (HEAP32[$209 >> 2] | 0) + 2; //@line 73546
    $213 = HEAPU16[$179 >> 1] | 0; //@line 73548
    $od_0 = ($213 & 32768 | 0) != 0 ? $213 | -65536 : $213; //@line 73554
    break;
   }
   _e68_exception_bus($c); //@line 73557
   $_0 = 1; //@line 73559
   return $_0 | 0; //@line 73562
  } else if (($168 | 0) == 3) {
   $219 = $c + 156 | 0; //@line 73564
   $220 = HEAP32[$219 >> 2] | 0; //@line 73565
   if (($220 & 1 | 0) != 0) {
    _e68_exception_address($c, $220, 0, 0); //@line 73570
    $_0 = 1; //@line 73572
    return $_0 | 0; //@line 73575
   }
   $225 = $c + 164 | 0; //@line 73577
   $227 = $c + 162 | 0; //@line 73579
   HEAP16[$227 >> 1] = HEAP16[$225 >> 1] | 0; //@line 73580
   $228 = $220 & 16777215; //@line 73581
   $229 = $228 + 1 | 0; //@line 73582
   $230 = $c + 36 | 0; //@line 73583
   if ($229 >>> 0 < (HEAP32[$230 >> 2] | 0) >>> 0) {
    $235 = HEAP32[$c + 32 >> 2] | 0; //@line 73589
    $250 = HEAPU8[$235 + $228 | 0] << 8 | HEAPU8[$235 + $229 | 0]; //@line 73599
   } else {
    $250 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $228) | 0; //@line 73607
   }
   HEAP16[$225 >> 1] = $250; //@line 73610
   $251 = $c + 336 | 0; //@line 73611
   if ((HEAP8[$251] | 0) != 0) {
    _e68_exception_bus($c); //@line 73616
    $_0 = 1; //@line 73618
    return $_0 | 0; //@line 73621
   }
   $257 = (HEAP32[$219 >> 2] | 0) + 2 | 0; //@line 73624
   HEAP32[$219 >> 2] = $257; //@line 73625
   $258 = $c + 152 | 0; //@line 73626
   HEAP32[$258 >> 2] = (HEAP32[$258 >> 2] | 0) + 2; //@line 73629
   $261 = HEAP16[$227 >> 1] | 0; //@line 73630
   if (($257 & 1 | 0) != 0) {
    _e68_exception_address($c, $257, 0, 0); //@line 73635
    $_0 = 1; //@line 73637
    return $_0 | 0; //@line 73640
   }
   HEAP16[$227 >> 1] = $250; //@line 73642
   $266 = $257 & 16777215; //@line 73643
   $267 = $266 + 1 | 0; //@line 73644
   do {
    if ($267 >>> 0 < (HEAP32[$230 >> 2] | 0) >>> 0) {
     $271 = HEAP32[$c + 32 >> 2] | 0; //@line 73651
     HEAP16[$225 >> 1] = HEAPU8[$271 + $266 | 0] << 8 | HEAPU8[$271 + $267 | 0]; //@line 73660
    } else {
     $284 = FUNCTION_TABLE_iii[HEAP32[$c + 12 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $266) | 0; //@line 73667
     $phitmp = (HEAP8[$251] | 0) == 0; //@line 73669
     HEAP16[$225 >> 1] = $284; //@line 73670
     if ($phitmp) {
      break;
     }
     _e68_exception_bus($c); //@line 73675
     $_0 = 1; //@line 73677
     return $_0 | 0; //@line 73680
    }
   } while (0);
   HEAP32[$219 >> 2] = (HEAP32[$219 >> 2] | 0) + 2; //@line 73685
   HEAP32[$258 >> 2] = (HEAP32[$258 >> 2] | 0) + 2; //@line 73688
   $od_0 = HEAPU16[$227 >> 1] | ($261 & 65535) << 16; //@line 73695
  } else if (($168 | 0) == 0) {
   _e68_exception_illegal($c); //@line 73697
   $_0 = 1; //@line 73699
   return $_0 | 0; //@line 73702
  } else {
   $od_0 = 0; //@line 73704
  }
 } while (0);
 if (($ext & 4 | 0) == 0) {
  $343 = $c + 344 | 0; //@line 73712
  $348 = $bd_0 + ($ix_1 << $9) + (HEAP32[$343 >> 2] | 0) & 16777215; //@line 73717
  $349 = $348 + 3 | 0; //@line 73718
  if ($349 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
   $355 = HEAP32[$c + 32 >> 2] | 0; //@line 73725
   $_0_i = ((HEAPU8[$355 + $348 | 0] << 8 | HEAPU8[$355 + ($348 + 1) | 0]) << 8 | HEAPU8[$355 + ($348 + 2) | 0]) << 8 | HEAPU8[$355 + $349 | 0]; //@line 73747
  } else {
   $_0_i = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $348) | 0; //@line 73755
  }
  HEAP32[$343 >> 2] = $_0_i + $od_0; //@line 73759
  $_0 = 0; //@line 73760
  return $_0 | 0; //@line 73763
 }
 if ($4) {
  _e68_exception_illegal($c); //@line 73767
  $_0 = 1; //@line 73769
  return $_0 | 0; //@line 73772
 }
 $302 = $c + 344 | 0; //@line 73774
 $305 = (HEAP32[$302 >> 2] | 0) + $bd_0 & 16777215; //@line 73777
 $306 = $305 + 3 | 0; //@line 73778
 if ($306 >>> 0 < (HEAP32[$c + 36 >> 2] | 0) >>> 0) {
  $312 = HEAP32[$c + 32 >> 2] | 0; //@line 73785
  $_0_i22 = ((HEAPU8[$312 + $305 | 0] << 8 | HEAPU8[$312 + ($305 + 1) | 0]) << 8 | HEAPU8[$312 + ($305 + 2) | 0]) << 8 | HEAPU8[$312 + $306 | 0]; //@line 73807
 } else {
  $_0_i22 = FUNCTION_TABLE_iii[HEAP32[$c + 16 >> 2] & 63](HEAP32[$c + 4 >> 2] | 0, $305) | 0; //@line 73815
 }
 HEAP32[$302 >> 2] = $od_0 + ($ix_1 << $9) + $_0_i22; //@line 73821
 $_0 = 0; //@line 73823
 return $_0 | 0; //@line 73826
}
function _e6522_init($via, $addr_shift) {
 $via = $via | 0;
 $addr_shift = $addr_shift | 0;
 HEAP32[$via >> 2] = $addr_shift; //@line 73838
 HEAP32[$via + 48 >> 2] = 0; //@line 73841
 HEAP32[$via + 52 >> 2] = 0; //@line 73843
 HEAP8[$via + 56 | 0] = 0; //@line 73845
 HEAP32[$via + 60 >> 2] = 0; //@line 73847
 HEAP32[$via + 64 >> 2] = 0; //@line 73849
 HEAP8[$via + 68 | 0] = 0; //@line 73851
 _memset($via + 4 | 0, 0, 41); //@line 73853
 _memset($via + 72 | 0, 0, 17); //@line 73855
 return;
}
function _e6522_shift_out($via) {
 $via = $via | 0;
 var $6 = 0, $8 = 0, $9 = 0, $10 = 0, $14 = 0, $17 = 0, $20 = 0, $21 = 0, $23 = 0, $__i = 0, $_0_lobit_i = 0, $29 = 0, $34 = 0, $_0 = 0;
 if ((HEAP8[$via + 12 | 0] & 28) != 28) {
  $_0 = 0; //@line 73876
  return $_0 | 0; //@line 73879
 }
 $6 = $via + 10 | 0; //@line 73881
 $8 = HEAPU8[$6] | 0; //@line 73883
 $9 = $8 >>> 7; //@line 73884
 $10 = $9 & 255; //@line 73885
 HEAP8[$6] = ($8 << 1 | $9) & 255; //@line 73889
 $14 = $via + 11 | 0; //@line 73890
 $17 = (HEAP8[$14] | 0) + 1 & 7; //@line 73893
 HEAP8[$14] = $17; //@line 73894
 if ($17 << 24 >> 24 != 0) {
  $_0 = $10; //@line 73898
  return $_0 | 0; //@line 73901
 }
 $20 = $via + 14 | 0; //@line 73903
 $21 = HEAP8[$20] | 0; //@line 73904
 $23 = $21 & 123 | 4; //@line 73906
 $__i = ($23 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $23 : $21 | -124; //@line 73912
 HEAP8[$20] = $__i; //@line 73913
 $_0_lobit_i = ($__i & 255) >>> 7; //@line 73914
 $29 = $via + 88 | 0; //@line 73915
 if ((HEAP8[$29] | 0) == $_0_lobit_i << 24 >> 24) {
  $_0 = $10; //@line 73920
  return $_0 | 0; //@line 73923
 }
 HEAP8[$29] = $_0_lobit_i; //@line 73925
 $34 = HEAP32[$via + 84 >> 2] | 0; //@line 73927
 if (($34 | 0) == 0) {
  $_0 = $10; //@line 73931
  return $_0 | 0; //@line 73934
 }
 FUNCTION_TABLE_vii[$34 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 73938
 $_0 = $10; //@line 73940
 return $_0 | 0; //@line 73943
}
function _e6522_shift_in($via, $val) {
 $via = $via | 0;
 $val = $val | 0;
 var $6 = 0, $12 = 0, $15 = 0, $17 = 0, $19 = 0, $21 = 0, $22 = 0, $__i = 0, $_0_lobit_i = 0, $27 = 0, $32 = 0, $_pre_phi17 = 0, $_pre_phi15 = 0, $37 = 0, $39 = 0, $__i11 = 0, $_0_lobit_i12 = 0, $48 = 0;
 if ((HEAP8[$via + 12 | 0] & 28) != 12) {
  return;
 }
 $6 = $via + 10 | 0; //@line 73968
 HEAP8[$6] = HEAP8[$6] << 1 | $val << 24 >> 24 != 0; //@line 73974
 $12 = $via + 11 | 0; //@line 73975
 $15 = (HEAP8[$12] | 0) + 1 & 7; //@line 73978
 HEAP8[$12] = $15; //@line 73979
 $17 = $via + 14 | 0; //@line 73981
 do {
  if ($15 << 24 >> 24 == 0) {
   $19 = HEAP8[$17] | 0; //@line 73985
   $21 = $19 & 123 | 4; //@line 73987
   $22 = $via + 15 | 0; //@line 73988
   $__i = ($21 & HEAP8[$22]) << 24 >> 24 == 0 ? $21 : $19 | -124; //@line 73993
   HEAP8[$17] = $__i; //@line 73994
   $_0_lobit_i = ($__i & 255) >>> 7; //@line 73995
   $27 = $via + 88 | 0; //@line 73996
   if ((HEAP8[$27] | 0) == $_0_lobit_i << 24 >> 24) {
    $_pre_phi15 = $22;
    $_pre_phi17 = $27;
    break;
   }
   HEAP8[$27] = $_0_lobit_i; //@line 74004
   $32 = HEAP32[$via + 84 >> 2] | 0; //@line 74006
   if (($32 | 0) == 0) {
    $_pre_phi15 = $22;
    $_pre_phi17 = $27;
    break;
   }
   FUNCTION_TABLE_vii[$32 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 74015
   $_pre_phi15 = $22;
   $_pre_phi17 = $27;
  } else {
   $_pre_phi15 = $via + 15 | 0;
   $_pre_phi17 = $via + 88 | 0;
  }
 } while (0);
 $37 = HEAP8[$17] | 0; //@line 74027
 $39 = $37 & 111 | 16; //@line 74029
 $__i11 = ($39 & HEAP8[$_pre_phi15]) << 24 >> 24 == 0 ? $39 : $37 | -112; //@line 74034
 HEAP8[$17] = $__i11; //@line 74035
 $_0_lobit_i12 = ($__i11 & 255) >>> 7; //@line 74036
 if ((HEAP8[$_pre_phi17] | 0) == $_0_lobit_i12 << 24 >> 24) {
  return;
 }
 HEAP8[$_pre_phi17] = $_0_lobit_i12; //@line 74044
 $48 = HEAP32[$via + 84 >> 2] | 0; //@line 74046
 if (($48 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$48 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i12); //@line 74055
 return;
}
function _e6522_set_ca1_inp($via, $val) {
 $via = $via | 0;
 $val = $val | 0;
 var $1 = 0, $3 = 0, $4 = 0, $15 = 0, $16 = 0, $18 = 0, $__i = 0, $_0_lobit_i = 0, $24 = 0, $29 = 0;
 $1 = $via + 32 | 0; //@line 74071
 $3 = (HEAP8[$1] | 0) != 0; //@line 74073
 $4 = $val << 24 >> 24 != 0; //@line 74074
 HEAP8[$1] = $4 & 1; //@line 74076
 if (!($3 ^ $4)) {
  return;
 }
 if (($4 & 1 | 0) != (HEAP8[$via + 13 | 0] & 1 | 0)) {
  return;
 }
 $15 = $via + 14 | 0; //@line 74094
 $16 = HEAP8[$15] | 0; //@line 74095
 $18 = $16 & 125 | 2; //@line 74097
 $__i = ($18 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $18 : $16 | -126; //@line 74103
 HEAP8[$15] = $__i; //@line 74104
 $_0_lobit_i = ($__i & 255) >>> 7; //@line 74105
 $24 = $via + 88 | 0; //@line 74106
 if ((HEAP8[$24] | 0) == $_0_lobit_i << 24 >> 24) {
  return;
 }
 HEAP8[$24] = $_0_lobit_i; //@line 74114
 $29 = HEAP32[$via + 84 >> 2] | 0; //@line 74116
 if (($29 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$29 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 74125
 return;
}
function _e6522_set_ca2_inp($via, $val) {
 $via = $via | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $3 = 0, $7 = 0, $17 = 0, $18 = 0, $20 = 0, $__i = 0, $_0_lobit_i = 0, $26 = 0, $31 = 0;
 $1 = $via + 33 | 0; //@line 74142
 $2 = HEAP8[$1] | 0; //@line 74143
 $3 = $val << 24 >> 24 != 0; //@line 74144
 HEAP8[$1] = $3 & 1; //@line 74146
 $7 = HEAPU8[$via + 13 | 0] | 0; //@line 74149
 if (($7 & 8 | 0) != 0) {
  return;
 }
 if (!($2 << 24 >> 24 != 0 ^ $3)) {
  return;
 }
 if ($3 ^ ($7 & 4 | 0) != 0) {
  return;
 }
 $17 = $via + 14 | 0; //@line 74172
 $18 = HEAP8[$17] | 0; //@line 74173
 $20 = $18 & 126 | 1; //@line 74175
 $__i = ($20 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $20 : $18 | -127; //@line 74181
 HEAP8[$17] = $__i; //@line 74182
 $_0_lobit_i = ($__i & 255) >>> 7; //@line 74183
 $26 = $via + 88 | 0; //@line 74184
 if ((HEAP8[$26] | 0) == $_0_lobit_i << 24 >> 24) {
  return;
 }
 HEAP8[$26] = $_0_lobit_i; //@line 74192
 $31 = HEAP32[$via + 84 >> 2] | 0; //@line 74194
 if (($31 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$31 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 74203
 return;
}
function _e6522_set_ira_inp($via, $val) {
 $via = $via | 0;
 $val = $val | 0;
 var $3 = 0, $5 = 0;
 HEAP8[$via + 6 | 0] = $val; //@line 74218
 $3 = HEAP8[$via + 8 | 0] | 0; //@line 74220
 $5 = HEAP32[$via + 40 >> 2] | 0; //@line 74222
 if (($5 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$5 & 511](HEAP32[$via + 36 >> 2] | 0, HEAP8[$via + 4 | 0] & $3 | ~$3 & $val); //@line 74237
 return;
}
function _e6522_set_irb_inp($via, $val) {
 $via = $via | 0;
 $val = $val | 0;
 var $3 = 0, $5 = 0;
 HEAP8[$via + 7 | 0] = $val; //@line 74252
 $3 = HEAP8[$via + 9 | 0] | 0; //@line 74254
 $5 = HEAP32[$via + 52 >> 2] | 0; //@line 74256
 if (($5 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$5 & 511](HEAP32[$via + 48 >> 2] | 0, HEAP8[$via + 5 | 0] & $3 | ~$3 & $val); //@line 74271
 return;
}
function _e6522_set_shift_inp($via, $val) {
 $via = $via | 0;
 $val = $val | 0;
 var $8 = 0, $9 = 0, $11 = 0, $__i = 0, $_0_lobit_i = 0, $17 = 0, $22 = 0;
 if ((HEAP8[$via + 12 | 0] & 28) != 12) {
  return;
 }
 HEAP8[$via + 10 | 0] = $val; //@line 74297
 HEAP8[$via + 11 | 0] = 0; //@line 74299
 $8 = $via + 14 | 0; //@line 74300
 $9 = HEAP8[$8] | 0; //@line 74301
 $11 = $9 & 123 | 4; //@line 74303
 $__i = ($11 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $11 : $9 | -124; //@line 74309
 HEAP8[$8] = $__i; //@line 74310
 $_0_lobit_i = ($__i & 255) >>> 7; //@line 74311
 $17 = $via + 88 | 0; //@line 74312
 if ((HEAP8[$17] | 0) == $_0_lobit_i << 24 >> 24) {
  return;
 }
 HEAP8[$17] = $_0_lobit_i; //@line 74320
 $22 = HEAP32[$via + 84 >> 2] | 0; //@line 74322
 if (($22 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$22 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 74331
 return;
}
function _e6522_get_uint8($via, $addr) {
 $via = $via | 0;
 $addr = $addr | 0;
 var $1 = 0, $3 = 0, $5 = 0, $__i_i25 = 0, $_0_lobit_i_i26 = 0, $11 = 0, $16 = 0, $24 = 0, $32 = 0, $34 = 0, $__i_i27 = 0, $_0_lobit_i_i28 = 0, $40 = 0, $45 = 0, $53 = 0, $67 = 0, $69 = 0, $__i_i29 = 0, $_0_lobit_i_i30 = 0, $75 = 0, $80 = 0, $97 = 0, $99 = 0, $__i_i31 = 0, $_0_lobit_i_i32 = 0, $105 = 0, $110 = 0, $122 = 0, $124 = 0, $__i_i = 0, $_0_lobit_i_i = 0, $130 = 0, $135 = 0, $156 = 0, $val_0 = 0;
 $1 = $addr >>> ((HEAP32[$via >> 2] | 0) >>> 0); //@line 74366
 if (($1 | 0) == 3) {
  $val_0 = HEAP8[$via + 8 | 0] | 0; //@line 74371
  return $val_0 | 0; //@line 74374
 } else if (($1 | 0) == 9) {
  $val_0 = (HEAPU16[$via + 26 >> 1] | 0) >>> 8 & 255; //@line 74381
  return $val_0 | 0; //@line 74384
 } else if (($1 | 0) == 6) {
  $val_0 = HEAP16[$via + 16 >> 1] & 255; //@line 74390
  return $val_0 | 0; //@line 74393
 } else if (($1 | 0) == 15) {
  $156 = HEAP8[$via + 8 | 0] | 0; //@line 74398
  $val_0 = HEAP8[$via + 6 | 0] & ~$156 | $156 & HEAP8[$via + 4 | 0]; //@line 74406
  return $val_0 | 0; //@line 74409
 } else if (($1 | 0) == 0) {
  $3 = $via + 14 | 0; //@line 74411
  $5 = HEAP8[$3] & 103; //@line 74413
  $__i_i25 = (HEAP8[$via + 15 | 0] & $5) << 24 >> 24 == 0 ? $5 : $5 | -128; //@line 74419
  HEAP8[$3] = $__i_i25; //@line 74420
  $_0_lobit_i_i26 = ($__i_i25 & 255) >>> 7; //@line 74421
  $11 = $via + 88 | 0; //@line 74422
  do {
   if ((HEAP8[$11] | 0) != $_0_lobit_i_i26 << 24 >> 24) {
    HEAP8[$11] = $_0_lobit_i_i26; //@line 74428
    $16 = HEAP32[$via + 84 >> 2] | 0; //@line 74430
    if (($16 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$16 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i26); //@line 74438
   }
  } while (0);
  $24 = HEAP8[$via + 9 | 0] | 0; //@line 74445
  $val_0 = HEAP8[$via + 7 | 0] & ~$24 | $24 & HEAP8[$via + 5 | 0]; //@line 74453
  return $val_0 | 0; //@line 74456
 } else if (($1 | 0) == 10) {
  $122 = $via + 14 | 0; //@line 74458
  $124 = HEAP8[$122] & 123; //@line 74460
  $__i_i = (HEAP8[$via + 15 | 0] & $124) << 24 >> 24 == 0 ? $124 : $124 | -128; //@line 74466
  HEAP8[$122] = $__i_i; //@line 74467
  $_0_lobit_i_i = ($__i_i & 255) >>> 7; //@line 74468
  $130 = $via + 88 | 0; //@line 74469
  do {
   if ((HEAP8[$130] | 0) != $_0_lobit_i_i << 24 >> 24) {
    HEAP8[$130] = $_0_lobit_i_i; //@line 74475
    $135 = HEAP32[$via + 84 >> 2] | 0; //@line 74477
    if (($135 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$135 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i); //@line 74485
   }
  } while (0);
  HEAP8[$via + 11 | 0] = 0; //@line 74490
  $val_0 = HEAP8[$via + 10 | 0] | 0; //@line 74494
  return $val_0 | 0; //@line 74497
 } else if (($1 | 0) == 4) {
  $67 = $via + 14 | 0; //@line 74499
  $69 = HEAP8[$67] & 63; //@line 74501
  $__i_i29 = (HEAP8[$via + 15 | 0] & $69) << 24 >> 24 == 0 ? $69 : $69 | -128; //@line 74507
  HEAP8[$67] = $__i_i29; //@line 74508
  $_0_lobit_i_i30 = ($__i_i29 & 255) >>> 7; //@line 74509
  $75 = $via + 88 | 0; //@line 74510
  do {
   if ((HEAP8[$75] | 0) != $_0_lobit_i_i30 << 24 >> 24) {
    HEAP8[$75] = $_0_lobit_i_i30; //@line 74516
    $80 = HEAP32[$via + 84 >> 2] | 0; //@line 74518
    if (($80 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$80 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i30); //@line 74526
   }
  } while (0);
  $val_0 = HEAP16[$via + 18 >> 1] & 255; //@line 74534
  return $val_0 | 0; //@line 74537
 } else if (($1 | 0) == 8) {
  $97 = $via + 14 | 0; //@line 74539
  $99 = HEAP8[$97] & 95; //@line 74541
  $__i_i31 = (HEAP8[$via + 15 | 0] & $99) << 24 >> 24 == 0 ? $99 : $99 | -128; //@line 74547
  HEAP8[$97] = $__i_i31; //@line 74548
  $_0_lobit_i_i32 = ($__i_i31 & 255) >>> 7; //@line 74549
  $105 = $via + 88 | 0; //@line 74550
  do {
   if ((HEAP8[$105] | 0) != $_0_lobit_i_i32 << 24 >> 24) {
    HEAP8[$105] = $_0_lobit_i_i32; //@line 74556
    $110 = HEAP32[$via + 84 >> 2] | 0; //@line 74558
    if (($110 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$110 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i32); //@line 74566
   }
  } while (0);
  $val_0 = HEAP16[$via + 26 >> 1] & 255; //@line 74574
  return $val_0 | 0; //@line 74577
 } else if (($1 | 0) == 2) {
  $val_0 = HEAP8[$via + 9 | 0] | 0; //@line 74582
  return $val_0 | 0; //@line 74585
 } else if (($1 | 0) == 7) {
  $val_0 = (HEAPU16[$via + 16 >> 1] | 0) >>> 8 & 255; //@line 74592
  return $val_0 | 0; //@line 74595
 } else if (($1 | 0) == 14) {
  $val_0 = HEAP8[$via + 15 | 0] | -128; //@line 74601
  return $val_0 | 0; //@line 74604
 } else if (($1 | 0) == 12) {
  $val_0 = HEAP8[$via + 13 | 0] | 0; //@line 74609
  return $val_0 | 0; //@line 74612
 } else if (($1 | 0) == 13) {
  $val_0 = HEAP8[$via + 14 | 0] | 0; //@line 74617
  return $val_0 | 0; //@line 74620
 } else if (($1 | 0) == 11) {
  $val_0 = HEAP8[$via + 12 | 0] | 0; //@line 74625
  return $val_0 | 0; //@line 74628
 } else if (($1 | 0) == 1) {
  $32 = $via + 14 | 0; //@line 74630
  $34 = HEAP8[$32] & 124; //@line 74632
  $__i_i27 = (HEAP8[$via + 15 | 0] & $34) << 24 >> 24 == 0 ? $34 : $34 | -128; //@line 74638
  HEAP8[$32] = $__i_i27; //@line 74639
  $_0_lobit_i_i28 = ($__i_i27 & 255) >>> 7; //@line 74640
  $40 = $via + 88 | 0; //@line 74641
  do {
   if ((HEAP8[$40] | 0) != $_0_lobit_i_i28 << 24 >> 24) {
    HEAP8[$40] = $_0_lobit_i_i28; //@line 74647
    $45 = HEAP32[$via + 84 >> 2] | 0; //@line 74649
    if (($45 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$45 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i28); //@line 74657
   }
  } while (0);
  $53 = HEAP8[$via + 8 | 0] | 0; //@line 74664
  $val_0 = HEAP8[$via + 6 | 0] & ~$53 | $53 & HEAP8[$via + 4 | 0]; //@line 74672
  return $val_0 | 0; //@line 74675
 } else if (($1 | 0) == 5) {
  $val_0 = (HEAPU16[$via + 18 >> 1] | 0) >>> 8 & 255; //@line 74682
  return $val_0 | 0; //@line 74685
 } else {
  $val_0 = -86; //@line 74687
  return $val_0 | 0; //@line 74690
 }
 return 0;
}
function _e6522_get_uint16($via, $addr) {
 $via = $via | 0;
 $addr = $addr | 0;
 return (_e6522_get_uint8($via, $addr) | 0) & 255 | 0; //@line 74704
}
function _e6522_get_uint32($via, $addr) {
 $via = $via | 0;
 $addr = $addr | 0;
 return (_e6522_get_uint8($via, $addr) | 0) & 255 | 0; //@line 74717
}
function _e6522_set_uint8($via, $addr, $val) {
 $via = $via | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $1 = 0, $5 = 0, $7 = 0, $18 = 0, $20 = 0, $__i_i36 = 0, $_0_lobit_i_i37 = 0, $26 = 0, $31 = 0, $39 = 0, $41 = 0, $52 = 0, $54 = 0, $__i_i38 = 0, $_0_lobit_i_i39 = 0, $60 = 0, $65 = 0, $73 = 0, $89 = 0, $103 = 0, $109 = 0, $114 = 0, $123 = 0, $125 = 0, $__i_i44 = 0, $_0_lobit_i_i45 = 0, $131 = 0, $136 = 0, $142 = 0, $148 = 0, $155 = 0, $161 = 0, $166 = 0, $175 = 0, $177 = 0, $__i_i48 = 0, $_0_lobit_i_i49 = 0, $183 = 0, $188 = 0, $194 = 0, $196 = 0, $197 = 0, $__i_i50 = 0, $_0_lobit_i_i51 = 0, $202 = 0, $207 = 0, $220 = 0, $224 = 0, $226 = 0, $__i11_i = 0, $_0_lobit_i12_i = 0, $235 = 0, $247 = 0, $val_0_i_i = 0, $262 = 0, $267 = 0, $276 = 0, $val_0_i_i55 = 0, $289 = 0, $294 = 0, $300 = 0, $303 = 0, $304 = 0, $__i = 0, $_0_lobit_i = 0, $310 = 0, $315 = 0, $322 = 0, $324 = 0, $326 = 0, $329 = 0, $331 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $__i_i46 = 0, $_0_lobit_i_i47 = 0, $340 = 0, $345 = 0, $353 = 0, $355 = 0, $366 = 0, $368 = 0, $__i_i = 0, $_0_lobit_i_i = 0, $374 = 0, $379 = 0;
 $1 = $addr >>> ((HEAP32[$via >> 2] | 0) >>> 0); //@line 74773
 if (($1 | 0) == 3) {
  HEAP8[$via + 8 | 0] = $val; //@line 74776
  $89 = HEAP32[$via + 40 >> 2] | 0; //@line 74778
  if (($89 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$89 & 511](HEAP32[$via + 36 >> 2] | 0, HEAP8[$via + 6 | 0] & ~$val | HEAP8[$via + 4 | 0] & $val); //@line 74795
  return;
 } else if (($1 | 0) == 10) {
  $194 = $via + 14 | 0; //@line 74800
  $196 = HEAP8[$194] & 123; //@line 74802
  $197 = $via + 15 | 0; //@line 74803
  $__i_i50 = (HEAP8[$197] & $196) << 24 >> 24 == 0 ? $196 : $196 | -128; //@line 74808
  HEAP8[$194] = $__i_i50; //@line 74809
  $_0_lobit_i_i51 = ($__i_i50 & 255) >>> 7; //@line 74810
  $202 = $via + 88 | 0; //@line 74811
  do {
   if ((HEAP8[$202] | 0) != $_0_lobit_i_i51 << 24 >> 24) {
    HEAP8[$202] = $_0_lobit_i_i51; //@line 74817
    $207 = HEAP32[$via + 84 >> 2] | 0; //@line 74819
    if (($207 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$207 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i51); //@line 74827
   }
  } while (0);
  HEAP8[$via + 10 | 0] = $val; //@line 74832
  HEAP8[$via + 11 | 0] = 0; //@line 74834
  if ((HEAP8[$via + 12 | 0] & 28) != 28) {
   return;
  }
  $220 = HEAP32[$via + 76 >> 2] | 0; //@line 74845
  if (($220 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$220 & 511](HEAP32[$via + 72 >> 2] | 0, $val); //@line 74854
  $224 = HEAP8[$194] | 0; //@line 74855
  $226 = $224 & 123 | 4; //@line 74857
  $__i11_i = ($226 & HEAP8[$197]) << 24 >> 24 == 0 ? $226 : $224 | -124; //@line 74862
  HEAP8[$194] = $__i11_i; //@line 74863
  $_0_lobit_i12_i = ($__i11_i & 255) >>> 7; //@line 74864
  if ((HEAP8[$202] | 0) == $_0_lobit_i12_i << 24 >> 24) {
   return;
  }
  HEAP8[$202] = $_0_lobit_i12_i; //@line 74872
  $235 = HEAP32[$via + 84 >> 2] | 0; //@line 74874
  if (($235 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$235 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i12_i); //@line 74883
  return;
 } else if (($1 | 0) == 5) {
  $109 = $via + 16 | 0; //@line 74888
  $114 = HEAP16[$109 >> 1] & 255 | ($val & 255) << 8; //@line 74893
  HEAP16[$109 >> 1] = $114; //@line 74894
  HEAP16[$via + 18 >> 1] = $114; //@line 74896
  if ((HEAP8[$via + 12 | 0] & 64) == 0) {
   HEAP32[$via + 20 >> 2] = 1; //@line 74904
  }
  $123 = $via + 14 | 0; //@line 74907
  $125 = HEAP8[$123] & 63; //@line 74909
  $__i_i44 = (HEAP8[$via + 15 | 0] & $125) << 24 >> 24 == 0 ? $125 : $125 | -128; //@line 74915
  HEAP8[$123] = $__i_i44; //@line 74916
  $_0_lobit_i_i45 = ($__i_i44 & 255) >>> 7; //@line 74917
  $131 = $via + 88 | 0; //@line 74918
  if ((HEAP8[$131] | 0) == $_0_lobit_i_i45 << 24 >> 24) {
   return;
  }
  HEAP8[$131] = $_0_lobit_i_i45; //@line 74926
  $136 = HEAP32[$via + 84 >> 2] | 0; //@line 74928
  if (($136 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$136 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i45); //@line 74937
  return;
 } else if (($1 | 0) == 11) {
  HEAP8[$via + 12 | 0] = $val; //@line 74943
  if (($val & 28) == 0) {
   HEAP8[$via + 11 | 0] = 0; //@line 74949
  }
  $247 = $val & 255; //@line 74952
  do {
   if (($247 & 28 | 0) == 0) {
    $val_0_i_i = (HEAP8[$via + 13 | 0] & -32) << 24 >> 24 != -64 | 0; //@line 74964
   } else {
    if (($247 & 16 | 0) == 0) {
     $val_0_i_i = 1; //@line 74970
     break;
    }
    $val_0_i_i = HEAP8[$via + 10 | 0] & 1; //@line 74977
   }
  } while (0);
  $262 = $via + 68 | 0; //@line 74981
  if ($val_0_i_i << 24 >> 24 == (HEAP8[$262] | 0)) {
   return;
  }
  HEAP8[$262] = $val_0_i_i; //@line 74989
  $267 = HEAP32[$via + 64 >> 2] | 0; //@line 74991
  if (($267 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$267 & 511](HEAP32[$via + 60 >> 2] | 0, $val_0_i_i); //@line 75000
  return;
 } else if (($1 | 0) == 0) {
  HEAP8[$via + 5 | 0] = $val; //@line 75006
  $5 = HEAP8[$via + 9 | 0] | 0; //@line 75008
  $7 = HEAP32[$via + 52 >> 2] | 0; //@line 75010
  if (($7 | 0) != 0) {
   FUNCTION_TABLE_vii[$7 & 511](HEAP32[$via + 48 >> 2] | 0, HEAP8[$via + 7 | 0] & ~$5 | $5 & $val); //@line 75022
  }
  $18 = $via + 14 | 0; //@line 75025
  $20 = HEAP8[$18] & 103; //@line 75027
  $__i_i36 = (HEAP8[$via + 15 | 0] & $20) << 24 >> 24 == 0 ? $20 : $20 | -128; //@line 75033
  HEAP8[$18] = $__i_i36; //@line 75034
  $_0_lobit_i_i37 = ($__i_i36 & 255) >>> 7; //@line 75035
  $26 = $via + 88 | 0; //@line 75036
  if ((HEAP8[$26] | 0) == $_0_lobit_i_i37 << 24 >> 24) {
   return;
  }
  HEAP8[$26] = $_0_lobit_i_i37; //@line 75044
  $31 = HEAP32[$via + 84 >> 2] | 0; //@line 75046
  if (($31 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$31 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i37); //@line 75055
  return;
 } else if (($1 | 0) == 9) {
  $161 = $via + 24 | 0; //@line 75060
  $166 = HEAP16[$161 >> 1] & 255 | ($val & 255) << 8; //@line 75065
  HEAP16[$161 >> 1] = $166; //@line 75066
  HEAP16[$via + 26 >> 1] = $166; //@line 75068
  if ((HEAP8[$via + 12 | 0] & 32) == 0) {
   HEAP32[$via + 28 >> 2] = 1; //@line 75076
  }
  $175 = $via + 14 | 0; //@line 75079
  $177 = HEAP8[$175] & 95; //@line 75081
  $__i_i48 = (HEAP8[$via + 15 | 0] & $177) << 24 >> 24 == 0 ? $177 : $177 | -128; //@line 75087
  HEAP8[$175] = $__i_i48; //@line 75088
  $_0_lobit_i_i49 = ($__i_i48 & 255) >>> 7; //@line 75089
  $183 = $via + 88 | 0; //@line 75090
  if ((HEAP8[$183] | 0) == $_0_lobit_i_i49 << 24 >> 24) {
   return;
  }
  HEAP8[$183] = $_0_lobit_i_i49; //@line 75098
  $188 = HEAP32[$via + 84 >> 2] | 0; //@line 75100
  if (($188 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$188 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i49); //@line 75109
  return;
 } else if (($1 | 0) == 2) {
  HEAP8[$via + 9 | 0] = $val; //@line 75115
  $73 = HEAP32[$via + 52 >> 2] | 0; //@line 75117
  if (($73 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$73 & 511](HEAP32[$via + 48 >> 2] | 0, HEAP8[$via + 7 | 0] & ~$val | HEAP8[$via + 5 | 0] & $val); //@line 75134
  return;
 } else if (($1 | 0) == 1) {
  HEAP8[$via + 4 | 0] = $val; //@line 75140
  $39 = HEAP8[$via + 8 | 0] | 0; //@line 75142
  $41 = HEAP32[$via + 40 >> 2] | 0; //@line 75144
  if (($41 | 0) != 0) {
   FUNCTION_TABLE_vii[$41 & 511](HEAP32[$via + 36 >> 2] | 0, HEAP8[$via + 6 | 0] & ~$39 | $39 & $val); //@line 75156
  }
  $52 = $via + 14 | 0; //@line 75159
  $54 = HEAP8[$52] & 124; //@line 75161
  $__i_i38 = (HEAP8[$via + 15 | 0] & $54) << 24 >> 24 == 0 ? $54 : $54 | -128; //@line 75167
  HEAP8[$52] = $__i_i38; //@line 75168
  $_0_lobit_i_i39 = ($__i_i38 & 255) >>> 7; //@line 75169
  $60 = $via + 88 | 0; //@line 75170
  if ((HEAP8[$60] | 0) == $_0_lobit_i_i39 << 24 >> 24) {
   return;
  }
  HEAP8[$60] = $_0_lobit_i_i39; //@line 75178
  $65 = HEAP32[$via + 84 >> 2] | 0; //@line 75180
  if (($65 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$65 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i39); //@line 75189
  return;
 } else if (($1 | 0) == 7) {
  $148 = $via + 16 | 0; //@line 75194
  HEAP16[$148 >> 1] = HEAP16[$148 >> 1] & 255 | ($val & 255) << 8; //@line 75200
  return;
 } else if (($1 | 0) == 13) {
  $300 = $via + 14 | 0; //@line 75205
  $303 = HEAP8[$300] & ($val ^ 127); //@line 75208
  $304 = $303 & 127; //@line 75209
  $__i = ($304 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $304 : $303 | -128; //@line 75215
  HEAP8[$300] = $__i; //@line 75216
  $_0_lobit_i = ($__i & 255) >>> 7; //@line 75217
  $310 = $via + 88 | 0; //@line 75218
  if ((HEAP8[$310] | 0) == $_0_lobit_i << 24 >> 24) {
   return;
  }
  HEAP8[$310] = $_0_lobit_i; //@line 75226
  $315 = HEAP32[$via + 84 >> 2] | 0; //@line 75228
  if (($315 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$315 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 75237
  return;
 } else if (($1 | 0) == 12) {
  HEAP8[$via + 13 | 0] = $val; //@line 75243
  $276 = HEAPU8[$via + 12 | 0] | 0; //@line 75246
  do {
   if (($276 & 28 | 0) == 0) {
    $val_0_i_i55 = ($val & -32) << 24 >> 24 != -64 | 0; //@line 75256
   } else {
    if (($276 & 16 | 0) == 0) {
     $val_0_i_i55 = 1; //@line 75262
     break;
    }
    $val_0_i_i55 = HEAP8[$via + 10 | 0] & 1; //@line 75269
   }
  } while (0);
  $289 = $via + 68 | 0; //@line 75273
  if ($val_0_i_i55 << 24 >> 24 == (HEAP8[$289] | 0)) {
   return;
  }
  HEAP8[$289] = $val_0_i_i55; //@line 75281
  $294 = HEAP32[$via + 64 >> 2] | 0; //@line 75283
  if (($294 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$294 & 511](HEAP32[$via + 60 >> 2] | 0, $val_0_i_i55); //@line 75292
  return;
 } else if (($1 | 0) == 8) {
  $155 = $via + 24 | 0; //@line 75297
  HEAP16[$155 >> 1] = HEAP16[$155 >> 1] & -256 | $val & 255; //@line 75302
  return;
 } else if (($1 | 0) == 15) {
  HEAP8[$via + 4 | 0] = $val; //@line 75308
  $353 = HEAP8[$via + 8 | 0] | 0; //@line 75310
  $355 = HEAP32[$via + 40 >> 2] | 0; //@line 75312
  if (($355 | 0) != 0) {
   FUNCTION_TABLE_vii[$355 & 511](HEAP32[$via + 36 >> 2] | 0, HEAP8[$via + 6 | 0] & ~$353 | $353 & $val); //@line 75324
  }
  $366 = $via + 14 | 0; //@line 75327
  $368 = HEAP8[$366] & 124; //@line 75329
  $__i_i = (HEAP8[$via + 15 | 0] & $368) << 24 >> 24 == 0 ? $368 : $368 | -128; //@line 75335
  HEAP8[$366] = $__i_i; //@line 75336
  $_0_lobit_i_i = ($__i_i & 255) >>> 7; //@line 75337
  $374 = $via + 88 | 0; //@line 75338
  if ((HEAP8[$374] | 0) == $_0_lobit_i_i << 24 >> 24) {
   return;
  }
  HEAP8[$374] = $_0_lobit_i_i; //@line 75346
  $379 = HEAP32[$via + 84 >> 2] | 0; //@line 75348
  if (($379 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$379 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i); //@line 75357
  return;
 } else if (($1 | 0) == 14) {
  $322 = $val & 127; //@line 75363
  if ($val << 24 >> 24 > -1) {
   $329 = $via + 15 | 0; //@line 75367
   $331 = HEAP8[$329] & ($322 ^ 127); //@line 75369
   HEAP8[$329] = $331; //@line 75370
   $333 = $331; //@line 75371
  } else {
   $324 = $via + 15 | 0; //@line 75373
   $326 = HEAP8[$324] | $322; //@line 75375
   HEAP8[$324] = $326; //@line 75376
   $333 = $326; //@line 75378
  }
  $334 = $via + 14 | 0; //@line 75381
  $335 = HEAP8[$334] | 0; //@line 75382
  $336 = $335 & 127; //@line 75383
  $__i_i46 = ($336 & $333) << 24 >> 24 == 0 ? $336 : $335 | -128; //@line 75387
  HEAP8[$334] = $__i_i46; //@line 75388
  $_0_lobit_i_i47 = ($__i_i46 & 255) >>> 7; //@line 75389
  $340 = $via + 88 | 0; //@line 75390
  if ((HEAP8[$340] | 0) == $_0_lobit_i_i47 << 24 >> 24) {
   return;
  }
  HEAP8[$340] = $_0_lobit_i_i47; //@line 75398
  $345 = HEAP32[$via + 84 >> 2] | 0; //@line 75400
  if (($345 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$345 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i47); //@line 75409
  return;
 } else if (($1 | 0) == 6) {
  $142 = $via + 16 | 0; //@line 75414
  HEAP16[$142 >> 1] = HEAP16[$142 >> 1] & -256 | $val & 255; //@line 75419
  return;
 } else if (($1 | 0) == 4) {
  $103 = $via + 16 | 0; //@line 75424
  HEAP16[$103 >> 1] = HEAP16[$103 >> 1] & -256 | $val & 255; //@line 75429
  return;
 } else {
  return;
 }
}
function _e6522_set_uint16($via, $addr, $val) {
 $via = $via | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 _e6522_set_uint8($via, $addr, $val & 255); //@line 75448
 return;
}
function _e6522_set_uint32($via, $addr, $val) {
 $via = $via | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 _e6522_set_uint8($via, $addr, $val & 255); //@line 75462
 return;
}
function _e6522_reset($via) {
 $via = $via | 0;
 var $2 = 0, $4 = 0, $7 = 0, $15 = 0, $17 = 0, $29 = 0, $30 = 0, $__i = 0, $_0_lobit_i = 0, $35 = 0, $40 = 0;
 HEAP8[$via + 4 | 0] = 0; //@line 75479
 $2 = $via + 5 | 0; //@line 75480
 HEAP8[$2] = 0; //@line 75481
 $4 = $via + 14 | 0; //@line 75483
 _memset($via + 8 | 0, 0, 24); //@line 75486
 $7 = HEAP32[$via + 40 >> 2] | 0; //@line 75487
 if (($7 | 0) == 0) {
  $15 = 0; //@line 75491
 } else {
  FUNCTION_TABLE_vii[$7 & 511](HEAP32[$via + 36 >> 2] | 0, HEAP8[$via + 6 | 0] | 0); //@line 75498
  $15 = HEAP8[$via + 9 | 0] | 0; //@line 75501
 }
 $17 = HEAP32[$via + 52 >> 2] | 0; //@line 75505
 if (($17 | 0) != 0) {
  FUNCTION_TABLE_vii[$17 & 511](HEAP32[$via + 48 >> 2] | 0, HEAP8[$via + 7 | 0] & ~$15 | HEAP8[$2] & $15); //@line 75518
 }
 $29 = HEAP8[$4] | 0; //@line 75521
 $30 = $29 & 127; //@line 75522
 $__i = (HEAP8[$via + 15 | 0] & $30) << 24 >> 24 == 0 ? $30 : $29 | -128; //@line 75527
 HEAP8[$4] = $__i; //@line 75528
 $_0_lobit_i = ($__i & 255) >>> 7; //@line 75529
 $35 = $via + 88 | 0; //@line 75530
 if ((HEAP8[$35] | 0) == $_0_lobit_i << 24 >> 24) {
  return;
 }
 HEAP8[$35] = $_0_lobit_i; //@line 75538
 $40 = HEAP32[$via + 84 >> 2] | 0; //@line 75540
 if (($40 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$40 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i); //@line 75549
 return;
}
function _e8530_set_irq_fct($scc, $ext, $fct) {
 $scc = $scc | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$scc + 1288 >> 2] = $ext; //@line 75564
 HEAP32[$scc + 1292 >> 2] = $fct; //@line 75567
 return;
}
function _e8530_set_inp_fct($scc, $chn, $ext, $fct) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 if ($chn >>> 0 >= 2) {
  return;
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 608 >> 2] = $ext; //@line 75588
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 612 >> 2] = $fct; //@line 75591
 return;
}
function _e8530_set_out_fct($scc, $chn, $ext, $fct) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 if ($chn >>> 0 >= 2) {
  return;
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 616 >> 2] = $ext; //@line 75613
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 620 >> 2] = $fct; //@line 75616
 return;
}
function _e8530_set_rts_fct($scc, $chn, $ext, $fct) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 if ($chn >>> 0 >= 2) {
  return;
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 624 >> 2] = $ext; //@line 75638
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 628 >> 2] = $fct; //@line 75641
 return;
}
function _e8530_set_comm_fct($scc, $chn, $ext, $fct) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 if ($chn >>> 0 >= 2) {
  return;
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 632 >> 2] = $ext; //@line 75663
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 636 >> 2] = $fct; //@line 75666
 return;
}
function _e8530_set_multichar($scc, $chn, $read_max, $write_max) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $read_max = $read_max | 0;
 $write_max = $write_max | 0;
 if ($chn >>> 0 > 1) {
  return;
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 60 >> 2] = 0; //@line 75689
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 64 >> 2] = ($read_max | 0) == 0 ? 1 : $read_max; //@line 75693
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 68 >> 2] = 0; //@line 75695
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 72 >> 2] = ($write_max | 0) == 0 ? 1 : $write_max; //@line 75699
 return;
}
function _e8530_set_clock($scc, $pclk, $rtxca, $rtxcb) {
 $scc = $scc | 0;
 $pclk = $pclk | 0;
 $rtxca = $rtxca | 0;
 $rtxcb = $rtxcb | 0;
 HEAP32[$scc + 1284 >> 2] = $pclk; //@line 75715
 HEAP32[$scc + 80 >> 2] = $rtxca; //@line 75717
 HEAP32[$scc + 720 >> 2] = $rtxcb; //@line 75719
 return;
}
function _e6522_clock($via, $n) {
 $via = $via | 0;
 $n = $n | 0;
 var $1 = 0, $2 = 0, $3 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $__i_i = 0, $_0_lobit_i_i = 0, $25 = 0, $30 = 0, $36 = 0, $39 = 0, $_pre_phi_i = 0, $_0_i = 0, $49 = 0, $53 = 0, $54 = 0, $56 = 0, $__i22_i = 0, $_0_lobit_i23_i = 0, $62 = 0, $67 = 0, $72 = 0, $73 = 0, $74 = 0, $88 = 0, $92 = 0, $93 = 0, $95 = 0, $__i_i5 = 0, $_0_lobit_i_i6 = 0, $101 = 0, $106 = 0;
 $1 = $via + 18 | 0; //@line 75743
 $2 = HEAP16[$1 >> 1] | 0; //@line 75744
 $3 = $2 & 65535; //@line 75745
 do {
  if ($3 >>> 0 > $n >>> 0 | $2 << 16 >> 16 == 0) {
   HEAP16[$1 >> 1] = $3 - $n & 65535; //@line 75754
  } else {
   if ((HEAP8[$via + 12 | 0] & 64) == 0) {
    HEAP16[$1 >> 1] = $3 - $n & 65535; //@line 75765
    $49 = $via + 20 | 0; //@line 75766
    if ((HEAP32[$49 >> 2] | 0) == 0) {
     break;
    }
    HEAP32[$49 >> 2] = 0; //@line 75773
    $53 = $via + 14 | 0; //@line 75774
    $54 = HEAP8[$53] | 0; //@line 75775
    $56 = $54 & 63 | 64; //@line 75777
    $__i22_i = ($56 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $56 : $54 | -64; //@line 75783
    HEAP8[$53] = $__i22_i; //@line 75784
    $_0_lobit_i23_i = ($__i22_i & 255) >>> 7; //@line 75785
    $62 = $via + 88 | 0; //@line 75786
    if ((HEAP8[$62] | 0) == $_0_lobit_i23_i << 24 >> 24) {
     break;
    }
    HEAP8[$62] = $_0_lobit_i23_i; //@line 75793
    $67 = HEAP32[$via + 84 >> 2] | 0; //@line 75795
    if (($67 | 0) == 0) {
     break;
    }
    FUNCTION_TABLE_vii[$67 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i23_i); //@line 75803
    break;
   }
   $15 = $n - $3 | 0; //@line 75807
   $16 = $via + 14 | 0; //@line 75808
   $17 = HEAP8[$16] | 0; //@line 75809
   $19 = $17 & 63 | 64; //@line 75811
   $__i_i = ($19 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $19 : $17 | -64; //@line 75817
   HEAP8[$16] = $__i_i; //@line 75818
   $_0_lobit_i_i = ($__i_i & 255) >>> 7; //@line 75819
   $25 = $via + 88 | 0; //@line 75820
   do {
    if ((HEAP8[$25] | 0) != $_0_lobit_i_i << 24 >> 24) {
     HEAP8[$25] = $_0_lobit_i_i; //@line 75826
     $30 = HEAP32[$via + 84 >> 2] | 0; //@line 75828
     if (($30 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$30 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i); //@line 75836
    }
   } while (0);
   $36 = HEAP16[$via + 16 >> 1] | 0; //@line 75841
   if ($36 << 16 >> 16 == 0) {
    $_0_i = $15 & 65535;
    $_pre_phi_i = 0;
   } else {
    $39 = $36 & 65535; //@line 75848
    $_0_i = ($15 >>> 0) % ($39 >>> 0) | 0;
    $_pre_phi_i = $39;
   }
   HEAP16[$1 >> 1] = $_pre_phi_i - $_0_i & 65535; //@line 75857
  }
 } while (0);
 $72 = $via + 26 | 0; //@line 75861
 $73 = HEAP16[$72 >> 1] | 0; //@line 75862
 $74 = $73 & 65535; //@line 75863
 if ($74 >>> 0 > $n >>> 0 | $73 << 16 >> 16 == 0) {
  HEAP16[$72 >> 1] = $74 - $n & 65535; //@line 75871
  return;
 }
 if ((HEAP8[$via + 12 | 0] & 32) != 0) {
  return;
 }
 HEAP16[$72 >> 1] = $74 - $n & 65535; //@line 75887
 $88 = $via + 28 | 0; //@line 75888
 if ((HEAP32[$88 >> 2] | 0) == 0) {
  return;
 }
 HEAP32[$88 >> 2] = 0; //@line 75896
 $92 = $via + 14 | 0; //@line 75897
 $93 = HEAP8[$92] | 0; //@line 75898
 $95 = $93 & 95 | 32; //@line 75900
 $__i_i5 = ($95 & HEAP8[$via + 15 | 0]) << 24 >> 24 == 0 ? $95 : $93 | -96; //@line 75906
 HEAP8[$92] = $__i_i5; //@line 75907
 $_0_lobit_i_i6 = ($__i_i5 & 255) >>> 7; //@line 75908
 $101 = $via + 88 | 0; //@line 75909
 if ((HEAP8[$101] | 0) == $_0_lobit_i_i6 << 24 >> 24) {
  return;
 }
 HEAP8[$101] = $_0_lobit_i_i6; //@line 75917
 $106 = HEAP32[$via + 84 >> 2] | 0; //@line 75919
 if (($106 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$106 & 511](HEAP32[$via + 80 >> 2] | 0, $_0_lobit_i_i6); //@line 75928
 return;
}
function _e8530_init($scc) {
 $scc = $scc | 0;
 HEAP32[$scc >> 2] = 0; //@line 75945
 HEAP32[$scc + 1284 >> 2] = 0; //@line 75947
 HEAP8[$scc + 38 | 0] = 1; //@line 75949
 HEAP8[$scc + 39 | 0] = 1; //@line 75951
 HEAP32[$scc + 56 >> 2] = 0; //@line 75953
 HEAP32[$scc + 60 >> 2] = 16384; //@line 75955
 HEAP32[$scc + 64 >> 2] = 0; //@line 75957
 HEAP32[$scc + 68 >> 2] = 1; //@line 75959
 HEAP32[$scc + 72 >> 2] = 0; //@line 75961
 HEAP32[$scc + 76 >> 2] = 1; //@line 75963
 HEAP32[$scc + 80 >> 2] = 0; //@line 75965
 HEAP32[$scc + 84 >> 2] = 0; //@line 75967
 HEAP32[$scc + 88 >> 2] = 0; //@line 75969
 HEAP32[$scc + 348 >> 2] = 0; //@line 75971
 HEAP32[$scc + 352 >> 2] = 0; //@line 75973
 _memset($scc + 612 | 0, 0, 32); //@line 75976
 HEAP8[$scc + 678 | 0] = 1; //@line 75978
 HEAP8[$scc + 679 | 0] = 1; //@line 75980
 HEAP32[$scc + 696 >> 2] = 0; //@line 75982
 HEAP32[$scc + 700 >> 2] = 16384; //@line 75984
 HEAP32[$scc + 704 >> 2] = 0; //@line 75986
 HEAP32[$scc + 708 >> 2] = 1; //@line 75988
 HEAP32[$scc + 712 >> 2] = 0; //@line 75990
 HEAP32[$scc + 716 >> 2] = 1; //@line 75992
 HEAP32[$scc + 720 >> 2] = 0; //@line 75994
 HEAP32[$scc + 724 >> 2] = 0; //@line 75996
 HEAP32[$scc + 728 >> 2] = 0; //@line 75998
 HEAP32[$scc + 988 >> 2] = 0; //@line 76000
 HEAP32[$scc + 992 >> 2] = 0; //@line 76002
 _memset($scc + 1252 | 0, 0, 32); //@line 76005
 HEAP32[$scc + 1288 >> 2] = 0; //@line 76007
 HEAP32[$scc + 1292 >> 2] = 0; //@line 76009
 HEAP8[$scc + 1296 | 0] = 0; //@line 76011
 return;
}
function _e8530_set_reg($scc, $chn, $reg, $val) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $reg = $reg | 0;
 $val = $val | 0;
 var $1 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $14 = 0, $16 = 0, $23 = 0, $28 = 0, $35 = 0, $36 = 0, $41 = 0, $49 = 0, $51 = 0, $57 = 0, $62 = 0, $69 = 0, $70 = 0, $75 = 0, $92 = 0, $98 = 0, $99 = 0, $105 = 0, $111 = 0, $112 = 0, $115 = 0, $118 = 0, $120 = 0, $126 = 0, $131 = 0, $138 = 0, $139 = 0, $144 = 0, $149 = 0, $150 = 0, $153 = 0, $154 = 0, $168 = 0, $174 = 0, $183 = 0, $184 = 0, label = 0;
 $1 = $chn & 1; //@line 76045
 do {
  if (($reg | 0) == 9) {
   $183 = $scc + 13 | 0; //@line 76048
   $184 = HEAP8[$183] | 0; //@line 76049
   HEAP8[$183] = $val; //@line 76050
   HEAP8[$scc + 653 | 0] = $val; //@line 76052
   if (($val & 8 & ($184 ^ 8)) << 24 >> 24 == 0) {
    break;
   }
   _e8530_set_int_cond($scc, 0, 0); //@line 76061
   _e8530_set_int_cond($scc, 1, 0); //@line 76062
   label = 9656; //@line 76064
  } else if (($reg | 0) == 3) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 3 | 0] = $val; //@line 76067
   if (($val & 16) == 0) {
    break;
   }
   $92 = $scc + 4 + ($1 * 640 | 0) + 16 | 0; //@line 76074
   HEAP8[$92] = HEAP8[$92] | 16; //@line 76077
   label = 9656; //@line 76079
  } else if (($reg | 0) == 4) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 4 | 0] = $val; //@line 76082
   _e8530_set_params($scc, $1); //@line 76083
  } else if (($reg | 0) == 8) {
   $111 = $scc + 4 + ($1 * 640 | 0) + 8 | 0; //@line 76086
   HEAP8[$111] = $val; //@line 76087
   $112 = $scc + 4 + ($1 * 640 | 0) + 16 | 0; //@line 76088
   HEAP8[$112] = HEAP8[$112] & -5; //@line 76091
   $115 = $scc + 4 + ($1 * 640 | 0) + 34 | 0; //@line 76092
   HEAP8[$115] = 0; //@line 76093
   $118 = $scc + 23 | 0; //@line 76096
   $120 = HEAP8[$118] & (($1 | 0) == 0 ? -17 : -3); //@line 76098
   HEAP8[$118] = $120; //@line 76099
   do {
    if ((HEAP8[$scc + 13 | 0] & 8) == 0) {
     $126 = $scc + 1296 | 0; //@line 76107
     if ((HEAP8[$126] | 0) == 0) {
      break;
     }
     HEAP8[$126] = 0; //@line 76114
     $131 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76116
     if (($131 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$131 & 511](HEAP32[$scc + 1288 >> 2] | 0, 0); //@line 76124
    } else {
     $138 = $120 << 24 >> 24 != 0 | 0; //@line 76128
     $139 = $scc + 1296 | 0; //@line 76129
     if ((HEAP8[$139] | 0) == $138 << 24 >> 24) {
      break;
     }
     HEAP8[$139] = $138; //@line 76136
     $144 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76138
     if (($144 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$144 & 511](HEAP32[$scc + 1288 >> 2] | 0, $138); //@line 76146
    }
   } while (0);
   $149 = $scc + 4 + ($1 * 640 | 0) + 68 | 0; //@line 76150
   $150 = HEAP32[$149 >> 2] | 0; //@line 76151
   if (($150 | 0) == 0) {
    label = 9656; //@line 76155
    break;
   }
   $153 = $scc + 4 + ($1 * 640 | 0) + 80 | 0; //@line 76158
   $154 = HEAP32[$153 >> 2] | 0; //@line 76159
   if (($154 + 1 & 255 | 0) == (HEAP32[$scc + 4 + ($1 * 640 | 0) + 84 >> 2] | 0)) {
    label = 9656; //@line 76167
    break;
   }
   if ((HEAP8[$115] | 0) != 0) {
    HEAP8[$112] = HEAP8[$112] | 64; //@line 76176
    label = 9656; //@line 76178
    break;
   }
   HEAP32[$149 >> 2] = $150 - 1; //@line 76182
   $168 = HEAP8[$111] | 0; //@line 76183
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 88 + $154 | 0] = $168; //@line 76185
   HEAP32[$153 >> 2] = (HEAP32[$153 >> 2] | 0) + 1 & 255; //@line 76189
   $174 = HEAP32[$scc + 4 + ($1 * 640 | 0) + 620 >> 2] | 0; //@line 76191
   if (($174 | 0) != 0) {
    FUNCTION_TABLE_vii[$174 & 511](HEAP32[$scc + 4 + ($1 * 640 | 0) + 616 >> 2] | 0, $168); //@line 76197
   }
   HEAP8[$112] = HEAP8[$112] | 4; //@line 76202
   HEAP8[$115] = 1; //@line 76203
   _e8530_set_int_cond($scc, $1, 2); //@line 76204
   label = 9656; //@line 76206
  } else if (($reg | 0) == 14) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 14 | 0] = $val; //@line 76209
   _e8530_set_params($scc, $1); //@line 76210
  } else if (($reg | 0) == 5) {
   $98 = $scc + 4 + ($1 * 640 | 0) + 5 | 0; //@line 76213
   $99 = HEAP8[$98] | 0; //@line 76214
   HEAP8[$98] = $val; //@line 76215
   do {
    if ((($99 ^ $val) & 2) != 0) {
     $105 = HEAP32[$scc + 4 + ($1 * 640 | 0) + 628 >> 2] | 0; //@line 76223
     if (($105 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$105 & 511](HEAP32[$scc + 4 + ($1 * 640 | 0) + 624 >> 2] | 0, ($val & 255) >>> 1 & 1); //@line 76233
    }
   } while (0);
   _e8530_set_params($scc, $1); //@line 76237
   label = 9656; //@line 76239
  } else if (($reg | 0) == 2) {
   HEAP8[$scc + 6 | 0] = $val; //@line 76242
   HEAP8[$scc + 646 | 0] = $val; //@line 76244
   HEAP8[$scc + 22 | 0] = $val; //@line 76246
   HEAP8[$scc + 662 | 0] = $val; //@line 76248
  } else if (($reg | 0) == 0) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) | 0] = $val; //@line 76252
   $4 = $val & 255; //@line 76253
   $5 = $4 & 7; //@line 76254
   $6 = $scc | 0; //@line 76255
   HEAP32[$6 >> 2] = $5; //@line 76256
   $8 = $4 >>> 3 & 7; //@line 76258
   if (($8 | 0) == 1) {
    HEAP32[$6 >> 2] = $5 | 8; //@line 76261
    return;
   } else if (($8 | 0) == 2) {
    $14 = $scc + 23 | 0; //@line 76268
    $16 = HEAP8[$14] & (($1 | 0) == 0 ? -9 : -2); //@line 76270
    HEAP8[$14] = $16; //@line 76271
    HEAP8[$scc + 4 + ($1 * 640 | 0) + 32 | 0] = 0; //@line 76273
    if ((HEAP8[$scc + 13 | 0] & 8) != 0) {
     $35 = $16 << 24 >> 24 != 0 | 0; //@line 76281
     $36 = $scc + 1296 | 0; //@line 76282
     if ((HEAP8[$36] | 0) == $35 << 24 >> 24) {
      label = 9656; //@line 76287
      break;
     }
     HEAP8[$36] = $35; //@line 76290
     $41 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76292
     if (($41 | 0) == 0) {
      label = 9656; //@line 76296
      break;
     }
     FUNCTION_TABLE_vii[$41 & 511](HEAP32[$scc + 1288 >> 2] | 0, $35); //@line 76301
     label = 9656; //@line 76303
     break;
    }
    $23 = $scc + 1296 | 0; //@line 76306
    if ((HEAP8[$23] | 0) == 0) {
     return;
    }
    HEAP8[$23] = 0; //@line 76314
    $28 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76316
    if (($28 | 0) == 0) {
     label = 9656; //@line 76320
     break;
    }
    FUNCTION_TABLE_vii[$28 & 511](HEAP32[$scc + 1288 >> 2] | 0, 0); //@line 76325
    label = 9656; //@line 76327
    break;
   } else if (($8 | 0) == 5) {
    $49 = $scc + 23 | 0; //@line 76332
    $51 = HEAP8[$49] & (($1 | 0) == 0 ? -17 : -3); //@line 76334
    HEAP8[$49] = $51; //@line 76335
    if ((HEAP8[$scc + 13 | 0] & 8) == 0) {
     $57 = $scc + 1296 | 0; //@line 76342
     if ((HEAP8[$57] | 0) == 0) {
      label = 9656; //@line 76347
      break;
     }
     HEAP8[$57] = 0; //@line 76350
     $62 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76352
     if (($62 | 0) == 0) {
      label = 9656; //@line 76356
      break;
     }
     FUNCTION_TABLE_vii[$62 & 511](HEAP32[$scc + 1288 >> 2] | 0, 0); //@line 76361
     label = 9656; //@line 76363
     break;
    } else {
     $69 = $51 << 24 >> 24 != 0 | 0; //@line 76367
     $70 = $scc + 1296 | 0; //@line 76368
     if ((HEAP8[$70] | 0) == $69 << 24 >> 24) {
      label = 9656; //@line 76373
      break;
     }
     HEAP8[$70] = $69; //@line 76376
     $75 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76378
     if (($75 | 0) == 0) {
      label = 9656; //@line 76382
      break;
     }
     FUNCTION_TABLE_vii[$75 & 511](HEAP32[$scc + 1288 >> 2] | 0, $69); //@line 76387
     label = 9656; //@line 76389
     break;
    }
   } else {
    return;
   }
  } else if (($reg | 0) == 15) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 15 | 0] = $val; //@line 76398
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 31 | 0] = $val; //@line 76400
  } else if (($reg | 0) == 10) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 10 | 0] = $val; //@line 76404
  } else if (($reg | 0) == 11) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 11 | 0] = $val; //@line 76408
  } else if (($reg | 0) == 12) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 12 | 0] = $val; //@line 76412
   _e8530_set_params($scc, $1); //@line 76413
  } else if (($reg | 0) == 13) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 13 | 0] = $val; //@line 76417
   _e8530_set_params($scc, $1); //@line 76418
  } else if (($reg | 0) == 1) {
   HEAP8[$scc + 4 + ($1 * 640 | 0) + 1 | 0] = $val; //@line 76422
   _e8530_set_int_cond($scc, $1, 0); //@line 76423
  } else {
   HEAP8[($reg & 15) + ($scc + 4 + ($1 * 640 | 0)) | 0] = $val; //@line 76428
   label = 9656; //@line 76430
  }
 } while (0);
 do {
  if ((label | 0) == 9656) {
   if (($reg | 0) != 0) {
    break;
   }
   return;
  }
 } while (0);
 HEAP32[$scc >> 2] = 0; //@line 76445
 return;
}
function _e8530_receive($scc, $chn, $val) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $3 = 0;
 $1 = $chn & 1; //@line 76460
 $2 = $scc + 4 + ($1 * 640 | 0) + 344 | 0; //@line 76461
 $3 = HEAP32[$2 >> 2] | 0; //@line 76462
 if (($3 + 1 & 255 | 0) == (HEAP32[$scc + 4 + ($1 * 640 | 0) + 348 >> 2] | 0)) {
  return;
 }
 HEAP8[$scc + 4 + ($1 * 640 | 0) + 352 + $3 | 0] = $val; //@line 76474
 HEAP32[$2 >> 2] = (HEAP32[$2 >> 2] | 0) + 1 & 255; //@line 76478
 return;
}
function _e8530_send($scc, $chn) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 var $1 = 0, $4 = 0, $5 = 0, $9 = 0, $_0 = 0;
 $1 = $chn & 1; //@line 76492
 $4 = $scc + 4 + ($1 * 640 | 0) + 84 | 0; //@line 76495
 $5 = HEAP32[$4 >> 2] | 0; //@line 76496
 if ((HEAP32[$scc + 4 + ($1 * 640 | 0) + 80 >> 2] | 0) == ($5 | 0)) {
  $_0 = 0; //@line 76500
  return $_0 | 0; //@line 76503
 }
 $9 = HEAP8[$scc + 4 + ($1 * 640 | 0) + 88 + $5 | 0] | 0; //@line 76506
 HEAP32[$4 >> 2] = $5 + 1 & 255; //@line 76509
 $_0 = $9; //@line 76511
 return $_0 | 0; //@line 76514
}
function _e8530_inp_full($scc, $chn) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 var $1 = 0;
 $1 = $chn & 1; //@line 76525
 return ((HEAP32[$scc + 4 + ($1 * 640 | 0) + 344 >> 2] | 0) + 1 & 255 | 0) == (HEAP32[$scc + 4 + ($1 * 640 | 0) + 348 >> 2] | 0) | 0; //@line 76535
}
function _e8530_out_empty($scc, $chn) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 var $1 = 0;
 $1 = $chn & 1; //@line 76545
 return (HEAP32[$scc + 4 + ($1 * 640 | 0) + 80 >> 2] | 0) == (HEAP32[$scc + 4 + ($1 * 640 | 0) + 84 >> 2] | 0) | 0; //@line 76553
}
function _e8530_get_reg($scc, $chn, $reg) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $reg = $reg | 0;
 var $1 = 0, $6 = 0, $15 = 0, $20 = 0, $st_0_i = 0, $43 = 0, $58 = 0, $59 = 0, $60 = 0, $63 = 0, $66 = 0, $68 = 0, $74 = 0, $79 = 0, $86 = 0, $87 = 0, $92 = 0, $99 = 0, $100 = 0, $103 = 0, $104 = 0, $116 = 0, $val_0 = 0;
 $1 = $chn & 1; //@line 76577
 do {
  if (($reg | 0) == 0) {
   $6 = HEAP8[$scc + 4 + ($1 * 640 | 0) + 32 | 0] | 0; //@line 76583
   $val_0 = HEAP8[$scc + 4 + ($1 * 640 | 0) + 33 | 0] & $6 | HEAP8[$scc + 4 + ($1 * 640 | 0) + 16 | 0] & ~$6; //@line 76591
  } else if (($reg | 0) == 2) {
   $15 = HEAP8[$scc + 22 | 0] | 0; //@line 76594
   if (($1 | 0) == 0) {
    $val_0 = $15; //@line 76598
    break;
   }
   $20 = HEAPU8[$scc + 23 | 0] | 0; //@line 76603
   do {
    if (($20 & 32 | 0) == 0) {
     if (($20 & 16 | 0) != 0) {
      $st_0_i = 24; //@line 76613
      break;
     }
     if (($20 & 8 | 0) != 0) {
      $st_0_i = 90; //@line 76620
      break;
     }
     if (($20 & 4 | 0) != 0) {
      $st_0_i = 36; //@line 76627
      break;
     }
     if (($20 & 2 | 0) != 0) {
      $st_0_i = 0; //@line 76634
      break;
     }
     $st_0_i = ($20 & 1 | 0) == 0 ? 102 : 66; //@line 76640
    } else {
     $st_0_i = 60; //@line 76642
    }
   } while (0);
   $43 = $15 & 255; //@line 76650
   if ((HEAP8[$scc + 13 | 0] & 16) == 0) {
    $val_0 = ($st_0_i & 14 | $43 & 241) & 255; //@line 76657
    break;
   } else {
    $val_0 = ($st_0_i | $43) & 112; //@line 76664
    break;
   }
  } else if (($reg | 0) == 8) {
   $58 = $scc + 4 + ($1 * 640 | 0) + 24 | 0; //@line 76668
   $59 = HEAP8[$58] | 0; //@line 76669
   $60 = $scc + 4 + ($1 * 640 | 0) + 16 | 0; //@line 76670
   HEAP8[$60] = HEAP8[$60] & -2; //@line 76673
   $63 = $scc + 4 + ($1 * 640 | 0) + 35 | 0; //@line 76674
   HEAP8[$63] = 1; //@line 76675
   $66 = $scc + 23 | 0; //@line 76678
   $68 = HEAP8[$66] & (($1 | 0) == 0 ? -33 : -5); //@line 76680
   HEAP8[$66] = $68; //@line 76681
   do {
    if ((HEAP8[$scc + 13 | 0] & 8) == 0) {
     $74 = $scc + 1296 | 0; //@line 76689
     if ((HEAP8[$74] | 0) == 0) {
      break;
     }
     HEAP8[$74] = 0; //@line 76696
     $79 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76698
     if (($79 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$79 & 511](HEAP32[$scc + 1288 >> 2] | 0, 0); //@line 76706
    } else {
     $86 = $68 << 24 >> 24 != 0 | 0; //@line 76710
     $87 = $scc + 1296 | 0; //@line 76711
     if ((HEAP8[$87] | 0) == $86 << 24 >> 24) {
      break;
     }
     HEAP8[$87] = $86; //@line 76718
     $92 = HEAP32[$scc + 1292 >> 2] | 0; //@line 76720
     if (($92 | 0) == 0) {
      break;
     }
     FUNCTION_TABLE_vii[$92 & 511](HEAP32[$scc + 1288 >> 2] | 0, $86); //@line 76728
    }
   } while (0);
   $99 = $scc + 4 + ($1 * 640 | 0) + 348 | 0; //@line 76734
   $100 = HEAP32[$99 >> 2] | 0; //@line 76735
   if ((HEAP32[$scc + 4 + ($1 * 640 | 0) + 344 >> 2] | 0) == ($100 | 0)) {
    $val_0 = $59; //@line 76739
    break;
   }
   $103 = $scc + 4 + ($1 * 640 | 0) + 60 | 0; //@line 76742
   $104 = HEAP32[$103 >> 2] | 0; //@line 76743
   if (($104 | 0) == 0) {
    $val_0 = $59; //@line 76747
    break;
   }
   if ((HEAP8[$63] | 0) == 0) {
    $val_0 = $59; //@line 76754
    break;
   }
   HEAP32[$103 >> 2] = $104 - 1; //@line 76758
   HEAP8[$58] = HEAP8[$scc + 4 + ($1 * 640 | 0) + 352 + $100 | 0] | 0; //@line 76761
   HEAP32[$99 >> 2] = $100 + 1 & 255; //@line 76764
   $116 = HEAP32[$scc + 4 + ($1 * 640 | 0) + 612 >> 2] | 0; //@line 76766
   if (($116 | 0) != 0) {
    FUNCTION_TABLE_vii[$116 & 511](HEAP32[$scc + 4 + ($1 * 640 | 0) + 608 >> 2] | 0, 1); //@line 76772
   }
   HEAP8[$60] = HEAP8[$60] | 1; //@line 76777
   HEAP8[$63] = 0; //@line 76778
   _e8530_set_int_cond($scc, $1, 4); //@line 76779
   $val_0 = $59; //@line 76781
  } else if (($reg | 0) == 3) {
   if (($1 | 0) != 0) {
    $val_0 = 0; //@line 76786
    break;
   }
   $val_0 = HEAP8[$scc + 23 | 0] | 0; //@line 76792
  } else {
   $val_0 = HEAP8[($reg & 15) + ($scc + 4 + ($1 * 640 | 0) + 16) | 0] | 0; //@line 76798
  }
 } while (0);
 HEAP32[$scc >> 2] = 0; //@line 76803
 return $val_0 | 0; //@line 76805
}
function _e8530_get_ctl_a($scc) {
 $scc = $scc | 0;
 return _e8530_get_reg($scc, 0, HEAP32[$scc >> 2] | 0) | 0; //@line 76818
}
function _e8530_get_ctl_b($scc) {
 $scc = $scc | 0;
 return _e8530_get_reg($scc, 1, HEAP32[$scc >> 2] | 0) | 0; //@line 76831
}
function _e8530_set_ctl_a($scc, $val) {
 $scc = $scc | 0;
 $val = $val | 0;
 _e8530_set_reg($scc, 0, HEAP32[$scc >> 2] | 0, $val); //@line 76843
 return;
}
function _e8530_set_ctl_b($scc, $val) {
 $scc = $scc | 0;
 $val = $val | 0;
 _e8530_set_reg($scc, 1, HEAP32[$scc >> 2] | 0, $val); //@line 76857
 return;
}
function _e8530_get_data_a($scc) {
 $scc = $scc | 0;
 return _e8530_get_reg($scc, 0, 8) | 0; //@line 76870
}
function _e8530_get_data_b($scc) {
 $scc = $scc | 0;
 return _e8530_get_reg($scc, 1, 8) | 0; //@line 76881
}
function _e8530_set_data_a($scc, $val) {
 $scc = $scc | 0;
 $val = $val | 0;
 _e8530_set_reg($scc, 0, 8, $val); //@line 76890
 return;
}
function _e8530_set_data_b($scc, $val) {
 $scc = $scc | 0;
 $val = $val | 0;
 _e8530_set_reg($scc, 1, 8, $val); //@line 76901
 return;
}
function _e8530_set_dcd_a($scc, $val) {
 $scc = $scc | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $old_0_i = 0;
 $1 = $scc + 20 | 0; //@line 76914
 $2 = HEAP8[$1] | 0; //@line 76915
 $old_0_i = $val << 24 >> 24 == 0 ? $2 | 8 : $2 & -9; //@line 76919
 HEAP8[$1] = $old_0_i; //@line 76920
 if ((HEAP8[$scc + 19 | 0] & -6 & ($old_0_i ^ $2)) << 24 >> 24 == 0) {
  return;
 }
 _e8530_set_int_cond($scc, 0, 1); //@line 76932
 return;
}
function _e8530_set_dcd_b($scc, $val) {
 $scc = $scc | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $old_0_i = 0;
 $1 = $scc + 660 | 0; //@line 76946
 $2 = HEAP8[$1] | 0; //@line 76947
 $old_0_i = $val << 24 >> 24 == 0 ? $2 | 8 : $2 & -9; //@line 76951
 HEAP8[$1] = $old_0_i; //@line 76952
 if ((HEAP8[$scc + 659 | 0] & -6 & ($old_0_i ^ $2)) << 24 >> 24 == 0) {
  return;
 }
 _e8530_set_int_cond($scc, 1, 1); //@line 76964
 return;
}
function _e8530_set_cts($scc, $chn, $val) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $3 = 0, $rr0_0 = 0;
 $1 = $chn & 1; //@line 76979
 $2 = $scc + 4 + ($1 * 640 | 0) + 16 | 0; //@line 76980
 $3 = HEAP8[$2] | 0; //@line 76981
 $rr0_0 = $val << 24 >> 24 == 0 ? $3 | 32 : $3 & -33; //@line 76985
 HEAP8[$2] = $rr0_0; //@line 76986
 if ((HEAP8[$scc + 4 + ($1 * 640 | 0) + 15 | 0] & -6 & ($rr0_0 ^ $3)) << 24 >> 24 == 0) {
  return;
 }
 _e8530_set_int_cond($scc, $1, 1); //@line 76998
 return;
}
function _e8530_reset($scc) {
 $scc = $scc | 0;
 var $i_016 = 0, $10 = 0, $13 = 0, $23 = 0, $26 = 0, $37 = 0, $43 = 0, $48 = 0, $53 = 0;
 HEAP32[$scc >> 2] = 0; //@line 77017
 $i_016 = 0; //@line 77019
 do {
  HEAP8[$scc + 20 + $i_016 | 0] = 0; //@line 77023
  HEAP8[$scc + 4 + $i_016 | 0] = 0; //@line 77025
  HEAP8[$scc + 660 + $i_016 | 0] = 0; //@line 77027
  HEAP8[$scc + 644 + $i_016 | 0] = 0; //@line 77029
  $i_016 = $i_016 + 1 | 0; //@line 77030
 } while ($i_016 >>> 0 < 16);
 $10 = $scc + 20 | 0; //@line 77039
 HEAP8[$10] = HEAP8[$10] | 4; //@line 77042
 $13 = $scc + 21 | 0; //@line 77043
 HEAP8[$13] = HEAP8[$13] | 1; //@line 77046
 HEAP8[$scc + 36 | 0] = 0; //@line 77048
 HEAP32[$scc + 84 >> 2] = 0; //@line 77051
 HEAP32[$scc + 88 >> 2] = 0; //@line 77053
 HEAP32[$scc + 348 >> 2] = 0; //@line 77055
 HEAP32[$scc + 352 >> 2] = 0; //@line 77057
 _memset($scc + 40 | 0, 0, 16); //@line 77059
 $23 = $scc + 660 | 0; //@line 77060
 HEAP8[$23] = HEAP8[$23] | 4; //@line 77063
 $26 = $scc + 661 | 0; //@line 77064
 HEAP8[$26] = HEAP8[$26] | 1; //@line 77067
 HEAP8[$scc + 676 | 0] = 0; //@line 77069
 HEAP32[$scc + 724 >> 2] = 0; //@line 77072
 HEAP32[$scc + 728 >> 2] = 0; //@line 77074
 HEAP32[$scc + 988 >> 2] = 0; //@line 77076
 HEAP32[$scc + 992 >> 2] = 0; //@line 77078
 _memset($scc + 680 | 0, 0, 16); //@line 77080
 $37 = HEAP32[$scc + 632 >> 2] | 0; //@line 77082
 if (($37 | 0) != 0) {
  FUNCTION_TABLE_vii[$37 & 511](HEAP32[$scc + 628 >> 2] | 0, 0); //@line 77088
 }
 $43 = HEAP32[$scc + 1272 >> 2] | 0; //@line 77092
 if (($43 | 0) != 0) {
  FUNCTION_TABLE_vii[$43 & 511](HEAP32[$scc + 1268 >> 2] | 0, 0); //@line 77098
 }
 $48 = $scc + 1296 | 0; //@line 77101
 if ((HEAP8[$48] | 0) == 0) {
  return;
 }
 HEAP8[$48] = 0; //@line 77109
 $53 = HEAP32[$scc + 1292 >> 2] | 0; //@line 77111
 if (($53 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vii[$53 & 511](HEAP32[$scc + 1288 >> 2] | 0, 0); //@line 77120
 return;
}
function _e8530_clock($scc, $n) {
 $scc = $scc | 0;
 $n = $n | 0;
 _e8530_chn_clock($scc, 0, $n); //@line 77132
 _e8530_chn_clock($scc, 1, $n); //@line 77133
 return;
}
function _e8530_chn_clock($scc, $chn, $n) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $n = $n | 0;
 var $1 = 0, $2 = 0, $7 = 0, $9 = 0, $_0 = 0, $16 = 0, $17 = 0, $19 = 0, $20 = 0, $23 = 0, $24 = 0, $28 = 0, $39 = 0, $45 = 0, $48 = 0, $51 = 0, $52 = 0, $59 = 0, $63 = 0, $69 = 0, $75 = 0, $81 = 0;
 $1 = $scc + 4 + ($chn * 640 | 0) + 52 | 0; //@line 77154
 $2 = HEAP32[$1 >> 2] | 0; //@line 77155
 if ($2 >>> 0 > $n >>> 0) {
  HEAP32[$1 >> 2] = $2 - $n; //@line 77160
  return;
 }
 $7 = $n - $2 | 0; //@line 77165
 $9 = HEAP32[$scc + 4 + ($chn * 640 | 0) + 56 >> 2] | 0; //@line 77167
 if ($7 >>> 0 > $9 >>> 0) {
  $_0 = ($7 >>> 0) % ($9 >>> 0) | 0; //@line 77173
 } else {
  $_0 = $7; //@line 77175
 }
 HEAP32[$1 >> 2] = $9 - $_0; //@line 77179
 $16 = HEAP32[$scc + 4 + ($chn * 640 | 0) + 64 >> 2] | 0; //@line 77181
 $17 = $scc + 4 + ($chn * 640 | 0) + 60 | 0; //@line 77182
 HEAP32[$17 >> 2] = $16; //@line 77183
 $19 = HEAP32[$scc + 4 + ($chn * 640 | 0) + 72 >> 2] | 0; //@line 77185
 $20 = $scc + 4 + ($chn * 640 | 0) + 68 | 0; //@line 77186
 HEAP32[$20 >> 2] = $19; //@line 77187
 $23 = $scc + 4 + ($chn * 640 | 0) + 348 | 0; //@line 77190
 $24 = HEAP32[$23 >> 2] | 0; //@line 77191
 do {
  if ((HEAP32[$scc + 4 + ($chn * 640 | 0) + 344 >> 2] | 0) == ($24 | 0) | ($16 | 0) == 0) {
   $48 = $19; //@line 77198
  } else {
   $28 = $scc + 4 + ($chn * 640 | 0) + 35 | 0; //@line 77200
   if ((HEAP8[$28] | 0) == 0) {
    $48 = $19; //@line 77205
    break;
   }
   HEAP32[$17 >> 2] = $16 - 1; //@line 77209
   HEAP8[$scc + 4 + ($chn * 640 | 0) + 24 | 0] = HEAP8[$scc + 4 + ($chn * 640 | 0) + 352 + $24 | 0] | 0; //@line 77213
   HEAP32[$23 >> 2] = $24 + 1 & 255; //@line 77216
   $39 = HEAP32[$scc + 4 + ($chn * 640 | 0) + 612 >> 2] | 0; //@line 77218
   if (($39 | 0) != 0) {
    FUNCTION_TABLE_vii[$39 & 511](HEAP32[$scc + 4 + ($chn * 640 | 0) + 608 >> 2] | 0, 1); //@line 77224
   }
   $45 = $scc + 4 + ($chn * 640 | 0) + 16 | 0; //@line 77227
   HEAP8[$45] = HEAP8[$45] | 1; //@line 77230
   HEAP8[$28] = 0; //@line 77231
   _e8530_set_int_cond($scc, $chn, 4); //@line 77232
   $48 = HEAP32[$20 >> 2] | 0; //@line 77235
  }
 } while (0);
 if (($48 | 0) == 0) {
  return;
 }
 $51 = $scc + 4 + ($chn * 640 | 0) + 80 | 0; //@line 77245
 $52 = HEAP32[$51 >> 2] | 0; //@line 77246
 if (($52 + 1 & 255 | 0) == (HEAP32[$scc + 4 + ($chn * 640 | 0) + 84 >> 2] | 0)) {
  return;
 }
 $59 = $scc + 4 + ($chn * 640 | 0) + 34 | 0; //@line 77257
 if ((HEAP8[$59] | 0) != 0) {
  $63 = $scc + 4 + ($chn * 640 | 0) + 16 | 0; //@line 77262
  HEAP8[$63] = HEAP8[$63] | 64; //@line 77265
  return;
 }
 HEAP32[$20 >> 2] = $48 - 1; //@line 77271
 $69 = HEAP8[$scc + 4 + ($chn * 640 | 0) + 8 | 0] | 0; //@line 77273
 HEAP8[$scc + 4 + ($chn * 640 | 0) + 88 + $52 | 0] = $69; //@line 77275
 HEAP32[$51 >> 2] = (HEAP32[$51 >> 2] | 0) + 1 & 255; //@line 77279
 $75 = HEAP32[$scc + 4 + ($chn * 640 | 0) + 620 >> 2] | 0; //@line 77281
 if (($75 | 0) != 0) {
  FUNCTION_TABLE_vii[$75 & 511](HEAP32[$scc + 4 + ($chn * 640 | 0) + 616 >> 2] | 0, $69); //@line 77287
 }
 $81 = $scc + 4 + ($chn * 640 | 0) + 16 | 0; //@line 77290
 HEAP8[$81] = HEAP8[$81] | 4; //@line 77293
 HEAP8[$59] = 1; //@line 77294
 _e8530_set_int_cond($scc, $chn, 2); //@line 77295
 return;
}
function _e8530_set_int_cond($scc, $chn, $cond) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 $cond = $cond | 0;
 var $1 = 0, $12 = 0, $32 = 0, $46 = 0, $55 = 0, $60 = 0, $69 = 0, $70 = 0, $75 = 0;
 $1 = $cond & 255; //@line 77316
 do {
  if (($1 & 1 | 0) != 0) {
   if ((HEAP8[$scc + 4 + ($chn * 640 | 0) + 1 | 0] & 1) == 0) {
    break;
   }
   $12 = $scc + 23 | 0; //@line 77332
   HEAP8[$12] = HEAP8[$12] | (($chn | 0) == 0 ? 8 : 1); //@line 77335
   HEAP8[$scc + 4 + ($chn * 640 | 0) + 32 | 0] = HEAP8[$scc + 4 + ($chn * 640 | 0) + 15 | 0] | 0; //@line 77339
   HEAP8[$scc + 4 + ($chn * 640 | 0) + 33 | 0] = HEAP8[$scc + 4 + ($chn * 640 | 0) + 16 | 0] | 0; //@line 77343
  }
 } while (0);
 do {
  if (($1 & 2 | 0) != 0) {
   if ((HEAP8[$scc + 4 + ($chn * 640 | 0) + 1 | 0] & 2) == 0) {
    break;
   }
   $32 = $scc + 23 | 0; //@line 77362
   HEAP8[$32] = HEAP8[$32] | (($chn | 0) == 0 ? 16 : 2); //@line 77365
  }
 } while (0);
 do {
  if (($1 & 4 | 0) != 0) {
   if ((HEAP8[$scc + 4 + ($chn * 640 | 0) + 1 | 0] & 24) != 16) {
    break;
   }
   $46 = $scc + 23 | 0; //@line 77384
   HEAP8[$46] = HEAP8[$46] | (($chn | 0) == 0 ? 32 : 4); //@line 77387
  }
 } while (0);
 if ((HEAP8[$scc + 13 | 0] & 8) == 0) {
  $55 = $scc + 1296 | 0; //@line 77397
  if ((HEAP8[$55] | 0) == 0) {
   return;
  }
  HEAP8[$55] = 0; //@line 77405
  $60 = HEAP32[$scc + 1292 >> 2] | 0; //@line 77407
  if (($60 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$60 & 511](HEAP32[$scc + 1288 >> 2] | 0, 0); //@line 77416
  return;
 } else {
  $69 = (HEAP8[$scc + 23 | 0] | 0) != 0 | 0; //@line 77424
  $70 = $scc + 1296 | 0; //@line 77425
  if ((HEAP8[$70] | 0) == $69 << 24 >> 24) {
   return;
  }
  HEAP8[$70] = $69; //@line 77433
  $75 = HEAP32[$scc + 1292 >> 2] | 0; //@line 77435
  if (($75 | 0) == 0) {
   return;
  }
  FUNCTION_TABLE_vii[$75 & 511](HEAP32[$scc + 1288 >> 2] | 0, $69); //@line 77444
  return;
 }
}
function _mem_blk_get_uint8_null($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 return 0; //@line 77458
}
function _mem_blk_get_uint16_null($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 return 0; //@line 77468
}
function _mem_blk_get_uint32_null($ext, $addr) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 return 0; //@line 77478
}
function _mem_blk_set_uint8_null($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 return;
}
function _mem_blk_set_uint16_null($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 return;
}
function _mem_blk_set_uint32_null($ext, $addr, $val) {
 $ext = $ext | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 return;
}
function _mem_blk_set_fct($blk, $ext, $g8, $g16, $g32, $s8, $s16, $s32) {
 $blk = $blk | 0;
 $ext = $ext | 0;
 $g8 = $g8 | 0;
 $g16 = $g16 | 0;
 $g32 = $g32 | 0;
 $s8 = $s8 | 0;
 $s16 = $s16 | 0;
 $s32 = $s32 | 0;
 var $3 = 0, $5 = 0, $7 = 0, $9 = 0, $11 = 0, $13 = 0;
 HEAP32[$blk + 24 >> 2] = $ext; //@line 77530
 $3 = $blk | 0; //@line 77532
 HEAP32[$3 >> 2] = $g8; //@line 77533
 $5 = $blk + 4 | 0; //@line 77535
 HEAP32[$5 >> 2] = $g16; //@line 77536
 $7 = $blk + 8 | 0; //@line 77538
 HEAP32[$7 >> 2] = $g32; //@line 77539
 $9 = $blk + 12 | 0; //@line 77541
 HEAP32[$9 >> 2] = $s8; //@line 77542
 $11 = $blk + 16 | 0; //@line 77544
 HEAP32[$11 >> 2] = $s16; //@line 77545
 $13 = $blk + 20 | 0; //@line 77547
 HEAP32[$13 >> 2] = $s32; //@line 77548
 if ((HEAP32[$blk + 44 >> 2] | 0) != 0) {
  return;
 }
 if (($g8 | 0) == 0) {
  HEAP32[$3 >> 2] = 20; //@line 77560
 }
 if (($g16 | 0) == 0) {
  HEAP32[$5 >> 2] = 42; //@line 77566
 }
 if (($g32 | 0) == 0) {
  HEAP32[$7 >> 2] = 6; //@line 77572
 }
 if (($s8 | 0) == 0) {
  HEAP32[$9 >> 2] = 6; //@line 77578
 }
 if (($s16 | 0) == 0) {
  HEAP32[$11 >> 2] = 34; //@line 77584
 }
 if (($s32 | 0) != 0) {
  return;
 }
 HEAP32[$13 >> 2] = 26; //@line 77593
 return;
}
function _mem_blk_get_data($blk) {
 $blk = $blk | 0;
 return HEAP32[$blk + 44 >> 2] | 0; //@line 77608
}
function _mem_blk_set_readonly($blk, $val) {
 $blk = $blk | 0;
 $val = $val | 0;
 HEAP8[$blk + 29 | 0] = ($val | 0) != 0 | 0; //@line 77621
 return;
}
function _mem_blk_get_addr($blk) {
 $blk = $blk | 0;
 return HEAP32[$blk + 32 >> 2] | 0; //@line 77635
}
function _mem_blk_set_addr($blk, $addr) {
 $blk = $blk | 0;
 $addr = $addr | 0;
 HEAP32[$blk + 32 >> 2] = $addr; //@line 77646
 HEAP32[$blk + 36 >> 2] = $addr - 1 + (HEAP32[$blk + 40 >> 2] | 0); //@line 77652
 return;
}
function _mem_blk_get_size($blk) {
 $blk = $blk | 0;
 return HEAP32[$blk + 40 >> 2] | 0; //@line 77666
}
function _mem_blk_set_size($blk, $size) {
 $blk = $blk | 0;
 $size = $size | 0;
 HEAP32[$blk + 40 >> 2] = $size; //@line 77677
 HEAP32[$blk + 36 >> 2] = $size - 1 + (HEAP32[$blk + 32 >> 2] | 0); //@line 77683
 return;
}
function _buf_set_uint16_be($buf, $addr, $val) {
 $buf = $buf | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 HEAP8[$buf + $addr | 0] = ($val & 65535) >>> 8 & 255; //@line 77699
 HEAP8[$buf + ($addr + 1) | 0] = $val & 255; //@line 77703
 return;
}
function _buf_set_uint32_be($buf, $addr, $val) {
 $buf = $buf | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 HEAP8[$buf + $addr | 0] = $val >>> 24 & 255; //@line 77720
 HEAP8[$buf + ($addr + 1) | 0] = $val >>> 16 & 255; //@line 77725
 HEAP8[$buf + ($addr + 2) | 0] = $val >>> 8 & 255; //@line 77730
 HEAP8[$buf + ($addr + 3) | 0] = $val & 255; //@line 77734
 return;
}
function _mem_blk_get_uint32_be($blk, $addr) {
 $blk = $blk | 0;
 $addr = $addr | 0;
 var $2 = 0;
 $2 = HEAP32[$blk + 44 >> 2] | 0; //@line 77749
 return (((HEAPU8[$2 + $addr | 0] | 0) << 8 | (HEAPU8[$2 + ($addr + 1) | 0] | 0)) << 8 | (HEAPU8[$2 + ($addr + 2) | 0] | 0)) << 8 | (HEAPU8[$2 + ($addr + 3) | 0] | 0) | 0; //@line 77772
}
function _mem_set_fct($mem, $ext, $g8, $g16, $g32, $s8, $s16, $s32) {
 $mem = $mem | 0;
 $ext = $ext | 0;
 $g8 = $g8 | 0;
 $g16 = $g16 | 0;
 $g32 = $g32 | 0;
 $s8 = $s8 | 0;
 $s16 = $s16 | 0;
 $s32 = $s32 | 0;
 HEAP32[$mem + 24 >> 2] = $ext; //@line 77790
 HEAP32[$mem + 28 >> 2] = $g8; //@line 77793
 HEAP32[$mem + 32 >> 2] = $g16; //@line 77796
 HEAP32[$mem + 36 >> 2] = $g32; //@line 77799
 HEAP32[$mem + 40 >> 2] = $s8; //@line 77802
 HEAP32[$mem + 44 >> 2] = $s16; //@line 77805
 HEAP32[$mem + 48 >> 2] = $s32; //@line 77808
 return;
}
function _mem_get_blk($mem, $addr) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, label = 0;
 $1 = $mem + 8 | 0; //@line 77824
 $2 = HEAP32[$1 >> 2] | 0; //@line 77825
 do {
  if (($2 | 0) != 0) {
   $6 = HEAP32[$2 >> 2] | 0; //@line 77831
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    break;
   } else {
    $_0_i = $6; //@line 77853
   }
   return $_0_i | 0; //@line 77857
  }
 } while (0);
 $20 = HEAP32[$mem >> 2] | 0; //@line 77861
 if (($20 | 0) == 0) {
  $_0_i = 0; //@line 77865
  return $_0_i | 0; //@line 77868
 }
 $i_025_i = 0;
 $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
 L12273 : while (1) {
  $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 77878
  do {
   if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
    if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
     break;
    }
    if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
     break L12273;
    }
   }
  } while (0);
  $41 = $i_025_i + 1 | 0; //@line 77902
  if ($41 >>> 0 < $20 >>> 0) {
   $i_025_i = $41;
   $lst_026_i = $lst_026_i + 8 | 0;
  } else {
   $_0_i = 0; //@line 77908
   label = 9833; //@line 77909
   break;
  }
 }
 if ((label | 0) == 9833) {
  return $_0_i | 0; //@line 77916
 }
 HEAP32[$1 >> 2] = $lst_026_i; //@line 77918
 $_0_i = $26; //@line 77920
 return $_0_i | 0; //@line 77923
}
function _e8530_set_params($scc, $chn) {
 $scc = $scc | 0;
 $chn = $chn | 0;
 var $5 = 0, $10 = 0, $14 = 0, $15 = 0, $19 = 0, $22 = 0, $26 = 0, $28 = 0, $_0_i36 = 0, $_ = 0, $36 = 0, $clk_0_in = 0, $clk_0 = 0, $56 = 0, $bps_0 = 0, $69 = 0;
 $5 = (HEAPU8[$scc + 4 + ($chn * 640 | 0) + 5 | 0] | 0) >>> 5 & 3; //@line 77944
 if (($5 | 0) == 3) {
  $10 = 8; //@line 77947
 } else if (($5 | 0) == 1) {
  $10 = 7; //@line 77950
 } else if (($5 | 0) == 2) {
  $10 = 6; //@line 77953
 } else if (($5 | 0) == 0) {
  $10 = 5; //@line 77955
 } else {
  $10 = 0; //@line 77958
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 44 >> 2] = $10; //@line 77962
 $14 = HEAPU8[$scc + 4 + ($chn * 640 | 0) + 4 | 0] | 0; //@line 77965
 $15 = $14 & 3; //@line 77966
 if (($15 | 0) == 3) {
  $19 = 2; //@line 77969
 } else if (($15 | 0) == 0 | ($15 | 0) == 1) {
  $19 = $15;
 } else if (($15 | 0) == 2) {
  $19 = 0; //@line 77974
 } else {
  $19 = 0; //@line 77977
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 40 >> 2] = $19; //@line 77981
 $22 = $14 >>> 2 & 3; //@line 77983
 if (($22 | 0) == 1) {
  $26 = 2; //@line 77986
 } else if (($22 | 0) == 2) {
  $26 = 3; //@line 77989
 } else if (($22 | 0) == 3) {
  $26 = 4; //@line 77992
 } else {
  $26 = 0; //@line 77994
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 48 >> 2] = $26; //@line 77998
 $28 = $14 >>> 6; //@line 77999
 if (($28 | 0) == 0) {
  $_0_i36 = 2; //@line 78001
 } else if (($28 | 0) == 3) {
  $_0_i36 = 128; //@line 78004
 } else if (($28 | 0) == 1) {
  $_0_i36 = 32; //@line 78007
 } else if (($28 | 0) == 2) {
  $_0_i36 = 64; //@line 78010
 } else {
  $_0_i36 = 0; //@line 78013
 }
 $_ = ($26 | 0) == 0 ? 2 : $_0_i36; //@line 78017
 $36 = HEAPU8[$scc + 4 + ($chn * 640 | 0) + 14 | 0] | 0; //@line 78020
 if (($36 & 1 | 0) == 0) {
  HEAP32[$scc + 4 + ($chn * 640 | 0) + 56 >> 2] = 16384; //@line 78026
  $bps_0 = 0; //@line 78027
 } else {
  if (($36 & 2 | 0) == 0) {
   $clk_0_in = $scc + 4 + ($chn * 640 | 0) + 76 | 0; //@line 78034
  } else {
   $clk_0_in = $scc + 1284 | 0; //@line 78038
  }
  $clk_0 = HEAP32[$clk_0_in >> 2] | 0; //@line 78041
  $56 = Math_imul(((HEAPU8[$scc + 4 + ($chn * 640 | 0) + 13 | 0] | 0) << 8 | (HEAPU8[$scc + 4 + ($chn * 640 | 0) + 12 | 0] | 0)) + 2 | 0, $_) | 0; //@line 78051
  HEAP32[$scc + 4 + ($chn * 640 | 0) + 56 >> 2] = (Math_imul($56, $10 + 1 + $26 | 0) | 0) + (($19 | 0) == 0 ? 0 : $56); //@line 78059
  $bps_0 = ($clk_0 >>> 0) / ($56 >>> 0) | 0; //@line 78062
 }
 HEAP32[$scc + 4 + ($chn * 640 | 0) + 36 >> 2] = $bps_0; //@line 78066
 $69 = HEAP32[$scc + 4 + ($chn * 640 | 0) + 636 >> 2] | 0; //@line 78068
 if (($69 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viiiii[$69 & 3](HEAP32[$scc + 4 + ($chn * 640 | 0) + 632 >> 2] | 0, $bps_0, $19, $10, $26); //@line 78077
 return;
}
function _mem_blk_new($base, $size, $alloc) {
 $base = $base | 0;
 $size = $size | 0;
 $alloc = $alloc | 0;
 var $1 = 0, $2 = 0, $8 = 0, $15 = 0, $_0 = 0;
 $1 = _malloc(48) | 0; //@line 78094
 $2 = $1; //@line 78095
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 78099
  return $_0 | 0; //@line 78102
 }
 do {
  if (($alloc | 0) == 0) {
   HEAP32[$1 + 44 >> 2] = 0; //@line 78110
   $15 = 0; //@line 78111
  } else {
   $8 = _malloc($size + 16 | 0) | 0; //@line 78114
   HEAP32[$1 + 44 >> 2] = $8; //@line 78117
   if (($8 | 0) != 0) {
    $15 = $8; //@line 78121
    break;
   }
   _free($1); //@line 78124
   $_0 = 0; //@line 78126
   return $_0 | 0; //@line 78129
  }
 } while (0);
 _memset($1 | 0, 0, 24); //@line 78135
 HEAP32[$1 + 24 >> 2] = $1; //@line 78136
 HEAP8[$1 + 28 | 0] = 1; //@line 78138
 HEAP8[$1 + 29 | 0] = 0; //@line 78140
 HEAP8[$1 + 30 | 0] = ($15 | 0) != 0 | 0; //@line 78144
 HEAP32[$1 + 32 >> 2] = $base; //@line 78147
 HEAP32[$1 + 36 >> 2] = $base - 1 + $size; //@line 78152
 HEAP32[$1 + 40 >> 2] = $size; //@line 78155
 $_0 = $2; //@line 78157
 return $_0 | 0; //@line 78160
}
function _mem_blk_clone($blk) {
 $blk = $blk | 0;
 var $1 = 0, $4 = 0, $5 = 0, $_0 = 0;
 $1 = _malloc(48) | 0; //@line 78169
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 78173
  return $_0 | 0; //@line 78176
 }
 $4 = $1; //@line 78178
 $5 = $blk; //@line 78179
 _memcpy($1 | 0, $5 | 0, 48) | 0; //@line 78180
 HEAP8[$1 + 30 | 0] = 0; //@line 78182
 HEAP8[$1 + 28 | 0] = 1; //@line 78184
 $_0 = $4; //@line 78186
 return $_0 | 0; //@line 78189
}
function _mem_blk_clear($blk, $val) {
 $blk = $blk | 0;
 $val = $val | 0;
 var $2 = 0;
 $2 = HEAP32[$blk + 44 >> 2] | 0; //@line 78200
 if (($2 | 0) == 0) {
  return;
 }
 _memset($2 | 0, $val | 0, HEAP32[$blk + 40 >> 2] | 0); //@line 78209
 return;
}
function _mem_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(56) | 0; //@line 78220
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 78224
  return $_0 | 0; //@line 78227
 }
 _memset($1 | 0, 0, 52); //@line 78232
 HEAP32[$1 + 52 >> 2] = -1; //@line 78233
 $_0 = $1; //@line 78235
 return $_0 | 0; //@line 78238
}
function _mem_prt_state($mem, $fp) {
 $mem = $mem | 0;
 $fp = $fp | 0;
 var $1 = 0, $4 = 0, $i_09 = 0, $8 = 0, $10 = 0, $12 = 0, $14 = 0, $18 = 0, sp = 0;
 sp = STACKTOP; //@line 78249
 $1 = $mem | 0; //@line 78250
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  STACKTOP = sp; //@line 78255
  return;
 }
 $4 = $mem + 4 | 0; //@line 78258
 $i_09 = 0; //@line 78260
 do {
  $8 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($i_09 << 3) >> 2] | 0; //@line 78265
  $10 = HEAP32[$8 + 32 >> 2] | 0; //@line 78267
  $12 = HEAP32[$8 + 36 >> 2] | 0; //@line 78269
  $14 = HEAP32[$8 + 40 >> 2] | 0; //@line 78271
  $18 = (HEAP8[$8 + 29 | 0] | 0) != 0 | 0; //@line 78275
  _fprintf($fp | 0, 55544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 40 | 0, HEAP32[tempInt >> 2] = $i_09, HEAP32[tempInt + 8 >> 2] = $10, HEAP32[tempInt + 16 >> 2] = $12, HEAP32[tempInt + 24 >> 2] = $14, HEAP32[tempInt + 32 >> 2] = $18, tempInt) | 0) | 0; //@line 78276
  $i_09 = $i_09 + 1 | 0; //@line 78277
 } while ($i_09 >>> 0 < (HEAP32[$1 >> 2] | 0) >>> 0);
 STACKTOP = sp; //@line 78287
 return;
}
function _mem_add_blk($mem, $blk, $del) {
 $mem = $mem | 0;
 $blk = $blk | 0;
 $del = $del | 0;
 var $3 = 0, $6 = 0, $10 = 0, $11 = 0, $14 = 0;
 if (($blk | 0) == 0) {
  return;
 }
 $3 = $mem + 4 | 0; //@line 78307
 $6 = $mem | 0; //@line 78310
 $10 = _realloc(HEAP32[$3 >> 2] | 0, (HEAP32[$6 >> 2] << 3) + 8 | 0) | 0; //@line 78314
 $11 = $10; //@line 78315
 if (($10 | 0) == 0) {
  return;
 }
 HEAP32[$3 >> 2] = $11; //@line 78322
 $14 = HEAP32[$6 >> 2] | 0; //@line 78323
 HEAP32[$6 >> 2] = $14 + 1; //@line 78325
 HEAP32[$11 + ($14 << 3) >> 2] = $blk; //@line 78327
 HEAP32[$11 + ($14 << 3) + 4 >> 2] = ($del | 0) != 0; //@line 78331
 _memset($mem + 8 | 0, 0, 16); //@line 78334
 return;
}
function _mem_rmv_blk($mem, $blk) {
 $mem = $mem | 0;
 $blk = $blk | 0;
 var $2 = 0, $3 = 0, $4 = 0, $6 = 0, $i_012 = 0, $j_011 = 0, $7 = 0, $14 = 0, $15 = 0, $16$1 = 0, $18 = 0, $j_1 = 0, $19 = 0, $j_0_lcssa = 0, $scevgep_i = 0, $scevgep4_i = 0;
 $2 = HEAP32[$mem + 4 >> 2] | 0; //@line 78351
 $3 = $mem | 0; //@line 78352
 $4 = HEAP32[$3 >> 2] | 0; //@line 78353
 if (($4 | 0) == 0) {
  $j_0_lcssa = 0; //@line 78357
  HEAP32[$3 >> 2] = $j_0_lcssa; //@line 78359
  $scevgep_i = $mem + 8 | 0; //@line 78360
  $scevgep4_i = $scevgep_i; //@line 78361
  _memset($scevgep4_i | 0, 0, 16); //@line 78362
  return;
 } else {
  $j_011 = 0;
  $i_012 = 0;
  $6 = $4;
 }
 while (1) {
  $7 = $2 + ($i_012 << 3) | 0; //@line 78372
  if ((HEAP32[$7 >> 2] | 0) == ($blk | 0)) {
   $j_1 = $j_011;
   $18 = $6;
  } else {
   $14 = $7; //@line 78382
   $15 = $2 + ($j_011 << 3) | 0; //@line 78383
   $16$1 = HEAP32[$14 + 4 >> 2] | 0; //@line 78387
   HEAP32[$15 >> 2] = HEAP32[$14 >> 2]; //@line 78389
   HEAP32[$15 + 4 >> 2] = $16$1; //@line 78391
   $j_1 = $j_011 + 1 | 0;
   $18 = HEAP32[$3 >> 2] | 0;
  }
  $19 = $i_012 + 1 | 0; //@line 78398
  if ($19 >>> 0 < $18 >>> 0) {
   $j_011 = $j_1;
   $i_012 = $19;
   $6 = $18;
  } else {
   $j_0_lcssa = $j_1; //@line 78404
   break;
  }
 }
 HEAP32[$3 >> 2] = $j_0_lcssa; //@line 78409
 $scevgep_i = $mem + 8 | 0; //@line 78410
 $scevgep4_i = $scevgep_i; //@line 78411
 _memset($scevgep4_i | 0, 0, 16); //@line 78412
 return;
}
function _mem_get_uint8($mem, $addr) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, $47 = 0, $49 = 0, $61 = 0, $_0 = 0, label = 0;
 $1 = $mem + 12 | 0; //@line 78431
 $2 = HEAP32[$1 >> 2] | 0; //@line 78432
 do {
  if (($2 | 0) == 0) {
   label = 9914; //@line 78437
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 78440
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 9914; //@line 78446
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 9914; //@line 78454
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 9914; //@line 78462
   } else {
    $_0_i = $6; //@line 78464
    label = 9921; //@line 78465
   }
  }
 } while (0);
 L12373 : do {
  if ((label | 0) == 9914) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 78472
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i = 0;
   $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
   L12376 : while (1) {
    $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 78486
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12376;
      }
     }
    } while (0);
    $41 = $i_025_i + 1 | 0; //@line 78510
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i = $41;
     $lst_026_i = $lst_026_i + 8 | 0;
    } else {
     break L12373;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i; //@line 78519
   $_0_i = $26; //@line 78521
   label = 9921; //@line 78522
  }
 } while (0);
 do {
  if ((label | 0) == 9921) {
   if (($_0_i | 0) == 0) {
    break;
   }
   $47 = $addr - (HEAP32[$_0_i + 32 >> 2] | 0) | 0; //@line 78535
   $49 = HEAP32[$_0_i >> 2] | 0; //@line 78537
   if (($49 | 0) == 0) {
    $_0 = HEAP8[(HEAP32[$_0_i + 44 >> 2] | 0) + $47 | 0] | 0; //@line 78546
    return $_0 | 0; //@line 78549
   } else {
    $_0 = FUNCTION_TABLE_iii[$49 & 63](HEAP32[$_0_i + 24 >> 2] | 0, $47) | 0; //@line 78555
    return $_0 | 0; //@line 78558
   }
  }
 } while (0);
 $61 = HEAP32[$mem + 28 >> 2] | 0; //@line 78563
 if (($61 | 0) == 0) {
  $_0 = HEAP32[$mem + 52 >> 2] & 255; //@line 78571
  return $_0 | 0; //@line 78574
 } else {
  $_0 = FUNCTION_TABLE_iii[$61 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr) | 0; //@line 78580
  return $_0 | 0; //@line 78583
 }
 return 0;
}
function _mem_get_uint16_be($mem, $addr) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, $45 = 0, $52 = 0, $59 = 0, $61 = 0, $69 = 0, $80 = 0, $_0 = 0, label = 0;
 $1 = $mem + 12 | 0; //@line 78603
 $2 = HEAP32[$1 >> 2] | 0; //@line 78604
 do {
  if (($2 | 0) == 0) {
   label = 9937; //@line 78609
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 78612
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 9937; //@line 78618
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 9937; //@line 78626
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 9937; //@line 78634
   } else {
    $_0_i = $6; //@line 78636
    label = 9944; //@line 78637
   }
  }
 } while (0);
 L12402 : do {
  if ((label | 0) == 9937) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 78644
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i = 0;
   $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
   L12405 : while (1) {
    $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 78658
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12405;
      }
     }
    } while (0);
    $41 = $i_025_i + 1 | 0; //@line 78682
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i = $41;
     $lst_026_i = $lst_026_i + 8 | 0;
    } else {
     break L12402;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i; //@line 78691
   $_0_i = $26; //@line 78693
   label = 9944; //@line 78694
  }
 } while (0);
 do {
  if ((label | 0) == 9944) {
   if (($_0_i | 0) == 0) {
    break;
   }
   $45 = $addr + 1 | 0; //@line 78705
   if ($45 >>> 0 > (HEAP32[$_0_i + 36 >> 2] | 0) >>> 0) {
    $52 = ((_mem_get_uint8($mem, $addr) | 0) & 255) << 8; //@line 78713
    $_0 = $52 | (_mem_get_uint8($mem, $45) | 0) & 255; //@line 78718
    return $_0 | 0; //@line 78721
   }
   $59 = $addr - (HEAP32[$_0_i + 32 >> 2] | 0) | 0; //@line 78725
   $61 = HEAP32[$_0_i + 4 >> 2] | 0; //@line 78727
   if (($61 | 0) == 0) {
    $69 = HEAP32[$_0_i + 44 >> 2] | 0; //@line 78732
    $_0 = HEAPU8[$69 + $59 | 0] << 8 | HEAPU8[$69 + ($59 + 1) | 0]; //@line 78743
    return $_0 | 0; //@line 78746
   } else {
    $_0 = FUNCTION_TABLE_iii[$61 & 63](HEAP32[$_0_i + 24 >> 2] | 0, $59) | 0; //@line 78752
    return $_0 | 0; //@line 78755
   }
  }
 } while (0);
 $80 = HEAP32[$mem + 32 >> 2] | 0; //@line 78760
 if (($80 | 0) == 0) {
  $_0 = HEAP32[$mem + 52 >> 2] & 65535; //@line 78768
  return $_0 | 0; //@line 78771
 } else {
  $_0 = FUNCTION_TABLE_iii[$80 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr) | 0; //@line 78777
  return $_0 | 0; //@line 78780
 }
 return 0;
}
function _mem_get_uint32_be($mem, $addr) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, $45 = 0, $52 = 0, $57 = 0, $62 = 0, $69 = 0, $71 = 0, $79 = 0, $102 = 0, $_0 = 0, label = 0;
 $1 = $mem + 12 | 0; //@line 78803
 $2 = HEAP32[$1 >> 2] | 0; //@line 78804
 do {
  if (($2 | 0) == 0) {
   label = 9963; //@line 78809
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 78812
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 9963; //@line 78818
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 9963; //@line 78826
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 9963; //@line 78834
   } else {
    $_0_i = $6; //@line 78836
    label = 9970; //@line 78837
   }
  }
 } while (0);
 L12435 : do {
  if ((label | 0) == 9963) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 78844
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i = 0;
   $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
   L12438 : while (1) {
    $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 78858
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12438;
      }
     }
    } while (0);
    $41 = $i_025_i + 1 | 0; //@line 78882
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i = $41;
     $lst_026_i = $lst_026_i + 8 | 0;
    } else {
     break L12435;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i; //@line 78891
   $_0_i = $26; //@line 78893
   label = 9970; //@line 78894
  }
 } while (0);
 do {
  if ((label | 0) == 9970) {
   if (($_0_i | 0) == 0) {
    break;
   }
   $45 = $addr + 3 | 0; //@line 78905
   if ($45 >>> 0 > (HEAP32[$_0_i + 36 >> 2] | 0) >>> 0) {
    $52 = ((_mem_get_uint8($mem, $addr) | 0) & 255) << 24; //@line 78913
    $57 = ((_mem_get_uint8($mem, $addr + 1 | 0) | 0) & 255) << 16 | $52; //@line 78918
    $62 = $57 | ((_mem_get_uint8($mem, $addr + 2 | 0) | 0) & 255) << 8; //@line 78923
    $_0 = $62 | (_mem_get_uint8($mem, $45) | 0) & 255; //@line 78928
    return $_0 | 0; //@line 78931
   }
   $69 = $addr - (HEAP32[$_0_i + 32 >> 2] | 0) | 0; //@line 78935
   $71 = HEAP32[$_0_i + 8 >> 2] | 0; //@line 78937
   if (($71 | 0) == 0) {
    $79 = HEAP32[$_0_i + 44 >> 2] | 0; //@line 78942
    $_0 = HEAPU8[$79 + ($69 + 1) | 0] << 16 | HEAPU8[$79 + $69 | 0] << 24 | HEAPU8[$79 + ($69 + 2) | 0] << 8 | HEAPU8[$79 + ($69 + 3) | 0]; //@line 78965
    return $_0 | 0; //@line 78968
   } else {
    $_0 = FUNCTION_TABLE_iii[$71 & 63](HEAP32[$_0_i + 24 >> 2] | 0, $69) | 0; //@line 78974
    return $_0 | 0; //@line 78977
   }
  }
 } while (0);
 $102 = HEAP32[$mem + 36 >> 2] | 0; //@line 78982
 if (($102 | 0) == 0) {
  $_0 = HEAP32[$mem + 52 >> 2] | 0; //@line 78989
  return $_0 | 0; //@line 78992
 } else {
  $_0 = FUNCTION_TABLE_iii[$102 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr) | 0; //@line 78998
  return $_0 | 0; //@line 79001
 }
 return 0;
}
function _mem_set_uint8_rw($mem, $addr, $val) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i_i = 0, $i_025_i_i = 0, $26 = 0, $41 = 0, $_0_i_i = 0, $47 = 0, $49 = 0, $59 = 0, label = 0;
 $1 = $mem + 8 | 0; //@line 15
 $2 = HEAP32[$1 >> 2] | 0; //@line 16
 do {
  if (($2 | 0) == 0) {
   label = 9989; //@line 21
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 24
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 9989; //@line 30
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 9989; //@line 38
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 9989; //@line 46
   } else {
    $_0_i_i = $6; //@line 48
    label = 9996; //@line 49
   }
  }
 } while (0);
 L12468 : do {
  if ((label | 0) == 9989) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 56
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i_i = 0;
   $lst_026_i_i = HEAP32[$mem + 4 >> 2] | 0;
   L12471 : while (1) {
    $26 = HEAP32[$lst_026_i_i >> 2] | 0; //@line 70
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12471;
      }
     }
    } while (0);
    $41 = $i_025_i_i + 1 | 0; //@line 94
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i_i = $41;
     $lst_026_i_i = $lst_026_i_i + 8 | 0;
    } else {
     break L12468;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i_i; //@line 103
   $_0_i_i = $26; //@line 105
   label = 9996; //@line 106
  }
 } while (0);
 do {
  if ((label | 0) == 9996) {
   if (($_0_i_i | 0) == 0) {
    break;
   }
   $47 = $addr - (HEAP32[$_0_i_i + 32 >> 2] | 0) | 0; //@line 119
   $49 = HEAP32[$_0_i_i + 12 >> 2] | 0; //@line 121
   if (($49 | 0) == 0) {
    HEAP8[(HEAP32[$_0_i_i + 44 >> 2] | 0) + $47 | 0] = $val; //@line 128
    return;
   } else {
    FUNCTION_TABLE_viii[$49 & 63](HEAP32[$_0_i_i + 24 >> 2] | 0, $47, $val); //@line 134
    return;
   }
  }
 } while (0);
 $59 = HEAP32[$mem + 40 >> 2] | 0; //@line 142
 if (($59 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viii[$59 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr, $val); //@line 151
 return;
}
function _mem_set_uint8($mem, $addr, $val) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, $51 = 0, $53 = 0, $63 = 0, label = 0;
 $1 = $mem + 16 | 0; //@line 171
 $2 = HEAP32[$1 >> 2] | 0; //@line 172
 do {
  if (($2 | 0) == 0) {
   label = 10011; //@line 177
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 180
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 10011; //@line 186
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 10011; //@line 194
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 10011; //@line 202
   } else {
    $_0_i = $6; //@line 204
    label = 10018; //@line 205
   }
  }
 } while (0);
 L12496 : do {
  if ((label | 0) == 10011) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 212
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i = 0;
   $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
   L12499 : while (1) {
    $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 226
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12499;
      }
     }
    } while (0);
    $41 = $i_025_i + 1 | 0; //@line 250
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i = $41;
     $lst_026_i = $lst_026_i + 8 | 0;
    } else {
     break L12496;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i; //@line 259
   $_0_i = $26; //@line 261
   label = 10018; //@line 262
  }
 } while (0);
 do {
  if ((label | 0) == 10018) {
   if (($_0_i | 0) == 0) {
    break;
   }
   if ((HEAP8[$_0_i + 29 | 0] | 0) != 0) {
    return;
   }
   $51 = $addr - (HEAP32[$_0_i + 32 >> 2] | 0) | 0; //@line 283
   $53 = HEAP32[$_0_i + 12 >> 2] | 0; //@line 285
   if (($53 | 0) == 0) {
    HEAP8[(HEAP32[$_0_i + 44 >> 2] | 0) + $51 | 0] = $val; //@line 292
    return;
   } else {
    FUNCTION_TABLE_viii[$53 & 63](HEAP32[$_0_i + 24 >> 2] | 0, $51, $val); //@line 298
    return;
   }
  }
 } while (0);
 $63 = HEAP32[$mem + 40 >> 2] | 0; //@line 306
 if (($63 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viii[$63 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr, $val); //@line 315
 return;
}
function _mem_set_uint16_be($mem, $addr, $val) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, $45 = 0, $60 = 0, $62 = 0, $70 = 0, $78 = 0, label = 0;
 $1 = $mem + 16 | 0; //@line 337
 $2 = HEAP32[$1 >> 2] | 0; //@line 338
 do {
  if (($2 | 0) == 0) {
   label = 10035; //@line 343
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 346
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 10035; //@line 352
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 10035; //@line 360
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 10035; //@line 368
   } else {
    $_0_i = $6; //@line 370
    label = 10042; //@line 371
   }
  }
 } while (0);
 L12527 : do {
  if ((label | 0) == 10035) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 378
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i = 0;
   $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
   L12530 : while (1) {
    $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 392
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12530;
      }
     }
    } while (0);
    $41 = $i_025_i + 1 | 0; //@line 416
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i = $41;
     $lst_026_i = $lst_026_i + 8 | 0;
    } else {
     break L12527;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i; //@line 425
   $_0_i = $26; //@line 427
   label = 10042; //@line 428
  }
 } while (0);
 do {
  if ((label | 0) == 10042) {
   if (($_0_i | 0) == 0) {
    break;
   }
   $45 = $addr + 1 | 0; //@line 439
   if ($45 >>> 0 > (HEAP32[$_0_i + 36 >> 2] | 0) >>> 0) {
    _mem_set_uint8($mem, $addr, ($val & 65535) >>> 8 & 255); //@line 447
    _mem_set_uint8($mem, $45, $val & 255); //@line 449
    return;
   }
   if ((HEAP8[$_0_i + 29 | 0] | 0) != 0) {
    return;
   }
   $60 = $addr - (HEAP32[$_0_i + 32 >> 2] | 0) | 0; //@line 464
   $62 = HEAP32[$_0_i + 16 >> 2] | 0; //@line 466
   if (($62 | 0) == 0) {
    $70 = $_0_i + 44 | 0; //@line 472
    HEAP8[(HEAP32[$70 >> 2] | 0) + $60 | 0] = ($val & 65535) >>> 8 & 255; //@line 475
    HEAP8[(HEAP32[$70 >> 2] | 0) + ($60 + 1) | 0] = $val & 255; //@line 480
    return;
   } else {
    FUNCTION_TABLE_viii[$62 & 63](HEAP32[$_0_i + 24 >> 2] | 0, $60, $val); //@line 486
    return;
   }
  }
 } while (0);
 $78 = HEAP32[$mem + 44 >> 2] | 0; //@line 494
 if (($78 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viii[$78 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr, $val); //@line 503
 return;
}
function _mem_set_uint32_be($mem, $addr, $val) {
 $mem = $mem | 0;
 $addr = $addr | 0;
 $val = $val | 0;
 var $1 = 0, $2 = 0, $6 = 0, $20 = 0, $lst_026_i = 0, $i_025_i = 0, $26 = 0, $41 = 0, $_0_i = 0, $45 = 0, $66 = 0, $68 = 0, $76 = 0, $94 = 0, label = 0;
 $1 = $mem + 16 | 0; //@line 527
 $2 = HEAP32[$1 >> 2] | 0; //@line 528
 do {
  if (($2 | 0) == 0) {
   label = 10062; //@line 533
  } else {
   $6 = HEAP32[$2 >> 2] | 0; //@line 536
   if ((HEAP8[$6 + 28 | 0] | 0) == 0) {
    label = 10062; //@line 542
    break;
   }
   if ((HEAP32[$6 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
    label = 10062; //@line 550
    break;
   }
   if ((HEAP32[$6 + 36 >> 2] | 0) >>> 0 < $addr >>> 0) {
    label = 10062; //@line 558
   } else {
    $_0_i = $6; //@line 560
    label = 10069; //@line 561
   }
  }
 } while (0);
 L12562 : do {
  if ((label | 0) == 10062) {
   $20 = HEAP32[$mem >> 2] | 0; //@line 568
   if (($20 | 0) == 0) {
    break;
   }
   $i_025_i = 0;
   $lst_026_i = HEAP32[$mem + 4 >> 2] | 0;
   L12565 : while (1) {
    $26 = HEAP32[$lst_026_i >> 2] | 0; //@line 582
    do {
     if ((HEAP8[$26 + 28 | 0] | 0) != 0) {
      if ((HEAP32[$26 + 32 >> 2] | 0) >>> 0 > $addr >>> 0) {
       break;
      }
      if ((HEAP32[$26 + 36 >> 2] | 0) >>> 0 >= $addr >>> 0) {
       break L12565;
      }
     }
    } while (0);
    $41 = $i_025_i + 1 | 0; //@line 606
    if ($41 >>> 0 < $20 >>> 0) {
     $i_025_i = $41;
     $lst_026_i = $lst_026_i + 8 | 0;
    } else {
     break L12562;
    }
   }
   HEAP32[$1 >> 2] = $lst_026_i; //@line 615
   $_0_i = $26; //@line 617
   label = 10069; //@line 618
  }
 } while (0);
 do {
  if ((label | 0) == 10069) {
   if (($_0_i | 0) == 0) {
    break;
   }
   $45 = $addr + 3 | 0; //@line 629
   if ($45 >>> 0 > (HEAP32[$_0_i + 36 >> 2] | 0) >>> 0) {
    _mem_set_uint8($mem, $addr, $val >>> 24 & 255); //@line 637
    _mem_set_uint8($mem, $addr + 1 | 0, $val >>> 16 & 255); //@line 641
    _mem_set_uint8($mem, $addr + 2 | 0, $val >>> 8 & 255); //@line 645
    _mem_set_uint8($mem, $45, $val & 255); //@line 647
    return;
   }
   if ((HEAP8[$_0_i + 29 | 0] | 0) != 0) {
    return;
   }
   $66 = $addr - (HEAP32[$_0_i + 32 >> 2] | 0) | 0; //@line 662
   $68 = HEAP32[$_0_i + 20 >> 2] | 0; //@line 664
   if (($68 | 0) == 0) {
    $76 = $_0_i + 44 | 0; //@line 670
    HEAP8[(HEAP32[$76 >> 2] | 0) + $66 | 0] = $val >>> 24 & 255; //@line 673
    HEAP8[(HEAP32[$76 >> 2] | 0) + ($66 + 1) | 0] = $val >>> 16 & 255; //@line 679
    HEAP8[(HEAP32[$76 >> 2] | 0) + ($66 + 2) | 0] = $val >>> 8 & 255; //@line 685
    HEAP8[(HEAP32[$76 >> 2] | 0) + ($66 + 3) | 0] = $val & 255; //@line 690
    return;
   } else {
    FUNCTION_TABLE_viii[$68 & 63](HEAP32[$_0_i + 24 >> 2] | 0, $66, $val); //@line 696
    return;
   }
  }
 } while (0);
 $94 = HEAP32[$mem + 48 >> 2] | 0; //@line 704
 if (($94 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viii[$94 & 63](HEAP32[$mem + 24 >> 2] | 0, $addr, $val); //@line 713
 return;
}
function _dsk_psi_set_encoding($fdc, $enc) {
 $fdc = $fdc | 0;
 $enc = $enc | 0;
 HEAP32[$fdc + 76 >> 2] = $enc; //@line 727
 return;
}
function _dsk_get_uint32_be($buf, $i) {
 $buf = $buf | 0;
 $i = $i | 0;
 return (((HEAPU8[$buf + $i | 0] | 0) << 8 | (HEAPU8[$buf + ($i + 1) | 0] | 0)) << 8 | (HEAPU8[$buf + ($i + 2) | 0] | 0)) << 8 | (HEAPU8[$buf + ($i + 3) | 0] | 0) | 0; //@line 763
}
function _dsk_set_uint32_be($buf, $i, $v) {
 $buf = $buf | 0;
 $i = $i | 0;
 $v = $v | 0;
 HEAP8[$buf + $i | 0] = $v >>> 24 & 255; //@line 778
 HEAP8[$buf + ($i + 1) | 0] = $v >>> 16 & 255; //@line 783
 HEAP8[$buf + ($i + 2) | 0] = $v >>> 8 & 255; //@line 788
 HEAP8[$buf + ($i + 3) | 0] = $v & 255; //@line 792
 return;
}
function _dsk_psi_read_chs($fdc, $buf, $cnt, $c, $h, $s, $phy) {
 $fdc = $fdc | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $phy = $phy | 0;
 var $2 = 0, $6 = 0, $10 = 0, $12 = 0, $alt_0 = 0, $16 = 0, $19 = 0, $23 = 0, $ret_0 = 0, $27 = 0, $30 = 0, $ret_0_ = 0, $ret_2 = 0, $ret_2_ = 0, $ret_4 = 0, $_0 = 0;
 $2 = HEAP32[$fdc + 68 >> 2] | 0; //@line 815
 if (($2 | 0) == 0) {
  HEAP32[$cnt >> 2] = 0; //@line 819
  $_0 = 1; //@line 821
  return $_0 | 0; //@line 824
 }
 $6 = _psi_img_get_sector($2, $c, $h, $s, $phy) | 0; //@line 826
 if (($6 | 0) == 0) {
  HEAP32[$cnt >> 2] = 0; //@line 830
  $_0 = 1; //@line 832
  return $_0 | 0; //@line 835
 }
 $10 = $6 + 20 | 0; //@line 837
 $12 = _psi_sct_get_alternate($6, HEAP32[$10 >> 2] | 0) | 0; //@line 839
 if (($12 | 0) == 0) {
  HEAP32[$10 >> 2] = 0; //@line 843
  $alt_0 = $6; //@line 845
 } else {
  $alt_0 = $12; //@line 847
 }
 $16 = HEAP32[$cnt >> 2] | 0; //@line 850
 $19 = HEAPU16[$alt_0 + 10 >> 1] | 0; //@line 853
 if ($16 >>> 0 > $19 >>> 0) {
  HEAP32[$cnt >> 2] = $19; //@line 857
  $ret_0 = 32;
  $23 = $19;
 } else {
  $ret_0 = 0;
  $23 = $16;
 }
 if (($23 | 0) != 0) {
  $27 = HEAP32[$alt_0 + 24 >> 2] | 0; //@line 869
  _memcpy($buf | 0, $27 | 0, $23) | 0; //@line 870
 }
 $30 = HEAP32[$alt_0 + 12 >> 2] | 0; //@line 874
 $ret_0_ = ($30 & 8 | 0) == 0 ? $ret_0 : $ret_0 | 2; //@line 878
 $ret_2 = ($30 & 1 | 0) == 0 ? $ret_0_ : $ret_0_ | 4; //@line 882
 $ret_2_ = ($30 & 2 | 0) == 0 ? $ret_2 : $ret_2 | 8; //@line 886
 $ret_4 = ($30 & 4 | 0) == 0 ? $ret_2_ : $ret_2_ | 16; //@line 890
 if ((HEAP32[$6 >> 2] | 0) == 0) {
  $_0 = $ret_4; //@line 896
  return $_0 | 0; //@line 899
 }
 HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 1; //@line 903
 $_0 = $ret_4; //@line 905
 return $_0 | 0; //@line 908
}
function _dsk_psi_read_tags($fdc, $buf, $cnt, $c, $h, $s, $phy) {
 $fdc = $fdc | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $phy = $phy | 0;
 var $2 = 0, $5 = 0, $8 = 0, $10 = 0, $alt_0 = 0, $_0 = 0;
 _memset($buf | 0, 0, $cnt | 0); //@line 924
 $2 = HEAP32[$fdc + 68 >> 2] | 0; //@line 926
 if (($2 | 0) == 0) {
  $_0 = 0; //@line 930
  return $_0 | 0; //@line 933
 }
 $5 = _psi_img_get_sector($2, $c, $h, $s, $phy) | 0; //@line 935
 if (($5 | 0) == 0) {
  $_0 = 0; //@line 939
  return $_0 | 0; //@line 942
 }
 $8 = $5 + 20 | 0; //@line 944
 $10 = _psi_sct_get_alternate($5, HEAP32[$8 >> 2] | 0) | 0; //@line 946
 if (($10 | 0) == 0) {
  HEAP32[$8 >> 2] = 0; //@line 950
  $alt_0 = $5; //@line 952
 } else {
  $alt_0 = $10; //@line 954
 }
 $_0 = _psi_sct_get_tags($alt_0, $buf, $cnt) | 0; //@line 959
 return $_0 | 0; //@line 962
}
function _dsk_psi_write_chs($fdc, $buf, $cnt, $c, $h, $s, $phy) {
 $fdc = $fdc | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $phy = $phy | 0;
 var $2 = 0, $10 = 0, $14 = 0, $20 = 0, $23 = 0, $27 = 0, $ret_0 = 0, $31 = 0, $35 = 0, $36 = 0, $_0 = 0;
 $2 = HEAP32[$fdc + 68 >> 2] | 0; //@line 981
 if (($2 | 0) == 0) {
  HEAP32[$cnt >> 2] = 0; //@line 985
  $_0 = 1; //@line 987
  return $_0 | 0; //@line 990
 }
 if ((HEAP8[$fdc + 56 | 0] | 0) != 0) {
  $_0 = 64; //@line 997
  return $_0 | 0; //@line 1000
 }
 $10 = _psi_img_get_sector($2, $c, $h, $s, $phy) | 0; //@line 1002
 if (($10 | 0) == 0) {
  HEAP32[$cnt >> 2] = 0; //@line 1006
  $_0 = 1; //@line 1008
  return $_0 | 0; //@line 1011
 }
 $14 = $10 + 12 | 0; //@line 1013
 if ((HEAP32[$14 >> 2] & 8 | 0) != 0) {
  $_0 = 2; //@line 1019
  return $_0 | 0; //@line 1022
 }
 HEAP8[$fdc + 72 | 0] = 1; //@line 1025
 $20 = HEAP32[$cnt >> 2] | 0; //@line 1026
 $23 = HEAPU16[$10 + 10 >> 1] | 0; //@line 1029
 if ($20 >>> 0 > $23 >>> 0) {
  HEAP32[$cnt >> 2] = $23; //@line 1033
  $ret_0 = 32;
  $27 = $23;
 } else {
  $ret_0 = 0;
  $27 = $20;
 }
 if (($27 | 0) != 0) {
  $31 = HEAP32[$10 + 24 >> 2] | 0; //@line 1045
  _memcpy($31 | 0, $buf | 0, $27) | 0; //@line 1046
 }
 HEAP32[$14 >> 2] = HEAP32[$14 >> 2] & -3; //@line 1051
 $35 = $10 | 0; //@line 1052
 $36 = HEAP32[$35 >> 2] | 0; //@line 1053
 if (($36 | 0) == 0) {
  $_0 = $ret_0; //@line 1057
  return $_0 | 0; //@line 1060
 }
 _psi_sct_del($36); //@line 1062
 HEAP32[$35 >> 2] = 0; //@line 1063
 HEAP32[$10 + 20 >> 2] = 0; //@line 1065
 $_0 = $ret_0; //@line 1067
 return $_0 | 0; //@line 1070
}
function _dsk_psi_write_tags($fdc, $buf, $cnt, $c, $h, $s, $phy) {
 $fdc = $fdc | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $phy = $phy | 0;
 var $2 = 0, $9 = 0, $_0 = 0;
 $2 = HEAP32[$fdc + 68 >> 2] | 0; //@line 1087
 if (($2 | 0) == 0) {
  $_0 = 0; //@line 1091
  return $_0 | 0; //@line 1094
 }
 if ((HEAP8[$fdc + 56 | 0] | 0) != 0) {
  $_0 = 0; //@line 1101
  return $_0 | 0; //@line 1104
 }
 $9 = _psi_img_get_sector($2, $c, $h, $s, $phy) | 0; //@line 1106
 if (($9 | 0) == 0) {
  $_0 = 0; //@line 1110
  return $_0 | 0; //@line 1113
 }
 HEAP8[$fdc + 72 | 0] = 1; //@line 1116
 $_0 = _psi_sct_set_tags($9, $buf, $cnt) | 0; //@line 1119
 return $_0 | 0; //@line 1122
}
function _dsk_psi_erase_disk($fdc) {
 $fdc = $fdc | 0;
 var $2 = 0, $_0 = 0;
 $2 = HEAP32[$fdc + 68 >> 2] | 0; //@line 1133
 if (($2 | 0) == 0) {
  $_0 = 1; //@line 1137
  return $_0 | 0; //@line 1140
 }
 if ((HEAP8[$fdc + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 1147
  return $_0 | 0; //@line 1150
 }
 _psi_img_erase($2); //@line 1152
 HEAP32[$fdc + 28 >> 2] = 0; //@line 1154
 HEAP8[$fdc + 72 | 0] = 1; //@line 1156
 $_0 = 0; //@line 1158
 return $_0 | 0; //@line 1161
}
function _dsk_psi_format_sector($fdc, $pc, $ph, $c, $h, $s, $cnt, $fill) {
 $fdc = $fdc | 0;
 $pc = $pc | 0;
 $ph = $ph | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $cnt = $cnt | 0;
 $fill = $fill | 0;
 var $2 = 0, $9 = 0, $13 = 0, $22 = 0, $_0 = 0;
 $2 = HEAP32[$fdc + 68 >> 2] | 0; //@line 1180
 if (($2 | 0) == 0) {
  $_0 = 1; //@line 1184
  return $_0 | 0; //@line 1187
 }
 if ((HEAP8[$fdc + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 1194
  return $_0 | 0; //@line 1197
 }
 $9 = _psi_img_get_track($2, $pc, $ph, 1) | 0; //@line 1199
 if (($9 | 0) == 0) {
  $_0 = 1; //@line 1203
  return $_0 | 0; //@line 1206
 }
 HEAP8[$fdc + 72 | 0] = 1; //@line 1209
 $13 = _psi_sct_new($c, $h, $s, $cnt) | 0; //@line 1210
 if (($13 | 0) == 0) {
  $_0 = 1; //@line 1214
  return $_0 | 0; //@line 1217
 }
 _psi_sct_fill($13, $fill); //@line 1219
 if ((_psi_trk_add_sector($9, $13) | 0) == 0) {
  _psi_sct_set_encoding($13, HEAP32[$fdc + 76 >> 2] | 0); //@line 1226
  $22 = $fdc + 28 | 0; //@line 1227
  HEAP32[$22 >> 2] = (HEAP32[$22 >> 2] | 0) + 1; //@line 1230
  $_0 = 0; //@line 1232
  return $_0 | 0; //@line 1235
 } else {
  _psi_sct_del($13); //@line 1237
  $_0 = 1; //@line 1239
  return $_0 | 0; //@line 1242
 }
 return 0;
}
function _dsk_psi_open_fp($fp, $type, $ro) {
 $fp = $fp | 0;
 $type = $type | 0;
 $ro = $ro | 0;
 var $1 = 0, $4 = 0, $20 = 0, $27 = 0, $28 = 0, $31 = 0, $c_06_i = 0, $sct_cnt_05_i = 0, $trk_cnt_04_i = 0, $34 = 0, $36 = 0, $37 = 0, $38 = 0, $41 = 0, $t_03_i = 0, $sct_cnt_12_i = 0, $48 = 0, $49 = 0, $sct_cnt_1_lcssa_i = 0, $51 = 0, $59 = 0, $63 = 0, $_0 = 0;
 $1 = _malloc(88) | 0; //@line 1262
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 1266
  return $_0 | 0; //@line 1269
 }
 $4 = $1; //@line 1271
 _dsk_init($4, $1, 0, 0, 0, 0); //@line 1272
 _dsk_set_type($4, 6); //@line 1273
 _dsk_set_readonly($4, $ro); //@line 1274
 HEAP32[$1 + 4 >> 2] = 406; //@line 1277
 HEAP32[$1 + 8 >> 2] = 42; //@line 1280
 HEAP32[$1 + 12 >> 2] = 38; //@line 1283
 HEAP32[$1 + 20 >> 2] = 32; //@line 1286
 HEAP8[$1 + 72 | 0] = 0; //@line 1288
 HEAP32[$1 + 76 >> 2] = 2; //@line 1291
 HEAP32[$1 + 80 >> 2] = $type; //@line 1294
 HEAP32[$1 + 84 >> 2] = 0; //@line 1297
 $20 = _psi_load_fp($fp, $type) | 0; //@line 1298
 HEAP32[$1 + 68 >> 2] = $20; //@line 1301
 if (($20 | 0) == 0) {
  _dsk_psi_del($4); //@line 1305
  $_0 = 0; //@line 1307
  return $_0 | 0; //@line 1310
 }
 $27 = HEAP16[$20 >> 1] | 0; //@line 1313
 $28 = $27 & 65535; //@line 1314
 if ($27 << 16 >> 16 == 0) {
  $_0 = $4; //@line 1318
  return $_0 | 0; //@line 1321
 }
 $31 = HEAP32[$20 + 4 >> 2] | 0; //@line 1324
 $trk_cnt_04_i = 0;
 $sct_cnt_05_i = 0;
 $c_06_i = 0;
 while (1) {
  $34 = HEAP32[$31 + ($c_06_i << 2) >> 2] | 0; //@line 1332
  $36 = HEAP16[$34 + 2 >> 1] | 0; //@line 1334
  $37 = $36 & 65535; //@line 1335
  $38 = $37 + $trk_cnt_04_i | 0; //@line 1336
  if ($36 << 16 >> 16 == 0) {
   $sct_cnt_1_lcssa_i = $sct_cnt_05_i; //@line 1340
  } else {
   $41 = HEAP32[$34 + 4 >> 2] | 0; //@line 1343
   $sct_cnt_12_i = $sct_cnt_05_i;
   $t_03_i = 0;
   while (1) {
    $48 = (HEAPU16[(HEAP32[$41 + ($t_03_i << 2) >> 2] | 0) + 2 >> 1] | 0) + $sct_cnt_12_i | 0; //@line 1354
    $49 = $t_03_i + 1 | 0; //@line 1355
    if ($49 >>> 0 < $37 >>> 0) {
     $sct_cnt_12_i = $48;
     $t_03_i = $49;
    } else {
     $sct_cnt_1_lcssa_i = $48; //@line 1361
     break;
    }
   }
  }
  $51 = $c_06_i + 1 | 0; //@line 1367
  if ($51 >>> 0 < $28 >>> 0) {
   $trk_cnt_04_i = $38;
   $sct_cnt_05_i = $sct_cnt_1_lcssa_i;
   $c_06_i = $51;
  } else {
   break;
  }
 }
 if (($38 | 0) == 0 | ($sct_cnt_1_lcssa_i | 0) == 0) {
  $_0 = $4; //@line 1381
  return $_0 | 0; //@line 1384
 }
 $59 = ((((($38 >>> 0) / ($28 >>> 0) | 0) >>> 1) + $38 | 0) >>> 0) / ($28 >>> 0) | 0; //@line 1389
 $63 = ((((($sct_cnt_1_lcssa_i >>> 0) / ($38 >>> 0) | 0) >>> 1) + $sct_cnt_1_lcssa_i | 0) >>> 0) / ($38 >>> 0) | 0; //@line 1393
 if ((_dsk_set_geometry($4, $sct_cnt_1_lcssa_i, $28, $59, $63) | 0) != 0) {
  $_0 = $4; //@line 1398
  return $_0 | 0; //@line 1401
 }
 _dsk_set_visible_chs($4, $28, $59, $63); //@line 1403
 $_0 = $4; //@line 1405
 return $_0 | 0; //@line 1408
}
function _dsk_psi_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $17 = 0, $30 = 0, $31 = 0, $36 = 0, $40 = 0, $41 = 0, $42 = 0, sp = 0;
 sp = STACKTOP; //@line 1420
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 1422
 L12717 : do {
  if ((HEAP8[$2 + 72 | 0] | 0) != 0) {
   $7 = HEAP32[_stderr >> 2] | 0; //@line 1429
   $8 = $dsk + 24 | 0; //@line 1430
   $9 = HEAP32[$8 >> 2] | 0; //@line 1431
   _fprintf($7 | 0, 42808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $9, tempInt) | 0) | 0; //@line 1432
   $12 = $2 + 84 | 0; //@line 1434
   do {
    if ((HEAP32[$12 >> 2] | 0) != 0) {
     $17 = $2 + 68 | 0; //@line 1441
     if ((HEAP32[$17 >> 2] | 0) == 0) {
      break;
     }
     if ((_dsk_get_readonly($2) | 0) != 0) {
      break;
     }
     if ((_psi_save(HEAP32[$12 >> 2] | 0, HEAP32[$17 >> 2] | 0, HEAP32[$2 + 80 >> 2] | 0) | 0) == 0) {
      break L12717;
     }
    }
   } while (0);
   $30 = HEAP32[_stderr >> 2] | 0; //@line 1468
   $31 = HEAP32[$8 >> 2] | 0; //@line 1469
   _fprintf($30 | 0, 39672, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $31, tempInt) | 0) | 0; //@line 1470
  }
 } while (0);
 $36 = HEAP32[$2 + 68 >> 2] | 0; //@line 1476
 if (($36 | 0) == 0) {
  $40 = $2 + 84 | 0; //@line 1480
  $41 = $40; //@line 1481
  $42 = HEAP32[$41 >> 2] | 0; //@line 1482
  _free($42); //@line 1483
  _free($2); //@line 1484
  STACKTOP = sp; //@line 1485
  return;
 }
 _psi_img_del($36); //@line 1488
 $40 = $2 + 84 | 0; //@line 1490
 $41 = $40; //@line 1491
 $42 = HEAP32[$41 >> 2] | 0; //@line 1492
 _free($42); //@line 1493
 _free($2); //@line 1494
 STACKTOP = sp; //@line 1495
 return;
}
function _dsk_psi_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $c = 0, $h = 0, $s = 0, $cnt = 0, $2 = 0, $3 = 0, $5 = 0, $tmp_014 = 0, $_0913 = 0, $_01012 = 0, $15 = 0, $21 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 1510
 STACKTOP = STACKTOP + 32 | 0; //@line 1510
 $c = sp | 0; //@line 1511
 $h = sp + 8 | 0; //@line 1512
 $s = sp + 16 | 0; //@line 1513
 $cnt = sp + 24 | 0; //@line 1514
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 1516
 $3 = $2; //@line 1517
 $5 = $2 + 68 | 0; //@line 1519
 if (($n | 0) == 0) {
  $_0 = 0; //@line 1523
  STACKTOP = sp; //@line 1525
  return $_0 | 0; //@line 1526
 } else {
  $_01012 = $i;
  $_0913 = $n;
  $tmp_014 = $buf;
 }
 while (1) {
  if ((_psi_img_map_sector(HEAP32[$5 >> 2] | 0, $_01012, $c, $h, $s) | 0) != 0) {
   $_0 = 1; //@line 1539
   label = 10198; //@line 1540
   break;
  }
  HEAP32[$cnt >> 2] = 512; //@line 1543
  $15 = (_dsk_psi_read_chs($3, $tmp_014, $cnt, HEAP32[$c >> 2] | 0, HEAP32[$h >> 2] | 0, HEAP32[$s >> 2] | 0, 1) | 0) == 0; //@line 1548
  if (!($15 & (HEAP32[$cnt >> 2] | 0) == 512)) {
   $_0 = 1; //@line 1554
   label = 10201; //@line 1555
   break;
  }
  $21 = $_0913 - 1 | 0; //@line 1560
  if (($21 | 0) == 0) {
   $_0 = 0; //@line 1564
   label = 10199; //@line 1565
   break;
  } else {
   $_01012 = $_01012 + 1 | 0;
   $_0913 = $21;
   $tmp_014 = $tmp_014 + 512 | 0;
  }
 }
 if ((label | 0) == 10199) {
  STACKTOP = sp; //@line 1573
  return $_0 | 0; //@line 1574
 } else if ((label | 0) == 10201) {
  STACKTOP = sp; //@line 1578
  return $_0 | 0; //@line 1579
 } else if ((label | 0) == 10198) {
  STACKTOP = sp; //@line 1583
  return $_0 | 0; //@line 1584
 }
 return 0;
}
function _dsk_psi_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $c = 0, $h = 0, $s = 0, $6 = 0, $8 = 0, $9 = 0, $11 = 0, $tmp_019 = 0, $_01018 = 0, $_01117 = 0, $20 = 0, $26 = 0, $29 = 0, $35 = 0, $ret_0_i14 = 0, $40 = 0, $42 = 0, $ret_0_i15 = 0, $44 = 0, $47 = 0, $48 = 0, $57 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 1603
 STACKTOP = STACKTOP + 24 | 0; //@line 1603
 $c = sp | 0; //@line 1604
 $h = sp + 8 | 0; //@line 1605
 $s = sp + 16 | 0; //@line 1606
 if ((HEAP8[$dsk + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 1612
  STACKTOP = sp; //@line 1614
  return $_0 | 0; //@line 1615
 }
 $6 = HEAP32[$dsk + 64 >> 2] | 0; //@line 1618
 $8 = $6 + 68 | 0; //@line 1620
 $9 = $6 + 56 | 0; //@line 1621
 if (($n | 0) == 0) {
  $_0 = 0; //@line 1625
  STACKTOP = sp; //@line 1627
  return $_0 | 0; //@line 1628
 }
 $11 = $6 + 72 | 0; //@line 1630
 $_01117 = $i;
 $_01018 = $n;
 $tmp_019 = $buf;
 while (1) {
  if ((_psi_img_map_sector(HEAP32[$8 >> 2] | 0, $_01117, $c, $h, $s) | 0) != 0) {
   $_0 = 1; //@line 1642
   label = 10218; //@line 1643
   break;
  }
  $20 = HEAP32[$8 >> 2] | 0; //@line 1649
  if (($20 | 0) == 0) {
   $_0 = 1; //@line 1653
   label = 10222; //@line 1654
   break;
  }
  if ((HEAP8[$9] | 0) != 0) {
   $_0 = 1; //@line 1661
   label = 10226; //@line 1662
   break;
  }
  $26 = _psi_img_get_sector($20, HEAP32[$c >> 2] | 0, HEAP32[$h >> 2] | 0, HEAP32[$s >> 2] | 0, 1) | 0; //@line 1665
  if (($26 | 0) == 0) {
   $_0 = 1; //@line 1669
   label = 10221; //@line 1670
   break;
  }
  $29 = $26 + 12 | 0; //@line 1673
  if ((HEAP32[$29 >> 2] & 8 | 0) != 0) {
   $_0 = 1; //@line 1679
   label = 10219; //@line 1680
   break;
  }
  HEAP8[$11] = 1; //@line 1683
  $35 = HEAP16[$26 + 10 >> 1] | 0; //@line 1685
  if (($35 & 65535) < 512) {
   if ($35 << 16 >> 16 == 0) {
    $44 = 0;
    $ret_0_i15 = 32;
   } else {
    $40 = $35 & 65535;
    $ret_0_i14 = 32;
    label = 10212; //@line 1696
   }
  } else {
   $40 = 512;
   $ret_0_i14 = 0;
   label = 10212; //@line 1700
  }
  if ((label | 0) == 10212) {
   label = 0; //@line 1703
   $42 = HEAP32[$26 + 24 >> 2] | 0; //@line 1707
   _memcpy($42 | 0, $tmp_019 | 0, $40) | 0; //@line 1708
   $44 = $40;
   $ret_0_i15 = $ret_0_i14;
  }
  HEAP32[$29 >> 2] = HEAP32[$29 >> 2] & -3; //@line 1716
  $47 = $26 | 0; //@line 1717
  $48 = HEAP32[$47 >> 2] | 0; //@line 1718
  if (($48 | 0) != 0) {
   _psi_sct_del($48); //@line 1722
   HEAP32[$47 >> 2] = 0; //@line 1723
   HEAP32[$26 + 20 >> 2] = 0; //@line 1725
  }
  if (!(($ret_0_i15 | 0) == 0 & ($44 | 0) == 512)) {
   $_0 = 1; //@line 1733
   label = 10225; //@line 1734
   break;
  }
  $57 = $_01018 - 1 | 0; //@line 1739
  if (($57 | 0) == 0) {
   $_0 = 0; //@line 1743
   label = 10223; //@line 1744
   break;
  } else {
   $_01117 = $_01117 + 1 | 0;
   $_01018 = $57;
   $tmp_019 = $tmp_019 + 512 | 0;
  }
 }
 if ((label | 0) == 10222) {
  STACKTOP = sp; //@line 1752
  return $_0 | 0; //@line 1753
 } else if ((label | 0) == 10223) {
  STACKTOP = sp; //@line 1757
  return $_0 | 0; //@line 1758
 } else if ((label | 0) == 10219) {
  STACKTOP = sp; //@line 1762
  return $_0 | 0; //@line 1763
 } else if ((label | 0) == 10218) {
  STACKTOP = sp; //@line 1767
  return $_0 | 0; //@line 1768
 } else if ((label | 0) == 10226) {
  STACKTOP = sp; //@line 1772
  return $_0 | 0; //@line 1773
 } else if ((label | 0) == 10221) {
  STACKTOP = sp; //@line 1777
  return $_0 | 0; //@line 1778
 } else if ((label | 0) == 10225) {
  STACKTOP = sp; //@line 1782
  return $_0 | 0; //@line 1783
 }
 return 0;
}
function _dsk_psi_set_msg($dsk, $msg, $val) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $2 = 0, $7 = 0, $12 = 0, $_0 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 1798
 if ((_strcmp($msg | 0, 46328) | 0) != 0) {
  $_0 = 1; //@line 1803
  return $_0 | 0; //@line 1806
 }
 $7 = $2 + 84 | 0; //@line 1809
 if ((HEAP32[$7 >> 2] | 0) == 0) {
  $_0 = 1; //@line 1814
  return $_0 | 0; //@line 1817
 }
 $12 = $2 + 68 | 0; //@line 1820
 if ((HEAP32[$12 >> 2] | 0) == 0) {
  $_0 = 1; //@line 1825
  return $_0 | 0; //@line 1828
 }
 if ((_dsk_get_readonly($2) | 0) != 0) {
  $_0 = 1; //@line 1835
  return $_0 | 0; //@line 1838
 }
 if ((_psi_save(HEAP32[$7 >> 2] | 0, HEAP32[$12 >> 2] | 0, HEAP32[$2 + 80 >> 2] | 0) | 0) != 0) {
  $_0 = 1; //@line 1849
  return $_0 | 0; //@line 1852
 }
 HEAP8[$2 + 72 | 0] = 0; //@line 1855
 $_0 = 0; //@line 1857
 return $_0 | 0; //@line 1860
}
function _dsk_psi_open($fname, $type, $ro) {
 $fname = $fname | 0;
 $type = $type | 0;
 $ro = $ro | 0;
 var $3 = 0, $6 = 0, $_02224 = 0, $12 = 0, $_023 = 0, $fp_0 = 0, $fp_027 = 0, $_02326 = 0, $18 = 0, $23 = 0, $26 = 0, $_0 = 0, label = 0;
 do {
  if (($type | 0) == 0) {
   $3 = _psi_probe($fname) | 0; //@line 1878
   if (($3 | 0) != 0) {
    $_02224 = $3; //@line 1882
    break;
   }
   $6 = _psi_guess_type($fname) | 0; //@line 1885
   if (($6 | 0) == 0) {
    $_0 = 0; //@line 1889
   } else {
    $_02224 = $6; //@line 1891
    break;
   }
   return $_0 | 0; //@line 1896
  } else {
   $_02224 = $type; //@line 1898
  }
 } while (0);
 do {
  if (($ro | 0) == 0) {
   $12 = _fopen($fname | 0, 56912) | 0; //@line 1906
   if (($12 | 0) != 0) {
    $_02326 = 0;
    $fp_027 = $12;
    break;
   }
   $fp_0 = _fopen($fname | 0, 55344) | 0;
   $_023 = 1;
   label = 10247; //@line 1916
  } else {
   $fp_0 = _fopen($fname | 0, 55344) | 0;
   $_023 = $ro;
   label = 10247; //@line 1921
  }
 } while (0);
 do {
  if ((label | 0) == 10247) {
   if (($fp_0 | 0) == 0) {
    $_0 = 0; //@line 1931
   } else {
    $_02326 = $_023;
    $fp_027 = $fp_0;
    break;
   }
   return $_0 | 0; //@line 1938
  }
 } while (0);
 $18 = _dsk_psi_open_fp($fp_027, $_02224, $_02326) | 0; //@line 1943
 _fclose($fp_027 | 0) | 0; //@line 1944
 if (($18 | 0) == 0) {
  $_0 = 0; //@line 1948
  return $_0 | 0; //@line 1951
 }
 $23 = HEAP32[$18 + 64 >> 2] | 0; //@line 1954
 $26 = _malloc((_strlen($fname | 0) | 0) + 1 | 0) | 0; //@line 1957
 HEAP32[$23 + 84 >> 2] = $26; //@line 1960
 if (($26 | 0) != 0) {
  _strcpy($26 | 0, $fname | 0) | 0; //@line 1964
 }
 _dsk_set_fname($18, $fname); //@line 1967
 $_0 = $18; //@line 1969
 return $_0 | 0; //@line 1972
}
function _dsk_psi_probe($fname) {
 $fname = $fname | 0;
 return _psi_probe($fname) | 0; //@line 1983
}
function _dsk_get_uint32_le($buf, $i) {
 $buf = $buf | 0;
 $i = $i | 0;
 return (((HEAPU8[$buf + ($i + 3) | 0] | 0) << 8 | (HEAPU8[$buf + ($i + 2) | 0] | 0)) << 8 | (HEAPU8[$buf + ($i + 1) | 0] | 0)) << 8 | (HEAPU8[$buf + $i | 0] | 0) | 0; //@line 2017
}
function _dsk_get_uint64_le($buf, $i) {
 $buf = $buf | 0;
 $i = $i | 0;
 var $4$0 = 0, $9$0 = 0, $14$0 = 0, $19$0 = 0, $24$0 = 0, $29$0 = 0, $34$0 = 0;
 $4$0 = HEAPU8[$buf + ($i + 7) | 0] | 0; //@line 2039
 $9$0 = $4$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + ($i + 6) | 0] | 0); //@line 2048
 $14$0 = $9$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + ($i + 5) | 0] | 0); //@line 2057
 $19$0 = $14$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + ($i + 4) | 0] | 0); //@line 2066
 $24$0 = $19$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + ($i + 3) | 0] | 0); //@line 2075
 $29$0 = $24$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + ($i + 2) | 0] | 0); //@line 2084
 $34$0 = $29$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + ($i + 1) | 0] | 0); //@line 2093
 return (tempRet0 = ((((((0 << 8 | $4$0 >>> 24) << 8 | $9$0 >>> 24) << 8 | $14$0 >>> 24) << 8 | $19$0 >>> 24) << 8 | $24$0 >>> 24) << 8 | $29$0 >>> 24) << 8 | $34$0 >>> 24 | 0, $34$0 << 8 | 0 >>> 24 | (HEAPU8[$buf + $i | 0] | 0)) | 0; //@line 2103
}
function _dsk_set_uint32_le($buf, $i, $v) {
 $buf = $buf | 0;
 $i = $i | 0;
 $v = $v | 0;
 HEAP8[$buf + $i | 0] = $v & 255; //@line 2117
 HEAP8[$buf + ($i + 1) | 0] = $v >>> 8 & 255; //@line 2122
 HEAP8[$buf + ($i + 2) | 0] = $v >>> 16 & 255; //@line 2127
 HEAP8[$buf + ($i + 3) | 0] = $v >>> 24 & 255; //@line 2132
 return;
}
function _dsk_set_uint64_le($buf, $i, $v$0, $v$1) {
 $buf = $buf | 0;
 $i = $i | 0;
 $v$0 = $v$0 | 0;
 $v$1 = $v$1 | 0;
 HEAP8[$buf + $i | 0] = $v$0 & 255; //@line 2154
 HEAP8[$buf + ($i + 1) | 0] = ($v$0 >>> 8 | $v$1 << 24) & 255; //@line 2161
 HEAP8[$buf + ($i + 2) | 0] = ($v$0 >>> 16 | $v$1 << 16) & 255; //@line 2168
 HEAP8[$buf + ($i + 3) | 0] = ($v$0 >>> 24 | $v$1 << 8) & 255; //@line 2175
 HEAP8[$buf + ($i + 4) | 0] = $v$1 & 255; //@line 2182
 HEAP8[$buf + ($i + 5) | 0] = ($v$1 >>> 8 | 0 << 24) & 255; //@line 2189
 HEAP8[$buf + ($i + 6) | 0] = ($v$1 >>> 16 | 0 << 16) & 255; //@line 2196
 HEAP8[$buf + ($i + 7) | 0] = ($v$1 >>> 24 | 0 << 8) & 255; //@line 2203
 return;
}
function _dsk_set_drive($dsk, $d) {
 $dsk = $dsk | 0;
 $d = $d | 0;
 HEAP32[$dsk + 24 >> 2] = $d; //@line 2216
 return;
}
function _dsk_get_type($dsk) {
 $dsk = $dsk | 0;
 return HEAP32[$dsk >> 2] | 0; //@line 2230
}
function _dsk_set_type($dsk, $type) {
 $dsk = $dsk | 0;
 $type = $type | 0;
 HEAP32[$dsk >> 2] = $type; //@line 2241
 return;
}
function _dsk_get_readonly($dsk) {
 $dsk = $dsk | 0;
 return (HEAP8[$dsk + 56 | 0] | 0) != 0 | 0; //@line 2257
}
function _dsk_set_readonly($dsk, $v) {
 $dsk = $dsk | 0;
 $v = $v | 0;
 HEAP8[$dsk + 56 | 0] = ($v | 0) != 0 | 0; //@line 2270
 return;
}
function _dsk_set_geometry($dsk, $n, $c, $h, $s) {
 $dsk = $dsk | 0;
 $n = $n | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 var $4 = 0, $n35 = 0, $_s = 0, $h32 = 0, $13 = 0, $_s27 = 0, $h3045 = 0, $c344244 = 0, $s24_ph = 0, $_0 = 0;
 do {
  if (($n | 0) == 0) {
   $4 = Math_imul(Math_imul($h, $c) | 0, $s) | 0; //@line 2293
   if (($4 | 0) == 0) {
    $_0 = 1; //@line 2297
   } else {
    $n35 = $4; //@line 2299
    break;
   }
   return $_0 | 0; //@line 2304
  } else {
   $n35 = $n; //@line 2306
  }
 } while (0);
 do {
  if (($c | 0) == 0) {
   $_s = ($s | 0) == 0 ? 63 : $s; //@line 2315
   $h32 = ($h | 0) == 0 ? 16 : $h; //@line 2317
   $s24_ph = $_s;
   $c344244 = ($n35 >>> 0) / ((Math_imul($_s, $h32) | 0) >>> 0) | 0;
   $h3045 = $h32;
  } else {
   $13 = ($s | 0) == 0; //@line 2324
   if (($h | 0) == 0) {
    $_s27 = $13 ? 63 : $s; //@line 2327
    $s24_ph = $_s27;
    $c344244 = $c;
    $h3045 = ($n35 >>> 0) / ((Math_imul($_s27, $c) | 0) >>> 0) | 0;
    break;
   }
   if (!$13) {
    $s24_ph = $s;
    $c344244 = $c;
    $h3045 = $h;
    break;
   }
   $s24_ph = ($n35 >>> 0) / ((Math_imul($h, $c) | 0) >>> 0) | 0;
   $c344244 = $c;
   $h3045 = $h;
  }
 } while (0);
 HEAP32[$dsk + 28 >> 2] = $n35; //@line 2349
 HEAP32[$dsk + 32 >> 2] = $c344244; //@line 2351
 HEAP32[$dsk + 36 >> 2] = $h3045; //@line 2353
 HEAP32[$dsk + 40 >> 2] = $s24_ph; //@line 2355
 $_0 = 0; //@line 2357
 return $_0 | 0; //@line 2360
}
function _dsk_set_visible_chs($dsk, $c, $h, $s) {
 $dsk = $dsk | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 HEAP32[$dsk + 44 >> 2] = $c; //@line 2373
 HEAP32[$dsk + 48 >> 2] = $h; //@line 2375
 HEAP32[$dsk + 52 >> 2] = $s; //@line 2377
 return;
}
function _dsk_get_drive($dsk) {
 $dsk = $dsk | 0;
 return HEAP32[$dsk + 24 >> 2] | 0; //@line 2391
}
function _dsk_get_block_cnt($dsk) {
 $dsk = $dsk | 0;
 return HEAP32[$dsk + 28 >> 2] | 0; //@line 2403
}
function _dsk_read($fp, $buf, $ofs$0, $ofs$1, $cnt$0, $cnt$1) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $ofs$0 = $ofs$0 | 0;
 $ofs$1 = $ofs$1 | 0;
 $cnt$0 = $cnt$0 | 0;
 $cnt$1 = $cnt$1 | 0;
 var $$etemp$0$1 = 0, $6 = 0, $7$0 = 0, $7$1 = 0, $11$0 = 0, $_0 = 0;
 $$etemp$0$1 = 0; //@line 2420
 if ($ofs$1 >>> 0 > $$etemp$0$1 >>> 0 | $ofs$1 >>> 0 == $$etemp$0$1 >>> 0 & $ofs$0 >>> 0 > 2147483647 >>> 0) {
  $_0 = 1; //@line 2424
  return $_0 | 0; //@line 2427
 }
 if ((_fseek($fp | 0, $ofs$0 | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 2435
  return $_0 | 0; //@line 2438
 }
 $6 = _fread($buf | 0, 1, $cnt$0 | 0, $fp | 0) | 0; //@line 2442
 $7$0 = $6; //@line 2443
 $7$1 = 0; //@line 2444
 if (!($7$1 >>> 0 < $cnt$1 >>> 0 | $7$1 >>> 0 == $cnt$1 >>> 0 & $7$0 >>> 0 < $cnt$0 >>> 0)) {
  $_0 = 0; //@line 2448
  return $_0 | 0; //@line 2451
 }
 $11$0 = _i64Subtract($cnt$0, $cnt$1, $7$0, $7$1) | 0;
 _memset($buf + $6 | 0, 0, $11$0 | 0); //@line 2457
 $_0 = 0; //@line 2459
 return $_0 | 0; //@line 2462
}
function _dsk_write($fp, $buf, $ofs$0, $ofs$1, $cnt$0, $cnt$1) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $ofs$0 = $ofs$0 | 0;
 $ofs$1 = $ofs$1 | 0;
 $cnt$0 = $cnt$0 | 0;
 $cnt$1 = $cnt$1 | 0;
 var $$etemp$0$1 = 0, $_0 = 0;
 $$etemp$0$1 = 0; //@line 2478
 if ($ofs$1 >>> 0 > $$etemp$0$1 >>> 0 | $ofs$1 >>> 0 == $$etemp$0$1 >>> 0 & $ofs$0 >>> 0 > 2147483647 >>> 0) {
  $_0 = 1; //@line 2482
  return $_0 | 0; //@line 2485
 }
 if ((_fseek($fp | 0, $ofs$0 | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 2493
  return $_0 | 0; //@line 2496
 }
 $_0 = ((_fwrite($buf | 0, 1, $cnt$0 | 0, $fp | 0) | 0) != ($cnt$0 | 0) | 0 != ($cnt$1 | 0)) & 1; //@line 2506
 return $_0 | 0; //@line 2509
}
function _dsk_get_filesize($fp, $cnt) {
 $fp = $fp | 0;
 $cnt = $cnt | 0;
 var $4 = 0, $_0 = 0;
 do {
  if ((_fseek($fp | 0, 0, 2) | 0) == 0) {
   $4 = _ftell($fp | 0) | 0; //@line 2525
   if (($4 | 0) == -1) {
    $_0 = 1; //@line 2529
    break;
   }
   HEAP32[$cnt >> 2] = $4; //@line 2535
   HEAP32[$cnt + 4 >> 2] = ($4 | 0) < 0 ? -1 : 0; //@line 2537
   $_0 = 0; //@line 2539
  } else {
   $_0 = 1; //@line 2541
  }
 } while (0);
 return $_0 | 0; //@line 2546
}
function _dsk_set_filesize($fp, $cnt$0, $cnt$1) {
 $fp = $fp | 0;
 $cnt$0 = $cnt$0 | 0;
 $cnt$1 = $cnt$1 | 0;
 _fflush($fp | 0) | 0; //@line 2557
 return (_ftruncate(_fileno($fp | 0) | 0, $cnt$0 | 0) | 0) != 0 | 0; //@line 2565
}
function _dsk_init($dsk, $ext, $n, $c, $h, $s) {
 $dsk = $dsk | 0;
 $ext = $ext | 0;
 $n = $n | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 var $5 = 0, $n51 = 0, $_s = 0, $h48 = 0, $14 = 0, $_s43 = 0, $n52 = 0, $c49 = 0, $h45 = 0, $s40 = 0, label = 0;
 _memset($dsk | 0, 0, 28); //@line 2585
 if (($n | 0) == 0) {
  $5 = Math_imul(Math_imul($h, $c) | 0, $s) | 0; //@line 2589
  if (($5 | 0) == 0) {
   $s40 = $s;
   $h45 = $h;
   $c49 = $c;
   $n52 = 0;
  } else {
   $n51 = $5; //@line 2595
   label = 10305; //@line 2596
  }
 } else {
  $n51 = $n; //@line 2599
  label = 10305; //@line 2600
 }
 do {
  if ((label | 0) == 10305) {
   if (($c | 0) == 0) {
    $_s = ($s | 0) == 0 ? 63 : $s; //@line 2609
    $h48 = ($h | 0) == 0 ? 16 : $h; //@line 2611
    $s40 = $_s;
    $h45 = $h48;
    $c49 = ($n51 >>> 0) / ((Math_imul($_s, $h48) | 0) >>> 0) | 0;
    $n52 = $n51;
    break;
   }
   $14 = ($s | 0) == 0; //@line 2619
   if (($h | 0) == 0) {
    $_s43 = $14 ? 63 : $s; //@line 2622
    $s40 = $_s43;
    $h45 = ($n51 >>> 0) / ((Math_imul($_s43, $c) | 0) >>> 0) | 0;
    $c49 = $c;
    $n52 = $n51;
    break;
   }
   if (!$14) {
    $s40 = $s;
    $h45 = $h;
    $c49 = $c;
    $n52 = $n51;
    break;
   }
   $s40 = ($n51 >>> 0) / ((Math_imul($h, $c) | 0) >>> 0) | 0;
   $h45 = $h;
   $c49 = $c;
   $n52 = $n51;
  }
 } while (0);
 HEAP32[$dsk + 28 >> 2] = $n52; //@line 2645
 HEAP32[$dsk + 32 >> 2] = $c49; //@line 2647
 HEAP32[$dsk + 36 >> 2] = $h45; //@line 2649
 HEAP32[$dsk + 40 >> 2] = $s40; //@line 2651
 HEAP32[$dsk + 44 >> 2] = $c49; //@line 2653
 HEAP32[$dsk + 48 >> 2] = $h45; //@line 2655
 HEAP32[$dsk + 52 >> 2] = $s40; //@line 2657
 HEAP8[$dsk + 56 | 0] = 0; //@line 2659
 HEAP32[$dsk + 60 >> 2] = 0; //@line 2661
 HEAP32[$dsk + 64 >> 2] = $ext; //@line 2663
 return;
}
function _dsk_del($dsk) {
 $dsk = $dsk | 0;
 var $6 = 0;
 if (($dsk | 0) == 0) {
  return;
 }
 _free(HEAP32[$dsk + 60 >> 2] | 0); //@line 2682
 $6 = HEAP32[$dsk + 4 >> 2] | 0; //@line 2684
 if (($6 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vi[$6 & 1023]($dsk); //@line 2691
 return;
}
function _dsk_set_fname($dsk, $fname) {
 $dsk = $dsk | 0;
 $fname = $fname | 0;
 var $1 = 0, $2 = 0, $11 = 0;
 $1 = $dsk + 60 | 0; //@line 2705
 $2 = HEAP32[$1 >> 2] | 0; //@line 2706
 if (($2 | 0) != 0) {
  _free($2); //@line 2710
 }
 if (($fname | 0) == 0) {
  HEAP32[$1 >> 2] = 0; //@line 2716
  return;
 }
 $11 = _malloc((_strlen($fname | 0) | 0) + 1 | 0) | 0; //@line 2723
 HEAP32[$1 >> 2] = $11; //@line 2724
 if (($11 | 0) == 0) {
  return;
 }
 _strcpy($11 | 0, $fname | 0) | 0; //@line 2731
 return;
}
function _dsk_guess_geometry($dsk) {
 $dsk = $dsk | 0;
 var $buf_i = 0, $1 = 0, $2 = 0, $3 = 0, $s_042_i = 0, $h_041_i = 0, $i_040_i = 0, $15 = 0, $16 = 0, $27 = 0, $32 = 0, $33 = 0, $51 = 0, $57 = 0, $63 = 0, $81 = 0, $87 = 0, $88 = 0, $90 = 0, $94$0 = 0, $94$1 = 0, $96$0 = 0, $96$1 = 0, $97$0 = 0, $97$1 = 0, $98$0 = 0, $98$1 = 0, $99$0 = 0, $99$1 = 0, $101$0 = 0, $101$1 = 0, $106$0 = 0, $106$1 = 0, $107$0 = 0, $107$1 = 0, $108$0 = 0, $108$1 = 0, $109$0 = 0, $110$0 = 0, $111 = 0, $112$0 = 0, $112$1 = 0, $113$0 = 0, $113$1 = 0, $116$0 = 0, $117$0 = 0, $118$0 = 0, $119 = 0, $122 = 0, $128 = 0, $h_1_i = 0, $s_1_i = 0, $129 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $141 = 0, $n35_i_i = 0, $c344244_i_i = 0, $148 = 0, $178 = 0, $179 = 0, $187 = 0, $188 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $201 = 0, $n35_i_i13 = 0, $c344244_i_i16 = 0, $208 = 0, $chk_011_i = 0, $i_010_i = 0, $226 = 0, $230 = 0, $232 = 0, $274 = 0, $275 = 0, $283 = 0, $284 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $299 = 0, $n35_i_i22 = 0, $_s_i_i = 0, $h32_i_i = 0, $308 = 0, $_s27_i_i = 0, $h3045_i_i = 0, $c344244_i_i25 = 0, $s24_ph_i_i = 0, $319 = 0, $320 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $361 = 0, $n35_i = 0, $_s_i = 0, $h32_i = 0, $370 = 0, $_s27_i = 0, $h3045_i = 0, $c344244_i = 0, $s24_ph_i = 0, sp = 0;
 sp = STACKTOP; //@line 2792
 STACKTOP = STACKTOP + 512 | 0; //@line 2792
 $buf_i = sp | 0; //@line 2793
 $1 = $buf_i | 0; //@line 2794
 $2 = $dsk + 8 | 0; //@line 2795
 $3 = HEAP32[$2 >> 2] | 0; //@line 2796
 L12895 : do {
  if (($3 | 0) != 0) {
   if ((FUNCTION_TABLE_iiiii[$3 & 127]($dsk, $1, 0, 1) | 0) != 0) {
    break;
   }
   if ((HEAP8[$buf_i + 510 | 0] | 0) != 85) {
    break;
   }
   if ((HEAP8[$buf_i + 511 | 0] | 0) == -86) {
    $15 = 0;
    $i_040_i = 0;
    $h_041_i = 0;
    $s_042_i = 0;
   } else {
    break;
   }
   while (1) {
    $16 = $i_040_i << 4; //@line 2828
    do {
     if ((HEAP8[$buf_i + ($16 + 446) | 0] & 127) == 0) {
      $27 = HEAPU8[$buf_i + ($16 + 448) | 0] | 0; //@line 2844
      $32 = HEAP8[$buf_i + ($16 + 447) | 0] | 0; //@line 2850
      $33 = $27 & 63; //@line 2851
      $51 = ((HEAPU8[$buf_i + ($16 + 457) | 0] << 8 | HEAPU8[$buf_i + ($16 + 456) | 0]) << 8 | HEAPU8[$buf_i + ($16 + 455) | 0]) << 8 | HEAPU8[$buf_i + ($16 + 454) | 0]; //@line 2873
      $57 = HEAPU8[$buf_i + ($16 + 452) | 0] | 0; //@line 2881
      $63 = $57 & 63; //@line 2888
      $81 = ((HEAPU8[$buf_i + ($16 + 461) | 0] << 8 | HEAPU8[$buf_i + ($16 + 460) | 0]) << 8 | HEAPU8[$buf_i + ($16 + 459) | 0]) << 8 | HEAPU8[$buf_i + ($16 + 458) | 0]; //@line 2910
      if (($33 | 0) == 0 | ($63 | 0) == 0 | ($51 | 0) == 0 | ($81 | 0) == 0) {
       $s_1_i = $s_042_i;
       $h_1_i = $h_041_i;
       $128 = $15;
       break;
      }
      $87 = $33 - 1 | 0; //@line 2923
      $88 = $63 - 1 | 0; //@line 2924
      $90 = $51 - 1 + $81 | 0; //@line 2926
      if (!($51 >>> 0 > $87 >>> 0 & $90 >>> 0 > $88 >>> 0)) {
       $s_1_i = $s_042_i;
       $h_1_i = $h_041_i;
       $128 = $15;
       break;
      }
      $94$0 = $27 << 2 & 768 | HEAPU8[$buf_i + ($16 + 449) | 0]; //@line 2935
      $94$1 = 0; //@line 2936
      $96$0 = $90 - $88 | 0; //@line 2938
      $96$1 = 0; //@line 2939
      $97$0 = $57 << 2 & 768 | HEAPU8[$buf_i + ($16 + 453) | 0]; //@line 2940
      $97$1 = 0; //@line 2941
      $98$0 = HEAPU8[$buf_i + ($16 + 451) | 0] | 0; //@line 2942
      $98$1 = 0; //@line 2943
      $99$0 = ___muldi3($98$0, $98$1, $94$0, $94$1) | 0;
      $99$1 = tempRet0;
      $101$0 = ___muldi3($97$0, $97$1, $32 & 255, 0) | 0;
      $101$1 = tempRet0;
      if (($99$0 | 0) == ($101$0 | 0) & ($99$1 | 0) == ($101$1 | 0)) {
       $s_1_i = $s_042_i;
       $h_1_i = $h_041_i;
       $128 = $15;
       break;
      }
      $106$0 = ___muldi3($97$0, $97$1, $51 - $87 | 0, 0) | 0;
      $106$1 = tempRet0;
      $107$0 = ___muldi3($96$0, $96$1, $94$0, $94$1) | 0;
      $107$1 = tempRet0;
      $108$0 = _i64Subtract($99$0, $99$1, $101$0, $101$1) | 0;
      $108$1 = tempRet0;
      $109$0 = _i64Subtract($107$0, $107$1, $106$0, $106$1) | 0;
      $110$0 = ___divdi3($109$0, tempRet0, $108$0, $108$1) | 0;
      $111 = $110$0; //@line 2963
      $112$0 = $110$0 | 0; //@line 2966
      $112$1 = tempRet0 & 0; //@line 2967
      $113$0 = ___muldi3($112$0, $112$1, $97$0, $97$1) | 0;
      $113$1 = tempRet0;
      if (($113$0 | 0) == 0 & ($113$1 | 0) == 0) {
       $122 = $15; //@line 2974
      } else {
       $116$0 = ___muldi3($112$0, $112$1, $98$0, $98$1) | 0;
       $117$0 = _i64Subtract($96$0, $96$1, $116$0, tempRet0) | 0;
       $118$0 = ___divdi3($117$0, tempRet0, $113$0, $113$1) | 0;
       $119 = $118$0; //@line 2980
       if (($119 | 0) == 0) {
        $s_1_i = $s_042_i;
        $h_1_i = $h_041_i;
        $128 = 0;
        break;
       }
       if (($111 | 0) == 0) {
        $s_1_i = $s_042_i;
        $h_1_i = $h_041_i;
        $128 = $119;
        break;
       } else {
        $122 = $119; //@line 2993
       }
      }
      if (!(($h_041_i | 0) == 0 | ($h_041_i | 0) == ($122 | 0))) {
       break L12895;
      }
      if (($s_042_i | 0) == 0 | ($s_042_i | 0) == ($111 | 0)) {
       $s_1_i = $111;
       $h_1_i = $122;
       $128 = $122;
      } else {
       break L12895;
      }
     } else {
      $s_1_i = $s_042_i;
      $h_1_i = $h_041_i;
      $128 = $15;
     }
    } while (0);
    $129 = $i_040_i + 1 | 0; //@line 3020
    if ($129 >>> 0 < 4) {
     $15 = $128;
     $i_040_i = $129;
     $h_041_i = $h_1_i;
     $s_042_i = $s_1_i;
    } else {
     break;
    }
   }
   if (($h_1_i | 0) == 0 | ($s_1_i | 0) == 0) {
    break;
   }
   $135 = $dsk + 28 | 0; //@line 3036
   $136 = HEAP32[$135 >> 2] | 0; //@line 3037
   $137 = Math_imul($s_1_i, $h_1_i) | 0; //@line 3038
   $138 = ($136 >>> 0) / ($137 >>> 0) | 0; //@line 3039
   do {
    if (($136 | 0) == 0) {
     $141 = Math_imul($138, $137) | 0; //@line 3044
     if (($141 | 0) != 0) {
      $n35_i_i = $141; //@line 3048
      break;
     }
     STACKTOP = sp; //@line 3051
     return 0; //@line 3052
    } else {
     $n35_i_i = $136; //@line 3054
    }
   } while (0);
   if (($138 | 0) == 0) {
    $c344244_i_i = ($n35_i_i >>> 0) / ($137 >>> 0) | 0; //@line 3063
   } else {
    $c344244_i_i = $138; //@line 3065
   }
   HEAP32[$135 >> 2] = $n35_i_i; //@line 3068
   HEAP32[$dsk + 32 >> 2] = $c344244_i_i; //@line 3070
   HEAP32[$dsk + 36 >> 2] = $h_1_i; //@line 3072
   HEAP32[$dsk + 40 >> 2] = $s_1_i; //@line 3074
   STACKTOP = sp; //@line 3076
   return 0; //@line 3077
  }
 } while (0);
 $148 = HEAP32[$2 >> 2] | 0; //@line 3080
 do {
  if (($148 | 0) != 0) {
   if ((FUNCTION_TABLE_iiiii[$148 & 127]($dsk, $1, 0, 1) | 0) != 0) {
    break;
   }
   if ((HEAP8[$buf_i + 510 | 0] | 0) != 85) {
    break;
   }
   if ((HEAP8[$buf_i + 511 | 0] | 0) != -86) {
    break;
   }
   if ((HEAPU8[$buf_i + 12 | 0] << 8 | HEAPU8[$buf_i + 11 | 0]) << 16 >> 16 != 512) {
    break;
   }
   $178 = HEAPU8[$buf_i + 27 | 0] << 8 | HEAPU8[$buf_i + 26 | 0]; //@line 3125
   $179 = $178 & 65535; //@line 3126
   $187 = HEAPU8[$buf_i + 25 | 0] << 8 | HEAPU8[$buf_i + 24 | 0]; //@line 3134
   $188 = $187 & 65535; //@line 3135
   if ($178 << 16 >> 16 == 0 | ($178 & 65535) > 255) {
    break;
   }
   if ($187 << 16 >> 16 == 0 | ($187 & 65535) > 255) {
    break;
   }
   $195 = $dsk + 28 | 0; //@line 3150
   $196 = HEAP32[$195 >> 2] | 0; //@line 3151
   $197 = Math_imul($188, $179) | 0; //@line 3152
   $198 = ($196 >>> 0) / ($197 >>> 0) | 0; //@line 3153
   do {
    if (($196 | 0) == 0) {
     $201 = Math_imul($198, $197) | 0; //@line 3158
     if (($201 | 0) != 0) {
      $n35_i_i13 = $201; //@line 3162
      break;
     }
     STACKTOP = sp; //@line 3165
     return 0; //@line 3166
    } else {
     $n35_i_i13 = $196; //@line 3168
    }
   } while (0);
   if (($198 | 0) == 0) {
    $c344244_i_i16 = ($n35_i_i13 >>> 0) / ($197 >>> 0) | 0; //@line 3177
   } else {
    $c344244_i_i16 = $198; //@line 3179
   }
   HEAP32[$195 >> 2] = $n35_i_i13; //@line 3182
   HEAP32[$dsk + 32 >> 2] = $c344244_i_i16; //@line 3184
   HEAP32[$dsk + 36 >> 2] = $179; //@line 3186
   HEAP32[$dsk + 40 >> 2] = $188; //@line 3188
   STACKTOP = sp; //@line 3190
   return 0; //@line 3191
  }
 } while (0);
 $208 = HEAP32[$2 >> 2] | 0; //@line 3194
 do {
  if (($208 | 0) != 0) {
   if ((FUNCTION_TABLE_iiiii[$208 & 127]($dsk, $1, 0, 1) | 0) != 0) {
    break;
   }
   if ((HEAPU8[$buf_i + 508 | 0] << 8 | HEAPU8[$buf_i + 509 | 0]) << 16 >> 16 == -9538) {
    $i_010_i = 0;
    $chk_011_i = 0;
   } else {
    break;
   }
   while (1) {
    $226 = HEAPU8[$buf_i + $i_010_i | 0] << 8 ^ $chk_011_i; //@line 3227
    $230 = HEAPU8[$buf_i + ($i_010_i | 1) | 0] | 0; //@line 3231
    $232 = $i_010_i + 2 | 0; //@line 3233
    if ($232 >>> 0 < 512) {
     $i_010_i = $232;
     $chk_011_i = $226 ^ $230;
    } else {
     break;
    }
   }
   if (($226 | 0) != ($230 | 0)) {
    break;
   }
   if ((((HEAPU8[$buf_i + 128 | 0] << 8 | HEAPU8[$buf_i + 129 | 0]) << 8 | HEAPU8[$buf_i + 130 | 0]) << 8 | HEAPU8[$buf_i + 131 | 0] | 0) != 1) {
    break;
   }
   if (((HEAPU8[$buf_i + 140 | 0] << 8 | HEAPU8[$buf_i + 141 | 0]) & 65535) > 8) {
    break;
   }
   $274 = HEAPU8[$buf_i + 422 | 0] << 8 | HEAPU8[$buf_i + 423 | 0]; //@line 3290
   $275 = $274 & 65535; //@line 3291
   $283 = HEAPU8[$buf_i + 436 | 0] << 8 | HEAPU8[$buf_i + 437 | 0]; //@line 3299
   $284 = $283 & 65535; //@line 3300
   $292 = HEAPU8[$buf_i + 438 | 0] << 8 | HEAPU8[$buf_i + 439 | 0]; //@line 3308
   $293 = $292 & 65535; //@line 3309
   $294 = $dsk + 28 | 0; //@line 3310
   $295 = HEAP32[$294 >> 2] | 0; //@line 3311
   do {
    if (($295 | 0) == 0) {
     $299 = Math_imul(Math_imul($284, $275) | 0, $293) | 0; //@line 3317
     if (($299 | 0) != 0) {
      $n35_i_i22 = $299; //@line 3321
      break;
     }
     STACKTOP = sp; //@line 3324
     return 0; //@line 3325
    } else {
     $n35_i_i22 = $295; //@line 3327
    }
   } while (0);
   do {
    if ($274 << 16 >> 16 == 0) {
     $_s_i_i = $292 << 16 >> 16 == 0 ? 63 : $293; //@line 3336
     $h32_i_i = $283 << 16 >> 16 == 0 ? 16 : $284; //@line 3338
     $s24_ph_i_i = $_s_i_i;
     $c344244_i_i25 = ($n35_i_i22 >>> 0) / ((Math_imul($_s_i_i, $h32_i_i) | 0) >>> 0) | 0;
     $h3045_i_i = $h32_i_i;
    } else {
     $308 = $292 << 16 >> 16 == 0; //@line 3345
     if ($283 << 16 >> 16 == 0) {
      $_s27_i_i = $308 ? 63 : $293; //@line 3348
      $s24_ph_i_i = $_s27_i_i;
      $c344244_i_i25 = $275;
      $h3045_i_i = ($n35_i_i22 >>> 0) / ((Math_imul($_s27_i_i, $275) | 0) >>> 0) | 0;
      break;
     }
     if (!$308) {
      $s24_ph_i_i = $293;
      $c344244_i_i25 = $275;
      $h3045_i_i = $284;
      break;
     }
     $s24_ph_i_i = ($n35_i_i22 >>> 0) / ((Math_imul($284, $275) | 0) >>> 0) | 0;
     $c344244_i_i25 = $275;
     $h3045_i_i = $284;
    }
   } while (0);
   HEAP32[$294 >> 2] = $n35_i_i22; //@line 3369
   HEAP32[$dsk + 32 >> 2] = $c344244_i_i25; //@line 3371
   HEAP32[$dsk + 36 >> 2] = $h3045_i_i; //@line 3373
   HEAP32[$dsk + 40 >> 2] = $s24_ph_i_i; //@line 3375
   STACKTOP = sp; //@line 3377
   return 0; //@line 3378
  }
 } while (0);
 $319 = $dsk + 28 | 0; //@line 3381
 $320 = HEAP32[$319 >> 2] | 0; //@line 3382
 if (($320 | 0) == 2880) {
  HEAP32[$319 >> 2] = 2880; //@line 3384
  HEAP32[$dsk + 32 >> 2] = 80; //@line 3386
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3388
  HEAP32[$dsk + 40 >> 2] = 18; //@line 3390
  STACKTOP = sp; //@line 3392
  return 0; //@line 3393
 } else if (($320 | 0) == 5760) {
  HEAP32[$319 >> 2] = 5760; //@line 3395
  HEAP32[$dsk + 32 >> 2] = 80; //@line 3397
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3399
  HEAP32[$dsk + 40 >> 2] = 36; //@line 3401
  STACKTOP = sp; //@line 3403
  return 0; //@line 3404
 } else if (($320 | 0) == 320) {
  HEAP32[$319 >> 2] = 320; //@line 3406
  HEAP32[$dsk + 32 >> 2] = 40; //@line 3408
  HEAP32[$dsk + 36 >> 2] = 1; //@line 3410
  HEAP32[$dsk + 40 >> 2] = 8; //@line 3412
  STACKTOP = sp; //@line 3414
  return 0; //@line 3415
 } else if (($320 | 0) == 360) {
  HEAP32[$319 >> 2] = 360; //@line 3417
  HEAP32[$dsk + 32 >> 2] = 40; //@line 3419
  HEAP32[$dsk + 36 >> 2] = 1; //@line 3421
  HEAP32[$dsk + 40 >> 2] = 9; //@line 3423
  STACKTOP = sp; //@line 3425
  return 0; //@line 3426
 } else if (($320 | 0) == 640) {
  HEAP32[$319 >> 2] = 640; //@line 3428
  HEAP32[$dsk + 32 >> 2] = 40; //@line 3430
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3432
  HEAP32[$dsk + 40 >> 2] = 8; //@line 3434
  STACKTOP = sp; //@line 3436
  return 0; //@line 3437
 } else if (($320 | 0) == 720) {
  HEAP32[$319 >> 2] = 720; //@line 3439
  HEAP32[$dsk + 32 >> 2] = 40; //@line 3441
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3443
  HEAP32[$dsk + 40 >> 2] = 9; //@line 3445
  STACKTOP = sp; //@line 3447
  return 0; //@line 3448
 } else if (($320 | 0) == 800) {
  HEAP32[$319 >> 2] = 800; //@line 3450
  HEAP32[$dsk + 32 >> 2] = 40; //@line 3452
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3454
  HEAP32[$dsk + 40 >> 2] = 10; //@line 3456
  STACKTOP = sp; //@line 3458
  return 0; //@line 3459
 } else if (($320 | 0) == 1440) {
  HEAP32[$319 >> 2] = 1440; //@line 3461
  HEAP32[$dsk + 32 >> 2] = 80; //@line 3463
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3465
  HEAP32[$dsk + 40 >> 2] = 9; //@line 3467
  STACKTOP = sp; //@line 3469
  return 0; //@line 3470
 } else if (($320 | 0) == 1600) {
  HEAP32[$319 >> 2] = 1600; //@line 3472
  HEAP32[$dsk + 32 >> 2] = 80; //@line 3474
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3476
  HEAP32[$dsk + 40 >> 2] = 10; //@line 3478
  STACKTOP = sp; //@line 3480
  return 0; //@line 3481
 } else if (($320 | 0) == 2400) {
  HEAP32[$319 >> 2] = 2400; //@line 3483
  HEAP32[$dsk + 32 >> 2] = 80; //@line 3485
  HEAP32[$dsk + 36 >> 2] = 2; //@line 3487
  HEAP32[$dsk + 40 >> 2] = 15; //@line 3489
  STACKTOP = sp; //@line 3491
  return 0; //@line 3492
 } else {
  $352 = $dsk + 32 | 0; //@line 3494
  $353 = HEAP32[$352 >> 2] | 0; //@line 3495
  $354 = $dsk + 36 | 0; //@line 3496
  $355 = HEAP32[$354 >> 2] | 0; //@line 3497
  $356 = $dsk + 40 | 0; //@line 3498
  $357 = HEAP32[$356 >> 2] | 0; //@line 3499
  do {
   if (($320 | 0) == 0) {
    $361 = Math_imul(Math_imul($355, $353) | 0, $357) | 0; //@line 3505
    if (($361 | 0) != 0) {
     $n35_i = $361; //@line 3509
     break;
    }
    STACKTOP = sp; //@line 3512
    return 0; //@line 3513
   } else {
    $n35_i = $320; //@line 3515
   }
  } while (0);
  do {
   if (($353 | 0) == 0) {
    $_s_i = ($357 | 0) == 0 ? 63 : $357; //@line 3524
    $h32_i = ($355 | 0) == 0 ? 16 : $355; //@line 3526
    $s24_ph_i = $_s_i;
    $c344244_i = ($n35_i >>> 0) / ((Math_imul($_s_i, $h32_i) | 0) >>> 0) | 0;
    $h3045_i = $h32_i;
   } else {
    $370 = ($357 | 0) == 0; //@line 3533
    if (($355 | 0) == 0) {
     $_s27_i = $370 ? 63 : $357; //@line 3536
     $s24_ph_i = $_s27_i;
     $c344244_i = $353;
     $h3045_i = ($n35_i >>> 0) / ((Math_imul($_s27_i, $353) | 0) >>> 0) | 0;
     break;
    }
    if (!$370) {
     $s24_ph_i = $357;
     $c344244_i = $353;
     $h3045_i = $355;
     break;
    }
    $s24_ph_i = ($n35_i >>> 0) / ((Math_imul($355, $353) | 0) >>> 0) | 0;
    $c344244_i = $353;
    $h3045_i = $355;
   }
  } while (0);
  HEAP32[$319 >> 2] = $n35_i; //@line 3557
  HEAP32[$352 >> 2] = $c344244_i; //@line 3558
  HEAP32[$354 >> 2] = $h3045_i; //@line 3559
  HEAP32[$356 >> 2] = $s24_ph_i; //@line 3560
  STACKTOP = sp; //@line 3562
  return 0; //@line 3563
 }
 return 0;
}
function _dsk_pce_get_msg($dsk, $msg, $val, $max) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 $max = $max | 0;
 return 1; //@line 3576
}
function _dsks_rmv_disk($dsks, $dsk) {
 $dsks = $dsks | 0;
 $dsk = $dsk | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $j_013 = 0, $i_012 = 0, $r_011 = 0, $6 = 0, $8 = 0, $14 = 0, $r_1 = 0, $j_1 = 0, $15 = 0, $j_0_lcssa = 0, $r_0_lcssa = 0;
 $1 = $dsks | 0; //@line 3588
 $2 = HEAP32[$1 >> 2] | 0; //@line 3589
 if (($2 | 0) == 0) {
  $r_0_lcssa = 0;
  $j_0_lcssa = 0;
  HEAP32[$1 >> 2] = $j_0_lcssa; //@line 3596
  return $r_0_lcssa | 0; //@line 3598
 }
 $4 = $dsks + 4 | 0; //@line 3600
 $r_011 = 0;
 $i_012 = 0;
 $j_013 = 0;
 $5 = $2;
 while (1) {
  $6 = HEAP32[$4 >> 2] | 0; //@line 3608
  $8 = HEAP32[$6 + ($i_012 << 2) >> 2] | 0; //@line 3610
  if (($8 | 0) == ($dsk | 0)) {
   $j_1 = $j_013;
   $r_1 = 1;
   $14 = $5;
  } else {
   HEAP32[$6 + ($j_013 << 2) >> 2] = $8; //@line 3617
   $j_1 = $j_013 + 1 | 0;
   $r_1 = $r_011;
   $14 = HEAP32[$1 >> 2] | 0;
  }
  $15 = $i_012 + 1 | 0; //@line 3626
  if ($15 >>> 0 < $14 >>> 0) {
   $r_011 = $r_1;
   $i_012 = $15;
   $j_013 = $j_1;
   $5 = $14;
  } else {
   $r_0_lcssa = $r_1;
   $j_0_lcssa = $j_1;
   break;
  }
 }
 HEAP32[$1 >> 2] = $j_0_lcssa; //@line 3638
 return $r_0_lcssa | 0; //@line 3640
}
function _dsks_get_disk($dsks, $drive) {
 $dsks = $dsks | 0;
 $drive = $drive | 0;
 var $1 = 0, $3 = 0, $i_0 = 0, $9 = 0, $_0 = 0, label = 0;
 $1 = $dsks + 4 | 0; //@line 3651
 $3 = HEAP32[$dsks >> 2] | 0; //@line 3653
 $i_0 = 0; //@line 3655
 while (1) {
  if ($i_0 >>> 0 >= $3 >>> 0) {
   $_0 = 0; //@line 3661
   label = 10430; //@line 3662
   break;
  }
  $9 = HEAP32[(HEAP32[$1 >> 2] | 0) + ($i_0 << 2) >> 2] | 0; //@line 3667
  if ((HEAP32[$9 + 24 >> 2] | 0) == ($drive | 0)) {
   $_0 = $9; //@line 3674
   label = 10429; //@line 3675
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 3678
  }
 }
 if ((label | 0) == 10429) {
  return $_0 | 0; //@line 3684
 } else if ((label | 0) == 10430) {
  return $_0 | 0; //@line 3689
 }
 return 0;
}
function _dsk_auto_open($fname, $ofs$0, $ofs$1, $ro) {
 $fname = $fname | 0;
 $ofs$0 = $ofs$0 | 0;
 $ofs$1 = $ofs$1 | 0;
 $ro = $ro | 0;
 var $16 = 0, $21 = 0, $_0 = 0;
 do {
  if ((_dsk_pce_probe($fname) | 0) == 0) {
   if ((_dsk_qed_probe($fname) | 0) != 0) {
    $_0 = _dsk_qed_open($fname, $ro) | 0; //@line 3714
    break;
   }
   if ((_dsk_dosemu_probe($fname) | 0) != 0) {
    $_0 = _dsk_dosemu_open($fname, $ro) | 0; //@line 3723
    break;
   }
   $16 = _dsk_psi_probe($fname) | 0; //@line 3726
   if (($16 | 0) != 0) {
    $_0 = _dsk_psi_open($fname, $16, $ro) | 0; //@line 3732
    break;
   }
   $21 = _psi_guess_type($fname) | 0; //@line 3735
   if (($21 | 0) == 12 | ($21 | 0) == 0) {
    $_0 = _dsk_img_open($fname, $ofs$0, $ofs$1, $ro) | 0; //@line 3739
    break;
   } else {
    $_0 = _dsk_psi_open($fname, $21, $ro) | 0; //@line 3744
    break;
   }
  } else {
   $_0 = _dsk_pce_open($fname, $ro) | 0; //@line 3750
  }
 } while (0);
 return $_0 | 0; //@line 3755
}
function _dsk_read_lba($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $2 = 0, $_0 = 0;
 $2 = HEAP32[$dsk + 8 >> 2] | 0; //@line 3768
 if (($2 | 0) == 0) {
  $_0 = 1; //@line 3772
  return $_0 | 0; //@line 3775
 }
 $_0 = FUNCTION_TABLE_iiiii[$2 & 127]($dsk, $buf, $i, $n) | 0; //@line 3779
 return $_0 | 0; //@line 3782
}
function _dsk_write_lba($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $2 = 0, $_0 = 0;
 $2 = HEAP32[$dsk + 12 >> 2] | 0; //@line 3795
 if (($2 | 0) == 0) {
  $_0 = 1; //@line 3799
  return $_0 | 0; //@line 3802
 }
 $_0 = FUNCTION_TABLE_iiiii[$2 & 127]($dsk, $buf, $i, $n) | 0; //@line 3806
 return $_0 | 0; //@line 3809
}
function _dsks_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(8) | 0; //@line 3817
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 3821
  return $_0 | 0; //@line 3824
 }
 HEAP32[$1 >> 2] = 0; //@line 3828
 HEAP32[$1 + 4 >> 2] = 0; //@line 3831
 $_0 = $1; //@line 3833
 return $_0 | 0; //@line 3836
}
function _dsks_add_disk($dsks, $dsk) {
 $dsks = $dsks | 0;
 $dsk = $dsk | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $i_0 = 0, $17 = 0, $21 = 0, $22 = 0, $_0 = 0, label = 0;
 $1 = $dsks | 0; //@line 3848
 $2 = HEAP32[$1 >> 2] | 0; //@line 3849
 $3 = $dsks + 4 | 0; //@line 3850
 $4 = $dsk + 24 | 0; //@line 3851
 $i_0 = 0; //@line 3853
 while (1) {
  if ($i_0 >>> 0 >= $2 >>> 0) {
   break;
  }
  if ((HEAP32[(HEAP32[(HEAP32[$3 >> 2] | 0) + ($i_0 << 2) >> 2] | 0) + 24 >> 2] | 0) == (HEAP32[$4 >> 2] | 0)) {
   $_0 = 1; //@line 3871
   label = 10466; //@line 3872
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 3875
  }
 }
 if ((label | 0) == 10466) {
  return $_0 | 0; //@line 3881
 }
 $17 = $2 + 1 | 0; //@line 3883
 $21 = _realloc(HEAP32[$3 >> 2] | 0, $17 << 2) | 0; //@line 3887
 $22 = $21; //@line 3888
 if (($21 | 0) == 0) {
  $_0 = 1; //@line 3892
  return $_0 | 0; //@line 3895
 }
 HEAP32[$22 + (HEAP32[$1 >> 2] << 2) >> 2] = $dsk; //@line 3899
 HEAP32[$1 >> 2] = $17; //@line 3900
 HEAP32[$3 >> 2] = $22; //@line 3901
 $_0 = 0; //@line 3903
 return $_0 | 0; //@line 3906
}
function _dsks_commit($dsks) {
 $dsks = $dsks | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $r_07 = 0, $i_06 = 0, $8 = 0, $10 = 0, $r_0_ = 0, $15 = 0, $r_1 = 0, $16 = 0, $r_0_lcssa = 0;
 $1 = $dsks | 0; //@line 3917
 $2 = HEAP32[$1 >> 2] | 0; //@line 3918
 if (($2 | 0) == 0) {
  $r_0_lcssa = 0; //@line 3922
  return $r_0_lcssa | 0; //@line 3925
 }
 $4 = $dsks + 4 | 0; //@line 3927
 $i_06 = 0;
 $r_07 = 0;
 $5 = $2;
 while (1) {
  $8 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($i_06 << 2) >> 2] | 0; //@line 3936
  $10 = HEAP32[$8 + 20 >> 2] | 0; //@line 3938
  if (($10 | 0) == 0) {
   $r_1 = $r_07;
   $15 = $5;
  } else {
   $r_0_ = (FUNCTION_TABLE_iiii[$10 & 127]($8, 55144, 62904) | 0) == 0 ? $r_07 : 1; //@line 3946
   $r_1 = $r_0_;
   $15 = HEAP32[$1 >> 2] | 0;
  }
  $16 = $i_06 + 1 | 0; //@line 3953
  if ($16 >>> 0 < $15 >>> 0) {
   $i_06 = $16;
   $r_07 = $r_1;
   $5 = $15;
  } else {
   $r_0_lcssa = $r_1; //@line 3959
   break;
  }
 }
 return $r_0_lcssa | 0; //@line 3965
}
function _dsks_set_msg($dsks, $drv, $msg, $val) {
 $dsks = $dsks | 0;
 $drv = $drv | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $3 = 0, $i_0_i = 0, $9 = 0, $17 = 0, $_0 = 0, label = 0;
 $1 = $dsks + 4 | 0; //@line 3979
 $3 = HEAP32[$dsks >> 2] | 0; //@line 3981
 $i_0_i = 0; //@line 3983
 while (1) {
  if ($i_0_i >>> 0 >= $3 >>> 0) {
   $_0 = 1; //@line 3989
   label = 10483; //@line 3990
   break;
  }
  $9 = HEAP32[(HEAP32[$1 >> 2] | 0) + ($i_0_i << 2) >> 2] | 0; //@line 3995
  if ((HEAP32[$9 + 24 >> 2] | 0) == ($drv | 0)) {
   break;
  } else {
   $i_0_i = $i_0_i + 1 | 0; //@line 4004
  }
 }
 if ((label | 0) == 10483) {
  return $_0 | 0; //@line 4010
 }
 if (($9 | 0) == 0) {
  $_0 = 1; //@line 4015
  return $_0 | 0; //@line 4018
 }
 $17 = HEAP32[$9 + 20 >> 2] | 0; //@line 4021
 if (($17 | 0) == 0) {
  $_0 = 1; //@line 4025
  return $_0 | 0; //@line 4028
 }
 $_0 = FUNCTION_TABLE_iiii[$17 & 127]($9, $msg, ($val | 0) == 0 ? 62904 : $val) | 0; //@line 4034
 return $_0 | 0; //@line 4037
}
function _dsk_dosemu_open_fp($fp, $ro) {
 $fp = $fp | 0;
 $ro = $ro | 0;
 var $1 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $15 = 0, $18 = 0, $26 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 4050
 STACKTOP = STACKTOP + 32 | 0; //@line 4050
 $1 = sp | 0; //@line 4052
 if ((_dsk_read($fp, $1, 0, 0, 23, 0) | 0) != 0) {
  $_0 = 0; //@line 4061
  STACKTOP = sp; //@line 4063
  return $_0 | 0; //@line 4064
 }
 if ((_memcmp($1 | 0, 54912, 7) | 0) != 0) {
  $_0 = 0; //@line 4070
  STACKTOP = sp; //@line 4072
  return $_0 | 0; //@line 4073
 }
 $8 = _dsk_get_uint32_le($1, 15) | 0; //@line 4075
 $9 = _dsk_get_uint32_le($1, 7) | 0; //@line 4076
 $10 = _dsk_get_uint32_le($1, 11) | 0; //@line 4077
 $11 = _dsk_get_uint32_le($1, 19) | 0; //@line 4078
 if ($11 >>> 0 < 23) {
  $_0 = 0; //@line 4084
  STACKTOP = sp; //@line 4086
  return $_0 | 0; //@line 4087
 }
 $15 = _malloc(80) | 0; //@line 4089
 if (($15 | 0) == 0) {
  $_0 = 0; //@line 4093
  STACKTOP = sp; //@line 4095
  return $_0 | 0; //@line 4096
 }
 $18 = $15; //@line 4098
 _dsk_init($18, $15, 0, $8, $9, $10); //@line 4099
 _dsk_set_type($18, 4); //@line 4100
 _dsk_set_readonly($18, $ro); //@line 4101
 HEAP32[$15 + 4 >> 2] = 380; //@line 4104
 HEAP32[$15 + 8 >> 2] = 72; //@line 4107
 HEAP32[$15 + 12 >> 2] = 68; //@line 4110
 $26 = $15 + 72 | 0; //@line 4112
 HEAP32[$26 >> 2] = $11; //@line 4114
 HEAP32[$26 + 4 >> 2] = 0; //@line 4116
 HEAP32[$15 + 68 >> 2] = $fp; //@line 4119
 $_0 = $18; //@line 4121
 STACKTOP = sp; //@line 4123
 return $_0 | 0; //@line 4124
}
function _dsk_dosemu_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 4134
 _fclose(HEAP32[$2 + 68 >> 2] | 0) | 0; //@line 4138
 _free($2); //@line 4139
 return;
}
function _dsk_dosemu_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $7 = 0, $9 = 0, $11$0 = 0, $13$0 = 0, $14$0 = 0, $_0 = 0;
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 4162
  return $_0 | 0; //@line 4165
 }
 $7 = HEAP32[$dsk + 64 >> 2] | 0; //@line 4168
 $9 = $7 + 72 | 0; //@line 4170
 $11$0 = $i; //@line 4175
 $13$0 = _i64Add(HEAP32[$9 >> 2] | 0, HEAP32[$9 + 4 >> 2] | 0, $11$0 << 9 | 0 >>> 23, 0 << 9 | $11$0 >>> 23) | 0;
 $14$0 = $n; //@line 4180
 $_0 = (_dsk_read(HEAP32[$7 + 68 >> 2] | 0, $buf, $13$0, tempRet0, $14$0 << 9 | 0 >>> 23, 0 << 9 | $14$0 >>> 23) | 0) != 0 | 0; //@line 4191
 return $_0 | 0; //@line 4194
}
function _dsk_dosemu_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $11 = 0, $13 = 0, $15$0 = 0, $17$0 = 0, $18$0 = 0, $21 = 0, $_0 = 0;
 if ((HEAP8[$dsk + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 4214
  return $_0 | 0; //@line 4217
 }
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 4225
  return $_0 | 0; //@line 4228
 }
 $11 = HEAP32[$dsk + 64 >> 2] | 0; //@line 4231
 $13 = $11 + 72 | 0; //@line 4233
 $15$0 = $i; //@line 4238
 $17$0 = _i64Add(HEAP32[$13 >> 2] | 0, HEAP32[$13 + 4 >> 2] | 0, $15$0 << 9 | 0 >>> 23, 0 << 9 | $15$0 >>> 23) | 0;
 $18$0 = $n; //@line 4243
 $21 = $11 + 68 | 0; //@line 4248
 if ((_dsk_write(HEAP32[$21 >> 2] | 0, $buf, $17$0, tempRet0, $18$0 << 9 | 0 >>> 23, 0 << 9 | $18$0 >>> 23) | 0) != 0) {
  $_0 = 1; //@line 4254
  return $_0 | 0; //@line 4257
 }
 _fflush(HEAP32[$21 >> 2] | 0) | 0; //@line 4260
 $_0 = 0; //@line 4262
 return $_0 | 0; //@line 4265
}
function _dsk_dosemu_open($fname, $ro) {
 $fname = $fname | 0;
 $ro = $ro | 0;
 var $5 = 0, $_011 = 0, $fp_0 = 0, $fp_013 = 0, $_01112 = 0, $11 = 0, $_0 = 0, label = 0;
 do {
  if (($ro | 0) == 0) {
   $5 = _fopen($fname | 0, 50312 | 0) | 0; //@line 4280
   if (($5 | 0) != 0) {
    $_01112 = 0;
    $fp_013 = $5;
    break;
   }
   $fp_0 = _fopen($fname | 0, 56880 | 0) | 0;
   $_011 = 1;
   label = 10516; //@line 4290
  } else {
   $fp_0 = _fopen($fname | 0, 56880 | 0) | 0;
   $_011 = $ro;
   label = 10516; //@line 4295
  }
 } while (0);
 do {
  if ((label | 0) == 10516) {
   if (($fp_0 | 0) == 0) {
    $_0 = 0; //@line 4305
   } else {
    $_01112 = $_011;
    $fp_013 = $fp_0;
    break;
   }
   return $_0 | 0; //@line 4312
  }
 } while (0);
 $11 = _dsk_dosemu_open_fp($fp_013, $_01112) | 0; //@line 4317
 if (($11 | 0) == 0) {
  _fclose($fp_013 | 0) | 0; //@line 4321
  $_0 = 0; //@line 4323
  return $_0 | 0; //@line 4326
 } else {
  _dsk_set_fname($11, $fname); //@line 4328
  $_0 = $11; //@line 4330
  return $_0 | 0; //@line 4333
 }
 return 0;
}
function _dsk_dosemu_probe($fname) {
 $fname = $fname | 0;
 var $1 = 0, $4 = 0, $_0_i = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 4343
 STACKTOP = STACKTOP + 8 | 0; //@line 4343
 $1 = _fopen($fname | 0, 56880) | 0; //@line 4345
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 4349
  STACKTOP = sp; //@line 4351
  return $_0 | 0; //@line 4352
 }
 $4 = sp | 0; //@line 4354
 if ((_dsk_read($1, $4, 0, 0, 8, 0) | 0) == 0) {
  $_0_i = (_memcmp($4 | 0, 54912, 7) | 0) == 0 | 0; //@line 4367
 } else {
  $_0_i = 0; //@line 4369
 }
 _fclose($1 | 0) | 0; //@line 4372
 $_0 = $_0_i; //@line 4374
 STACKTOP = sp; //@line 4376
 return $_0 | 0; //@line 4377
}
function _dsk_pce_open_fp($fp, $ro) {
 $fp = $fp | 0;
 $ro = $ro | 0;
 var $1 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $21 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 4390
 STACKTOP = STACKTOP + 32 | 0; //@line 4390
 $1 = sp | 0; //@line 4392
 if ((_fread($1 | 0, 1, 32, $fp | 0) | 0) != 32) {
  $_0 = 0; //@line 4397
  STACKTOP = sp; //@line 4399
  return $_0 | 0; //@line 4400
 }
 if ((_dsk_get_uint32_be($1, 0) | 0) != 1346981191) {
  $_0 = 0; //@line 4406
  STACKTOP = sp; //@line 4408
  return $_0 | 0; //@line 4409
 }
 if ((_dsk_get_uint32_be($1, 4) | 0) != 0) {
  $_0 = 0; //@line 4415
  STACKTOP = sp; //@line 4417
  return $_0 | 0; //@line 4418
 }
 if ((_dsk_get_uint32_be($1, 28) | 0) != 512) {
  $_0 = 0; //@line 4424
  STACKTOP = sp; //@line 4426
  return $_0 | 0; //@line 4427
 }
 $14 = _dsk_get_uint32_be($1, 12) | 0; //@line 4429
 $15 = _dsk_get_uint32_be($1, 16) | 0; //@line 4430
 $16 = _dsk_get_uint32_be($1, 20) | 0; //@line 4431
 $17 = _dsk_get_uint32_be($1, 24) | 0; //@line 4432
 $18 = _malloc(80) | 0; //@line 4433
 if (($18 | 0) == 0) {
  $_0 = 0; //@line 4437
  STACKTOP = sp; //@line 4439
  return $_0 | 0; //@line 4440
 }
 $21 = $18; //@line 4442
 _dsk_init($21, $18, $14, $15, $16, $17); //@line 4443
 _dsk_set_type($21, 3); //@line 4444
 _dsk_set_readonly($21, $ro); //@line 4445
 HEAP32[$18 + 68 >> 2] = $fp; //@line 4448
 HEAP32[$18 + 4 >> 2] = 82; //@line 4451
 HEAP32[$18 + 8 >> 2] = 48; //@line 4454
 HEAP32[$18 + 12 >> 2] = 70; //@line 4457
 HEAP32[$18 + 16 >> 2] = 44; //@line 4460
 HEAP32[$18 + 20 >> 2] = 24; //@line 4463
 HEAP32[$18 + 72 >> 2] = _dsk_get_uint32_be($1, 8) | 0; //@line 4467
 HEAP32[$18 + 76 >> 2] = _dsk_get_uint32_be($1, 28) | 0; //@line 4471
 $_0 = $21; //@line 4473
 STACKTOP = sp; //@line 4475
 return $_0 | 0; //@line 4476
}
function _dsk_pce_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0, $5 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 4486
 $5 = HEAP32[$2 + 68 >> 2] | 0; //@line 4489
 if (($5 | 0) == 0) {
  _free($2); //@line 4493
  return;
 }
 _fclose($5 | 0) | 0; //@line 4497
 _free($2); //@line 4499
 return;
}
function _dsk_pce_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $2 = 0, $13$0 = 0, $15$0 = 0, $16$0 = 0, $_0 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 4517
 if (($n + $i | 0) >>> 0 > (HEAP32[$2 + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 4525
  return $_0 | 0; //@line 4528
 }
 $13$0 = $i; //@line 4535
 $15$0 = _i64Add(HEAP32[$2 + 72 >> 2] | 0, 0, $13$0 << 9 | 0 >>> 23, 0 << 9 | $13$0 >>> 23) | 0;
 $16$0 = $n; //@line 4540
 $_0 = (_dsk_read(HEAP32[$2 + 68 >> 2] | 0, $buf, $15$0, tempRet0, $16$0 << 9 | 0 >>> 23, 0 << 9 | $16$0 >>> 23) | 0) != 0 | 0; //@line 4551
 return $_0 | 0; //@line 4554
}
function _dsk_pce_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $2 = 0, $16$0 = 0, $18$0 = 0, $19$0 = 0, $22 = 0, $_0 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 4570
 if ((HEAP8[$dsk + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 4576
  return $_0 | 0; //@line 4579
 }
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 4587
  return $_0 | 0; //@line 4590
 }
 $16$0 = $i; //@line 4597
 $18$0 = _i64Add(HEAP32[$2 + 72 >> 2] | 0, 0, $16$0 << 9 | 0 >>> 23, 0 << 9 | $16$0 >>> 23) | 0;
 $19$0 = $n; //@line 4602
 $22 = $2 + 68 | 0; //@line 4607
 if ((_dsk_write(HEAP32[$22 >> 2] | 0, $buf, $18$0, tempRet0, $19$0 << 9 | 0 >>> 23, 0 << 9 | $19$0 >>> 23) | 0) != 0) {
  $_0 = 1; //@line 4613
  return $_0 | 0; //@line 4616
 }
 _fflush(HEAP32[$22 >> 2] | 0) | 0; //@line 4619
 $_0 = 0; //@line 4621
 return $_0 | 0; //@line 4624
}
function _dsk_pce_set_msg($dsk, $msg, $val) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 return (_strcmp($msg | 0, 46320) | 0) != 0 | 0; //@line 4639
}
function _dsk_pce_open($fname, $ro) {
 $fname = $fname | 0;
 $ro = $ro | 0;
 var $5 = 0, $_011 = 0, $fp_0 = 0, $fp_013 = 0, $_01112 = 0, $11 = 0, $_0 = 0, label = 0;
 do {
  if (($ro | 0) == 0) {
   $5 = _fopen($fname | 0, 56872 | 0) | 0; //@line 4654
   if (($5 | 0) != 0) {
    $_01112 = 0;
    $fp_013 = $5;
    break;
   }
   $fp_0 = _fopen($fname | 0, 54872 | 0) | 0;
   $_011 = 1;
   label = 10568; //@line 4664
  } else {
   $fp_0 = _fopen($fname | 0, 54872 | 0) | 0;
   $_011 = $ro;
   label = 10568; //@line 4669
  }
 } while (0);
 do {
  if ((label | 0) == 10568) {
   if (($fp_0 | 0) == 0) {
    $_0 = 0; //@line 4679
   } else {
    $_01112 = $_011;
    $fp_013 = $fp_0;
    break;
   }
   return $_0 | 0; //@line 4686
  }
 } while (0);
 $11 = _dsk_pce_open_fp($fp_013, $_01112) | 0; //@line 4691
 if (($11 | 0) == 0) {
  _fclose($fp_013 | 0) | 0; //@line 4695
  $_0 = 0; //@line 4697
  return $_0 | 0; //@line 4700
 } else {
  _dsk_set_fname($11, $fname); //@line 4702
  $_0 = $11; //@line 4704
  return $_0 | 0; //@line 4707
 }
 return 0;
}
function _dsk_pce_probe($fname) {
 $fname = $fname | 0;
 var $1 = 0, $4 = 0, $_0_i = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 4717
 STACKTOP = STACKTOP + 8 | 0; //@line 4717
 $1 = _fopen($fname | 0, 54872) | 0; //@line 4719
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 4723
  STACKTOP = sp; //@line 4725
  return $_0 | 0; //@line 4726
 }
 $4 = sp | 0; //@line 4728
 if ((_dsk_read($1, $4, 0, 0, 4, 0) | 0) == 0) {
  $_0_i = (_dsk_get_uint32_be($4, 0) | 0) == 1346981191 | 0; //@line 4741
 } else {
  $_0_i = 0; //@line 4743
 }
 _fclose($1 | 0) | 0; //@line 4746
 $_0 = $_0_i; //@line 4748
 STACKTOP = sp; //@line 4750
 return $_0 | 0; //@line 4751
}
function _dsk_qed_get_msg($dsk, $msg, $val, $max) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 $max = $max | 0;
 return 1; //@line 4763
}
function _dsk_qed_open_fp($fp, $ro) {
 $fp = $fp | 0;
 $ro = $ro | 0;
 var $1 = 0, $5 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $20 = 0, $23 = 0, $26 = 0, $27 = 0, $30 = 0, $31 = 0, $35 = 0, $43 = 0, $46 = 0, $47$0 = 0, $49 = 0, $50$0 = 0, $52 = 0, $53$0 = 0, $53$1 = 0, $55 = 0, $57$0 = 0, $57$1 = 0, $60 = 0, $$etemp$14 = 0, $66$0 = 0, $68 = 0, $70 = 0, $71$0 = 0, $71$1 = 0, $73 = 0, $84 = 0, $91$0 = 0, $92$0 = 0, $93$0 = 0, $96$1 = 0, $104 = 0, $108 = 0, $118 = 0, $119 = 0, $122 = 0, $125 = 0, $129 = 0, $132 = 0, $146 = 0, $156 = 0, $159 = 0, $173 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 4802
 $1 = _malloc(4280) | 0; //@line 4803
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 4807
  STACKTOP = sp; //@line 4809
  return $_0 | 0; //@line 4810
 }
 $5 = $1 + 4276 | 0; //@line 4813
 HEAP32[$5 >> 2] = $fp; //@line 4814
 HEAP32[$1 + 68 >> 2] = 0; //@line 4817
 $9 = $1 + 4264 | 0; //@line 4819
 HEAP32[$9 >> 2] = 0; //@line 4820
 $11 = $1 + 4268 | 0; //@line 4822
 HEAP32[$11 >> 2] = 0; //@line 4823
 $13 = $1 + 4272 | 0; //@line 4825
 HEAP32[$13 >> 2] = 0; //@line 4826
 $14 = $1 + 152 | 0; //@line 4827
 do {
  if ((_dsk_read($fp, $14, 0, 0, 4096, 0) | 0) == 0) {
   if ((_dsk_get_uint32_le($14, 0) | 0) != 4474193) {
    break;
   }
   $20 = $1 + 4248 | 0; //@line 4843
   HEAP8[$20] = 0; //@line 4844
   $23 = $1 + 72 | 0; //@line 4847
   HEAP32[$23 >> 2] = _dsk_get_uint32_le($14, 4) | 0; //@line 4848
   $26 = $1 + 76 | 0; //@line 4851
   HEAP32[$26 >> 2] = _dsk_get_uint32_le($14, 8) | 0; //@line 4852
   $27 = _dsk_get_uint32_le($14, 12) | 0; //@line 4853
   HEAP32[$1 + 80 >> 2] = $27; //@line 4856
   $30 = HEAP32[$23 >> 2] | 0; //@line 4857
   $31 = $30 - 1 | 0; //@line 4858
   if (($31 & $30 | 0) != 0) {
    break;
   }
   $35 = HEAP32[$26 >> 2] | 0; //@line 4865
   if (($35 - 1 & $35 | 0) != 0 | ($27 | 0) == 0) {
    break;
   }
   $43 = $1 + 128 | 0; //@line 4877
   HEAP32[$43 >> 2] = Math_imul($35, $30) | 0; //@line 4878
   $46 = $1 + 136 | 0; //@line 4882
   HEAP32[$46 >> 2] = $31; //@line 4884
   HEAP32[$46 + 4 >> 2] = 0; //@line 4886
   $47$0 = _dsk_get_uint64_le($14, 16) | 0; //@line 4887
   $49 = $1 + 88 | 0; //@line 4890
   HEAP32[$49 >> 2] = $47$0; //@line 4892
   HEAP32[$49 + 4 >> 2] = tempRet0; //@line 4894
   $50$0 = _dsk_get_uint64_le($14, 24) | 0; //@line 4895
   $52 = $1 + 96 | 0; //@line 4898
   HEAP32[$52 >> 2] = $50$0; //@line 4900
   HEAP32[$52 + 4 >> 2] = tempRet0; //@line 4902
   $53$0 = _dsk_get_uint64_le($14, 32) | 0; //@line 4903
   $53$1 = tempRet0; //@line 4904
   $55 = $1 + 104 | 0; //@line 4906
   HEAP32[$55 >> 2] = $53$0; //@line 4908
   HEAP32[$55 + 4 >> 2] = $53$1; //@line 4910
   $57$0 = HEAP32[$49 >> 2] & -6; //@line 4917
   $57$1 = HEAP32[$49 + 4 >> 2] | 0; //@line 4918
   if (!(($57$0 | 0) == 0 & ($57$1 | 0) == 0)) {
    $60 = HEAP32[_stderr >> 2] | 0; //@line 4924
    $$etemp$14 = 42768; //@line 4925
    _fprintf($60 | 0, $$etemp$14 | 0, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $57$0, HEAP32[tempInt + 8 >> 2] = $57$1, tempInt) | 0) | 0; //@line 4926
    break;
   }
   if (!(($53$0 | 0) == 0 & ($53$1 | 0) == 0)) {
    HEAP8[$20] = 1; //@line 4935
    HEAP32[$55 >> 2] = 0; //@line 4939
    HEAP32[$55 + 4 >> 2] = 0; //@line 4941
    _dsk_set_uint64_le($14, 32, 0, 0); //@line 4944
   }
   $66$0 = _dsk_get_uint64_le($14, 40) | 0; //@line 4947
   $68 = $1 + 112 | 0; //@line 4950
   HEAP32[$68 >> 2] = $66$0; //@line 4952
   HEAP32[$68 + 4 >> 2] = tempRet0; //@line 4954
   $70 = $1 + 4256 | 0; //@line 4956
   HEAP32[$70 >> 2] = 0; //@line 4960
   HEAP32[$70 + 4 >> 2] = 0; //@line 4962
   $71$0 = _dsk_get_uint64_le($14, 48) | 0; //@line 4963
   $71$1 = tempRet0; //@line 4964
   $73 = $1 + 120 | 0; //@line 4966
   HEAP32[$73 >> 2] = $71$0; //@line 4968
   HEAP32[$73 + 4 >> 2] = $71$1; //@line 4970
   if (!((HEAP32[$46 >> 2] & HEAP32[$68 >> 2] | 0) == 0 & (HEAP32[$46 + 4 >> 2] & HEAP32[$68 + 4 >> 2] | 0) == 0)) {
    break;
   }
   if (!(($71$0 & 511 | 0) == 0 & ($71$1 & 0 | 0) == 0)) {
    break;
   }
   $84 = $1 + 144 | 0; //@line 5001
   if ((_dsk_get_filesize(HEAP32[$5 >> 2] | 0, $84) | 0) != 0) {
    break;
   }
   $91$0 = HEAP32[$23 >> 2] | 0; //@line 5013
   $92$0 = _i64Add(HEAP32[$84 >> 2] | 0, HEAP32[$84 + 4 >> 2] | 0, -1, -1) | 0;
   $93$0 = _i64Add($92$0, tempRet0, $91$0, 0) | 0;
   $96$1 = tempRet0 & ~HEAP32[$46 + 4 >> 2]; //@line 5028
   HEAP32[$84 >> 2] = $93$0 & ~HEAP32[$46 >> 2]; //@line 5030
   HEAP32[$84 + 4 >> 2] = $96$1; //@line 5032
   do {
    if ((HEAP8[$20] | 0) != 0 & ($ro | 0) == 0) {
     if ((_dsk_write(HEAP32[$5 >> 2] | 0, $14, 0, 0, 4096, 0) | 0) == 0) {
      $104 = HEAP32[$5 >> 2] | 0; //@line 5049
      _fflush($104 | 0) | 0; //@line 5050
      break;
     }
     _free($1); //@line 5054
     $_0 = 0; //@line 5056
     STACKTOP = sp; //@line 5058
     return $_0 | 0; //@line 5059
    }
   } while (0);
   $108 = $1; //@line 5062
   _dsk_init($108, $1, (HEAP32[$73 >> 2] | 0) >>> 9 | HEAP32[$73 + 4 >> 2] << 23, 0, 0, 0); //@line 5071
   _dsk_set_type($108, 7); //@line 5072
   _dsk_set_readonly($108, $ro); //@line 5073
   HEAP32[$1 + 4 >> 2] = 462; //@line 5076
   HEAP32[$1 + 8 >> 2] = 62; //@line 5079
   HEAP32[$1 + 12 >> 2] = 12; //@line 5082
   $118 = HEAP32[$43 >> 2] | 0; //@line 5083
   $119 = _malloc($118) | 0; //@line 5084
   HEAP32[$9 >> 2] = $119; //@line 5085
   do {
    if (($119 | 0) != 0) {
     $122 = _malloc($118) | 0; //@line 5090
     HEAP32[$11 >> 2] = $122; //@line 5091
     if (($122 | 0) == 0) {
      break;
     }
     $125 = _malloc(HEAP32[$23 >> 2] | 0) | 0; //@line 5098
     HEAP32[$13 >> 2] = $125; //@line 5099
     if (($125 | 0) == 0) {
      break;
     }
     if ((_dsk_read(HEAP32[$5 >> 2] | 0, $119, HEAP32[$68 >> 2] | 0, HEAP32[$68 + 4 >> 2] | 0, $118, 0) | 0) == 0) {
      _dsk_guess_geometry($108) | 0; //@line 5116
      $_0 = $108; //@line 5118
      STACKTOP = sp; //@line 5120
      return $_0 | 0; //@line 5121
     }
     $156 = HEAP32[$1 + 64 >> 2] | 0; //@line 5125
     $159 = HEAP32[$156 + 68 >> 2] | 0; //@line 5128
     if (($159 | 0) != 0) {
      _dsk_del($159); //@line 5132
     }
     _free(HEAP32[$156 + 4272 >> 2] | 0); //@line 5138
     _free(HEAP32[$156 + 4268 >> 2] | 0); //@line 5142
     _free(HEAP32[$156 + 4264 >> 2] | 0); //@line 5146
     $173 = HEAP32[$156 + 4276 >> 2] | 0; //@line 5149
     _fclose($173 | 0) | 0; //@line 5150
     _free($156); //@line 5151
     $_0 = 0; //@line 5153
     STACKTOP = sp; //@line 5155
     return $_0 | 0; //@line 5156
    }
   } while (0);
   $129 = HEAP32[$1 + 64 >> 2] | 0; //@line 5161
   $132 = HEAP32[$129 + 68 >> 2] | 0; //@line 5164
   if (($132 | 0) != 0) {
    _dsk_del($132); //@line 5168
   }
   _free(HEAP32[$129 + 4272 >> 2] | 0); //@line 5174
   _free(HEAP32[$129 + 4268 >> 2] | 0); //@line 5178
   _free(HEAP32[$129 + 4264 >> 2] | 0); //@line 5182
   $146 = HEAP32[$129 + 4276 >> 2] | 0; //@line 5185
   _fclose($146 | 0) | 0; //@line 5186
   _free($129); //@line 5187
   $_0 = 0; //@line 5189
   STACKTOP = sp; //@line 5191
   return $_0 | 0; //@line 5192
  }
 } while (0);
 _free($1); //@line 5195
 $_0 = 0; //@line 5197
 STACKTOP = sp; //@line 5199
 return $_0 | 0; //@line 5200
}
function _dsk_qed_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0, $5 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 5212
 $5 = HEAP32[$2 + 68 >> 2] | 0; //@line 5215
 if (($5 | 0) != 0) {
  _dsk_del($5); //@line 5219
 }
 _free(HEAP32[$2 + 4272 >> 2] | 0); //@line 5225
 _free(HEAP32[$2 + 4268 >> 2] | 0); //@line 5229
 _free(HEAP32[$2 + 4264 >> 2] | 0); //@line 5233
 _fclose(HEAP32[$2 + 4276 >> 2] | 0) | 0; //@line 5237
 _free($2); //@line 5238
 return;
}
function _dsk_qed_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $ofs = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, $15 = 0, $_02732 = 0, $_02831 = 0, $_02930 = 0, $18 = 0, $20 = 0, $_028_ = 0, $22$0 = 0, $27$0 = 0, $27$1 = 0, $30 = 0, $36 = 0, $39 = 0, $_pre_phi = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 5258
 STACKTOP = STACKTOP + 8 | 0; //@line 5258
 $ofs = sp | 0; //@line 5259
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 5266
  STACKTOP = sp; //@line 5268
  return $_0 | 0; //@line 5269
 }
 $7 = HEAP32[$dsk + 64 >> 2] | 0; //@line 5272
 $8 = $7; //@line 5273
 $10 = $7 + 72 | 0; //@line 5275
 $12 = $7 + 4276 | 0; //@line 5277
 if (($n | 0) == 0) {
  $_0 = 0; //@line 5281
  STACKTOP = sp; //@line 5283
  return $_0 | 0; //@line 5284
 }
 $15 = $7 + 68 | 0; //@line 5287
 $_02930 = $i;
 $_02831 = $n;
 $_02732 = $buf;
 L13253 : while (1) {
  $18 = (HEAP32[$10 >> 2] | 0) >>> 9; //@line 5295
  $20 = $18 - (($_02930 >>> 0) % ($18 >>> 0) | 0) | 0; //@line 5297
  $_028_ = $20 >>> 0 > $_02831 >>> 0 ? $_02831 : $20; //@line 5299
  $22$0 = $_02930; //@line 5300
  HEAP32[$ofs >> 2] = $22$0 << 9 | 0 >>> 23; //@line 5305
  HEAP32[$ofs + 4 >> 2] = 0 << 9 | $22$0 >>> 23; //@line 5307
  if ((_dsk_qed_translate($8, $ofs, 0) | 0) != 0) {
   $_0 = 1; //@line 5312
   label = 10634; //@line 5313
   break;
  }
  $27$0 = HEAP32[$ofs >> 2] | 0; //@line 5317
  $27$1 = HEAP32[$ofs + 4 >> 2] | 0; //@line 5319
  do {
   if (($27$0 | 0) == 0 & ($27$1 | 0) == 0) {
    $30 = HEAP32[$15 >> 2] | 0; //@line 5326
    if (($30 | 0) == 0) {
     $36 = $_028_ << 9; //@line 5330
     _memset($_02732 | 0, 0, $36 | 0); //@line 5331
     $_pre_phi = $36; //@line 5332
     break;
    }
    if ((_dsk_read_lba($30, $_02732, $_02930, $_028_) | 0) != 0) {
     $_0 = 1; //@line 5339
     label = 10637; //@line 5340
     break L13253;
    }
    $_pre_phi = $_028_ << 9; //@line 5345
   } else {
    $39 = $_028_ << 9; //@line 5348
    if ((_dsk_read(HEAP32[$12 >> 2] | 0, $_02732, $27$0, $27$1, $39, 0) | 0) == 0) {
     $_pre_phi = $39; //@line 5355
    } else {
     $_0 = 1; //@line 5357
     label = 10638; //@line 5358
     break L13253;
    }
   }
  } while (0);
  if (($_02831 | 0) == ($_028_ | 0)) {
   $_0 = 0; //@line 5370
   label = 10639; //@line 5371
   break;
  } else {
   $_02930 = $_028_ + $_02930 | 0;
   $_02831 = $_02831 - $_028_ | 0;
   $_02732 = $_02732 + $_pre_phi | 0;
  }
 }
 if ((label | 0) == 10637) {
  STACKTOP = sp; //@line 5379
  return $_0 | 0; //@line 5380
 } else if ((label | 0) == 10639) {
  STACKTOP = sp; //@line 5384
  return $_0 | 0; //@line 5385
 } else if ((label | 0) == 10638) {
  STACKTOP = sp; //@line 5389
  return $_0 | 0; //@line 5390
 } else if ((label | 0) == 10634) {
  STACKTOP = sp; //@line 5394
  return $_0 | 0; //@line 5395
 }
 return 0;
}
function _dsk_qed_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $ofs = 0, $7 = 0, $8 = 0, $10 = 0, $12 = 0, $_02126 = 0, $_02225 = 0, $_02324 = 0, $15 = 0, $17 = 0, $_022_ = 0, $19$0 = 0, $26 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 5412
 STACKTOP = STACKTOP + 8 | 0; //@line 5412
 $ofs = sp | 0; //@line 5413
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 5420
  STACKTOP = sp; //@line 5422
  return $_0 | 0; //@line 5423
 }
 $7 = HEAP32[$dsk + 64 >> 2] | 0; //@line 5426
 $8 = $7; //@line 5427
 $10 = $7 + 72 | 0; //@line 5429
 $12 = $7 + 4276 | 0; //@line 5431
 if (($n | 0) == 0) {
  $_0 = 0; //@line 5435
  STACKTOP = sp; //@line 5437
  return $_0 | 0; //@line 5438
 } else {
  $_02324 = $i;
  $_02225 = $n;
  $_02126 = $buf;
 }
 while (1) {
  $15 = (HEAP32[$10 >> 2] | 0) >>> 9; //@line 5447
  $17 = $15 - (($_02324 >>> 0) % ($15 >>> 0) | 0) | 0; //@line 5449
  $_022_ = $17 >>> 0 > $_02225 >>> 0 ? $_02225 : $17; //@line 5451
  $19$0 = $_02324; //@line 5452
  HEAP32[$ofs >> 2] = $19$0 << 9 | 0 >>> 23; //@line 5457
  HEAP32[$ofs + 4 >> 2] = 0 << 9 | $19$0 >>> 23; //@line 5459
  if ((_dsk_qed_translate($8, $ofs, 1) | 0) != 0) {
   $_0 = 1; //@line 5464
   label = 10648; //@line 5465
   break;
  }
  $26 = $_022_ << 9; //@line 5473
  if ((_dsk_write(HEAP32[$12 >> 2] | 0, $_02126, HEAP32[$ofs >> 2] | 0, HEAP32[$ofs + 4 >> 2] | 0, $26, 0) | 0) != 0) {
   $_0 = 1; //@line 5480
   label = 10649; //@line 5481
   break;
  }
  if (($_02225 | 0) == ($_022_ | 0)) {
   $_0 = 0; //@line 5490
   label = 10646; //@line 5491
   break;
  } else {
   $_02324 = $_022_ + $_02324 | 0;
   $_02225 = $_02225 - $_022_ | 0;
   $_02126 = $_02126 + $26 | 0;
  }
 }
 if ((label | 0) == 10649) {
  STACKTOP = sp; //@line 5499
  return $_0 | 0; //@line 5500
 } else if ((label | 0) == 10648) {
  STACKTOP = sp; //@line 5504
  return $_0 | 0; //@line 5505
 } else if ((label | 0) == 10646) {
  STACKTOP = sp; //@line 5509
  return $_0 | 0; //@line 5510
 }
 return 0;
}
function _dsk_qed_open($fname, $ro) {
 $fname = $fname | 0;
 $ro = $ro | 0;
 var $5 = 0, $_011 = 0, $fp_0 = 0, $fp_013 = 0, $_01112 = 0, $11 = 0, $_0 = 0, label = 0;
 do {
  if (($ro | 0) == 0) {
   $5 = _fopen($fname | 0, 56864 | 0) | 0; //@line 5526
   if (($5 | 0) != 0) {
    $_01112 = 0;
    $fp_013 = $5;
    break;
   }
   $fp_0 = _fopen($fname | 0, 54848 | 0) | 0;
   $_011 = 1;
   label = 10655; //@line 5536
  } else {
   $fp_0 = _fopen($fname | 0, 54848 | 0) | 0;
   $_011 = $ro;
   label = 10655; //@line 5541
  }
 } while (0);
 do {
  if ((label | 0) == 10655) {
   if (($fp_0 | 0) == 0) {
    $_0 = 0; //@line 5551
   } else {
    $_01112 = $_011;
    $fp_013 = $fp_0;
    break;
   }
   return $_0 | 0; //@line 5558
  }
 } while (0);
 $11 = _dsk_qed_open_fp($fp_013, $_01112) | 0; //@line 5563
 if (($11 | 0) == 0) {
  _fclose($fp_013 | 0) | 0; //@line 5567
  $_0 = 0; //@line 5569
  return $_0 | 0; //@line 5572
 } else {
  _dsk_set_fname($11, $fname); //@line 5574
  $_0 = $11; //@line 5576
  return $_0 | 0; //@line 5579
 }
 return 0;
}
function _dsk_qed_cow_new($dsk, $fname) {
 $dsk = $dsk | 0;
 $fname = $fname | 0;
 var $1 = 0, $minclst_0 = 0, $15 = 0, $16 = 0, $18 = 0, $24 = 0, $27 = 0, $fp_013_i = 0, $_01112_i = 0, $29 = 0, $35 = 0, $43 = 0, $44$0 = 0, $47 = 0, $48 = 0, $49 = 0, $54 = 0, $_42 = 0, $58 = 0, $59 = 0, $62 = 0, $67 = 0, $_0 = 0;
 $1 = _fopen($fname | 0, 56864) | 0; //@line 5600
 do {
  if (($1 | 0) == 0) {
   if ((HEAP32[$dsk >> 2] | 0) == 7) {
    $minclst_0 = HEAP32[(HEAP32[$dsk + 64 >> 2] | 0) + 72 >> 2] | 0; //@line 5616
   } else {
    $minclst_0 = 0; //@line 5618
   }
   $15 = HEAP32[$dsk + 28 >> 2] | 0; //@line 5622
   $16 = _fopen($fname | 0, 50304) | 0; //@line 5623
   if (($16 | 0) == 0) {
    $_0 = 0; //@line 5627
    return $_0 | 0; //@line 5630
   }
   $18 = _dsk_qed_create_fp($16, $15, $minclst_0) | 0; //@line 5632
   _fclose($16 | 0) | 0; //@line 5633
   if (($18 | 0) == 0) {
    break;
   } else {
    $_0 = 0; //@line 5639
   }
   return $_0 | 0; //@line 5643
  } else {
   _fclose($1 | 0) | 0; //@line 5645
  }
 } while (0);
 $24 = _fopen($fname | 0, 56864) | 0; //@line 5648
 do {
  if (($24 | 0) == 0) {
   $27 = _fopen($fname | 0, 54848) | 0; //@line 5653
   if (($27 | 0) == 0) {
    $_0 = 0; //@line 5657
   } else {
    $_01112_i = 1;
    $fp_013_i = $27;
    break;
   }
   return $_0 | 0; //@line 5664
  } else {
   $_01112_i = 0;
   $fp_013_i = $24;
  }
 } while (0);
 $29 = _dsk_qed_open_fp($fp_013_i, $_01112_i) | 0; //@line 5671
 if (($29 | 0) == 0) {
  _fclose($fp_013_i | 0) | 0; //@line 5675
  $_0 = 0; //@line 5677
  return $_0 | 0; //@line 5680
 }
 _dsk_set_fname($29, $fname); //@line 5682
 $35 = HEAP32[$29 + 64 >> 2] | 0; //@line 5684
 HEAP32[$35 + 68 >> 2] = $dsk; //@line 5687
 HEAP32[$29 + 16 >> 2] = 8; //@line 5689
 HEAP32[$29 + 20 >> 2] = 14; //@line 5691
 HEAP32[$29 + 24 >> 2] = HEAP32[$dsk + 24 >> 2]; //@line 5695
 $43 = $35 + 152 | 0; //@line 5696
 $44$0 = _dsk_get_uint64_le($43, 16) | 0; //@line 5697
 $47 = (HEAP32[$dsk >> 2] | 0) == 1; //@line 5701
 _dsk_set_uint64_le($43, 16, ($47 ? 5 : 1) | $44$0, ($47 ? 0 : 0) | tempRet0); //@line 5710
 $48 = $dsk + 60 | 0; //@line 5711
 $49 = HEAP32[$48 >> 2] | 0; //@line 5712
 if (($49 | 0) == 0) {
  $54 = 0; //@line 5716
 } else {
  $54 = _strlen($49 | 0) | 0; //@line 5720
 }
 $_42 = $54 >>> 0 > 1024 ? 0 : $54; //@line 5724
 _dsk_set_uint32_le($43, 56, 64); //@line 5725
 _dsk_set_uint32_le($43, 60, $_42); //@line 5726
 if (($_42 | 0) != 0) {
  $58 = $35 + 216 | 0; //@line 5730
  $59 = HEAP32[$48 >> 2] | 0; //@line 5731
  _memcpy($58 | 0, $59 | 0, $_42) | 0; //@line 5732
 }
 $62 = $35 + 4276 | 0; //@line 5736
 if ((_dsk_write(HEAP32[$62 >> 2] | 0, $43, 0, 0, 4096, 0) | 0) == 0) {
  $67 = HEAP32[$62 >> 2] | 0; //@line 5746
  _fflush($67 | 0) | 0; //@line 5747
 }
 _dsk_set_geometry($29, HEAP32[$dsk + 28 >> 2] | 0, HEAP32[$dsk + 32 >> 2] | 0, HEAP32[$dsk + 36 >> 2] | 0, HEAP32[$dsk + 40 >> 2] | 0) | 0; //@line 5758
 _dsk_set_visible_chs($29, HEAP32[$dsk + 44 >> 2] | 0, HEAP32[$dsk + 48 >> 2] | 0, HEAP32[$dsk + 52 >> 2] | 0); //@line 5765
 _dsk_set_fname($29, $fname); //@line 5766
 $_0 = $29; //@line 5768
 return $_0 | 0; //@line 5771
}
function _dsk_qed_set_msg($dsk, $msg, $val) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $5 = 0, $7 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $23 = 0, $24 = 0, $26 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $i_048_us_i = 0, $blki_047_us_i = 0, $36 = 0, $37$0 = 0, $37$1 = 0, $42$0 = 0, $42$1 = 0, $blki_145_us_i = 0, $j_044_us_i = 0, $56$0 = 0, $56$1 = 0, $65 = 0, $66 = 0, $68 = 0, $_pre_phi55_i = 0, $74 = 0, $blki_2_us_i = 0, $79 = 0, $_pre_phi53_i = 0, $_pre_phi_i = 0, $82 = 0, $86 = 0, $97$0 = 0, $97$1 = 0, $99 = 0, $_0 = 0, label = 0;
 if ((_strcmp($msg | 0, 46312) | 0) != 0) {
  $_0 = 1; //@line 5804
  return $_0 | 0; //@line 5807
 }
 $5 = HEAP32[$dsk + 64 >> 2] | 0; //@line 5810
 $7 = $5 + 68 | 0; //@line 5812
 if ((HEAP32[$7 >> 2] | 0) == 0) {
  $_0 = 1; //@line 5817
  return $_0 | 0; //@line 5820
 }
 $12 = $5 + 128 | 0; //@line 5823
 $13 = HEAP32[$12 >> 2] | 0; //@line 5824
 $14 = $13 >>> 3; //@line 5825
 $16 = $5 + 72 | 0; //@line 5827
 $18 = (HEAP32[$16 >> 2] | 0) >>> 9; //@line 5829
 do {
  if (($14 | 0) == 0) {
   $82 = $13;
   $_pre_phi_i = $5 + 4276 | 0;
   $_pre_phi53_i = $5 + 4264 | 0;
  } else {
   $23 = $5 + 4264 | 0; //@line 5842
   $24 = Math_imul($18, $14) | 0; //@line 5843
   $26 = $5 + 136 | 0; //@line 5845
   $28 = $5 + 4256 | 0; //@line 5847
   $30 = $5 + 4276 | 0; //@line 5849
   $32 = $5 + 4268 | 0; //@line 5851
   $33 = $5 + 4272 | 0; //@line 5853
   $blki_047_us_i = 0;
   $i_048_us_i = 0;
   L13337 : while (1) {
    $36 = $i_048_us_i << 3; //@line 5860
    $37$0 = _dsk_get_uint64_le(HEAP32[$23 >> 2] | 0, $36) | 0; //@line 5861
    $37$1 = tempRet0; //@line 5862
    if (($37$0 | 0) == 0 & ($37$1 | 0) == 0) {
     $blki_2_us_i = $blki_047_us_i + $24 | 0; //@line 5870
    } else {
     $42$0 = $37$0 & ~HEAP32[$26 >> 2]; //@line 5880
     $42$1 = $37$1 & ~HEAP32[$26 + 4 >> 2]; //@line 5881
     if ((HEAP32[$28 >> 2] | 0) == ($42$0 | 0) & (HEAP32[$28 + 4 >> 2] | 0) == ($42$1 | 0)) {
      $j_044_us_i = 0;
      $blki_145_us_i = $blki_047_us_i;
     } else {
      if ((_dsk_read(HEAP32[$30 >> 2] | 0, HEAP32[$32 >> 2] | 0, $42$0, $42$1, HEAP32[$12 >> 2] | 0, 0) | 0) != 0) {
       $_0 = 1; //@line 5900
       label = 10710; //@line 5901
       break;
      }
      HEAP32[$28 >> 2] = $42$0; //@line 5905
      HEAP32[$28 + 4 >> 2] = $42$1; //@line 5907
      $j_044_us_i = 0;
      $blki_145_us_i = $blki_047_us_i;
     }
     while (1) {
      $56$0 = _dsk_get_uint64_le(HEAP32[$32 >> 2] | 0, $j_044_us_i << 3) | 0; //@line 5916
      $56$1 = tempRet0; //@line 5917
      if (($56$0 | 0) == 0 & ($56$1 | 0) == 0) {
       $_pre_phi55_i = $blki_145_us_i + $18 | 0; //@line 5925
      } else {
       if ((_dsk_read(HEAP32[$30 >> 2] | 0, HEAP32[$33 >> 2] | 0, $56$0 & ~HEAP32[$26 >> 2], $56$1 & ~HEAP32[$26 + 4 >> 2], HEAP32[$16 >> 2] | 0, 0) | 0) != 0) {
        $_0 = 1; //@line 5946
        label = 10707; //@line 5947
        break L13337;
       }
       $65 = $blki_145_us_i + $18 | 0; //@line 5950
       $66 = HEAP32[$7 >> 2] | 0; //@line 5951
       $68 = HEAP32[$66 + 28 >> 2] | 0; //@line 5953
       if ((_dsk_write_lba($66, HEAP32[$33 >> 2] | 0, $blki_145_us_i, $65 >>> 0 > $68 >>> 0 ? $68 - $blki_145_us_i | 0 : $18) | 0) == 0) {
        $_pre_phi55_i = $65; //@line 5962
       } else {
        $_0 = 1; //@line 5964
        label = 10713; //@line 5965
        break L13337;
       }
      }
      $74 = $j_044_us_i + 1 | 0; //@line 5970
      if ($74 >>> 0 < $14 >>> 0) {
       $j_044_us_i = $74;
       $blki_145_us_i = $_pre_phi55_i;
      } else {
       break;
      }
     }
     _dsk_set_uint64_le(HEAP32[$23 >> 2] | 0, $36, 0, 0); //@line 5982
     $blki_2_us_i = $_pre_phi55_i; //@line 5984
    }
    $79 = $i_048_us_i + 1 | 0; //@line 5987
    if ($79 >>> 0 < $14 >>> 0) {
     $blki_047_us_i = $blki_2_us_i;
     $i_048_us_i = $79;
    } else {
     label = 10703; //@line 5993
     break;
    }
   }
   if ((label | 0) == 10707) {
    return $_0 | 0; //@line 6000
   } else if ((label | 0) == 10703) {
    $82 = HEAP32[$12 >> 2] | 0;
    $_pre_phi_i = $30;
    $_pre_phi53_i = $23;
    break;
   } else if ((label | 0) == 10713) {
    return $_0 | 0; //@line 6011
   } else if ((label | 0) == 10710) {
    return $_0 | 0; //@line 6016
   }
  }
 } while (0);
 $86 = $5 + 112 | 0; //@line 6026
 if ((_dsk_write(HEAP32[$_pre_phi_i >> 2] | 0, HEAP32[$_pre_phi53_i >> 2] | 0, HEAP32[$86 >> 2] | 0, HEAP32[$86 + 4 >> 2] | 0, $82, 0) | 0) != 0) {
  $_0 = 1; //@line 6037
  return $_0 | 0; //@line 6040
 }
 _fflush(HEAP32[$_pre_phi_i >> 2] | 0) | 0; //@line 6043
 $97$0 = _i64Add(HEAP32[$12 >> 2] | 0, 0, HEAP32[$86 >> 2] | 0, HEAP32[$86 + 4 >> 2] | 0) | 0;
 $97$1 = tempRet0;
 $99 = $5 + 144 | 0; //@line 6053
 HEAP32[$99 >> 2] = $97$0; //@line 6055
 HEAP32[$99 + 4 >> 2] = $97$1; //@line 6057
 _dsk_set_filesize(HEAP32[$_pre_phi_i >> 2] | 0, $97$0, $97$1) | 0; //@line 6059
 $_0 = 0; //@line 6061
 return $_0 | 0; //@line 6064
}
function _dsk_qed_create_fp($fp, $n, $minclst) {
 $fp = $fp | 0;
 $n = $n | 0;
 $minclst = $minclst | 0;
 var $1$0 = 0, $2$0 = 0, $2$1 = 0, $_0_i = 0, $10 = 0, $_09_i = 0, $13$0 = 0, $13$1 = 0, $14$0 = 0, $14$1 = 0, $15$0 = 0, $16$0 = 0, $16$1 = 0, $max_size_060$0 = 0, $max_size_060$1 = 0, $max_size_0_lcssa$0 = 0, $max_size_0_lcssa$1 = 0, $table_size_0_lcssa = 0, $18 = 0, $20$0 = 0, $20$1 = 0, $table_size_061 = 0, $21 = 0, $23$0 = 0, $23$1 = 0, $24$0 = 0, $max_size_0$0 = 0, $max_size_0$1 = 0, $cluster_size_058 = 0, $27 = 0, $31$0 = 0, $31$1 = 0, $33$0 = 0, $34$0 = 0, $34$1 = 0, $35 = 0, $_lcssa = 0, $cluster_size_0_lcssa = 0, $38 = 0, $41$0 = 0, $41$1 = 0, $46 = 0, $i_0 = 0, $51$0 = 0, $_0 = 0, label = 0;
 $1$0 = $n; //@line 6085
 $2$0 = $1$0 << 9 | 0 >>> 23; //@line 6087
 $2$1 = 0 << 9 | $1$0 >>> 23; //@line 6088
 do {
  if ($minclst >>> 0 < 4097) {
   $_09_i = 4096; //@line 6093
  } else {
   if ($minclst >>> 0 > 134217727) {
    $_09_i = 134217728; //@line 6098
    break;
   }
   $_0_i = ($minclst << 1) - 1 | 0; //@line 6104
   while (1) {
    $10 = $_0_i - 1 & $_0_i; //@line 6108
    if (($10 | 0) == 0) {
     $_09_i = $_0_i; //@line 6112
     break;
    } else {
     $_0_i = $10; //@line 6115
    }
   }
  }
 } while (0);
 $13$0 = $_09_i >>> 3; //@line 6122
 $13$1 = 0; //@line 6123
 $14$0 = $13$0 << 1 | 0 >>> 31; //@line 6124
 $14$1 = $13$1 << 1 | $13$0 >>> 31; //@line 6125
 $15$0 = ___muldi3($14$0, $14$1, $14$0, $14$1) | 0;
 $16$0 = $_09_i; //@line 6127
 $16$1 = 0; //@line 6128
 $max_size_060$0 = ___muldi3($15$0, tempRet0, $16$0, $16$1) | 0;
 $max_size_060$1 = tempRet0;
 if ($max_size_060$1 >>> 0 < $2$1 >>> 0 | $max_size_060$1 >>> 0 == $2$1 >>> 0 & $max_size_060$0 >>> 0 < $2$0 >>> 0) {
  $table_size_061 = 2; //@line 6133
  while (1) {
   $21 = $table_size_061 << 1; //@line 6136
   $23$0 = ___muldi3($21, 0, $13$0, $13$1) | 0;
   $23$1 = tempRet0;
   $24$0 = ___muldi3($23$0, $23$1, $23$0, $23$1) | 0;
   $max_size_0$0 = ___muldi3($24$0, tempRet0, $16$0, $16$1) | 0;
   $max_size_0$1 = tempRet0;
   if (($max_size_0$1 >>> 0 < $2$1 >>> 0 | $max_size_0$1 >>> 0 == $2$1 >>> 0 & $max_size_0$0 >>> 0 < $2$0 >>> 0) & $21 >>> 0 < 16) {
    $table_size_061 = $21; //@line 6147
   } else {
    $table_size_0_lcssa = $21;
    $max_size_0_lcssa$1 = $max_size_0$1;
    $max_size_0_lcssa$0 = $max_size_0$0;
    break;
   }
  }
 } else {
  $table_size_0_lcssa = 2;
  $max_size_0_lcssa$1 = $max_size_060$1;
  $max_size_0_lcssa$0 = $max_size_060$0;
 }
 $18 = $max_size_0_lcssa$1 >>> 0 < $2$1 >>> 0 | $max_size_0_lcssa$1 >>> 0 == $2$1 >>> 0 & $max_size_0_lcssa$0 >>> 0 < $2$0 >>> 0; //@line 6159
 if ($18 & $_09_i >>> 0 < 134217728) {
  $20$0 = $table_size_0_lcssa; //@line 6164
  $20$1 = 0; //@line 6165
  $cluster_size_058 = $_09_i; //@line 6167
  while (1) {
   $27 = $cluster_size_058 << 1; //@line 6170
   $31$0 = ___muldi3($cluster_size_058 >>> 2 & 536870911, 0, $20$0, $20$1) | 0;
   $31$1 = tempRet0;
   $33$0 = ___muldi3($31$0, $31$1, $27, 0) | 0;
   $34$0 = ___muldi3($33$0, tempRet0, $31$0, $31$1) | 0;
   $34$1 = tempRet0;
   $35 = $34$1 >>> 0 < $2$1 >>> 0 | $34$1 >>> 0 == $2$1 >>> 0 & $34$0 >>> 0 < $2$0 >>> 0; //@line 6180
   if ($35 & $27 >>> 0 < 134217728) {
    $cluster_size_058 = $27; //@line 6185
   } else {
    $cluster_size_0_lcssa = $27;
    $_lcssa = $35;
    break;
   }
  }
 } else {
  $cluster_size_0_lcssa = $_09_i;
  $_lcssa = $18;
 }
 if ($_lcssa) {
  $_0 = 1; //@line 6198
  return $_0 | 0; //@line 6201
 }
 $38 = _malloc($cluster_size_0_lcssa) | 0; //@line 6203
 if (($38 | 0) == 0) {
  $_0 = 1; //@line 6207
  return $_0 | 0; //@line 6210
 }
 _memset($38 | 0, 0, $cluster_size_0_lcssa | 0); //@line 6212
 _dsk_set_uint32_le($38, 0, 4474193); //@line 6213
 _dsk_set_uint32_le($38, 4, $cluster_size_0_lcssa); //@line 6214
 _dsk_set_uint32_le($38, 8, $table_size_0_lcssa); //@line 6215
 _dsk_set_uint32_le($38, 12, 1); //@line 6216
 _dsk_set_uint64_le($38, 16, 0, 0); //@line 6219
 _dsk_set_uint64_le($38, 24, 0, 0); //@line 6222
 _dsk_set_uint64_le($38, 32, 0, 0); //@line 6225
 $41$0 = $cluster_size_0_lcssa; //@line 6226
 $41$1 = 0; //@line 6227
 _dsk_set_uint64_le($38, 40, $41$0, $41$1); //@line 6228
 _dsk_set_uint64_le($38, 48, $2$0, $2$1); //@line 6229
 if ((_dsk_write($fp, $38, 0, 0, $41$0, $41$1) | 0) != 0) {
  _free($38); //@line 6236
  $_0 = 1; //@line 6238
  return $_0 | 0; //@line 6241
 }
 _memset($38 | 0, 0, $cluster_size_0_lcssa | 0); //@line 6243
 $46 = $table_size_0_lcssa | 1; //@line 6244
 $i_0 = 1; //@line 6246
 while (1) {
  if ($i_0 >>> 0 >= $46 >>> 0) {
   label = 10731; //@line 6252
   break;
  }
  $51$0 = ___muldi3($i_0, 0, $41$0, $41$1) | 0;
  if ((_dsk_write($fp, $38, $51$0, tempRet0, $41$0, $41$1) | 0) == 0) {
   $i_0 = $i_0 + 1 | 0; //@line 6263
  } else {
   label = 10730; //@line 6265
   break;
  }
 }
 if ((label | 0) == 10731) {
  _free($38); //@line 6270
  $_0 = 0; //@line 6272
  return $_0 | 0; //@line 6275
 } else if ((label | 0) == 10730) {
  _free($38); //@line 6278
  $_0 = 1; //@line 6280
  return $_0 | 0; //@line 6283
 }
 return 0;
}
function _dsk_qed_probe($fname) {
 $fname = $fname | 0;
 var $1 = 0, $4 = 0, $_0_i = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 6293
 STACKTOP = STACKTOP + 8 | 0; //@line 6293
 $1 = _fopen($fname | 0, 54848) | 0; //@line 6295
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 6299
  STACKTOP = sp; //@line 6301
  return $_0 | 0; //@line 6302
 }
 $4 = sp | 0; //@line 6304
 if ((_dsk_read($1, $4, 0, 0, 4, 0) | 0) == 0) {
  $_0_i = (_dsk_get_uint32_le($4, 0) | 0) == 4474193 | 0; //@line 6317
 } else {
  $_0_i = 0; //@line 6319
 }
 _fclose($1 | 0) | 0; //@line 6322
 $_0 = $_0_i; //@line 6324
 STACKTOP = sp; //@line 6326
 return $_0 | 0; //@line 6327
}
function _dsk_qed_translate($qed, $ofs, $alloc) {
 $qed = $qed | 0;
 $ofs = $ofs | 0;
 $alloc = $alloc | 0;
 var $3 = 0, $4 = 0, $6 = 0, $9$0 = 0, $9$1 = 0, $10$0 = 0, $10$1 = 0, $11$0 = 0, $12 = 0, $13$0 = 0, $14 = 0, $15 = 0, $17 = 0, $19$0 = 0, $19$1 = 0, $20$0 = 0, $20$1 = 0, $21 = 0, $22$0 = 0, $22$1 = 0, $23$0 = 0, $23$1 = 0, $31 = 0, $33 = 0, $36$0 = 0, $36$1 = 0, $37 = 0, $38 = 0, $47 = 0, $48 = 0, $49 = 0, $54 = 0, $57 = 0, $61 = 0, $n_0_i = 0, $qed_idx65 = 0, $68 = 0, $74$0 = 0, $74$1 = 0, $82 = 0, $84 = 0, $90 = 0, $97 = 0, $100$0 = 0, $103$0 = 0, $106$0 = 0, $106$1 = 0, $107 = 0, $113 = 0, $_pre_phi = 0, $123 = 0, $125$0 = 0, $125$1 = 0, $131 = 0, $132 = 0, $143 = 0, $144 = 0, $145 = 0, $150 = 0, $153 = 0, $157 = 0, $n_0_i71 = 0, $161 = 0, $165 = 0, $187$0 = 0, $191$0 = 0, $197$0 = 0, $_0 = 0;
 $3 = $qed + 72 | 0; //@line 6378
 $4 = HEAP32[$3 >> 2] | 0; //@line 6379
 $6 = Math_imul($4 >>> 3, HEAP32[$qed + 76 >> 2] | 0) | 0; //@line 6381
 $9$0 = ___udivdi3(HEAP32[$ofs >> 2] | 0, HEAP32[$ofs + 4 >> 2] | 0, $4, 0) | 0;
 $9$1 = tempRet0;
 $10$0 = $6; //@line 6389
 $10$1 = 0; //@line 6390
 $11$0 = ___udivdi3($9$0, $9$1, $10$0, $10$1) | 0;
 $12 = $11$0; //@line 6393
 $13$0 = ___uremdi3($9$0, $9$1, $10$0, $10$1) | 0;
 $14 = $13$0; //@line 6396
 $15 = $qed + 4264 | 0; //@line 6397
 $17 = $12 << 3; //@line 6399
 $19$0 = _dsk_get_uint64_le((HEAP32[$15 >> 2] | 0) + $17 | 0, 0) | 0; //@line 6401
 $19$1 = tempRet0; //@line 6402
 $20$0 = HEAP32[$ofs >> 2] | 0; //@line 6404
 $20$1 = HEAP32[$ofs + 4 >> 2] | 0; //@line 6406
 $21 = $qed + 136 | 0; //@line 6407
 $22$0 = HEAP32[$21 >> 2] | 0; //@line 6409
 $22$1 = HEAP32[$21 + 4 >> 2] | 0; //@line 6411
 $23$0 = $22$0 & $20$0; //@line 6412
 $23$1 = $22$1 & $20$1; //@line 6413
 if ($12 >>> 0 >= $6 >>> 0) {
  $_0 = 1; //@line 6417
  return $_0 | 0; //@line 6420
 }
 if (($19$0 | 0) == 0 & ($19$1 | 0) == 0) {
  if (($alloc | 0) == 0) {
   HEAP32[$ofs >> 2] = 0; //@line 6433
   HEAP32[$ofs + 4 >> 2] = 0; //@line 6435
   $_0 = 0; //@line 6437
   return $_0 | 0; //@line 6440
  }
  $31 = $qed + 144 | 0; //@line 6442
  $33 = $qed + 128 | 0; //@line 6447
  $36$0 = _i64Add(HEAP32[$33 >> 2] | 0, 0, HEAP32[$31 >> 2] | 0, HEAP32[$31 + 4 >> 2] | 0) | 0;
  $36$1 = tempRet0;
  $37 = $qed + 68 | 0; //@line 6452
  $38 = HEAP32[$37 >> 2] | 0; //@line 6453
  do {
   if (($38 | 0) == 0) {
    _memset(HEAP32[$qed + 4272 >> 2] | 0, 0, HEAP32[$3 >> 2] | 0); //@line 6461
   } else {
    $47 = (($22$0 ^ -512) & $20$0) >>> 9 | (($22$1 ^ 511) & $20$1) << 23; //@line 6473
    $48 = HEAP32[$3 >> 2] | 0; //@line 6474
    $49 = $48 >>> 9; //@line 6475
    $54 = $qed + 4272 | 0; //@line 6480
    if (($49 + $47 | 0) >>> 0 > (HEAP32[$38 + 28 >> 2] | 0) >>> 0) {
     _memset(HEAP32[$54 >> 2] | 0, 0, $48 | 0); //@line 6484
     $57 = HEAP32[$37 >> 2] | 0; //@line 6485
     $n_0_i = (HEAP32[$57 + 28 >> 2] | 0) - $47 | 0;
     $61 = $57;
    } else {
     $n_0_i = $49;
     $61 = $38;
    }
    if ((_dsk_read_lba($61, HEAP32[$54 >> 2] | 0, $47, $n_0_i) | 0) == 0) {
     break;
    } else {
     $_0 = 1; //@line 6503
    }
    return $_0 | 0; //@line 6507
   }
  } while (0);
  $qed_idx65 = $qed + 4276 | 0; //@line 6513
  if ((_dsk_write(HEAP32[$qed_idx65 >> 2] | 0, HEAP32[$qed + 4272 >> 2] | 0, $36$0, $36$1, HEAP32[$3 >> 2] | 0, 0) | 0) != 0) {
   $_0 = 1; //@line 6521
   return $_0 | 0; //@line 6524
  }
  $68 = $qed + 4268 | 0; //@line 6526
  _memset(HEAP32[$68 >> 2] | 0, 0, HEAP32[$33 >> 2] | 0); //@line 6529
  _dsk_set_uint64_le((HEAP32[$68 >> 2] | 0) + ($14 << 3) | 0, 0, $36$0, $36$1); //@line 6533
  $74$0 = HEAP32[$31 >> 2] | 0; //@line 6535
  $74$1 = HEAP32[$31 + 4 >> 2] | 0; //@line 6537
  if ((_dsk_write(HEAP32[$qed_idx65 >> 2] | 0, HEAP32[$68 >> 2] | 0, $74$0, $74$1, HEAP32[$33 >> 2] | 0, 0) | 0) != 0) {
   $_0 = 1; //@line 6547
   return $_0 | 0; //@line 6550
  }
  $82 = HEAP32[$qed_idx65 >> 2] | 0; //@line 6552
  _fflush($82 | 0) | 0; //@line 6553
  $84 = $qed + 4256 | 0; //@line 6554
  HEAP32[$84 >> 2] = $74$0; //@line 6556
  HEAP32[$84 + 4 >> 2] = $74$1; //@line 6558
  _dsk_set_uint64_le((HEAP32[$15 >> 2] | 0) + $17 | 0, 0, HEAP32[$31 >> 2] | 0, HEAP32[$31 + 4 >> 2] | 0); //@line 6565
  $90 = $qed + 112 | 0; //@line 6568
  if ((_dsk_write(HEAP32[$qed_idx65 >> 2] | 0, HEAP32[$15 >> 2] | 0, HEAP32[$90 >> 2] | 0, HEAP32[$90 + 4 >> 2] | 0, HEAP32[$33 >> 2] | 0, 0) | 0) != 0) {
   $_0 = 1; //@line 6580
   return $_0 | 0; //@line 6583
  }
  $97 = HEAP32[$qed_idx65 >> 2] | 0; //@line 6585
  _fflush($97 | 0) | 0; //@line 6586
  $100$0 = _i64Add($36$0, $36$1, $23$0 | 0, $23$1 & 0) | 0;
  HEAP32[$ofs >> 2] = $100$0; //@line 6593
  HEAP32[$ofs + 4 >> 2] = tempRet0; //@line 6595
  $103$0 = _i64Add(HEAP32[$3 >> 2] | 0, 0, $36$0, $36$1) | 0;
  HEAP32[$31 >> 2] = $103$0; //@line 6601
  HEAP32[$31 + 4 >> 2] = tempRet0; //@line 6603
  $_0 = 0; //@line 6605
  return $_0 | 0; //@line 6608
 }
 $106$0 = $19$0 & ~$22$0; //@line 6614
 $106$1 = $19$1 & ~$22$1; //@line 6615
 $107 = $qed + 4256 | 0; //@line 6616
 do {
  if ((HEAP32[$107 >> 2] | 0) == ($106$0 | 0) & (HEAP32[$107 + 4 >> 2] | 0) == ($106$1 | 0)) {
   $_pre_phi = $qed + 4268 | 0; //@line 6627
  } else {
   $113 = $qed + 4268 | 0; //@line 6631
   if ((_dsk_read(HEAP32[$qed + 4276 >> 2] | 0, HEAP32[$113 >> 2] | 0, $106$0, $106$1, HEAP32[$qed + 128 >> 2] | 0, 0) | 0) == 0) {
    HEAP32[$107 >> 2] = $106$0; //@line 6642
    HEAP32[$107 + 4 >> 2] = $106$1; //@line 6644
    $_pre_phi = $113; //@line 6646
    break;
   } else {
    $_0 = 1; //@line 6649
    return $_0 | 0; //@line 6652
   }
  }
 } while (0);
 $123 = $14 << 3; //@line 6658
 $125$0 = _dsk_get_uint64_le((HEAP32[$_pre_phi >> 2] | 0) + $123 | 0, 0) | 0; //@line 6660
 $125$1 = tempRet0; //@line 6661
 if (!(($125$0 | 0) == 0 & ($125$1 | 0) == 0)) {
  $197$0 = _i64Add($125$0 & ~HEAP32[$21 >> 2], $125$1 & ~HEAP32[$21 + 4 >> 2], $23$0 | 0, $23$1 & 0) | 0;
  HEAP32[$ofs >> 2] = $197$0; //@line 6683
  HEAP32[$ofs + 4 >> 2] = tempRet0; //@line 6685
  $_0 = 0; //@line 6687
  return $_0 | 0; //@line 6690
 }
 if (($alloc | 0) == 0) {
  HEAP32[$ofs >> 2] = 0; //@line 6698
  HEAP32[$ofs + 4 >> 2] = 0; //@line 6700
  $_0 = 0; //@line 6702
  return $_0 | 0; //@line 6705
 }
 $131 = $qed + 68 | 0; //@line 6707
 $132 = HEAP32[$131 >> 2] | 0; //@line 6708
 do {
  if (($132 | 0) == 0) {
   _memset(HEAP32[$qed + 4272 >> 2] | 0, 0, HEAP32[$3 >> 2] | 0); //@line 6716
  } else {
   $143 = ((HEAP32[$21 >> 2] ^ -512) & HEAP32[$ofs >> 2]) >>> 9 | ((HEAP32[$21 + 4 >> 2] ^ 511) & HEAP32[$ofs + 4 >> 2]) << 23; //@line 6736
   $144 = HEAP32[$3 >> 2] | 0; //@line 6737
   $145 = $144 >>> 9; //@line 6738
   $150 = $qed + 4272 | 0; //@line 6743
   if (($143 + $145 | 0) >>> 0 > (HEAP32[$132 + 28 >> 2] | 0) >>> 0) {
    _memset(HEAP32[$150 >> 2] | 0, 0, $144 | 0); //@line 6747
    $153 = HEAP32[$131 >> 2] | 0; //@line 6748
    $n_0_i71 = (HEAP32[$153 + 28 >> 2] | 0) - $143 | 0;
    $157 = $153;
   } else {
    $n_0_i71 = $145;
    $157 = $132;
   }
   if ((_dsk_read_lba($157, HEAP32[$150 >> 2] | 0, $143, $n_0_i71) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 6766
   }
   return $_0 | 0; //@line 6770
  }
 } while (0);
 $161 = $qed + 4276 | 0; //@line 6773
 $165 = $qed + 144 | 0; //@line 6777
 if ((_dsk_write(HEAP32[$161 >> 2] | 0, HEAP32[$qed + 4272 >> 2] | 0, HEAP32[$165 >> 2] | 0, HEAP32[$165 + 4 >> 2] | 0, HEAP32[$3 >> 2] | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 6789
  return $_0 | 0; //@line 6792
 }
 _dsk_set_uint64_le((HEAP32[$_pre_phi >> 2] | 0) + $123 | 0, 0, HEAP32[$165 >> 2] | 0, HEAP32[$165 + 4 >> 2] | 0); //@line 6800
 if ((_dsk_write(HEAP32[$161 >> 2] | 0, HEAP32[$_pre_phi >> 2] | 0, $106$0, $106$1, HEAP32[$qed + 128 >> 2] | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 6811
  return $_0 | 0; //@line 6814
 }
 _fflush(HEAP32[$161 >> 2] | 0) | 0; //@line 6817
 HEAP32[$107 >> 2] = $106$0; //@line 6819
 HEAP32[$107 + 4 >> 2] = $106$1; //@line 6821
 $187$0 = _i64Add(HEAP32[$165 >> 2] | 0, HEAP32[$165 + 4 >> 2] | 0, $23$0 | 0, $23$1 & 0) | 0;
 HEAP32[$ofs >> 2] = $187$0; //@line 6832
 HEAP32[$ofs + 4 >> 2] = tempRet0; //@line 6834
 $191$0 = _i64Add(HEAP32[$165 >> 2] | 0, HEAP32[$165 + 4 >> 2] | 0, HEAP32[$3 >> 2] | 0, 0) | 0;
 HEAP32[$165 >> 2] = $191$0; //@line 6844
 HEAP32[$165 + 4 >> 2] = tempRet0; //@line 6846
 $_0 = 0; //@line 6848
 return $_0 | 0; //@line 6851
}
function _dsk_img_open_fp($fp, $ofs$0, $ofs$1, $ro) {
 $fp = $fp | 0;
 $ofs$0 = $ofs$0 | 0;
 $ofs$1 = $ofs$1 | 0;
 $ro = $ro | 0;
 var $cnt = 0, $4$0 = 0, $4$1 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $8$1 = 0, $11 = 0, $14 = 0, $22 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 6866
 STACKTOP = STACKTOP + 8 | 0; //@line 6866
 $cnt = sp | 0; //@line 6867
 if ((_dsk_get_filesize($fp, $cnt) | 0) != 0) {
  $_0 = 0; //@line 6872
  STACKTOP = sp; //@line 6874
  return $_0 | 0; //@line 6875
 }
 $4$0 = HEAP32[$cnt >> 2] | 0; //@line 6878
 $4$1 = HEAP32[$cnt + 4 >> 2] | 0; //@line 6880
 if (!($4$1 >>> 0 > $ofs$1 >>> 0 | $4$1 >>> 0 == $ofs$1 >>> 0 & $4$0 >>> 0 > $ofs$0 >>> 0)) {
  $_0 = 0; //@line 6884
  STACKTOP = sp; //@line 6886
  return $_0 | 0; //@line 6887
 }
 $7$0 = _i64Subtract($4$0, $4$1, $ofs$0, $ofs$1) | 0;
 $7$1 = tempRet0;
 $8$0 = $7$0 >>> 9 | $7$1 << 23; //@line 6890
 $8$1 = $7$1 >>> 9 | 0 << 23; //@line 6891
 HEAP32[$cnt >> 2] = $8$0; //@line 6893
 HEAP32[$cnt + 4 >> 2] = $8$1; //@line 6895
 if (($8$0 | 0) == 0 & ($8$1 | 0) == 0) {
  $_0 = 0; //@line 6901
  STACKTOP = sp; //@line 6903
  return $_0 | 0; //@line 6904
 }
 $11 = _malloc(80) | 0; //@line 6906
 if (($11 | 0) == 0) {
  $_0 = 0; //@line 6910
  STACKTOP = sp; //@line 6912
  return $_0 | 0; //@line 6913
 }
 $14 = $11; //@line 6917
 _dsk_init($14, $11, $8$0, 0, 0, 0); //@line 6918
 _dsk_set_type($14, 1); //@line 6919
 _dsk_set_readonly($14, $ro); //@line 6920
 HEAP32[$11 + 4 >> 2] = 158; //@line 6923
 HEAP32[$11 + 8 >> 2] = 66; //@line 6926
 HEAP32[$11 + 12 >> 2] = 26; //@line 6929
 $22 = $11 + 72 | 0; //@line 6931
 HEAP32[$22 >> 2] = $ofs$0; //@line 6933
 HEAP32[$22 + 4 >> 2] = $ofs$1; //@line 6935
 HEAP32[$11 + 68 >> 2] = $fp; //@line 6938
 _dsk_guess_geometry($14) | 0; //@line 6939
 $_0 = $14; //@line 6941
 STACKTOP = sp; //@line 6943
 return $_0 | 0; //@line 6944
}
function _dsk_img_open($fname, $ofs$0, $ofs$1, $ro) {
 $fname = $fname | 0;
 $ofs$0 = $ofs$0 | 0;
 $ofs$1 = $ofs$1 | 0;
 $ro = $ro | 0;
 var $5 = 0, $_012 = 0, $fp_0 = 0, $fp_014 = 0, $_01213 = 0, $11 = 0, $_0 = 0, label = 0;
 do {
  if (($ro | 0) == 0) {
   $5 = _fopen($fname | 0, 56848 | 0) | 0; //@line 6961
   if (($5 | 0) != 0) {
    $_01213 = 0;
    $fp_014 = $5;
    break;
   }
   $fp_0 = _fopen($fname | 0, 54776 | 0) | 0;
   $_012 = 1;
   label = 10804; //@line 6971
  } else {
   $fp_0 = _fopen($fname | 0, 54776 | 0) | 0;
   $_012 = $ro;
   label = 10804; //@line 6976
  }
 } while (0);
 do {
  if ((label | 0) == 10804) {
   if (($fp_0 | 0) == 0) {
    $_0 = 0; //@line 6986
   } else {
    $_01213 = $_012;
    $fp_014 = $fp_0;
    break;
   }
   return $_0 | 0; //@line 6993
  }
 } while (0);
 $11 = _dsk_img_open_fp($fp_014, $ofs$0, $ofs$1, $_01213) | 0; //@line 6998
 if (($11 | 0) == 0) {
  _fclose($fp_014 | 0) | 0; //@line 7002
  $_0 = 0; //@line 7004
  return $_0 | 0; //@line 7007
 } else {
  _dsk_set_fname($11, $fname); //@line 7009
  $_0 = $11; //@line 7011
  return $_0 | 0; //@line 7014
 }
 return 0;
}
function _dsk_img_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 7025
 _fclose(HEAP32[$2 + 68 >> 2] | 0) | 0; //@line 7029
 _free($2); //@line 7030
 return;
}
function _dsk_img_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $7 = 0, $9 = 0, $11$0 = 0, $13$0 = 0, $14$0 = 0, $_0 = 0;
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 7053
  return $_0 | 0; //@line 7056
 }
 $7 = HEAP32[$dsk + 64 >> 2] | 0; //@line 7059
 $9 = $7 + 72 | 0; //@line 7061
 $11$0 = $i; //@line 7066
 $13$0 = _i64Add(HEAP32[$9 >> 2] | 0, HEAP32[$9 + 4 >> 2] | 0, $11$0 << 9 | 0 >>> 23, 0 << 9 | $11$0 >>> 23) | 0;
 $14$0 = $n; //@line 7071
 $_0 = (_dsk_read(HEAP32[$7 + 68 >> 2] | 0, $buf, $13$0, tempRet0, $14$0 << 9 | 0 >>> 23, 0 << 9 | $14$0 >>> 23) | 0) != 0 | 0; //@line 7082
 return $_0 | 0; //@line 7085
}
function _dsk_img_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $11 = 0, $13 = 0, $15$0 = 0, $17$0 = 0, $18$0 = 0, $21 = 0, $_0 = 0;
 if ((HEAP8[$dsk + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 7105
  return $_0 | 0; //@line 7108
 }
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 7116
  return $_0 | 0; //@line 7119
 }
 $11 = HEAP32[$dsk + 64 >> 2] | 0; //@line 7122
 $13 = $11 + 72 | 0; //@line 7124
 $15$0 = $i; //@line 7129
 $17$0 = _i64Add(HEAP32[$13 >> 2] | 0, HEAP32[$13 + 4 >> 2] | 0, $15$0 << 9 | 0 >>> 23, 0 << 9 | $15$0 >>> 23) | 0;
 $18$0 = $n; //@line 7134
 $21 = $11 + 68 | 0; //@line 7139
 if ((_dsk_write(HEAP32[$21 >> 2] | 0, $buf, $17$0, tempRet0, $18$0 << 9 | 0 >>> 23, 0 << 9 | $18$0 >>> 23) | 0) != 0) {
  $_0 = 1; //@line 7145
  return $_0 | 0; //@line 7148
 }
 _fflush(HEAP32[$21 >> 2] | 0) | 0; //@line 7151
 $_0 = 0; //@line 7153
 return $_0 | 0; //@line 7156
}
function _chr_log_flush($cdrv) {
 $cdrv = $cdrv | 0;
 var $1 = 0, $2 = 0, $_pre = 0, $_pre_i = 0, $7 = 0, $_038_i = 0, $_02937_i = 0, $9 = 0, $10 = 0, $13 = 0, $i_030_i = 0, $23 = 0, $24 = 0, $i_131_i = 0, $26 = 0, $28 = 0, $_lcssa_i = 0, $i_233_i = 0, $32 = 0, sp = 0;
 sp = STACKTOP; //@line 7170
 $1 = $cdrv + 28 | 0; //@line 7171
 $2 = HEAP32[$1 >> 2] | 0; //@line 7172
 $_pre = $cdrv + 48 | 0; //@line 7174
 if (($2 | 0) == 0) {
  HEAP32[$1 >> 2] = 0; //@line 7177
  HEAP32[$_pre >> 2] = 0; //@line 7178
  STACKTOP = sp; //@line 7179
  return;
 }
 $_pre_i = $cdrv + 52 | 0; //@line 7184
 $7 = (HEAP32[$_pre >> 2] | 0) != 0 ? 50488 : 49536; //@line 7186
 $_02937_i = $2;
 $_038_i = $cdrv + 32 | 0;
 while (1) {
  $9 = $_02937_i >>> 0 < 16; //@line 7192
  $10 = $9 ? $_02937_i : 16; //@line 7193
  $13 = HEAPU8[$_038_i] | 0; //@line 7196
  _fprintf(HEAP32[$_pre_i >> 2] | 0, 50808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $7, HEAP32[tempInt + 8 >> 2] = $13, tempInt) | 0) | 0; //@line 7197
  if ($10 >>> 0 > 1) {
   $i_030_i = 1; //@line 7201
   do {
    _fprintf(HEAP32[$_pre_i >> 2] | 0, 49064, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAPU8[$_038_i + $i_030_i | 0] | 0, tempInt) | 0) | 0; //@line 7208
    $i_030_i = $i_030_i + 1 | 0; //@line 7209
   } while ($i_030_i >>> 0 < $10 >>> 0);
  }
  $23 = HEAP32[$_pre_i >> 2] | 0; //@line 7219
  if ($9) {
   $i_131_i = $10;
   $24 = $23;
   while (1) {
    _fwrite(48672, 3, 1, $24 | 0) | 0; //@line 7226
    $26 = $i_131_i + 1 | 0; //@line 7227
    $28 = HEAP32[$_pre_i >> 2] | 0; //@line 7229
    if ($26 >>> 0 < 16) {
     $i_131_i = $26;
     $24 = $28;
    } else {
     $_lcssa_i = $28; //@line 7234
     break;
    }
   }
  } else {
   $_lcssa_i = $23; //@line 7239
  }
  _fwrite(48280, 2, 1, $_lcssa_i | 0) | 0; //@line 7242
  if (($10 | 0) != 0) {
   $i_233_i = 0; //@line 7246
   do {
    $32 = HEAP8[$_038_i + $i_233_i | 0] | 0; //@line 7250
    _fputc((($32 - 32 & 255) > 94 ? 46 : $32 & 255) | 0, HEAP32[$_pre_i >> 2] | 0) | 0; //@line 7256
    $i_233_i = $i_233_i + 1 | 0; //@line 7257
   } while ($i_233_i >>> 0 < $10 >>> 0);
  }
  _fputc(10, HEAP32[$_pre_i >> 2] | 0) | 0; //@line 7268
  if (($_02937_i | 0) == ($10 | 0)) {
   break;
  } else {
   $_02937_i = $_02937_i - $10 | 0;
   $_038_i = $_038_i + $10 | 0;
  }
 }
 _fflush(HEAP32[$_pre_i >> 2] | 0) | 0; //@line 7280
 HEAP32[$1 >> 2] = 0; //@line 7282
 HEAP32[$_pre >> 2] = 0; //@line 7283
 STACKTOP = sp; //@line 7284
 return;
}
function _chr_init($cdrv, $ext) {
 $cdrv = $cdrv | 0;
 $ext = $ext | 0;
 HEAP32[$cdrv >> 2] = $ext; //@line 7296
 _memset($cdrv + 4 | 0, 0, 28); //@line 7300
 _memset($cdrv + 48 | 0, 0, 32); //@line 7302
 return;
}
function _chr_close($cdrv) {
 $cdrv = $cdrv | 0;
 var $3 = 0, $7 = 0, $11 = 0;
 if (($cdrv | 0) == 0) {
  return;
 }
 $3 = $cdrv + 52 | 0; //@line 7320
 if ((HEAP32[$3 >> 2] | 0) != 0) {
  _chr_log_flush($cdrv); //@line 7325
  $7 = HEAP32[$3 >> 2] | 0; //@line 7326
  _fclose($7 | 0) | 0; //@line 7327
 }
 $11 = HEAP32[$cdrv + 56 >> 2] | 0; //@line 7331
 if (($11 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vi[$11 & 1023]($cdrv); //@line 7338
 return;
}
function _chr_read($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $4 = 0, $7 = 0, $13 = 0, $_pre = 0, $_026_i = 0, $_02425_i = 0, $21 = 0, $22 = 0, $_0__i = 0, $24 = 0, $26 = 0, $_0 = 0;
 if (($cdrv | 0) == 0) {
  $_0 = 0; //@line 7358
  return $_0 | 0; //@line 7361
 }
 $4 = HEAP32[$cdrv + 60 >> 2] | 0; //@line 7364
 if (($4 | 0) == 0) {
  $_0 = 0; //@line 7368
  return $_0 | 0; //@line 7371
 }
 $7 = FUNCTION_TABLE_iiii[$4 & 127]($cdrv, $buf, $cnt) | 0; //@line 7373
 if ((HEAP32[$cdrv + 52 >> 2] | 0) == 0 | ($7 | 0) == 0) {
  $_0 = $7; //@line 7381
  return $_0 | 0; //@line 7384
 }
 $13 = $cdrv + 28 | 0; //@line 7386
 $_pre = $cdrv + 48 | 0; //@line 7389
 do {
  if ((HEAP32[$13 >> 2] | 0) != 0) {
   if ((HEAP32[$_pre >> 2] | 0) == 0) {
    break;
   }
   _chr_log_flush($cdrv); //@line 7399
  }
 } while (0);
 $_02425_i = $buf;
 $_026_i = $7;
 while (1) {
  $21 = HEAP32[$13 >> 2] | 0; //@line 7408
  $22 = 16 - $21 | 0; //@line 7409
  $_0__i = $_026_i >>> 0 < $22 >>> 0 ? $_026_i : $22; //@line 7411
  $24 = $cdrv + 32 + $21 | 0; //@line 7412
  _memcpy($24 | 0, $_02425_i | 0, $_0__i) | 0; //@line 7413
  $26 = $_0__i + (HEAP32[$13 >> 2] | 0) | 0; //@line 7415
  HEAP32[$13 >> 2] = $26; //@line 7416
  HEAP32[$_pre >> 2] = 0; //@line 7417
  if ($26 >>> 0 > 15) {
   _chr_log_flush($cdrv); //@line 7421
  }
  if (($_026_i | 0) == ($_0__i | 0)) {
   $_0 = $7; //@line 7427
   break;
  }
  $_02425_i = $_02425_i + $_0__i | 0;
  $_026_i = $_026_i - $_0__i | 0;
 }
 return $_0 | 0; //@line 7437
}
function _chr_mouse_write($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return $cnt | 0; //@line 7448
}
function _chr_mouse_get_ctl($cdrv, $ctl) {
 $cdrv = $cdrv | 0;
 $ctl = $ctl | 0;
 HEAP32[$ctl >> 2] = 1792; //@line 7457
 return 0; //@line 7459
}
function _chr_mouse_set_params($cdrv, $bps, $bpc, $parity, $stop) {
 $cdrv = $cdrv | 0;
 $bps = $bps | 0;
 $bpc = $bpc | 0;
 $parity = $parity | 0;
 $stop = $stop | 0;
 return 0; //@line 7472
}
function _chr_mouse_set_ctl($cdrv, $ctl) {
 $cdrv = $cdrv | 0;
 $ctl = $ctl | 0;
 var $2 = 0, $3 = 0, $5 = 0, $_pre = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 7487
 $3 = $ctl & 1; //@line 7488
 $5 = $ctl & 2; //@line 7490
 $_pre = $2 + 348 | 0; //@line 7498
 do {
  if (!((HEAP32[$2 + 80 >> 2] | 0) != 0 | ($5 | 0) == 0 | ($3 | 0) == 0)) {
   if ((HEAP8[$_pre] | 0) != 0) {
    if ((HEAP8[$2 + 349 | 0] | 0) != 0) {
     break;
    }
   }
   HEAP32[$2 + 352 >> 2] = 0; //@line 7516
   HEAP32[$2 + 356 >> 2] = 0; //@line 7519
   HEAP32[$2 + 372 >> 2] = 0; //@line 7522
   HEAP32[$2 + 384 >> 2] = 0; //@line 7525
   HEAP32[$2 + 84 >> 2] = 1; //@line 7528
   HEAP32[$2 + 88 >> 2] = 0; //@line 7531
   HEAP8[$2 + 92 | 0] = 77; //@line 7533
  }
 } while (0);
 HEAP8[$_pre] = $3 & 255; //@line 7538
 HEAP8[$2 + 349 | 0] = $5 >>> 1 & 255; //@line 7542
 return 0; //@line 7544
}
function _chr_write($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $4 = 0, $7 = 0, $13 = 0, $_pre = 0, $_026_i = 0, $_02425_i = 0, $21 = 0, $22 = 0, $_0__i = 0, $24 = 0, $26 = 0, $_0 = 0;
 if (($cdrv | 0) == 0) {
  $_0 = $cnt; //@line 7561
  return $_0 | 0; //@line 7564
 }
 $4 = HEAP32[$cdrv + 64 >> 2] | 0; //@line 7567
 if (($4 | 0) == 0) {
  $_0 = $cnt; //@line 7571
  return $_0 | 0; //@line 7574
 }
 $7 = FUNCTION_TABLE_iiii[$4 & 127]($cdrv, $buf, $cnt) | 0; //@line 7576
 if ((HEAP32[$cdrv + 52 >> 2] | 0) == 0 | ($7 | 0) == 0) {
  $_0 = $7; //@line 7584
  return $_0 | 0; //@line 7587
 }
 $13 = $cdrv + 28 | 0; //@line 7589
 $_pre = $cdrv + 48 | 0; //@line 7592
 do {
  if ((HEAP32[$13 >> 2] | 0) != 0) {
   if ((HEAP32[$_pre >> 2] | 0) == 1) {
    break;
   }
   _chr_log_flush($cdrv); //@line 7602
  }
 } while (0);
 $_02425_i = $buf;
 $_026_i = $7;
 while (1) {
  $21 = HEAP32[$13 >> 2] | 0; //@line 7611
  $22 = 16 - $21 | 0; //@line 7612
  $_0__i = $_026_i >>> 0 < $22 >>> 0 ? $_026_i : $22; //@line 7614
  $24 = $cdrv + 32 + $21 | 0; //@line 7615
  _memcpy($24 | 0, $_02425_i | 0, $_0__i) | 0; //@line 7616
  $26 = $_0__i + (HEAP32[$13 >> 2] | 0) | 0; //@line 7618
  HEAP32[$13 >> 2] = $26; //@line 7619
  HEAP32[$_pre >> 2] = 1; //@line 7620
  if ($26 >>> 0 > 15) {
   _chr_log_flush($cdrv); //@line 7624
  }
  if (($_026_i | 0) == ($_0__i | 0)) {
   $_0 = $7; //@line 7630
   break;
  }
  $_02425_i = $_02425_i + $_0__i | 0;
  $_026_i = $_026_i - $_0__i | 0;
 }
 return $_0 | 0; //@line 7640
}
function _chr_log_ctl($cdrv, $old, $new) {
 $cdrv = $cdrv | 0;
 $old = $old | 0;
 $new = $new | 0;
 var $1 = 0, $6 = 0, $10 = 0, $_lobit = 0, $16 = 0, $17 = 0, $22 = 0, $_lobit27 = 0, $28 = 0, $_lobit28 = 0, $34 = 0, $_lobit29 = 0, sp = 0;
 sp = STACKTOP; //@line 7655
 $1 = $cdrv + 52 | 0; //@line 7656
 if ((HEAP32[$1 >> 2] | 0) == 0 | ($old | 0) == ($new | 0)) {
  STACKTOP = sp; //@line 7663
  return;
 }
 _chr_log_flush($cdrv); //@line 7666
 $6 = $new ^ $old; //@line 7667
 if (($6 & 512 | 0) != 0) {
  $10 = HEAP32[$1 >> 2] | 0; //@line 7672
  $_lobit = $new >>> 9 & 1; //@line 7674
  _fprintf($10 | 0, 51312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 55288, HEAP32[tempInt + 8 >> 2] = $_lobit, tempInt) | 0) | 0; //@line 7675
 }
 if (($6 & 1 | 0) != 0) {
  $16 = HEAP32[$1 >> 2] | 0; //@line 7682
  $17 = $new & 1; //@line 7683
  _fprintf($16 | 0, 51312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 54624, HEAP32[tempInt + 8 >> 2] = $17, tempInt) | 0) | 0; //@line 7684
 }
 if (($6 & 2 | 0) != 0) {
  $22 = HEAP32[$1 >> 2] | 0; //@line 7691
  $_lobit27 = $new >>> 1 & 1; //@line 7693
  _fprintf($22 | 0, 51312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 53928, HEAP32[tempInt + 8 >> 2] = $_lobit27, tempInt) | 0) | 0; //@line 7694
 }
 if (($6 & 256 | 0) != 0) {
  $28 = HEAP32[$1 >> 2] | 0; //@line 7701
  $_lobit28 = $new >>> 8 & 1; //@line 7703
  _fprintf($28 | 0, 51312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 53320, HEAP32[tempInt + 8 >> 2] = $_lobit28, tempInt) | 0) | 0; //@line 7704
 }
 if (($6 & 1024 | 0) != 0) {
  $34 = HEAP32[$1 >> 2] | 0; //@line 7711
  $_lobit29 = $new >>> 10 & 1; //@line 7713
  _fprintf($34 | 0, 51312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 52480, HEAP32[tempInt + 8 >> 2] = $_lobit29, tempInt) | 0) | 0; //@line 7714
 }
 if (($6 & 2048 | 0) == 0) {
  STACKTOP = sp; //@line 7721
  return;
 }
 _fprintf(HEAP32[$1 >> 2] | 0, 51312, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 51840, HEAP32[tempInt + 8 >> 2] = $new >>> 11 & 1, tempInt) | 0) | 0; //@line 7727
 STACKTOP = sp; //@line 7729
 return;
}
function _chr_set_ctl($cdrv, $ctl) {
 $cdrv = $cdrv | 0;
 $ctl = $ctl | 0;
 var $3 = 0, $4 = 0, $8 = 0, $_0 = 0;
 do {
  if (($cdrv | 0) == 0) {
   $_0 = 1; //@line 7745
  } else {
   $3 = $cdrv + 24 | 0; //@line 7747
   $4 = HEAP32[$3 >> 2] | 0; //@line 7748
   if (($4 | 0) == ($ctl | 0)) {
    $_0 = 0; //@line 7752
    break;
   }
   _chr_log_ctl($cdrv, $4, $ctl); //@line 7755
   HEAP32[$3 >> 2] = $ctl; //@line 7756
   $8 = HEAP32[$cdrv + 72 >> 2] | 0; //@line 7758
   if (($8 | 0) == 0) {
    $_0 = 0; //@line 7762
    break;
   }
   $_0 = FUNCTION_TABLE_iii[$8 & 63]($cdrv, $ctl) | 0; //@line 7767
  }
 } while (0);
 return $_0 | 0; //@line 7772
}
function _chr_set_params($cdrv, $bps, $bpc, $parity, $stop) {
 $cdrv = $cdrv | 0;
 $bps = $bps | 0;
 $bpc = $bpc | 0;
 $parity = $parity | 0;
 $stop = $stop | 0;
 var $3 = 0, $6 = 0, $17 = 0, $18 = 0, $19 = 0, $23 = 0, $par_0_i = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $36 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 7787
 if (($cdrv | 0) == 0) {
  $_0 = 1; //@line 7791
  STACKTOP = sp; //@line 7793
  return $_0 | 0; //@line 7794
 }
 $3 = $cdrv + 4 | 0; //@line 7796
 $6 = $cdrv + 8 | 0; //@line 7799
 do {
  if ((HEAP32[$3 >> 2] | 0) == ($bps | 0)) {
   if ((HEAP32[$6 >> 2] | 0) != ($bpc | 0)) {
    break;
   }
   if ((HEAP32[$cdrv + 12 >> 2] | 0) != ($parity | 0)) {
    break;
   }
   if ((HEAP32[$cdrv + 16 >> 2] | 0) == ($stop | 0)) {
    $_0 = 0; //@line 7821
   } else {
    break;
   }
   STACKTOP = sp; //@line 7826
   return $_0 | 0; //@line 7827
  }
 } while (0);
 HEAP32[$3 >> 2] = $bps; //@line 7830
 HEAP32[$6 >> 2] = $bpc; //@line 7831
 $17 = $cdrv + 12 | 0; //@line 7832
 HEAP32[$17 >> 2] = $parity; //@line 7833
 $18 = $cdrv + 16 | 0; //@line 7834
 HEAP32[$18 >> 2] = $stop; //@line 7835
 $19 = $cdrv + 52 | 0; //@line 7836
 if ((HEAP32[$19 >> 2] | 0) != 0) {
  _chr_log_flush($cdrv); //@line 7841
  $23 = HEAP32[$17 >> 2] | 0; //@line 7842
  if (($23 | 0) == 2) {
   $par_0_i = 58040; //@line 7845
  } else if (($23 | 0) == 1) {
   $par_0_i = 30888; //@line 7848
  } else if (($23 | 0) == 0) {
   $par_0_i = 31848; //@line 7850
  } else {
   $par_0_i = 57248; //@line 7853
  }
  $28 = HEAP32[$19 >> 2] | 0; //@line 7856
  $29 = HEAP32[$3 >> 2] | 0; //@line 7857
  $30 = HEAP32[$6 >> 2] | 0; //@line 7858
  $31 = HEAP32[$18 >> 2] | 0; //@line 7859
  _fprintf($28 | 0, 56024, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $29, HEAP32[tempInt + 8 >> 2] = $30, HEAP32[tempInt + 16 >> 2] = $par_0_i, HEAP32[tempInt + 24 >> 2] = $31, tempInt) | 0) | 0; //@line 7860
  $33 = HEAP32[$19 >> 2] | 0; //@line 7861
  _fflush($33 | 0) | 0; //@line 7862
 }
 $36 = HEAP32[$cdrv + 76 >> 2] | 0; //@line 7866
 if (($36 | 0) == 0) {
  $_0 = 1; //@line 7870
  STACKTOP = sp; //@line 7872
  return $_0 | 0; //@line 7873
 }
 $_0 = FUNCTION_TABLE_iiiiii[$36 & 7]($cdrv, $bps, $bpc, $parity, $stop) | 0; //@line 7877
 STACKTOP = sp; //@line 7879
 return $_0 | 0; //@line 7880
}
function _chr_open($name) {
 $name = $name | 0;
 var $1 = 0, $3 = 0, $i_018 = 0, $4 = 0, $_pr = 0, $d_016 = 0, $s_015 = 0, $9 = 0, $10 = 0, $11 = 0, $s_013 = 0, $14 = 0, $18 = 0, $21 = 0, $24 = 0, $28 = 0, $32 = 0, $34 = 0, $_0 = 0, label = 0;
 $1 = HEAP32[7262] | 0; //@line 7893
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 7897
  return $_0 | 0; //@line 7900
 } else {
  $i_018 = 0;
  $3 = $1;
 }
 while (1) {
  $4 = HEAP8[$3] | 0; //@line 7907
  L13650 : do {
   if ($4 << 24 >> 24 == 0) {
    $s_013 = $name; //@line 7912
    label = 10935; //@line 7913
   } else {
    $s_015 = $name;
    $d_016 = $3;
    $_pr = $4;
    while (1) {
     if ($_pr << 24 >> 24 != (HEAP8[$s_015] | 0)) {
      break;
     }
     $9 = $d_016 + 1 | 0; //@line 7925
     $10 = $s_015 + 1 | 0; //@line 7926
     $11 = HEAP8[$9] | 0; //@line 7927
     if ($11 << 24 >> 24 == 0) {
      $s_013 = $10; //@line 7931
      label = 10935; //@line 7932
      break L13650;
     } else {
      $s_015 = $10;
      $d_016 = $9;
      $_pr = $11;
     }
    }
    if ($_pr << 24 >> 24 == 0) {
     $s_013 = $s_015; //@line 7941
     label = 10935; //@line 7942
    }
   }
  } while (0);
  if ((label | 0) == 10935) {
   label = 0; //@line 7947
   $14 = HEAP8[$s_013] | 0; //@line 7949
   if (($14 << 24 >> 24 | 0) == 58 | ($14 << 24 >> 24 | 0) == 0) {
    break;
   }
  }
  $32 = $i_018 + 1 | 0; //@line 7954
  $34 = HEAP32[29048 + ($32 << 3) >> 2] | 0; //@line 7956
  if (($34 | 0) == 0) {
   $_0 = 0; //@line 7960
   label = 10944; //@line 7961
   break;
  } else {
   $i_018 = $32;
   $3 = $34;
  }
 }
 if ((label | 0) == 10944) {
  return $_0 | 0; //@line 7970
 }
 $18 = FUNCTION_TABLE_ii[HEAP32[29052 + ($i_018 << 3) >> 2] & 31]($name) | 0; //@line 7974
 if (($18 | 0) == 0) {
  $_0 = 0; //@line 7978
  return $_0 | 0; //@line 7981
 }
 $21 = _drv_get_option($name, 33728) | 0; //@line 7983
 if (($21 | 0) == 0) {
  $_0 = $18; //@line 7987
  return $_0 | 0; //@line 7990
 }
 $24 = $18 + 52 | 0; //@line 7992
 if ((HEAP32[$24 >> 2] | 0) != 0) {
  _chr_log_flush($18); //@line 7997
  $28 = HEAP32[$24 >> 2] | 0; //@line 7998
  _fclose($28 | 0) | 0; //@line 7999
 }
 HEAP32[$24 >> 2] = _fopen($21 | 0, 36728) | 0; //@line 8003
 _free($21); //@line 8004
 $_0 = $18; //@line 8006
 return $_0 | 0; //@line 8009
}
function _chr_mouse_open($name) {
 $name = $name | 0;
 var $1 = 0, $4 = 0, $5 = 0, $19 = 0, $32 = 0, $storemerge_i = 0, $45 = 0, $47 = 0, $56 = 0, $58 = 0, $64 = 0, $65 = 0, $_0 = 0;
 $1 = _malloc(388) | 0; //@line 8025
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 8029
  return $_0 | 0; //@line 8032
 }
 $4 = $1; //@line 8034
 $5 = $1; //@line 8035
 _chr_init($5, $1); //@line 8036
 HEAP32[$1 + 56 >> 2] = 258; //@line 8039
 HEAP32[$1 + 60 >> 2] = 22; //@line 8042
 HEAP32[$1 + 64 >> 2] = 102; //@line 8045
 HEAP32[$1 + 68 >> 2] = 38; //@line 8048
 HEAP32[$1 + 72 >> 2] = 40; //@line 8051
 HEAP32[$1 + 76 >> 2] = 4; //@line 8054
 $19 = $1 + 80 | 0; //@line 8056
 HEAP32[$19 >> 2] = 0; //@line 8057
 HEAP32[$1 + 84 >> 2] = 0; //@line 8060
 HEAP32[$1 + 88 >> 2] = 0; //@line 8063
 HEAP8[$1 + 348 | 0] = 0; //@line 8065
 HEAP8[$1 + 349 | 0] = 0; //@line 8067
 HEAP32[$1 + 352 >> 2] = 0; //@line 8070
 HEAP32[$1 + 356 >> 2] = 0; //@line 8073
 HEAP32[$1 + 360 >> 2] = 0; //@line 8076
 $32 = _drv_get_option($name, 54352) | 0; //@line 8077
 if (($32 | 0) != 0) {
  do {
   if ((_strcmp($32 | 0, 56760) | 0) == 0) {
    $storemerge_i = 0; //@line 8086
   } else {
    if ((_strcmp($32 | 0, 50264) | 0) == 0) {
     $storemerge_i = 1; //@line 8092
     break;
    }
    _free($32); //@line 8095
    _free($1); //@line 8096
    $_0 = 0; //@line 8098
    return $_0 | 0; //@line 8101
   }
  } while (0);
  HEAP32[$19 >> 2] = $storemerge_i; //@line 8105
  _free($32); //@line 8106
 }
 HEAP32[$1 + 364 >> 2] = _drv_get_option_sint($name, 46280, 1) | 0; //@line 8112
 $45 = _drv_get_option_sint($name, 42736, 1) | 0; //@line 8113
 $47 = $1 + 368 | 0; //@line 8115
 HEAP32[$47 >> 2] = $45; //@line 8116
 HEAP32[$1 + 372 >> 2] = 0; //@line 8119
 if (($45 | 0) == 0) {
  HEAP32[$47 >> 2] = 1; //@line 8123
 }
 HEAP32[$1 + 376 >> 2] = _drv_get_option_sint($name, 39640, 1) | 0; //@line 8129
 $56 = _drv_get_option_sint($name, 36704, 1) | 0; //@line 8130
 $58 = $1 + 380 | 0; //@line 8132
 HEAP32[$58 >> 2] = $56; //@line 8133
 HEAP32[$1 + 384 >> 2] = 0; //@line 8136
 if (($56 | 0) == 0) {
  HEAP32[$58 >> 2] = 1; //@line 8140
 }
 $64 = HEAP32[15682] | 0; //@line 8143
 $65 = $64 + 1 | 0; //@line 8144
 if ($65 >>> 0 >= 8) {
  $_0 = $5; //@line 8148
  return $_0 | 0; //@line 8151
 }
 HEAP32[15682] = $65; //@line 8153
 HEAP32[62736 + ($64 << 2) >> 2] = $4; //@line 8155
 $_0 = $5; //@line 8157
 return $_0 | 0; //@line 8160
}
function _chr_mouse_close($cdrv) {
 $cdrv = $cdrv | 0;
 var $2 = 0, $3 = 0, $4 = 0, $i_07 = 0, $n_06 = 0, $7 = 0, $n_1 = 0, $13 = 0, $n_0_lcssa = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 8171
 $3 = $2; //@line 8172
 $4 = HEAP32[15682] | 0; //@line 8173
 if (($4 | 0) == 0) {
  $n_0_lcssa = 0; //@line 8177
  HEAP32[15682] = $n_0_lcssa; //@line 8179
  _free($2); //@line 8180
  return;
 } else {
  $n_06 = 0;
  $i_07 = 0;
 }
 while (1) {
  $7 = HEAP32[62736 + ($i_07 << 2) >> 2] | 0; //@line 8190
  if (($7 | 0) == ($3 | 0)) {
   $n_1 = $n_06; //@line 8194
  } else {
   HEAP32[62736 + ($n_06 << 2) >> 2] = $7; //@line 8198
   $n_1 = $n_06 + 1 | 0; //@line 8200
  }
  $13 = $i_07 + 1 | 0; //@line 8203
  if ($13 >>> 0 < $4 >>> 0) {
   $n_06 = $n_1;
   $i_07 = $13;
  } else {
   $n_0_lcssa = $n_1; //@line 8209
   break;
  }
 }
 HEAP32[15682] = $n_0_lcssa; //@line 8214
 _free($2); //@line 8215
 return;
}
function _chr_mouse_read($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $2 = 0, $3 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $23 = 0, $24 = 0, $28 = 0, $cnt_ = 0, $31 = 0, $i_021 = 0, $37 = 0, $38 = 0, $_0 = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 8233
 $3 = $2; //@line 8234
 $5 = $2 + 84 | 0; //@line 8236
 $6 = HEAP32[$5 >> 2] | 0; //@line 8237
 $8 = $2 + 88 | 0; //@line 8239
 $9 = HEAP32[$8 >> 2] | 0; //@line 8240
 if (($6 | 0) == ($9 | 0)) {
  do {
   if ((HEAP32[$2 + 352 >> 2] | 0) == 0) {
    if ((HEAP32[$2 + 356 >> 2] | 0) == 0) {
     $_0 = 0; //@line 8257
    } else {
     break;
    }
    return $_0 | 0; //@line 8263
   }
  } while (0);
  _chr_mouse_add_packet($3); //@line 8266
  $24 = HEAP32[$5 >> 2] | 0;
  $23 = HEAP32[$8 >> 2] | 0;
 } else {
  $24 = $6;
  $23 = $9;
 }
 if (($24 | 0) == ($23 | 0)) {
  $_0 = 0; //@line 8279
  return $_0 | 0; //@line 8282
 }
 $28 = $24 - $23 & 255; //@line 8285
 $cnt_ = $28 >>> 0 > $cnt >>> 0 ? $cnt : $28; //@line 8287
 if (($cnt_ | 0) == 0) {
  $_0 = 0; //@line 8291
  return $_0 | 0; //@line 8294
 } else {
  $i_021 = 0;
  $31 = $23;
 }
 while (1) {
  HEAP8[$buf + $i_021 | 0] = HEAP8[$2 + ($31 + 92) | 0] | 0; //@line 8305
  $37 = (HEAP32[$8 >> 2] | 0) + 1 & 255; //@line 8308
  HEAP32[$8 >> 2] = $37; //@line 8309
  $38 = $i_021 + 1 | 0; //@line 8310
  if ($38 >>> 0 < $cnt_ >>> 0) {
   $i_021 = $38;
   $31 = $37;
  } else {
   $_0 = $cnt_; //@line 8316
   break;
  }
 }
 return $_0 | 0; //@line 8322
}
function _chr_null_read($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return 0; //@line 8333
}
function _chr_null_write($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return $cnt | 0; //@line 8344
}
function _chr_null_get_ctl($cdrv, $ctl) {
 $cdrv = $cdrv | 0;
 $ctl = $ctl | 0;
 HEAP32[$ctl >> 2] = 1792; //@line 8353
 return 0; //@line 8355
}
function _chr_null_set_ctl($cdrv, $ctl) {
 $cdrv = $cdrv | 0;
 $ctl = $ctl | 0;
 return 0; //@line 8365
}
function _chr_null_set_params($cdrv, $bps, $bpc, $parity, $stop) {
 $cdrv = $cdrv | 0;
 $bps = $bps | 0;
 $bpc = $bpc | 0;
 $parity = $parity | 0;
 $stop = $stop | 0;
 return 0; //@line 8378
}
function _chr_mouse_add_packet($drv) {
 $drv = $drv | 0;
 var $2 = 0, $drv_idx_i = 0, $drv_idx_val_i = 0, $9 = 0, $10 = 0, $tmp_0_i17_i = 0, $15 = 0, $16 = 0, $tmp_0_i_i = 0, $22 = 0, $39 = 0, $44 = 0, $drv_idx_i3 = 0, $drv_idx_val_i4 = 0, $57 = 0, $60 = 0, $69 = 0, $70 = 0, $71 = 0, $72 = 0, $tmp_0_i17_i8 = 0, $81 = 0, $82 = 0, $tmp_0_i_i11 = 0, $92 = 0, $93 = 0, $tmp_0_i17_1_i = 0, $102 = 0, $103 = 0, $tmp_0_i_1_i = 0;
 $2 = HEAP32[$drv + 80 >> 2] | 0; //@line 8403
 if (($2 | 0) == 1) {
  $drv_idx_i3 = $drv + 84 | 0; //@line 8405
  $drv_idx_val_i4 = HEAP32[$drv_idx_i3 >> 2] | 0; //@line 8406
  if ((256 - ($drv_idx_val_i4 - (HEAP32[$drv + 88 >> 2] | 0) & 255) | 0) >>> 0 < 5) {
   return;
  }
  $57 = HEAP32[$drv + 360 >> 2] | 0; //@line 8419
  $60 = $57 >>> 1; //@line 8422
  HEAP8[$drv + 92 + $drv_idx_val_i4 | 0] = (($60 & 1 | $57 << 2 & 4 | $60 & 2) ^ 135) & 255; //@line 8430
  $69 = (HEAP32[$drv_idx_i3 >> 2] | 0) + 1 & 255; //@line 8433
  HEAP32[$drv_idx_i3 >> 2] = $69; //@line 8434
  $70 = $drv + 352 | 0; //@line 8435
  $71 = $drv + 356 | 0; //@line 8436
  $72 = HEAP32[$70 >> 2] | 0; //@line 8437
  if (($72 | 0) < -127) {
   $tmp_0_i17_i8 = -127; //@line 8441
  } else {
   $tmp_0_i17_i8 = ($72 | 0) > 127 ? 127 : $72; //@line 8446
  }
  HEAP32[$70 >> 2] = $72 - $tmp_0_i17_i8; //@line 8450
  HEAP8[$drv + 92 + $69 | 0] = $tmp_0_i17_i8 & 255; //@line 8453
  $81 = (HEAP32[$drv_idx_i3 >> 2] | 0) + 1 & 255; //@line 8456
  HEAP32[$drv_idx_i3 >> 2] = $81; //@line 8457
  $82 = HEAP32[$71 >> 2] | 0; //@line 8458
  if (($82 | 0) < -127) {
   $tmp_0_i_i11 = -127; //@line 8462
  } else {
   $tmp_0_i_i11 = ($82 | 0) > 127 ? 127 : $82; //@line 8467
  }
  HEAP32[$71 >> 2] = $82 - $tmp_0_i_i11; //@line 8471
  HEAP8[$drv + 92 + $81 | 0] = -$tmp_0_i_i11 & 255; //@line 8475
  $92 = (HEAP32[$drv_idx_i3 >> 2] | 0) + 1 & 255; //@line 8478
  HEAP32[$drv_idx_i3 >> 2] = $92; //@line 8479
  $93 = HEAP32[$70 >> 2] | 0; //@line 8480
  if (($93 | 0) < -127) {
   $tmp_0_i17_1_i = -127; //@line 8484
  } else {
   $tmp_0_i17_1_i = ($93 | 0) > 127 ? 127 : $93; //@line 8489
  }
  HEAP32[$70 >> 2] = $93 - $tmp_0_i17_1_i; //@line 8493
  HEAP8[$drv + 92 + $92 | 0] = $tmp_0_i17_1_i & 255; //@line 8496
  $102 = (HEAP32[$drv_idx_i3 >> 2] | 0) + 1 & 255; //@line 8499
  HEAP32[$drv_idx_i3 >> 2] = $102; //@line 8500
  $103 = HEAP32[$71 >> 2] | 0; //@line 8501
  if (($103 | 0) < -127) {
   $tmp_0_i_1_i = -127; //@line 8505
  } else {
   $tmp_0_i_1_i = ($103 | 0) > 127 ? 127 : $103; //@line 8510
  }
  HEAP32[$71 >> 2] = $103 - $tmp_0_i_1_i; //@line 8514
  HEAP8[$drv + 92 + $102 | 0] = -$tmp_0_i_1_i & 255; //@line 8518
  HEAP32[$drv_idx_i3 >> 2] = (HEAP32[$drv_idx_i3 >> 2] | 0) + 1 & 255; //@line 8522
  return;
 } else if (($2 | 0) == 0) {
  $drv_idx_i = $drv + 84 | 0; //@line 8526
  $drv_idx_val_i = HEAP32[$drv_idx_i >> 2] | 0; //@line 8527
  if ((256 - ($drv_idx_val_i - (HEAP32[$drv + 88 >> 2] | 0) & 255) | 0) >>> 0 < 3) {
   return;
  }
  $9 = $drv + 352 | 0; //@line 8539
  $10 = HEAP32[$9 >> 2] | 0; //@line 8540
  if (($10 | 0) < -127) {
   $tmp_0_i17_i = -127; //@line 8544
  } else {
   $tmp_0_i17_i = ($10 | 0) > 127 ? 127 : $10; //@line 8549
  }
  HEAP32[$9 >> 2] = $10 - $tmp_0_i17_i; //@line 8553
  $15 = $drv + 356 | 0; //@line 8554
  $16 = HEAP32[$15 >> 2] | 0; //@line 8555
  if (($16 | 0) < -127) {
   $tmp_0_i_i = -127; //@line 8559
  } else {
   $tmp_0_i_i = ($16 | 0) > 127 ? 127 : $16; //@line 8564
  }
  HEAP32[$15 >> 2] = $16 - $tmp_0_i_i; //@line 8568
  $22 = HEAP32[$drv + 360 >> 2] | 0; //@line 8570
  HEAP8[$drv + 92 + $drv_idx_val_i | 0] = ($tmp_0_i17_i >>> 6 & 3 | $tmp_0_i_i >>> 4 & 12 | $22 << 3 & 16 | $22 << 5 & 32 | 64) & 255; //@line 8585
  $39 = (HEAP32[$drv_idx_i >> 2] | 0) + 1 & 255; //@line 8588
  HEAP32[$drv_idx_i >> 2] = $39; //@line 8589
  HEAP8[$drv + 92 + $39 | 0] = $tmp_0_i17_i & 63; //@line 8593
  $44 = (HEAP32[$drv_idx_i >> 2] | 0) + 1 & 255; //@line 8596
  HEAP32[$drv_idx_i >> 2] = $44; //@line 8597
  HEAP8[$drv + 92 + $44 | 0] = $tmp_0_i_i & 63; //@line 8601
  HEAP32[$drv_idx_i >> 2] = (HEAP32[$drv_idx_i >> 2] | 0) + 1 & 255; //@line 8605
  return;
 } else {
  return;
 }
}
function _chr_null_open($name) {
 $name = $name | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _malloc(80) | 0; //@line 8622
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 8626
  return $_0 | 0; //@line 8629
 }
 $4 = $1; //@line 8631
 _chr_init($4, $1); //@line 8632
 HEAP32[$1 + 56 >> 2] = 122; //@line 8635
 HEAP32[$1 + 60 >> 2] = 36; //@line 8638
 HEAP32[$1 + 64 >> 2] = 48; //@line 8641
 HEAP32[$1 + 68 >> 2] = 16; //@line 8644
 HEAP32[$1 + 72 >> 2] = 34; //@line 8647
 HEAP32[$1 + 76 >> 2] = 2; //@line 8650
 $_0 = $4; //@line 8652
 return $_0 | 0; //@line 8655
}
function _chr_null_close($cdrv) {
 $cdrv = $cdrv | 0;
 _free(HEAP32[$cdrv >> 2] | 0); //@line 8666
 return;
}
function _chr_posix_open($name) {
 $name = $name | 0;
 var $1 = 0, $4 = 0, $12 = 0, $14 = 0, $16 = 0, $18 = 0, $20 = 0, $21 = 0, $25 = 0, $_pr_i = 0, $27 = 0, $36 = 0, $40 = 0, $48 = 0, $51 = 0, $53 = 0, $62 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 8682
 $1 = _malloc(100) | 0; //@line 8683
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 8687
  STACKTOP = sp; //@line 8689
  return $_0 | 0; //@line 8690
 }
 $4 = $1; //@line 8692
 _chr_init($4, $1); //@line 8693
 HEAP32[$1 + 56 >> 2] = 38; //@line 8696
 HEAP32[$1 + 60 >> 2] = 56; //@line 8699
 HEAP32[$1 + 64 >> 2] = 64; //@line 8702
 $12 = $1 + 80 | 0; //@line 8704
 HEAP32[$12 >> 2] = 0; //@line 8705
 $14 = $1 + 84 | 0; //@line 8707
 HEAP32[$14 >> 2] = 0; //@line 8708
 $16 = $1 + 88 | 0; //@line 8710
 HEAP32[$16 >> 2] = 0; //@line 8711
 $18 = $1 + 92 | 0; //@line 8713
 HEAP32[$18 >> 2] = -1; //@line 8714
 $20 = $1 + 96 | 0; //@line 8716
 HEAP32[$20 >> 2] = -1; //@line 8717
 $21 = _drv_get_option($name, 54248) | 0; //@line 8718
 HEAP32[$12 >> 2] = $21; //@line 8719
 L13764 : do {
  if (($21 | 0) == 0) {
   HEAP32[$14 >> 2] = _drv_get_option($name, 56752) | 0; //@line 8725
   $25 = _drv_get_option($name, 50256) | 0; //@line 8726
   HEAP32[$16 >> 2] = $25; //@line 8727
   $_pr_i = HEAP32[$12 >> 2] | 0; //@line 8728
   if (($_pr_i | 0) != 0) {
    $27 = $_pr_i; //@line 8732
    label = 11021; //@line 8733
    break;
   }
   $40 = HEAP32[$14 >> 2] | 0; //@line 8736
   do {
    if (($40 | 0) == 0) {
     if (($25 | 0) != 0) {
      $53 = $25; //@line 8744
      break;
     }
     if ((_strncmp($name | 0, 39632, 6) | 0) != 0) {
      $_0 = $4; //@line 8751
      STACKTOP = sp; //@line 8753
      return $_0 | 0; //@line 8754
     }
     HEAP32[$18 >> 2] = 0; //@line 8756
     HEAP32[$20 >> 2] = 1; //@line 8757
     $_0 = $4; //@line 8759
     STACKTOP = sp; //@line 8761
     return $_0 | 0; //@line 8762
    } else {
     if ((_strcmp($40 | 0, 46272) | 0) == 0) {
      HEAP32[$18 >> 2] = 0; //@line 8768
      $51 = $25; //@line 8770
     } else {
      $48 = _open($40 | 0, 32768, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 0, tempInt) | 0) | 0; //@line 8772
      HEAP32[$18 >> 2] = $48; //@line 8773
      if (($48 | 0) < 0) {
       break L13764;
      }
      $51 = HEAP32[$16 >> 2] | 0; //@line 8781
     }
     if (($51 | 0) == 0) {
      $_0 = $4; //@line 8787
     } else {
      $53 = $51; //@line 8789
      break;
     }
     STACKTOP = sp; //@line 8793
     return $_0 | 0; //@line 8794
    }
   } while (0);
   if ((_strcmp($53 | 0, 46272) | 0) == 0) {
    HEAP32[$20 >> 2] = 1; //@line 8802
    $_0 = $4; //@line 8804
    STACKTOP = sp; //@line 8806
    return $_0 | 0; //@line 8807
   }
   if ((_strcmp($53 | 0, 42728) | 0) == 0) {
    HEAP32[$20 >> 2] = 2; //@line 8813
    $_0 = $4; //@line 8815
    STACKTOP = sp; //@line 8817
    return $_0 | 0; //@line 8818
   } else {
    $62 = _open($53 | 0, 34305, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 420, tempInt) | 0) | 0; //@line 8820
    HEAP32[$20 >> 2] = $62; //@line 8821
    if (($62 | 0) < 0) {
     break;
    } else {
     $_0 = $4; //@line 8827
    }
    STACKTOP = sp; //@line 8830
    return $_0 | 0; //@line 8831
   }
  } else {
   $27 = $21; //@line 8834
   label = 11021; //@line 8835
  }
 } while (0);
 do {
  if ((label | 0) == 11021) {
   if ((_strcmp($27 | 0, 46272) | 0) == 0) {
    HEAP32[$18 >> 2] = 0; //@line 8845
    HEAP32[$20 >> 2] = 1; //@line 8846
    $_0 = $4; //@line 8848
    STACKTOP = sp; //@line 8850
    return $_0 | 0; //@line 8851
   }
   if ((_strcmp($27 | 0, 42728) | 0) == 0) {
    HEAP32[$18 >> 2] = 0; //@line 8857
    HEAP32[$20 >> 2] = 2; //@line 8858
    $_0 = $4; //@line 8860
    STACKTOP = sp; //@line 8862
    return $_0 | 0; //@line 8863
   }
   $36 = _open($27 | 0, 34306, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = 420, tempInt) | 0) | 0; //@line 8865
   HEAP32[$18 >> 2] = $36; //@line 8866
   if (($36 | 0) < 0) {
    break;
   }
   HEAP32[$20 >> 2] = $36; //@line 8872
   $_0 = $4; //@line 8873
   STACKTOP = sp; //@line 8875
   return $_0 | 0; //@line 8876
  }
 } while (0);
 _chr_posix_close($4); //@line 8879
 $_0 = 0; //@line 8881
 STACKTOP = sp; //@line 8883
 return $_0 | 0; //@line 8884
}
function _chr_posix_close($cdrv) {
 $cdrv = $cdrv | 0;
 var $2 = 0, $4 = 0, $5 = 0, $12 = 0, $22 = 0, $28 = 0, $34 = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 8897
 $4 = $2 + 96 | 0; //@line 8899
 $5 = HEAP32[$4 >> 2] | 0; //@line 8900
 if (($5 | 0) > 2) {
  _close($5 | 0) | 0; //@line 8904
 }
 $12 = HEAP32[$2 + 92 >> 2] | 0; //@line 8909
 do {
  if (($12 | 0) > 2) {
   if (($12 | 0) == (HEAP32[$4 >> 2] | 0)) {
    break;
   }
   _close($12 | 0) | 0; //@line 8920
  }
 } while (0);
 $22 = HEAP32[$2 + 88 >> 2] | 0; //@line 8926
 if (($22 | 0) != 0) {
  _free($22); //@line 8930
 }
 $28 = HEAP32[$2 + 84 >> 2] | 0; //@line 8935
 if (($28 | 0) != 0) {
  _free($28); //@line 8939
 }
 $34 = HEAP32[$2 + 80 >> 2] | 0; //@line 8944
 if (($34 | 0) == 0) {
  _free($2); //@line 8948
  return;
 }
 _free($34); //@line 8952
 _free($2); //@line 8954
 return;
}
function _chr_posix_read($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $pfd_i = 0, $4 = 0, $5 = 0, $21 = 0, sp = 0;
 sp = STACKTOP; //@line 8968
 STACKTOP = STACKTOP + 8 | 0; //@line 8968
 $pfd_i = sp | 0; //@line 8969
 $4 = (HEAP32[$cdrv >> 2] | 0) + 92 | 0; //@line 8973
 $5 = HEAP32[$4 >> 2] | 0; //@line 8974
 if (($5 | 0) < 0) {
  STACKTOP = sp; //@line 8978
  return 0; //@line 8979
 }
 HEAP32[$pfd_i >> 2] = $5; //@line 8984
 HEAP16[$pfd_i + 4 >> 1] = 1; //@line 8986
 if ((_poll($pfd_i | 0, 1, 0) | 0) < 0) {
  STACKTOP = sp; //@line 8991
  return 0; //@line 8992
 }
 if ((HEAP16[$pfd_i + 6 >> 1] & 3) == 0) {
  STACKTOP = sp; //@line 9000
  return 0; //@line 9001
 } else {
  $21 = _read(HEAP32[$4 >> 2] | 0, $buf | 0, (($cnt | 0) < 0 ? 2147483647 : $cnt) | 0) | 0; //@line 9006
  STACKTOP = sp; //@line 9009
  return (($21 | 0) > 0 ? $21 : 0) | 0; //@line 9010
 }
 return 0;
}
function _chr_posix_write($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $pfd_i = 0, $4 = 0, $5 = 0, $21 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 9023
 STACKTOP = STACKTOP + 8 | 0; //@line 9023
 $pfd_i = sp | 0; //@line 9024
 $4 = (HEAP32[$cdrv >> 2] | 0) + 96 | 0; //@line 9028
 $5 = HEAP32[$4 >> 2] | 0; //@line 9029
 if (($5 | 0) < 0) {
  $_0 = $cnt; //@line 9033
  STACKTOP = sp; //@line 9035
  return $_0 | 0; //@line 9036
 }
 HEAP32[$pfd_i >> 2] = $5; //@line 9041
 HEAP16[$pfd_i + 4 >> 1] = 2; //@line 9043
 if ((_poll($pfd_i | 0, 1, 0) | 0) < 0) {
  $_0 = 0; //@line 9048
  STACKTOP = sp; //@line 9050
  return $_0 | 0; //@line 9051
 }
 if ((HEAP16[$pfd_i + 6 >> 1] & 3) == 0) {
  $_0 = 0; //@line 9059
  STACKTOP = sp; //@line 9061
  return $_0 | 0; //@line 9062
 } else {
  $21 = _write(HEAP32[$4 >> 2] | 0, $buf | 0, (($cnt | 0) < 0 ? 2147483647 : $cnt) | 0) | 0; //@line 9067
  STACKTOP = sp; //@line 9070
  return (($21 | 0) > 0 ? $21 : 0) | 0; //@line 9071
 }
 return 0;
}
function _chr_pty_open($name) {
 $name = $name | 0;
 var $tio_i_i = 0, $1 = 0, $4 = 0, $12 = 0, $15 = 0, $16 = 0, $18 = 0, $27 = 0, $28 = 0, $34 = 0, $35 = 0, $37 = 0, $38 = 0, $41 = 0, $43 = 0, $48 = 0, $51 = 0, $58 = 0, $65 = 0, $66 = 0, $67 = 0, $71 = 0, $73 = 0, $74 = 0, $82 = 0, $88 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 9089
 STACKTOP = STACKTOP + 48 | 0; //@line 9089
 $tio_i_i = sp | 0; //@line 9090
 $1 = _malloc(92) | 0; //@line 9091
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 9095
  STACKTOP = sp; //@line 9097
  return $_0 | 0; //@line 9098
 }
 $4 = $1; //@line 9100
 _chr_init($4, $1); //@line 9101
 HEAP32[$1 + 56 >> 2] = 370; //@line 9104
 HEAP32[$1 + 60 >> 2] = 88; //@line 9107
 HEAP32[$1 + 64 >> 2] = 72; //@line 9110
 $12 = $1 + 84 | 0; //@line 9112
 HEAP32[$12 >> 2] = 0; //@line 9113
 $15 = $1 + 88 | 0; //@line 9116
 HEAP32[$15 >> 2] = _drv_get_option($name, 54208) | 0; //@line 9117
 $16 = _posix_openpt(32770) | 0; //@line 9118
 $18 = $1 + 80 | 0; //@line 9120
 HEAP32[$18 >> 2] = $16; //@line 9121
 do {
  if (($16 | 0) >= 0) {
   if ((_grantpt($16 | 0) | 0) != 0) {
    break;
   }
   if ((_unlockpt($16 | 0) | 0) != 0) {
    break;
   }
   $27 = _ptsname($16 | 0) | 0; //@line 9138
   $28 = $27; //@line 9139
   if (($27 | 0) == 0) {
    break;
   }
   if ((_strlen($28 | 0) | 0) >>> 0 > 255) {
    break;
   }
   $34 = _strdup($28 | 0) | 0; //@line 9151
   HEAP32[$12 >> 2] = $34; //@line 9152
   $35 = HEAP32[_stderr >> 2] | 0; //@line 9153
   _fprintf($35 | 0, 50240, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $34, tempInt) | 0) | 0; //@line 9154
   $37 = HEAP32[$18 >> 2] | 0; //@line 9155
   $38 = _fcntl($37 | 0, 1, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0) | 0; //@line 9156
   if (($38 | 0) != -1) {
    $41 = $38 | 16384; //@line 9160
    _fcntl($37 | 0, 4, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $41, tempInt) | 0) | 0; //@line 9161
   }
   $43 = HEAP32[$18 >> 2] | 0; //@line 9164
   do {
    if ((_tcgetattr($43 | 0, $tio_i_i | 0) | 0) == 0) {
     $48 = $tio_i_i | 0; //@line 9171
     HEAP32[$48 >> 2] = HEAP32[$48 >> 2] & -449; //@line 9174
     $51 = $tio_i_i + 12 | 0; //@line 9175
     HEAP32[$51 >> 2] = HEAP32[$51 >> 2] & -11; //@line 9178
     if ((_tcsetattr($43 | 0, 0, $tio_i_i | 0) | 0) != 0) {
      break;
     }
     _tcflush($43 | 0, 3) | 0; //@line 9185
    }
   } while (0);
   $58 = HEAP32[$15 >> 2] | 0; //@line 9189
   if (($58 | 0) == 0) {
    $_0 = $4; //@line 9193
    STACKTOP = sp; //@line 9195
    return $_0 | 0; //@line 9196
   }
   if ((_symlink(HEAP32[$12 >> 2] | 0, $58 | 0) | 0) == 0) {
    $_0 = $4; //@line 9203
    STACKTOP = sp; //@line 9205
    return $_0 | 0; //@line 9206
   }
   $65 = HEAP32[_stderr >> 2] | 0; //@line 9208
   $66 = HEAP32[$12 >> 2] | 0; //@line 9209
   $67 = HEAP32[$15 >> 2] | 0; //@line 9210
   _fprintf($65 | 0, 56704, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $66, HEAP32[tempInt + 8 >> 2] = $67, tempInt) | 0) | 0; //@line 9211
   $_0 = $4; //@line 9213
   STACKTOP = sp; //@line 9215
   return $_0 | 0; //@line 9216
  }
 } while (0);
 $71 = HEAP32[$1 >> 2] | 0; //@line 9220
 $73 = $71 + 88 | 0; //@line 9222
 $74 = HEAP32[$73 >> 2] | 0; //@line 9223
 if (($74 | 0) != 0) {
  _unlink($74 | 0) | 0; //@line 9227
  _free(HEAP32[$73 >> 2] | 0); //@line 9229
 }
 $82 = HEAP32[$71 + 84 >> 2] | 0; //@line 9234
 if (($82 | 0) != 0) {
  _free($82); //@line 9238
 }
 $88 = HEAP32[$71 + 80 >> 2] | 0; //@line 9243
 if (($88 | 0) > -1) {
  _close($88 | 0) | 0; //@line 9247
 }
 _free($71); //@line 9250
 $_0 = 0; //@line 9252
 STACKTOP = sp; //@line 9254
 return $_0 | 0; //@line 9255
}
function _chr_pty_close($cdrv) {
 $cdrv = $cdrv | 0;
 var $2 = 0, $4 = 0, $5 = 0, $13 = 0, $19 = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 9267
 $4 = $2 + 88 | 0; //@line 9269
 $5 = HEAP32[$4 >> 2] | 0; //@line 9270
 if (($5 | 0) != 0) {
  _unlink($5 | 0) | 0; //@line 9274
  _free(HEAP32[$4 >> 2] | 0); //@line 9276
 }
 $13 = HEAP32[$2 + 84 >> 2] | 0; //@line 9281
 if (($13 | 0) != 0) {
  _free($13); //@line 9285
 }
 $19 = HEAP32[$2 + 80 >> 2] | 0; //@line 9290
 if (($19 | 0) <= -1) {
  _free($2); //@line 9294
  return;
 }
 _close($19 | 0) | 0; //@line 9298
 _free($2); //@line 9300
 return;
}
function _chr_pty_read($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $5 = 0, $9 = 0;
 $5 = HEAP32[(HEAP32[$cdrv >> 2] | 0) + 80 >> 2] | 0; //@line 9318
 if (($5 | 0) < 0) {
  return 0; //@line 9323
 } else {
  $9 = _read($5 | 0, $buf | 0, (($cnt | 0) < 0 ? 2147483647 : $cnt) | 0) | 0; //@line 9327
  return (($9 | 0) > 0 ? $9 : 0) | 0; //@line 9331
 }
 return 0;
}
function _chr_pty_write($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $5 = 0, $9 = 0;
 $5 = HEAP32[(HEAP32[$cdrv >> 2] | 0) + 80 >> 2] | 0; //@line 9348
 if (($5 | 0) < 0) {
  return $cnt | 0; //@line 9353
 } else {
  $9 = _write($5 | 0, $buf | 0, (($cnt | 0) < 0 ? 2147483647 : $cnt) | 0) | 0; //@line 9357
  return (($9 | 0) > 0 ? $9 : 0) | 0; //@line 9361
 }
 return 0;
}
function _chr_stdio_read($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return 0; //@line 9373
}
function _chr_stdio_open($name) {
 $name = $name | 0;
 var $1 = 0, $4 = 0, $12 = 0, $15 = 0, $19 = 0, $27 = 0, $31 = 0, $34 = 0, $40 = 0, $_0 = 0;
 $1 = _malloc(92) | 0; //@line 9387
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 9391
  return $_0 | 0; //@line 9394
 }
 $4 = $1; //@line 9396
 _chr_init($4, $1); //@line 9397
 HEAP32[$1 + 56 >> 2] = 412; //@line 9400
 HEAP32[$1 + 60 >> 2] = 8; //@line 9403
 HEAP32[$1 + 64 >> 2] = 90; //@line 9406
 $12 = $1 + 88 | 0; //@line 9408
 HEAP32[$12 >> 2] = 0; //@line 9409
 $15 = $1 + 80 | 0; //@line 9412
 HEAP32[$15 >> 2] = _drv_get_option($name, 54184) | 0; //@line 9413
 HEAP32[$1 + 84 >> 2] = _drv_get_option_bool($name, 56696, 1) | 0; //@line 9417
 $19 = HEAP32[$15 >> 2] | 0; //@line 9418
 if (($19 | 0) == 0) {
  $_0 = $4; //@line 9422
  return $_0 | 0; //@line 9425
 }
 if ((_strcmp($19 | 0, 50224) | 0) == 0) {
  HEAP32[$12 >> 2] = HEAP32[_stdout >> 2]; //@line 9432
  $_0 = $4; //@line 9434
  return $_0 | 0; //@line 9437
 }
 $27 = _fopen($19 | 0, 46264) | 0; //@line 9439
 HEAP32[$12 >> 2] = $27; //@line 9440
 if (($27 | 0) != 0) {
  $_0 = $4; //@line 9444
  return $_0 | 0; //@line 9447
 }
 $31 = HEAP32[$1 >> 2] | 0; //@line 9450
 $34 = HEAP32[$31 + 80 >> 2] | 0; //@line 9453
 if (($34 | 0) != 0) {
  _free($34); //@line 9457
 }
 $40 = HEAP32[$31 + 88 >> 2] | 0; //@line 9462
 if (!(($40 | 0) == 0 | ($40 | 0) == (HEAP32[_stdin >> 2] | 0) | ($40 | 0) == (HEAP32[_stdout >> 2] | 0) | ($40 | 0) == (HEAP32[_stderr >> 2] | 0))) {
  _fclose($40 | 0) | 0; //@line 9475
 }
 _free($31); //@line 9478
 $_0 = 0; //@line 9480
 return $_0 | 0; //@line 9483
}
function _chr_stdio_close($cdrv) {
 $cdrv = $cdrv | 0;
 var $2 = 0, $5 = 0, $11 = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 9495
 $5 = HEAP32[$2 + 80 >> 2] | 0; //@line 9498
 if (($5 | 0) != 0) {
  _free($5); //@line 9502
 }
 $11 = HEAP32[$2 + 88 >> 2] | 0; //@line 9507
 if (($11 | 0) == 0 | ($11 | 0) == (HEAP32[_stdin >> 2] | 0) | ($11 | 0) == (HEAP32[_stdout >> 2] | 0) | ($11 | 0) == (HEAP32[_stderr >> 2] | 0)) {
  _free($2); //@line 9520
  return;
 }
 _fclose($11 | 0) | 0; //@line 9524
 _free($2); //@line 9526
 return;
}
function _chr_stdio_write($cdrv, $buf, $cnt) {
 $cdrv = $cdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $2 = 0, $4 = 0, $5 = 0, $8 = 0, $_0 = 0;
 $2 = HEAP32[$cdrv >> 2] | 0; //@line 9541
 $4 = $2 + 88 | 0; //@line 9543
 $5 = HEAP32[$4 >> 2] | 0; //@line 9544
 if (($5 | 0) == 0) {
  $_0 = $cnt; //@line 9548
  return $_0 | 0; //@line 9551
 }
 $8 = _fwrite($buf | 0, 1, $cnt | 0, $5 | 0) | 0; //@line 9553
 if ((HEAP32[$2 + 84 >> 2] | 0) == 0) {
  $_0 = $8; //@line 9560
  return $_0 | 0; //@line 9563
 }
 _fflush(HEAP32[$4 >> 2] | 0) | 0; //@line 9566
 $_0 = $8; //@line 9568
 return $_0 | 0; //@line 9571
}
function _pri_decode_gcr_trk($trk, $h) {
 $trk = $trk | 0;
 $h = $h | 0;
 var $bit_i56_i_i = 0, $bit_i46_i_i = 0, $bit_i36_i_i = 0, $bit_i26_i_i = 0, $bit_i16_i_i = 0, $bit_i_i_i = 0, $buf_i_i = 0, $bit_i84_i = 0, $bit_i74_i = 0, $bit_i64_i = 0, $bit_i54_i = 0, $bit_i44_i = 0, $bit_i34_i = 0, $bit_i_i = 0, $buf_i = 0, $bit_i = 0, $1 = 0, $4 = 0, $8 = 0, $9 = 0, $15 = 0, $16 = 0, $24 = 0, $26 = 0, $28 = 0, $29 = 0, $buf_sroa_2_047 = 0, $buf_sroa_1_046 = 0, $32 = 0, $cnt_09_i = 0, $val_08_i = 0, $36 = 0, $cnt_0_lcssa_i = 0, $44 = 0, $45 = 0, $46 = 0, $54 = 0, $cnt_09_i_i = 0, $val_08_i_i = 0, $58 = 0, $cnt_0_lcssa_i_i = 0, $68 = 0, $69 = 0, $71 = 0, $cnt_09_i35_i = 0, $val_08_i36_i = 0, $75 = 0, $cnt_0_lcssa_i42_i = 0, $85 = 0, $86 = 0, $88 = 0, $cnt_09_i45_i = 0, $val_08_i46_i = 0, $92 = 0, $cnt_0_lcssa_i52_i = 0, $102 = 0, $103 = 0, $105 = 0, $cnt_09_i55_i = 0, $val_08_i56_i = 0, $109 = 0, $cnt_0_lcssa_i62_i = 0, $119 = 0, $121 = 0, $cnt_09_i65_i = 0, $val_08_i66_i = 0, $125 = 0, $cnt_0_lcssa_i72_i = 0, $135 = 0, $139 = 0, $141 = 0, $142 = 0, $152 = 0, $153 = 0, $i_0112_i = 0, $155 = 0, $cnt_09_i75_i = 0, $val_08_i76_i = 0, $159 = 0, $167 = 0, $cnt_0_lcssa_i82_i = 0, $168 = 0, $178 = 0, $cnt_09_i85_i = 0, $val_08_i86_i = 0, $182 = 0, $cnt_0_lcssa_i92_i = 0, $192 = 0, $196 = 0, $high_080_i_i = 0, $i_079_i_i = 0, $204 = 0, $cnt_09_i_i_i = 0, $val_08_i_i_i = 0, $208 = 0, $cnt_0_lcssa_i_i_i = 0, $high_1_i_i = 0, $222 = 0, $cnt_09_i17_i_i = 0, $val_08_i18_i_i = 0, $226 = 0, $cnt_0_lcssa_i24_i_i = 0, $242 = 0, $246 = 0, $cnt_09_i27_i_i = 0, $val_08_i28_i_i = 0, $250 = 0, $cnt_0_lcssa_i34_i_i = 0, $260 = 0, $261 = 0, $263 = 0, $cnt_09_i37_i_i = 0, $val_08_i38_i_i = 0, $267 = 0, $cnt_0_lcssa_i44_i_i = 0, $280 = 0, $282 = 0, $cnt_09_i47_i_i = 0, $val_08_i48_i_i = 0, $286 = 0, $cnt_0_lcssa_i54_i_i = 0, $300 = 0, $302 = 0, $cnt_09_i57_i_i = 0, $val_08_i58_i_i = 0, $306 = 0, $cnt_0_lcssa_i64_i_i = 0, $319 = 0, $chk_sroa_0_037_i_i_i = 0, $chk_sroa_1_036_i_i_i = 0, $chk_sroa_2_035_i_i_i = 0, $i_034_i_i_i = 0, $chk_sroa_0_1_i_i_i = 0, $val_0_i_i_i = 0, $336 = 0, $339 = 0, $346 = 0, $350 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 9636
 STACKTOP = STACKTOP + 1168 | 0; //@line 9636
 $bit_i56_i_i = sp | 0; //@line 9637
 $bit_i46_i_i = sp + 8 | 0; //@line 9638
 $bit_i36_i_i = sp + 16 | 0; //@line 9639
 $bit_i26_i_i = sp + 24 | 0; //@line 9640
 $bit_i16_i_i = sp + 32 | 0; //@line 9641
 $bit_i_i_i = sp + 40 | 0; //@line 9642
 $buf_i_i = sp + 48 | 0; //@line 9643
 $bit_i84_i = sp + 576 | 0; //@line 9644
 $bit_i74_i = sp + 584 | 0; //@line 9645
 $bit_i64_i = sp + 592 | 0; //@line 9646
 $bit_i54_i = sp + 600 | 0; //@line 9647
 $bit_i44_i = sp + 608 | 0; //@line 9648
 $bit_i34_i = sp + 616 | 0; //@line 9649
 $bit_i_i = sp + 624 | 0; //@line 9650
 $buf_i = sp + 632 | 0; //@line 9651
 $bit_i = sp + 1160 | 0; //@line 9652
 $1 = _psi_trk_new($h) | 0; //@line 9653
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 9657
  STACKTOP = sp; //@line 9659
  return $_0 | 0; //@line 9660
 }
 _pri_trk_set_pos($trk, 0); //@line 9662
 $4 = $trk + 16 | 0; //@line 9663
 if ((HEAP8[$4] | 0) != 0) {
  $_0 = $1; //@line 9668
  STACKTOP = sp; //@line 9670
  return $_0 | 0; //@line 9671
 }
 $8 = $trk + 12 | 0; //@line 9674
 $9 = $buf_i | 0; //@line 9675
 $15 = $buf_i + 1 | 0; //@line 9681
 $16 = $buf_i + 2 | 0; //@line 9682
 $24 = $buf_i_i + 524 | 0; //@line 9690
 $26 = $buf_i_i + 525 | 0; //@line 9692
 $28 = $buf_i_i + 526 | 0; //@line 9694
 $29 = $buf_i + 12 | 0; //@line 9695
 $buf_sroa_1_046 = 0;
 $buf_sroa_2_047 = 0;
 while (1) {
  _pri_trk_get_bits($trk, $bit_i, 8) | 0; //@line 9701
  $32 = HEAP32[$bit_i >> 2] | 0; //@line 9702
  if (($32 & 128 | 0) == 0) {
   $val_08_i = $32;
   $cnt_09_i = 8;
   do {
    _pri_trk_get_bits($trk, $bit_i, 1) | 0; //@line 9711
    $36 = $val_08_i << 1; //@line 9712
    $val_08_i = HEAP32[$bit_i >> 2] & 1 | $36; //@line 9715
    $cnt_09_i = $cnt_09_i + 1 | 0; //@line 9716
   } while (($36 & 128 | 0) == 0 & $cnt_09_i >>> 0 < 64);
   $cnt_0_lcssa_i = $cnt_09_i >>> 0 > 63 ? 0 : $val_08_i; //@line 9731
  } else {
   $cnt_0_lcssa_i = $32; //@line 9733
  }
  $44 = $cnt_0_lcssa_i & 255; //@line 9736
  $45 = HEAP32[$8 >> 2] | 0; //@line 9737
  $46 = HEAP8[$4] | 0; //@line 9738
  do {
   if ($buf_sroa_1_046 << 24 >> 24 == -43 & $buf_sroa_2_047 << 24 >> 24 == -86) {
    if (($cnt_0_lcssa_i & 255 | 0) != 150) {
     break;
    }
    _pri_trk_get_bits($trk, $bit_i_i, 8) | 0; //@line 9751
    $54 = HEAP32[$bit_i_i >> 2] | 0; //@line 9752
    if (($54 & 128 | 0) == 0) {
     $val_08_i_i = $54;
     $cnt_09_i_i = 8;
     do {
      _pri_trk_get_bits($trk, $bit_i_i, 1) | 0; //@line 9761
      $58 = $val_08_i_i << 1; //@line 9762
      $val_08_i_i = HEAP32[$bit_i_i >> 2] & 1 | $58; //@line 9765
      $cnt_09_i_i = $cnt_09_i_i + 1 | 0; //@line 9766
     } while (($58 & 128 | 0) == 0 & $cnt_09_i_i >>> 0 < 64);
     $cnt_0_lcssa_i_i = $cnt_09_i_i >>> 0 > 63 ? 0 : $val_08_i_i; //@line 9781
    } else {
     $cnt_0_lcssa_i_i = $54; //@line 9783
    }
    $68 = HEAP8[16216 + ($cnt_0_lcssa_i_i & 255) | 0] | 0; //@line 9788
    $69 = $68 & 255; //@line 9789
    _pri_trk_get_bits($trk, $bit_i34_i, 8) | 0; //@line 9790
    $71 = HEAP32[$bit_i34_i >> 2] | 0; //@line 9791
    if (($71 & 128 | 0) == 0) {
     $val_08_i36_i = $71;
     $cnt_09_i35_i = 8;
     do {
      _pri_trk_get_bits($trk, $bit_i34_i, 1) | 0; //@line 9800
      $75 = $val_08_i36_i << 1; //@line 9801
      $val_08_i36_i = HEAP32[$bit_i34_i >> 2] & 1 | $75; //@line 9804
      $cnt_09_i35_i = $cnt_09_i35_i + 1 | 0; //@line 9805
     } while (($75 & 128 | 0) == 0 & $cnt_09_i35_i >>> 0 < 64);
     $cnt_0_lcssa_i42_i = $cnt_09_i35_i >>> 0 > 63 ? 0 : $val_08_i36_i; //@line 9820
    } else {
     $cnt_0_lcssa_i42_i = $71; //@line 9822
    }
    $85 = HEAP8[16216 + ($cnt_0_lcssa_i42_i & 255) | 0] | 0; //@line 9827
    $86 = $85 & 255; //@line 9828
    _pri_trk_get_bits($trk, $bit_i44_i, 8) | 0; //@line 9829
    $88 = HEAP32[$bit_i44_i >> 2] | 0; //@line 9830
    if (($88 & 128 | 0) == 0) {
     $val_08_i46_i = $88;
     $cnt_09_i45_i = 8;
     do {
      _pri_trk_get_bits($trk, $bit_i44_i, 1) | 0; //@line 9839
      $92 = $val_08_i46_i << 1; //@line 9840
      $val_08_i46_i = HEAP32[$bit_i44_i >> 2] & 1 | $92; //@line 9843
      $cnt_09_i45_i = $cnt_09_i45_i + 1 | 0; //@line 9844
     } while (($92 & 128 | 0) == 0 & $cnt_09_i45_i >>> 0 < 64);
     $cnt_0_lcssa_i52_i = $cnt_09_i45_i >>> 0 > 63 ? 0 : $val_08_i46_i; //@line 9859
    } else {
     $cnt_0_lcssa_i52_i = $88; //@line 9861
    }
    $102 = HEAP8[16216 + ($cnt_0_lcssa_i52_i & 255) | 0] | 0; //@line 9866
    $103 = $102 & 255; //@line 9867
    _pri_trk_get_bits($trk, $bit_i54_i, 8) | 0; //@line 9868
    $105 = HEAP32[$bit_i54_i >> 2] | 0; //@line 9869
    if (($105 & 128 | 0) == 0) {
     $val_08_i56_i = $105;
     $cnt_09_i55_i = 8;
     do {
      _pri_trk_get_bits($trk, $bit_i54_i, 1) | 0; //@line 9878
      $109 = $val_08_i56_i << 1; //@line 9879
      $val_08_i56_i = HEAP32[$bit_i54_i >> 2] & 1 | $109; //@line 9882
      $cnt_09_i55_i = $cnt_09_i55_i + 1 | 0; //@line 9883
     } while (($109 & 128 | 0) == 0 & $cnt_09_i55_i >>> 0 < 64);
     $cnt_0_lcssa_i62_i = $cnt_09_i55_i >>> 0 > 63 ? 0 : $val_08_i56_i; //@line 9898
    } else {
     $cnt_0_lcssa_i62_i = $105; //@line 9900
    }
    $119 = HEAP8[16216 + ($cnt_0_lcssa_i62_i & 255) | 0] | 0; //@line 9905
    _pri_trk_get_bits($trk, $bit_i64_i, 8) | 0; //@line 9906
    $121 = HEAP32[$bit_i64_i >> 2] | 0; //@line 9907
    if (($121 & 128 | 0) == 0) {
     $val_08_i66_i = $121;
     $cnt_09_i65_i = 8;
     do {
      _pri_trk_get_bits($trk, $bit_i64_i, 1) | 0; //@line 9916
      $125 = $val_08_i66_i << 1; //@line 9917
      $val_08_i66_i = HEAP32[$bit_i64_i >> 2] & 1 | $125; //@line 9920
      $cnt_09_i65_i = $cnt_09_i65_i + 1 | 0; //@line 9921
     } while (($125 & 128 | 0) == 0 & $cnt_09_i65_i >>> 0 < 64);
     $cnt_0_lcssa_i72_i = $cnt_09_i65_i >>> 0 > 63 ? 0 : $val_08_i66_i; //@line 9936
    } else {
     $cnt_0_lcssa_i72_i = $121; //@line 9938
    }
    $135 = HEAP8[16216 + ($cnt_0_lcssa_i72_i & 255) | 0] | 0; //@line 9943
    $139 = $103 << 6 & 1984 | $69 & 63; //@line 9947
    $141 = $103 >>> 5 & 3; //@line 9949
    $142 = _psi_sct_new($139, $141, $86, 512) | 0; //@line 9950
    if (($142 | 0) != 0) {
     _psi_sct_set_encoding($142, 3); //@line 9957
     _psi_sct_set_flags($142, 8, 1); //@line 9958
     _psi_sct_set_gcr_format($142, $119); //@line 9959
     if ($135 << 24 >> 24 != ($85 ^ $68 ^ $102 ^ $119) << 24 >> 24) {
      _psi_sct_set_flags($142, 1, 1); //@line 9963
     }
     HEAP8[$9] = 0; //@line 9966
     HEAP8[$15] = 0; //@line 9967
     HEAP8[$16] = 0; //@line 9968
     $i_0112_i = 0;
     $153 = 0;
     $152 = 0;
     while (1) {
      HEAP8[$9] = $152; //@line 9975
      HEAP8[$15] = $153; //@line 9976
      _pri_trk_get_bits($trk, $bit_i74_i, 8) | 0; //@line 9977
      $155 = HEAP32[$bit_i74_i >> 2] | 0; //@line 9978
      if (($155 & 128 | 0) == 0) {
       $val_08_i76_i = $155;
       $cnt_09_i75_i = 8;
       do {
        _pri_trk_get_bits($trk, $bit_i74_i, 1) | 0; //@line 9987
        $159 = $val_08_i76_i << 1; //@line 9988
        $val_08_i76_i = HEAP32[$bit_i74_i >> 2] & 1 | $159; //@line 9991
        $cnt_09_i75_i = $cnt_09_i75_i + 1 | 0; //@line 9992
       } while (($159 & 128 | 0) == 0 & $cnt_09_i75_i >>> 0 < 64);
       $cnt_0_lcssa_i82_i = $cnt_09_i75_i >>> 0 > 63 ? 0 : $val_08_i76_i;
       $167 = HEAP8[$9] | 0;
      } else {
       $cnt_0_lcssa_i82_i = $155;
       $167 = $152;
      }
      $168 = $cnt_0_lcssa_i82_i & 255; //@line 10014
      HEAP8[$16] = $168; //@line 10015
      if ($167 << 24 >> 24 == -43) {
       if ((HEAP8[$15] | 0) == -86) {
        label = 11189; //@line 10023
        break;
       }
      }
      $196 = $i_0112_i + 1 | 0; //@line 10027
      if ($196 >>> 0 >= 64) {
       break;
      }
      $i_0112_i = $196;
      $153 = $168;
      $152 = HEAP8[$15] | 0;
     }
     do {
      if ((label | 0) == 11189) {
       label = 0; //@line 10039
       if (($cnt_0_lcssa_i82_i & 255 | 0) != 173) {
        break;
       }
       _pri_trk_get_bits($trk, $bit_i84_i, 8) | 0; //@line 10046
       $178 = HEAP32[$bit_i84_i >> 2] | 0; //@line 10047
       if (($178 & 128 | 0) == 0) {
        $val_08_i86_i = $178;
        $cnt_09_i85_i = 8;
        do {
         _pri_trk_get_bits($trk, $bit_i84_i, 1) | 0; //@line 10056
         $182 = $val_08_i86_i << 1; //@line 10057
         $val_08_i86_i = HEAP32[$bit_i84_i >> 2] & 1 | $182; //@line 10060
         $cnt_09_i85_i = $cnt_09_i85_i + 1 | 0; //@line 10061
        } while (($182 & 128 | 0) == 0 & $cnt_09_i85_i >>> 0 < 64);
        $cnt_0_lcssa_i92_i = $cnt_09_i85_i >>> 0 > 63 ? 0 : $val_08_i86_i; //@line 10076
       } else {
        $cnt_0_lcssa_i92_i = $178; //@line 10078
       }
       $192 = HEAP8[16216 + ($cnt_0_lcssa_i92_i & 255) | 0] | 0; //@line 10083
       HEAP8[$16] = $192; //@line 10084
       if ($192 << 24 >> 24 != $85 << 24 >> 24 | $i_0112_i >>> 0 > 63) {
        break;
       }
       _psi_sct_set_flags($142, 8, 0); //@line 10092
       $i_079_i_i = 0;
       $high_080_i_i = 0;
       while (1) {
        if ((($i_079_i_i >>> 0) % 3 | 0 | 0) == 0) {
         _pri_trk_get_bits($trk, $bit_i_i_i, 8) | 0; //@line 10102
         $204 = HEAP32[$bit_i_i_i >> 2] | 0; //@line 10103
         if (($204 & 128 | 0) == 0) {
          $val_08_i_i_i = $204;
          $cnt_09_i_i_i = 8;
          do {
           _pri_trk_get_bits($trk, $bit_i_i_i, 1) | 0; //@line 10112
           $208 = $val_08_i_i_i << 1; //@line 10113
           $val_08_i_i_i = HEAP32[$bit_i_i_i >> 2] & 1 | $208; //@line 10116
           $cnt_09_i_i_i = $cnt_09_i_i_i + 1 | 0; //@line 10117
          } while (($208 & 128 | 0) == 0 & $cnt_09_i_i_i >>> 0 < 64);
          $cnt_0_lcssa_i_i_i = $cnt_09_i_i_i >>> 0 > 63 ? 0 : $val_08_i_i_i; //@line 10132
         } else {
          $cnt_0_lcssa_i_i_i = $204; //@line 10134
         }
         $high_1_i_i = HEAP8[16216 + ($cnt_0_lcssa_i_i_i & 255) | 0] << 2; //@line 10142
        } else {
         $high_1_i_i = $high_080_i_i; //@line 10144
        }
        _pri_trk_get_bits($trk, $bit_i16_i_i, 8) | 0; //@line 10147
        $222 = HEAP32[$bit_i16_i_i >> 2] | 0; //@line 10148
        if (($222 & 128 | 0) == 0) {
         $val_08_i18_i_i = $222;
         $cnt_09_i17_i_i = 8;
         do {
          _pri_trk_get_bits($trk, $bit_i16_i_i, 1) | 0; //@line 10157
          $226 = $val_08_i18_i_i << 1; //@line 10158
          $val_08_i18_i_i = HEAP32[$bit_i16_i_i >> 2] & 1 | $226; //@line 10161
          $cnt_09_i17_i_i = $cnt_09_i17_i_i + 1 | 0; //@line 10162
         } while (($226 & 128 | 0) == 0 & $cnt_09_i17_i_i >>> 0 < 64);
         $cnt_0_lcssa_i24_i_i = $cnt_09_i17_i_i >>> 0 > 63 ? 0 : $val_08_i18_i_i; //@line 10177
        } else {
         $cnt_0_lcssa_i24_i_i = $222; //@line 10179
        }
        HEAP8[$buf_i_i + $i_079_i_i | 0] = HEAP8[16216 + ($cnt_0_lcssa_i24_i_i & 255) | 0] & 63 | $high_1_i_i & -64; //@line 10190
        $242 = $i_079_i_i + 1 | 0; //@line 10191
        if ($242 >>> 0 < 524) {
         $i_079_i_i = $242;
         $high_080_i_i = $high_1_i_i << 2;
        } else {
         break;
        }
       }
       _pri_trk_get_bits($trk, $bit_i26_i_i, 8) | 0; //@line 10200
       $246 = HEAP32[$bit_i26_i_i >> 2] | 0; //@line 10201
       if (($246 & 128 | 0) == 0) {
        $val_08_i28_i_i = $246;
        $cnt_09_i27_i_i = 8;
        do {
         _pri_trk_get_bits($trk, $bit_i26_i_i, 1) | 0; //@line 10210
         $250 = $val_08_i28_i_i << 1; //@line 10211
         $val_08_i28_i_i = HEAP32[$bit_i26_i_i >> 2] & 1 | $250; //@line 10214
         $cnt_09_i27_i_i = $cnt_09_i27_i_i + 1 | 0; //@line 10215
        } while (($250 & 128 | 0) == 0 & $cnt_09_i27_i_i >>> 0 < 64);
        $cnt_0_lcssa_i34_i_i = $cnt_09_i27_i_i >>> 0 > 63 ? 0 : $val_08_i28_i_i; //@line 10230
       } else {
        $cnt_0_lcssa_i34_i_i = $246; //@line 10232
       }
       $260 = HEAP8[16216 + ($cnt_0_lcssa_i34_i_i & 255) | 0] | 0; //@line 10237
       $261 = $260 << 2; //@line 10238
       _pri_trk_get_bits($trk, $bit_i36_i_i, 8) | 0; //@line 10239
       $263 = HEAP32[$bit_i36_i_i >> 2] | 0; //@line 10240
       if (($263 & 128 | 0) == 0) {
        $val_08_i38_i_i = $263;
        $cnt_09_i37_i_i = 8;
        do {
         _pri_trk_get_bits($trk, $bit_i36_i_i, 1) | 0; //@line 10249
         $267 = $val_08_i38_i_i << 1; //@line 10250
         $val_08_i38_i_i = HEAP32[$bit_i36_i_i >> 2] & 1 | $267; //@line 10253
         $cnt_09_i37_i_i = $cnt_09_i37_i_i + 1 | 0; //@line 10254
        } while (($267 & 128 | 0) == 0 & $cnt_09_i37_i_i >>> 0 < 64);
        $cnt_0_lcssa_i44_i_i = $cnt_09_i37_i_i >>> 0 > 63 ? 0 : $val_08_i38_i_i; //@line 10269
       } else {
        $cnt_0_lcssa_i44_i_i = $263; //@line 10271
       }
       $280 = HEAP8[16216 + ($cnt_0_lcssa_i44_i_i & 255) | 0] & 63 | $261 & -64; //@line 10279
       HEAP8[$24] = $280; //@line 10280
       _pri_trk_get_bits($trk, $bit_i46_i_i, 8) | 0; //@line 10281
       $282 = HEAP32[$bit_i46_i_i >> 2] | 0; //@line 10282
       if (($282 & 128 | 0) == 0) {
        $val_08_i48_i_i = $282;
        $cnt_09_i47_i_i = 8;
        do {
         _pri_trk_get_bits($trk, $bit_i46_i_i, 1) | 0; //@line 10291
         $286 = $val_08_i48_i_i << 1; //@line 10292
         $val_08_i48_i_i = HEAP32[$bit_i46_i_i >> 2] & 1 | $286; //@line 10295
         $cnt_09_i47_i_i = $cnt_09_i47_i_i + 1 | 0; //@line 10296
        } while (($286 & 128 | 0) == 0 & $cnt_09_i47_i_i >>> 0 < 64);
        $cnt_0_lcssa_i54_i_i = $cnt_09_i47_i_i >>> 0 > 63 ? 0 : $val_08_i48_i_i; //@line 10311
       } else {
        $cnt_0_lcssa_i54_i_i = $282; //@line 10313
       }
       $300 = HEAP8[16216 + ($cnt_0_lcssa_i54_i_i & 255) | 0] & 63 | $260 << 4 & -64; //@line 10322
       HEAP8[$26] = $300; //@line 10323
       _pri_trk_get_bits($trk, $bit_i56_i_i, 8) | 0; //@line 10324
       $302 = HEAP32[$bit_i56_i_i >> 2] | 0; //@line 10325
       if (($302 & 128 | 0) == 0) {
        $val_08_i58_i_i = $302;
        $cnt_09_i57_i_i = 8;
        do {
         _pri_trk_get_bits($trk, $bit_i56_i_i, 1) | 0; //@line 10334
         $306 = $val_08_i58_i_i << 1; //@line 10335
         $val_08_i58_i_i = HEAP32[$bit_i56_i_i >> 2] & 1 | $306; //@line 10338
         $cnt_09_i57_i_i = $cnt_09_i57_i_i + 1 | 0; //@line 10339
        } while (($306 & 128 | 0) == 0 & $cnt_09_i57_i_i >>> 0 < 64);
        $cnt_0_lcssa_i64_i_i = $cnt_09_i57_i_i >>> 0 > 63 ? 0 : $val_08_i58_i_i; //@line 10354
       } else {
        $cnt_0_lcssa_i64_i_i = $302; //@line 10356
       }
       $319 = HEAP8[16216 + ($cnt_0_lcssa_i64_i_i & 255) | 0] & 63 | $260 << 6; //@line 10364
       HEAP8[$28] = $319; //@line 10365
       $i_034_i_i_i = 0;
       $chk_sroa_2_035_i_i_i = 0;
       $chk_sroa_1_036_i_i_i = 0;
       $chk_sroa_0_037_i_i_i = 0;
       while (1) {
        if ((($i_034_i_i_i >>> 0) % 3 | 0 | 0) == 0) {
         $chk_sroa_0_1_i_i_i = $chk_sroa_0_037_i_i_i << 1 & 510 | $chk_sroa_0_037_i_i_i >>> 7 & 1; //@line 10382
        } else {
         $chk_sroa_0_1_i_i_i = $chk_sroa_0_037_i_i_i; //@line 10384
        }
        $val_0_i_i_i = HEAPU8[$buf_i_i + $i_034_i_i_i | 0] ^ $chk_sroa_0_1_i_i_i; //@line 10390
        $336 = ($chk_sroa_0_1_i_i_i >>> 8 & 1) + $chk_sroa_2_035_i_i_i + ($val_0_i_i_i & 255) | 0; //@line 10395
        HEAP8[$buf_i + $i_034_i_i_i | 0] = $val_0_i_i_i & 255; //@line 10399
        $339 = $i_034_i_i_i + 1 | 0; //@line 10400
        if ($339 >>> 0 < 524) {
         $i_034_i_i_i = $339;
         $chk_sroa_2_035_i_i_i = $chk_sroa_1_036_i_i_i;
         $chk_sroa_1_036_i_i_i = $chk_sroa_0_1_i_i_i & 255;
         $chk_sroa_0_037_i_i_i = $336;
        } else {
         break;
        }
       }
       if ($280 << 24 >> 24 == ($chk_sroa_0_1_i_i_i & 255) << 24 >> 24 & $300 << 24 >> 24 == ($336 & 255) << 24 >> 24) {
        if (($319 & 255 | 0) != ($chk_sroa_1_036_i_i_i | 0)) {
         label = 11224; //@line 10420
        }
       } else {
        label = 11224; //@line 10423
       }
       if ((label | 0) == 11224) {
        label = 0; //@line 10426
        $346 = HEAP32[_stderr >> 2] | 0; //@line 10427
        _fprintf($346 | 0, 54136, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $139, HEAP32[tempInt + 8 >> 2] = $141, HEAP32[tempInt + 16 >> 2] = $86, tempInt) | 0) | 0; //@line 10428
        _psi_sct_set_flags($142, 2, 1); //@line 10429
       }
       $350 = HEAP32[$142 + 24 >> 2] | 0; //@line 10433
       _memcpy($350 | 0, $29 | 0, 512) | 0; //@line 10434
       _psi_sct_set_tags($142, $9, 12) | 0; //@line 10435
      }
     } while (0);
     _psi_trk_add_sector($1, $142) | 0; //@line 10439
    }
    HEAP32[$8 >> 2] = $45; //@line 10442
    HEAP8[$4] = $46; //@line 10443
   }
  } while (0);
  if ($46 << 24 >> 24 == 0) {
   $buf_sroa_1_046 = $buf_sroa_2_047;
   $buf_sroa_2_047 = $44;
  } else {
   $_0 = $1; //@line 10452
   break;
  }
 }
 STACKTOP = sp; //@line 10457
 return $_0 | 0; //@line 10458
}
function _pri_get_uint16_be($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (HEAPU8[$buf + $idx | 0] | 0) << 8 | (HEAPU8[$buf + ($idx + 1) | 0] | 0) | 0; //@line 10479
}
function _pri_get_uint16_le($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (HEAPU8[$buf + ($idx + 1) | 0] | 0) << 8 | (HEAPU8[$buf + $idx | 0] | 0) | 0; //@line 10500
}
function _pri_get_uint32_be($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (((HEAPU8[$buf + $idx | 0] | 0) << 8 | (HEAPU8[$buf + ($idx + 1) | 0] | 0)) << 8 | (HEAPU8[$buf + ($idx + 2) | 0] | 0)) << 8 | (HEAPU8[$buf + ($idx + 3) | 0] | 0) | 0; //@line 10534
}
function _pri_set_uint32_be($buf, $idx, $val) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 $val = $val | 0;
 HEAP8[$buf + $idx | 0] = $val >>> 24 & 255; //@line 10549
 HEAP8[$buf + ($idx + 1) | 0] = $val >>> 16 & 255; //@line 10554
 HEAP8[$buf + ($idx + 2) | 0] = $val >>> 8 & 255; //@line 10559
 HEAP8[$buf + ($idx + 3) | 0] = $val & 255; //@line 10563
 return;
}
function _pri_trk_set_clock($trk, $clock) {
 $trk = $trk | 0;
 $clock = $clock | 0;
 HEAP32[$trk >> 2] = $clock; //@line 10576
 return;
}
function _pri_trk_set_pos($trk, $pos) {
 $trk = $trk | 0;
 $pos = $pos | 0;
 var $2 = 0;
 $2 = HEAP32[$trk + 4 >> 2] | 0; //@line 10589
 if (($2 | 0) == 0) {
  return;
 }
 HEAP32[$trk + 12 >> 2] = ($pos >>> 0) % ($2 >>> 0) | 0; //@line 10598
 HEAP8[$trk + 16 | 0] = 0; //@line 10600
 return;
}
function _pri_decode_gcr($img) {
 $img = $img | 0;
 var $1 = 0, $3 = 0, $4 = 0, $6 = 0, $7 = 0, $c_023 = 0, $10 = 0, $12 = 0, $15 = 0, $h_020 = 0, $19 = 0, $dtrk_0 = 0, $30 = 0, $_pre_phi = 0, $42 = 0, $43 = 0, $_0 = 0, label = 0;
 $1 = _psi_img_new() | 0; //@line 10617
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 10621
  return $_0 | 0; //@line 10624
 }
 $3 = $img | 0; //@line 10626
 $4 = HEAP32[$3 >> 2] | 0; //@line 10627
 if (($4 | 0) == 0) {
  $_0 = $1; //@line 10631
  return $_0 | 0; //@line 10634
 }
 $6 = $img + 4 | 0; //@line 10636
 $c_023 = 0;
 $7 = $4;
 L14070 : while (1) {
  $10 = HEAP32[(HEAP32[$6 >> 2] | 0) + ($c_023 << 2) >> 2] | 0; //@line 10644
  do {
   if (($10 | 0) == 0) {
    $42 = $7; //@line 10649
   } else {
    $12 = $10 | 0; //@line 10651
    if ((HEAP32[$12 >> 2] | 0) == 0) {
     $42 = $7; //@line 10656
     break;
    }
    $15 = $10 + 4 | 0; //@line 10659
    $h_020 = 0; //@line 10661
    while (1) {
     $19 = HEAP32[(HEAP32[$15 >> 2] | 0) + ($h_020 << 2) >> 2] | 0; //@line 10666
     if (($19 | 0) == 0) {
      $dtrk_0 = _psi_trk_new($h_020) | 0; //@line 10672
     } else {
      $dtrk_0 = _pri_decode_gcr_trk($19, $h_020) | 0; //@line 10675
     }
     do {
      if ((HEAP16[$dtrk_0 + 2 >> 1] | 0) == 0) {
       $30 = $h_020 + 1 | 0; //@line 10684
       if (($30 | 0) != (HEAP32[$12 >> 2] | 0)) {
        label = 11255; //@line 10689
        break;
       }
       _psi_trk_del($dtrk_0); //@line 10692
       $_pre_phi = $30; //@line 10694
      } else {
       label = 11255; //@line 10696
      }
     } while (0);
     if ((label | 0) == 11255) {
      label = 0; //@line 10700
      if (($dtrk_0 | 0) == 0) {
       break L14070;
      }
      _psi_img_add_track($1, $dtrk_0, $c_023) | 0; //@line 10706
      $_pre_phi = $h_020 + 1 | 0; //@line 10709
     }
     if ($_pre_phi >>> 0 < (HEAP32[$12 >> 2] | 0) >>> 0) {
      $h_020 = $_pre_phi; //@line 10716
     } else {
      break;
     }
    }
    $42 = HEAP32[$3 >> 2] | 0; //@line 10723
   }
  } while (0);
  $43 = $c_023 + 1 | 0; //@line 10727
  if ($43 >>> 0 < $42 >>> 0) {
   $c_023 = $43;
   $7 = $42;
  } else {
   $_0 = $1; //@line 10733
   label = 11264; //@line 10734
   break;
  }
 }
 if ((label | 0) == 11264) {
  return $_0 | 0; //@line 10741
 }
 _psi_img_del($1); //@line 10743
 $_0 = 0; //@line 10745
 return $_0 | 0; //@line 10748
}
function _pri_encode_gcr_trk($dtrk, $strk, $fmt) {
 $dtrk = $dtrk | 0;
 $strk = $strk | 0;
 $fmt = $fmt | 0;
 var $buf_i = 0, $buf = 0, $1 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $scevgep62_i = 0, $scevgep_i = 0, $i_023 = 0, $i_122 = 0, $19 = 0, $21 = 0, $24 = 0, $26 = 0, $29 = 0, $30 = 0, $33 = 0, $34 = 0, $36 = 0, $38 = 0, $39 = 0, $i_059_i = 0, $fmt_ = 0, $49 = 0, $59 = 0, $chk_sroa_0_037_us_i_i = 0, $chk_sroa_1_036_us_i_i = 0, $chk_sroa_2_035_us_i_i = 0, $i_034_us_i_i = 0, $chk_sroa_0_1_us_i_i = 0, $102 = 0, $106 = 0, $110 = 0, $124 = 0, $125 = 0, $p_056_i = 0, $i_255_i = 0, $126 = 0, $156 = 0, $157 = 0, $163 = 0, $168 = 0, $223 = 0, $225 = 0, $cnt_08_i = 0, $230 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 10788
 STACKTOP = STACKTOP + 1056 | 0; //@line 10788
 $buf_i = sp | 0; //@line 10789
 $buf = sp + 528 | 0; //@line 10790
 _pri_trk_set_pos($dtrk, 0); //@line 10791
 $i_023 = 0; //@line 10793
 do {
  _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10796
  $i_023 = $i_023 + 1 | 0; //@line 10797
 } while ($i_023 >>> 0 < 32);
 $1 = $strk + 2 | 0; //@line 10806
 if ((HEAP16[$1 >> 1] | 0) != 0) {
  $4 = $strk + 4 | 0; //@line 10811
  $5 = $buf | 0; //@line 10812
  $6 = $buf + 12 | 0; //@line 10813
  $7 = $buf_i | 0; //@line 10814
  $8 = $buf_i + 524 | 0; //@line 10815
  $9 = $buf_i + 525 | 0; //@line 10816
  $10 = $buf_i + 526 | 0; //@line 10817
  $11 = $buf_i + 1 | 0; //@line 10818
  $scevgep62_i = $buf_i + 522 | 0; //@line 10819
  $scevgep_i = $buf_i + 523 | 0; //@line 10820
  $i_122 = 0; //@line 10822
  do {
   $19 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($i_122 << 2) >> 2] | 0; //@line 10827
   $21 = HEAP16[$19 + 10 >> 1] | 0; //@line 10829
   $24 = HEAP32[$19 + 24 >> 2] | 0; //@line 10832
   if (($21 & 65535) < 512) {
    $26 = $21 & 65535; //@line 10835
    _memcpy($6 | 0, $24 | 0, $26) | 0; //@line 10836
   } else {
    _memcpy($6 | 0, $24 | 0, 512) | 0; //@line 10839
   }
   $29 = _psi_sct_get_gcr_format($19) | 0; //@line 10841
   $30 = ($29 | 0) == 0; //@line 10842
   _psi_sct_get_tags($19, $5, 12) | 0; //@line 10843
   $33 = HEAP16[$19 + 4 >> 1] | 0; //@line 10845
   $34 = $33 & 65535; //@line 10846
   $36 = HEAP16[$19 + 6 >> 1] | 0; //@line 10848
   $38 = HEAP16[$19 + 8 >> 1] | 0; //@line 10850
   $39 = $34 >>> 6; //@line 10851
   $i_059_i = 0; //@line 10853
   do {
    _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10856
    $i_059_i = $i_059_i + 1 | 0; //@line 10857
   } while ($i_059_i >>> 0 < 38);
   $fmt_ = $30 ? $fmt : $29; //@line 10866
   $49 = ($36 & 65535) << 5 | $39 & 31; //@line 10871
   _pri_trk_set_bits($dtrk, 14002838, 24) | 0; //@line 10872
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($34 & 63) | 0] | 0, 8) | 0; //@line 10877
   $59 = HEAPU8[16152 + ($38 & 63) | 0] | 0; //@line 10881
   _pri_trk_set_bits($dtrk, $59, 8) | 0; //@line 10882
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($49 & 63) | 0] | 0, 8) | 0; //@line 10887
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($fmt_ & 63) | 0] | 0, 8) | 0; //@line 10892
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + (($49 ^ $fmt_ ^ ($38 ^ $33) & 65535) & 63) | 0] | 0, 8) | 0; //@line 10901
   _pri_trk_set_bits($dtrk, 57002, 16) | 0; //@line 10902
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10903
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10904
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10905
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10906
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10907
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10908
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10909
   _pri_trk_set_bits($dtrk, 255, 10) | 0; //@line 10910
   _pri_trk_set_bits($dtrk, 14002861, 24) | 0; //@line 10911
   _pri_trk_set_bits($dtrk, $59, 8) | 0; //@line 10912
   $i_034_us_i_i = 0;
   $chk_sroa_2_035_us_i_i = 0;
   $chk_sroa_1_036_us_i_i = 0;
   $chk_sroa_0_037_us_i_i = 0;
   while (1) {
    if ((($i_034_us_i_i >>> 0) % 3 | 0 | 0) == 0) {
     $chk_sroa_0_1_us_i_i = $chk_sroa_0_037_us_i_i << 1 & 510 | $chk_sroa_0_037_us_i_i >>> 7 & 1; //@line 10929
    } else {
     $chk_sroa_0_1_us_i_i = $chk_sroa_0_037_us_i_i; //@line 10931
    }
    $102 = HEAPU8[$buf + $i_034_us_i_i | 0] | 0; //@line 10936
    $106 = ($chk_sroa_0_1_us_i_i >>> 8 & 1) + $chk_sroa_2_035_us_i_i + $102 | 0; //@line 10940
    HEAP8[$buf_i + $i_034_us_i_i | 0] = ($102 ^ $chk_sroa_0_1_us_i_i) & 255; //@line 10945
    $110 = $i_034_us_i_i + 1 | 0; //@line 10946
    if ($110 >>> 0 < 524) {
     $i_034_us_i_i = $110;
     $chk_sroa_2_035_us_i_i = $chk_sroa_1_036_us_i_i;
     $chk_sroa_1_036_us_i_i = $chk_sroa_0_1_us_i_i & 255;
     $chk_sroa_0_037_us_i_i = $106;
    } else {
     break;
    }
   }
   HEAP8[$8] = $chk_sroa_0_1_us_i_i & 255; //@line 10957
   HEAP8[$9] = $106 & 255; //@line 10958
   HEAP8[$10] = $chk_sroa_1_036_us_i_i & 255; //@line 10960
   $i_255_i = 0;
   $p_056_i = $7;
   $125 = $11;
   $124 = (HEAPU8[$11] | 0) >>> 4 & 12 | (HEAPU8[$7] | 0) >>> 2 & 48;
   while (1) {
    $126 = $p_056_i + 2 | 0; //@line 10977
    _pri_trk_set_bits($dtrk, HEAPU8[16152 + ((HEAPU8[$126] | 0) >>> 6 | $124) | 0] | 0, 8) | 0; //@line 10985
    _pri_trk_set_bits($dtrk, HEAPU8[16152 + (HEAP8[$p_056_i] & 63) | 0] | 0, 8) | 0; //@line 10992
    _pri_trk_set_bits($dtrk, HEAPU8[16152 + (HEAP8[$125] & 63) | 0] | 0, 8) | 0; //@line 10999
    _pri_trk_set_bits($dtrk, HEAPU8[16152 + (HEAP8[$126] & 63) | 0] | 0, 8) | 0; //@line 11006
    $156 = $p_056_i + 3 | 0; //@line 11007
    $157 = $i_255_i + 3 | 0; //@line 11008
    $163 = $p_056_i + 4 | 0; //@line 11014
    $168 = (HEAPU8[$163] | 0) >>> 4 & 12 | (HEAPU8[$156] | 0) >>> 2 & 48; //@line 11019
    if ($157 >>> 0 < 522) {
     $i_255_i = $157;
     $p_056_i = $156;
     $125 = $163;
     $124 = $168;
    } else {
     break;
    }
   }
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + $168 | 0] | 0, 8) | 0; //@line 11030
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + (HEAP8[$scevgep62_i] & 63) | 0] | 0, 8) | 0; //@line 11037
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + (HEAP8[$scevgep_i] & 63) | 0] | 0, 8) | 0; //@line 11044
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($chk_sroa_0_1_us_i_i >>> 2 & 48 | $chk_sroa_1_036_us_i_i >>> 6 | $106 >>> 4 & 12) | 0] | 0, 8) | 0; //@line 11055
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($chk_sroa_0_1_us_i_i & 63) | 0] | 0, 8) | 0; //@line 11060
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($106 & 63) | 0] | 0, 8) | 0; //@line 11065
   _pri_trk_set_bits($dtrk, HEAPU8[16152 + ($chk_sroa_1_036_us_i_i & 63) | 0] | 0, 8) | 0; //@line 11070
   _pri_trk_set_bits($dtrk, 57002, 16) | 0; //@line 11071
   $i_122 = $i_122 + 1 | 0; //@line 11072
  } while ($i_122 >>> 0 < (HEAPU16[$1 >> 1] | 0) >>> 0);
 }
 if ((HEAP8[$dtrk + 16 | 0] | 0) != 0) {
  $_0 = 1; //@line 11089
  STACKTOP = sp; //@line 11091
  return $_0 | 0; //@line 11092
 }
 $223 = HEAP32[$dtrk + 4 >> 2] | 0; //@line 11095
 $225 = HEAP32[$dtrk + 12 >> 2] | 0; //@line 11097
 if (($223 | 0) == ($225 | 0)) {
  $_0 = 0; //@line 11101
  STACKTOP = sp; //@line 11103
  return $_0 | 0; //@line 11104
 }
 $cnt_08_i = $223 - $225 | 0; //@line 11108
 while (1) {
  $230 = $cnt_08_i >>> 0 < 10 ? $cnt_08_i : 10; //@line 11112
  _pri_trk_set_bits($dtrk, 255 >>> ((10 - $230 | 0) >>> 0), $230) | 0; //@line 11115
  if (($cnt_08_i | 0) == ($230 | 0)) {
   $_0 = 0; //@line 11120
   break;
  } else {
   $cnt_08_i = $cnt_08_i - $230 | 0; //@line 11123
  }
 }
 STACKTOP = sp; //@line 11127
 return $_0 | 0; //@line 11128
}
function _pri_encode_gcr_img($dimg, $simg) {
 $dimg = $dimg | 0;
 $simg = $simg | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $c_0_i = 0, $_0_i = 0, $c_018 = 0, $18 = 0, $_0_i16 = 0, $24 = 0, $25 = 0, $h_0 = 0, $33 = 0, $34 = 0, $44 = 0, $_0 = 0, label = 0;
 $1 = $simg + 4 | 0; //@line 11143
 $2 = $simg | 0; //@line 11144
 $3 = HEAP16[$2 >> 1] | 0; //@line 11145
 $4 = $3 & 65535; //@line 11146
 $c_0_i = 0; //@line 11148
 while (1) {
  if ($c_0_i >>> 0 >= $4 >>> 0) {
   $_0_i = 2; //@line 11154
   break;
  }
  if ((HEAPU16[(HEAP32[(HEAP32[$1 >> 2] | 0) + ($c_0_i << 2) >> 2] | 0) + 2 >> 1] | 0) > 1) {
   $_0_i = 34; //@line 11166
   break;
  } else {
   $c_0_i = $c_0_i + 1 | 0; //@line 11169
  }
 }
 if ($3 << 16 >> 16 == 0) {
  $_0 = 0; //@line 11176
  return $_0 | 0; //@line 11179
 } else {
  $c_018 = 0; //@line 11181
 }
 L14135 : while (1) {
  $18 = HEAP32[(HEAP32[$1 >> 2] | 0) + ($c_018 << 2) >> 2] | 0; //@line 11187
  if ($c_018 >>> 0 < 80) {
   $_0_i16 = HEAP32[16128 + ($c_018 >>> 4 << 2) >> 2] | 0; //@line 11195
  } else {
   $_0_i16 = 0; //@line 11197
  }
  $24 = $18 + 2 | 0; //@line 11200
  $25 = $18 + 4 | 0; //@line 11201
  $h_0 = 0; //@line 11203
  while (1) {
   if ($h_0 >>> 0 >= (HEAPU16[$24 >> 1] | 0) >>> 0) {
    break;
   }
   $33 = HEAP32[(HEAP32[$25 >> 2] | 0) + ($h_0 << 2) >> 2] | 0; //@line 11215
   $34 = _pri_img_get_track($dimg, $c_018, $h_0, 1) | 0; //@line 11216
   if (($34 | 0) == 0) {
    $_0 = 1; //@line 11220
    label = 11307; //@line 11221
    break L14135;
   }
   if ((_pri_trk_set_size($34, $_0_i16) | 0) != 0) {
    $_0 = 1; //@line 11228
    label = 11303; //@line 11229
    break L14135;
   }
   _pri_trk_set_clock($34, 5e5); //@line 11232
   if ((_pri_encode_gcr_trk($34, $33, $_0_i) | 0) == 0) {
    $h_0 = $h_0 + 1 | 0; //@line 11238
   } else {
    $_0 = 1; //@line 11240
    label = 11306; //@line 11241
    break L14135;
   }
  }
  $44 = $c_018 + 1 | 0; //@line 11245
  if ($44 >>> 0 < (HEAPU16[$2 >> 1] | 0) >>> 0) {
   $c_018 = $44; //@line 11251
  } else {
   $_0 = 0; //@line 11253
   label = 11304; //@line 11254
   break;
  }
 }
 if ((label | 0) == 11306) {
  return $_0 | 0; //@line 11261
 } else if ((label | 0) == 11304) {
  return $_0 | 0; //@line 11266
 } else if ((label | 0) == 11303) {
  return $_0 | 0; //@line 11271
 } else if ((label | 0) == 11307) {
  return $_0 | 0; //@line 11276
 }
 return 0;
}
function _pri_encode_gcr($img) {
 $img = $img | 0;
 var $1 = 0, $_0 = 0;
 $1 = _pri_img_new() | 0; //@line 11286
 do {
  if (($1 | 0) == 0) {
   $_0 = 0; //@line 11291
  } else {
   if ((_pri_encode_gcr_img($1, $img) | 0) == 0) {
    $_0 = $1; //@line 11297
    break;
   }
   _pri_img_del($1); //@line 11300
   $_0 = 0; //@line 11302
  }
 } while (0);
 return $_0 | 0; //@line 11307
}
function _pri_read($fp, $buf, $cnt) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return (_fread($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 11322
}
function _pri_read_ofs($fp, $ofs, $buf, $cnt) {
 $fp = $fp | 0;
 $ofs = $ofs | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $_0 = 0;
 if ((_fseek($fp | 0, $ofs | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 11338
  return $_0 | 0; //@line 11341
 }
 $_0 = (_fread($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 11347
 return $_0 | 0; //@line 11350
}
function _pri_write($fp, $buf, $cnt) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return (_fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 11365
}
function _pri_img_load($fname, $type) {
 $fname = $fname | 0;
 $type = $type | 0;
 var $i_0_i = 0, $ext_0_i = 0, $2 = 0, $3 = 0, $ext_1_i = 0, $_0_i = 0, $16 = 0, $img_0_i = 0, $_0 = 0;
 do {
  if (($type | 0) == 0) {
   $ext_0_i = 62872;
   $i_0_i = 0;
   while (1) {
    $2 = $fname + $i_0_i | 0; //@line 11385
    $3 = HEAP8[$2] | 0; //@line 11386
    if (($3 << 24 >> 24 | 0) == 0) {
     break;
    } else if (($3 << 24 >> 24 | 0) == 46) {
     $ext_1_i = $2; //@line 11391
    } else {
     $ext_1_i = $ext_0_i; //@line 11393
    }
    $ext_0_i = $ext_1_i;
    $i_0_i = $i_0_i + 1 | 0;
   }
   if ((_strcasecmp($ext_0_i | 0, 46240) | 0) == 0) {
    $_0_i = 1; //@line 11404
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 42720) | 0) == 0) {
    $_0_i = 2; //@line 11411
    break;
   }
   $_0_i = (_strcasecmp($ext_0_i | 0, 39624) | 0) == 0 ? 3 : 2; //@line 11418
  } else {
   $_0_i = $type; //@line 11420
  }
 } while (0);
 $16 = _fopen($fname | 0, 54128) | 0; //@line 11424
 if (($16 | 0) == 0) {
  $_0 = 0; //@line 11428
  return $_0 | 0; //@line 11431
 }
 if (($_0_i | 0) == 2) {
  $img_0_i = _pri_load_pri($16) | 0; //@line 11436
 } else if (($_0_i | 0) == 3) {
  $img_0_i = _pri_load_tc($16) | 0; //@line 11440
 } else if (($_0_i | 0) == 1) {
  $img_0_i = _pri_load_pbit($16) | 0; //@line 11444
 } else {
  $img_0_i = 0; //@line 11446
 }
 _fclose($16 | 0) | 0; //@line 11449
 $_0 = $img_0_i; //@line 11451
 return $_0 | 0; //@line 11454
}
function _pri_img_save($fname, $img, $type) {
 $fname = $fname | 0;
 $img = $img | 0;
 $type = $type | 0;
 var $i_0_i = 0, $ext_0_i = 0, $2 = 0, $3 = 0, $ext_1_i = 0, $_0_i = 0, $16 = 0, $_0_i7 = 0, $_0 = 0;
 do {
  if (($type | 0) == 0) {
   $ext_0_i = 62872;
   $i_0_i = 0;
   while (1) {
    $2 = $fname + $i_0_i | 0; //@line 11475
    $3 = HEAP8[$2] | 0; //@line 11476
    if (($3 << 24 >> 24 | 0) == 0) {
     break;
    } else if (($3 << 24 >> 24 | 0) == 46) {
     $ext_1_i = $2; //@line 11481
    } else {
     $ext_1_i = $ext_0_i; //@line 11483
    }
    $ext_0_i = $ext_1_i;
    $i_0_i = $i_0_i + 1 | 0;
   }
   if ((_strcasecmp($ext_0_i | 0, 46240) | 0) == 0) {
    $_0_i = 1; //@line 11494
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 42720) | 0) == 0) {
    $_0_i = 2; //@line 11501
    break;
   }
   $_0_i = (_strcasecmp($ext_0_i | 0, 39624) | 0) == 0 ? 3 : 2; //@line 11508
  } else {
   $_0_i = $type; //@line 11510
  }
 } while (0);
 $16 = _fopen($fname | 0, 56688) | 0; //@line 11514
 if (($16 | 0) == 0) {
  $_0 = 1; //@line 11518
  return $_0 | 0; //@line 11521
 }
 if (($_0_i | 0) == 3) {
  $_0_i7 = _pri_save_tc($16, $img) | 0; //@line 11526
 } else if (($_0_i | 0) == 2) {
  $_0_i7 = _pri_save_pri($16, $img) | 0; //@line 11530
 } else if (($_0_i | 0) == 1) {
  $_0_i7 = _pri_save_pbit($16, $img) | 0; //@line 11534
 } else {
  $_0_i7 = 1; //@line 11536
 }
 _fclose($16 | 0) | 0; //@line 11539
 $_0 = $_0_i7; //@line 11541
 return $_0 | 0; //@line 11544
}
function _pri_trk_set_size($trk, $size) {
 $trk = $trk | 0;
 $size = $size | 0;
 var $1 = 0, $8 = 0, $9 = 0, $14 = 0, $17 = 0, $size_ = 0, $19 = 0, $25 = 0, $26 = 0, $29 = 0, $_019_i = 0, $_0 = 0;
 $1 = $trk + 4 | 0; //@line 11558
 if ((HEAP32[$1 >> 2] | 0) == ($size | 0)) {
  $_0 = 0; //@line 11563
  return $_0 | 0; //@line 11566
 }
 HEAP32[$trk + 12 >> 2] = 0; //@line 11569
 HEAP8[$trk + 16 | 0] = 0; //@line 11571
 $8 = $trk + 8 | 0; //@line 11573
 $9 = HEAP32[$8 >> 2] | 0; //@line 11574
 if (($size | 0) == 0) {
  _free($9); //@line 11577
  HEAP32[$1 >> 2] = 0; //@line 11578
  HEAP32[$8 >> 2] = 0; //@line 11579
  $_0 = 0; //@line 11581
  return $_0 | 0; //@line 11584
 }
 $14 = _realloc($9, ($size + 7 | 0) >>> 3) | 0; //@line 11588
 if (($14 | 0) == 0) {
  $_0 = 1; //@line 11592
  return $_0 | 0; //@line 11595
 }
 $17 = HEAP32[$1 >> 2] | 0; //@line 11597
 $size_ = $17 >>> 0 > $size >>> 0 ? $size : $17; //@line 11599
 $19 = $size - 1 | 0; //@line 11600
 do {
  if (($19 | 7) >>> 0 >= $size_ >>> 0) {
   $25 = $size_ >>> 3; //@line 11608
   $26 = $19 >>> 3; //@line 11609
   $29 = $14 + $25 | 0; //@line 11612
   HEAP8[$29] = (HEAPU8[$29] | 0) & (255 >>> (($size_ & 7) >>> 0) ^ 255) & 255; //@line 11617
   if (($25 | 0) == ($26 | 0)) {
    break;
   }
   $_019_i = $25 + 1 | 0; //@line 11622
   if ($_019_i >>> 0 < $26 >>> 0) {
    _memset($14 + $_019_i | 0, 0, $26 - 1 - $25 | 0); //@line 11629
   }
   HEAP8[$14 + $26 | 0] = 0; //@line 11633
  }
 } while (0);
 HEAP32[$1 >> 2] = $size; //@line 11636
 HEAP32[$8 >> 2] = $14; //@line 11637
 $_0 = 0; //@line 11639
 return $_0 | 0; //@line 11642
}
function _pri_trk_get_bits($trk, $val, $cnt) {
 $trk = $trk | 0;
 $val = $val | 0;
 $cnt = $cnt | 0;
 var $2 = 0, $6 = 0, $7 = 0, $13 = 0, $16 = 0, $18 = 0, $p_023 = 0, $m_022 = 0, $v_021 = 0, $_020 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $33 = 0, $m_1 = 0, $p_1 = 0, $34 = 0, $_pre_phi = 0, $v_0_lcssa = 0, $_019 = 0;
 $2 = HEAP32[$trk + 4 >> 2] | 0; //@line 11659
 if (($2 | 0) == 0) {
  HEAP32[$val >> 2] = 0; //@line 11663
  $_019 = 1; //@line 11665
  return $_019 | 0; //@line 11668
 }
 $6 = $trk + 12 | 0; //@line 11670
 $7 = HEAP32[$6 >> 2] | 0; //@line 11671
 if (($cnt | 0) == 0) {
  $v_0_lcssa = 0;
  $_pre_phi = $trk + 16 | 0;
 } else {
  $13 = HEAP32[$trk + 8 >> 2] | 0; //@line 11683
  $16 = $trk + 16 | 0; //@line 11686
  $_020 = $cnt;
  $v_021 = 0;
  $m_022 = 128 >>> (($7 & 7) >>> 0) & 255;
  $p_023 = $13 + ($7 >>> 3) | 0;
  $18 = $7;
  while (1) {
   $24 = (HEAP8[$p_023] & $m_022) << 24 >> 24 != 0 | $v_021 << 1; //@line 11700
   $25 = ($m_022 & 255) >>> 1; //@line 11701
   $26 = $18 + 1 | 0; //@line 11702
   HEAP32[$6 >> 2] = $26; //@line 11703
   if ($26 >>> 0 < $2 >>> 0) {
    $30 = $25 << 24 >> 24 == 0; //@line 11707
    $p_1 = $30 ? $p_023 + 1 | 0 : $p_023;
    $m_1 = $30 ? -128 : $25;
    $33 = $26;
   } else {
    HEAP32[$6 >> 2] = 0; //@line 11714
    HEAP8[$16] = 1; //@line 11715
    $p_1 = $13;
    $m_1 = -128;
    $33 = 0;
   }
   $34 = $_020 - 1 | 0; //@line 11722
   if (($34 | 0) == 0) {
    $v_0_lcssa = $24;
    $_pre_phi = $16;
    break;
   } else {
    $_020 = $34;
    $v_021 = $24;
    $m_022 = $m_1;
    $p_023 = $p_1;
    $18 = $33;
   }
  }
 }
 HEAP32[$val >> 2] = $v_0_lcssa; //@line 11735
 $_019 = HEAP8[$_pre_phi] | 0; //@line 11739
 return $_019 | 0; //@line 11742
}
function _pri_trk_set_bits($trk, $val, $cnt) {
 $trk = $trk | 0;
 $val = $val | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $5 = 0, $6 = 0, $7 = 0, $15 = 0, $p_023 = 0, $m_022 = 0, $_021 = 0, $17 = 0, $storemerge = 0, $29 = 0, $31 = 0, $35 = 0, $m_0_be = 0, $p_0_be = 0, $38 = 0, $_pre_phi = 0, $_020 = 0;
 $1 = $trk + 4 | 0; //@line 11758
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  $_020 = 1; //@line 11763
  return $_020 | 0; //@line 11766
 }
 $5 = $trk + 8 | 0; //@line 11768
 $6 = $trk + 12 | 0; //@line 11769
 $7 = HEAP32[$6 >> 2] | 0; //@line 11770
 if (($cnt | 0) == 0) {
  $_pre_phi = $trk + 16 | 0; //@line 11776
 } else {
  $15 = $trk + 16 | 0; //@line 11784
  $_021 = $cnt;
  $m_022 = 128 >>> (($7 & 7) >>> 0) & 255;
  $p_023 = (HEAP32[$5 >> 2] | 0) + ($7 >>> 3) | 0;
  while (1) {
   $17 = $_021 - 1 | 0; //@line 11791
   if ((1 << $17 & $val | 0) == 0) {
    $storemerge = HEAP8[$p_023] & ~$m_022; //@line 11800
   } else {
    $storemerge = HEAP8[$p_023] | $m_022; //@line 11805
   }
   HEAP8[$p_023] = $storemerge; //@line 11808
   $29 = ($m_022 & 255) >>> 1; //@line 11809
   $31 = (HEAP32[$6 >> 2] | 0) + 1 | 0; //@line 11811
   HEAP32[$6 >> 2] = $31; //@line 11812
   if ($31 >>> 0 < (HEAP32[$1 >> 2] | 0) >>> 0) {
    $38 = $29 << 24 >> 24 == 0; //@line 11817
    $p_0_be = $38 ? $p_023 + 1 | 0 : $p_023;
    $m_0_be = $38 ? -128 : $29;
   } else {
    $35 = HEAP32[$5 >> 2] | 0; //@line 11824
    HEAP32[$6 >> 2] = 0; //@line 11825
    HEAP8[$15] = 1; //@line 11826
    $p_0_be = $35;
    $m_0_be = -128;
   }
   if (($17 | 0) == 0) {
    $_pre_phi = $15; //@line 11835
    break;
   } else {
    $_021 = $17;
    $m_022 = $m_0_be;
    $p_023 = $p_0_be;
   }
  }
 }
 $_020 = HEAP8[$_pre_phi] | 0; //@line 11846
 return $_020 | 0; //@line 11849
}
function _pri_trk_rotate($trk, $idx) {
 $trk = $trk | 0;
 $idx = $idx | 0;
 var $1 = 0, $2 = 0, $8 = 0, $9 = 0, $12 = 0, $21 = 0, $dp_033 = 0, $sp_032 = 0, $sm_031 = 0, $dm_030 = 0, $i_029 = 0, $_02628 = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0, $38 = 0, $39 = 0, $_1 = 0, $sm_1 = 0, $sp_1 = 0, $42 = 0, $_0 = 0;
 $1 = $trk + 4 | 0; //@line 11865
 $2 = HEAP32[$1 >> 2] | 0; //@line 11866
 if ($2 >>> 0 <= $idx >>> 0) {
  $_0 = 1; //@line 11870
  return $_0 | 0; //@line 11873
 }
 if (($idx | 0) == 0) {
  $_0 = 0; //@line 11878
  return $_0 | 0; //@line 11881
 }
 $8 = ($2 + 7 | 0) >>> 3; //@line 11884
 $9 = _malloc($8) | 0; //@line 11885
 if (($9 | 0) == 0) {
  $_0 = 1; //@line 11889
  return $_0 | 0; //@line 11892
 }
 _memset($9 | 0, 0, $8 | 0); //@line 11894
 $12 = $trk + 8 | 0; //@line 11895
 if (($2 | 0) != 0) {
  $_02628 = $idx;
  $i_029 = 0;
  $dm_030 = -128;
  $sm_031 = 128 >>> (($idx & 7) >>> 0) & 255;
  $sp_032 = (HEAP32[$12 >> 2] | 0) + ($idx >>> 3) | 0;
  $dp_033 = $9;
  $21 = $2;
  while (1) {
   if ((HEAP8[$sp_032] & $sm_031) << 24 >> 24 == 0) {
    $29 = $21; //@line 11920
   } else {
    HEAP8[$dp_033] = HEAP8[$dp_033] | $dm_030; //@line 11924
    $29 = HEAP32[$1 >> 2] | 0; //@line 11927
   }
   $30 = ($dm_030 & 255) >>> 1; //@line 11930
   $31 = $30 << 24 >> 24 == 0; //@line 11931
   $33 = $_02628 + 1 | 0; //@line 11935
   if ($33 >>> 0 < $29 >>> 0) {
    $38 = ($sm_031 & 255) >>> 1; //@line 11939
    $39 = $38 << 24 >> 24 == 0; //@line 11940
    $sp_1 = $39 ? $sp_032 + 1 | 0 : $sp_032;
    $sm_1 = $39 ? -128 : $38;
    $_1 = $33;
   } else {
    $sp_1 = HEAP32[$12 >> 2] | 0;
    $sm_1 = -128;
    $_1 = 0;
   }
   $42 = $i_029 + 1 | 0; //@line 11954
   if ($42 >>> 0 < $29 >>> 0) {
    $_02628 = $_1;
    $i_029 = $42;
    $dm_030 = $31 ? -128 : $30;
    $sm_031 = $sm_1;
    $sp_032 = $sp_1;
    $dp_033 = $31 ? $dp_033 + 1 | 0 : $dp_033;
    $21 = $29;
   } else {
    break;
   }
  }
 }
 _free(HEAP32[$12 >> 2] | 0); //@line 11965
 HEAP32[$12 >> 2] = $9; //@line 11966
 $_0 = 0; //@line 11968
 return $_0 | 0; //@line 11971
}
function _pri_cyl_get_track($cyl, $h, $alloc) {
 $cyl = $cyl | 0;
 $h = $h | 0;
 $alloc = $alloc | 0;
 var $1 = 0, $3 = 0, $8 = 0, $13 = 0, $14 = 0, $18 = 0, $19 = 0, $20 = 0, $23 = 0, $29 = 0, $33 = 0, $35 = 0, $36 = 0, $39 = 0, $_0 = 0;
 $1 = $cyl | 0; //@line 11986
 $3 = (HEAP32[$1 >> 2] | 0) >>> 0 > $h >>> 0; //@line 11988
 do {
  if ($3) {
   $8 = HEAP32[(HEAP32[$cyl + 4 >> 2] | 0) + ($h << 2) >> 2] | 0; //@line 11995
   if (($8 | 0) == 0) {
    break;
   } else {
    $_0 = $8; //@line 12001
   }
   return $_0 | 0; //@line 12005
  }
 } while (0);
 if (($alloc | 0) == 0) {
  $_0 = 0; //@line 12011
  return $_0 | 0; //@line 12014
 }
 $13 = _malloc(20) | 0; //@line 12016
 $14 = $13; //@line 12017
 if (($13 | 0) == 0) {
  $_0 = 0; //@line 12021
  return $_0 | 0; //@line 12024
 }
 $18 = $13 + 8 | 0; //@line 12027
 _memset($13 | 0, 0, 17); //@line 12028
 $19 = $cyl + 4 | 0; //@line 12029
 $20 = HEAP32[$19 >> 2] | 0; //@line 12030
 if ($3) {
  $23 = HEAP32[$20 + ($h << 2) >> 2] | 0; //@line 12034
  if (($23 | 0) == 0) {
   $29 = $20; //@line 12038
  } else {
   _free(HEAP32[$23 + 8 >> 2] | 0); //@line 12042
   _free($23); //@line 12044
   $29 = HEAP32[$19 >> 2] | 0; //@line 12047
  }
  HEAP32[$29 + ($h << 2) >> 2] = $14; //@line 12051
  $_0 = $14; //@line 12053
  return $_0 | 0; //@line 12056
 }
 $33 = $h + 1 | 0; //@line 12059
 $35 = _realloc($20, $33 << 2) | 0; //@line 12061
 $36 = $35; //@line 12062
 if (($35 | 0) == 0) {
  _free(HEAP32[$18 >> 2] | 0); //@line 12067
  _free($13); //@line 12068
  $_0 = 0; //@line 12070
  return $_0 | 0; //@line 12073
 }
 $39 = HEAP32[$1 >> 2] | 0; //@line 12075
 if ($39 >>> 0 < $h >>> 0) {
  _memset($35 + ($39 << 2) | 0, 0, $h - $39 << 2 | 0); //@line 12083
 }
 HEAP32[$36 + ($h << 2) >> 2] = $14; //@line 12087
 HEAP32[$19 >> 2] = $36; //@line 12088
 HEAP32[$1 >> 2] = $33; //@line 12089
 $_0 = $14; //@line 12091
 return $_0 | 0; //@line 12094
}
function _pri_img_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(16) | 0; //@line 12102
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 12106
  return $_0 | 0; //@line 12109
 }
 _memset($1 | 0, 0, 16); //@line 12112
 $_0 = $1; //@line 12114
 return $_0 | 0; //@line 12117
}
function _pri_img_del($img) {
 $img = $img | 0;
 var $2 = 0, $3 = 0, $_pre9 = 0, $5 = 0, $i_08 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $i_07_i = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $_lcssa_i = 0, $30 = 0, $31 = 0;
 if (($img | 0) == 0) {
  return;
 }
 $2 = $img | 0; //@line 12137
 $3 = HEAP32[$2 >> 2] | 0; //@line 12138
 $_pre9 = $img + 4 | 0; //@line 12140
 if (($3 | 0) != 0) {
  $i_08 = 0;
  $5 = $3;
  while (1) {
   $8 = HEAP32[(HEAP32[$_pre9 >> 2] | 0) + ($i_08 << 2) >> 2] | 0; //@line 12149
   if (($8 | 0) == 0) {
    $30 = $5; //@line 12153
   } else {
    $10 = $8 | 0; //@line 12155
    $11 = HEAP32[$10 >> 2] | 0; //@line 12156
    $13 = $8 + 4 | 0; //@line 12158
    $14 = HEAP32[$13 >> 2] | 0; //@line 12159
    if (($11 | 0) == 0) {
     $_lcssa_i = $14; //@line 12162
    } else {
     $i_07_i = 0;
     $16 = $14;
     $15 = $11;
     while (1) {
      $18 = HEAP32[$16 + ($i_07_i << 2) >> 2] | 0; //@line 12170
      if (($18 | 0) == 0) {
       $25 = $15;
       $24 = $16;
      } else {
       _free(HEAP32[$18 + 8 >> 2] | 0); //@line 12178
       _free($18); //@line 12180
       $25 = HEAP32[$10 >> 2] | 0;
       $24 = HEAP32[$13 >> 2] | 0;
      }
      $26 = $i_07_i + 1 | 0; //@line 12188
      if ($26 >>> 0 < $25 >>> 0) {
       $i_07_i = $26;
       $16 = $24;
       $15 = $25;
      } else {
       $_lcssa_i = $24; //@line 12194
       break;
      }
     }
    }
    _free($_lcssa_i); //@line 12201
    _free($8); //@line 12203
    $30 = HEAP32[$2 >> 2] | 0; //@line 12206
   }
   $31 = $i_08 + 1 | 0; //@line 12209
   if ($31 >>> 0 < $30 >>> 0) {
    $i_08 = $31;
    $5 = $30;
   } else {
    break;
   }
  }
 }
 _free(HEAP32[$img + 12 >> 2] | 0); //@line 12221
 _free(HEAP32[$_pre9 >> 2] | 0); //@line 12224
 _free($img); //@line 12226
 return;
}
function _pri_img_get_cylinder($img, $c, $alloc) {
 $img = $img | 0;
 $c = $c | 0;
 $alloc = $alloc | 0;
 var $8 = 0, $13 = 0, $15 = 0, $16 = 0, $18 = 0, $21 = 0, $23 = 0, $24 = 0, $25 = 0, $i_07_i = 0, $27 = 0, $33 = 0, $34 = 0, $35 = 0, $_lcssa_i = 0, $_0 = 0;
 do {
  if ((HEAP32[$img >> 2] | 0) >>> 0 > $c >>> 0) {
   $8 = HEAP32[(HEAP32[$img + 4 >> 2] | 0) + ($c << 2) >> 2] | 0; //@line 12253
   if (($8 | 0) == 0) {
    break;
   } else {
    $_0 = $8; //@line 12259
   }
   return $_0 | 0; //@line 12263
  }
 } while (0);
 if (($alloc | 0) == 0) {
  $_0 = 0; //@line 12269
  return $_0 | 0; //@line 12272
 }
 $13 = _malloc(8) | 0; //@line 12274
 if (($13 | 0) == 0) {
  $_0 = 0; //@line 12278
  return $_0 | 0; //@line 12281
 }
 $15 = $13; //@line 12283
 $16 = $13; //@line 12284
 HEAP32[$16 >> 2] = 0; //@line 12285
 $18 = $13 + 4 | 0; //@line 12287
 HEAP32[$18 >> 2] = 0; //@line 12288
 if ((_pri_img_set_cylinder($img, $15, $c) | 0) == 0) {
  $_0 = $15; //@line 12293
  return $_0 | 0; //@line 12296
 }
 $21 = HEAP32[$16 >> 2] | 0; //@line 12298
 $23 = HEAP32[$18 >> 2] | 0; //@line 12300
 if (($21 | 0) == 0) {
  $_lcssa_i = $23; //@line 12303
 } else {
  $i_07_i = 0;
  $25 = $23;
  $24 = $21;
  while (1) {
   $27 = HEAP32[$25 + ($i_07_i << 2) >> 2] | 0; //@line 12311
   if (($27 | 0) == 0) {
    $34 = $24;
    $33 = $25;
   } else {
    _free(HEAP32[$27 + 8 >> 2] | 0); //@line 12319
    _free($27); //@line 12321
    $34 = HEAP32[$16 >> 2] | 0;
    $33 = HEAP32[$18 >> 2] | 0;
   }
   $35 = $i_07_i + 1 | 0; //@line 12329
   if ($35 >>> 0 < $34 >>> 0) {
    $i_07_i = $35;
    $25 = $33;
    $24 = $34;
   } else {
    $_lcssa_i = $33; //@line 12335
    break;
   }
  }
 }
 _free($_lcssa_i); //@line 12342
 _free($13); //@line 12343
 $_0 = 0; //@line 12345
 return $_0 | 0; //@line 12348
}
function _pri_img_set_cylinder($img, $cyl, $c) {
 $img = $img | 0;
 $cyl = $cyl | 0;
 $c = $c | 0;
 var $1 = 0, $4 = 0, $5 = 0, $8 = 0, $10 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $i_07_i = 0, $18 = 0, $24 = 0, $25 = 0, $26 = 0, $_lcssa_i = 0, $30 = 0, $32 = 0, $_pre_i24 = 0, $35 = 0, $36 = 0, $44 = 0, $46 = 0, $47 = 0, $50 = 0, $58 = 0, $59 = 0, $_0 = 0, label = 0;
 $1 = $img | 0; //@line 12366
 $4 = $img + 4 | 0; //@line 12369
 $5 = HEAP32[$4 >> 2] | 0; //@line 12370
 if ((HEAP32[$1 >> 2] | 0) >>> 0 <= $c >>> 0) {
  $44 = $c + 1 | 0; //@line 12374
  $46 = _realloc($5, $44 << 2) | 0; //@line 12376
  $47 = $46; //@line 12377
  if (($46 | 0) == 0) {
   $_0 = 1; //@line 12381
   return $_0 | 0; //@line 12384
  }
  $50 = HEAP32[$1 >> 2] | 0; //@line 12386
  if ($50 >>> 0 < $c >>> 0) {
   _memset($46 + ($50 << 2) | 0, 0, $c - $50 << 2 | 0); //@line 12394
  }
  HEAP32[$47 + ($c << 2) >> 2] = $cyl; //@line 12398
  HEAP32[$4 >> 2] = $47; //@line 12399
  HEAP32[$1 >> 2] = $44; //@line 12400
  if (($44 | 0) == 0) {
   $_0 = 0; //@line 12404
   return $_0 | 0; //@line 12407
  } else {
   $58 = $44; //@line 12409
  }
  while (1) {
   $59 = $58 - 1 | 0; //@line 12413
   if ((HEAP32[$47 + ($59 << 2) >> 2] | 0) != 0) {
    $_0 = 0; //@line 12418
    label = 11489; //@line 12419
    break;
   }
   HEAP32[$1 >> 2] = $59; //@line 12422
   if (($59 | 0) == 0) {
    $_0 = 0; //@line 12426
    label = 11485; //@line 12427
    break;
   } else {
    $58 = $59; //@line 12430
   }
  }
  if ((label | 0) == 11489) {
   return $_0 | 0; //@line 12436
  } else if ((label | 0) == 11485) {
   return $_0 | 0; //@line 12441
  }
 }
 $8 = HEAP32[$5 + ($c << 2) >> 2] | 0; //@line 12445
 if (($8 | 0) == 0) {
  $30 = $5; //@line 12449
 } else {
  $10 = $8 | 0; //@line 12451
  $11 = HEAP32[$10 >> 2] | 0; //@line 12452
  $13 = $8 + 4 | 0; //@line 12454
  $14 = HEAP32[$13 >> 2] | 0; //@line 12455
  if (($11 | 0) == 0) {
   $_lcssa_i = $14; //@line 12458
  } else {
   $i_07_i = 0;
   $16 = $14;
   $15 = $11;
   while (1) {
    $18 = HEAP32[$16 + ($i_07_i << 2) >> 2] | 0; //@line 12466
    if (($18 | 0) == 0) {
     $25 = $15;
     $24 = $16;
    } else {
     _free(HEAP32[$18 + 8 >> 2] | 0); //@line 12474
     _free($18); //@line 12476
     $25 = HEAP32[$10 >> 2] | 0;
     $24 = HEAP32[$13 >> 2] | 0;
    }
    $26 = $i_07_i + 1 | 0; //@line 12484
    if ($26 >>> 0 < $25 >>> 0) {
     $i_07_i = $26;
     $16 = $24;
     $15 = $25;
    } else {
     $_lcssa_i = $24; //@line 12490
     break;
    }
   }
  }
  _free($_lcssa_i); //@line 12497
  _free($8); //@line 12499
  $30 = HEAP32[$4 >> 2] | 0; //@line 12502
 }
 HEAP32[$30 + ($c << 2) >> 2] = $cyl; //@line 12506
 $32 = HEAP32[$1 >> 2] | 0; //@line 12507
 if (($32 | 0) == 0) {
  $_0 = 0; //@line 12511
  return $_0 | 0; //@line 12514
 }
 $_pre_i24 = HEAP32[$4 >> 2] | 0; //@line 12516
 $35 = $32; //@line 12518
 while (1) {
  $36 = $35 - 1 | 0; //@line 12521
  if ((HEAP32[$_pre_i24 + ($36 << 2) >> 2] | 0) != 0) {
   $_0 = 0; //@line 12526
   label = 11487; //@line 12527
   break;
  }
  HEAP32[$1 >> 2] = $36; //@line 12530
  if (($36 | 0) == 0) {
   $_0 = 0; //@line 12534
   label = 11486; //@line 12535
   break;
  } else {
   $35 = $36; //@line 12538
  }
 }
 if ((label | 0) == 11486) {
  return $_0 | 0; //@line 12544
 } else if ((label | 0) == 11487) {
  return $_0 | 0; //@line 12549
 }
 return 0;
}
function _pri_img_get_track($img, $c, $h, $alloc) {
 $img = $img | 0;
 $c = $c | 0;
 $h = $h | 0;
 $alloc = $alloc | 0;
 var $1 = 0, $_0 = 0;
 $1 = _pri_img_get_cylinder($img, $c, $alloc) | 0; //@line 12562
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 12566
  return $_0 | 0; //@line 12569
 }
 $_0 = _pri_cyl_get_track($1, $h, $alloc) | 0; //@line 12573
 return $_0 | 0; //@line 12576
}
function _pri_img_add_comment($img, $buf, $cnt) {
 $img = $img | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $3 = 0, $6 = 0, $9 = 0, $10 = 0, $_0 = 0;
 $1 = $img + 12 | 0; //@line 12588
 $3 = $img + 8 | 0; //@line 12590
 $6 = _realloc(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + $cnt | 0) | 0; //@line 12593
 if (($6 | 0) == 0) {
  $_0 = 1; //@line 12597
  return $_0 | 0; //@line 12600
 }
 $9 = HEAP32[$3 >> 2] | 0; //@line 12602
 $10 = $6 + $9 | 0; //@line 12603
 _memcpy($10 | 0, $buf | 0, $cnt) | 0; //@line 12604
 HEAP32[$3 >> 2] = $9 + $cnt; //@line 12606
 HEAP32[$1 >> 2] = $6; //@line 12607
 $_0 = 0; //@line 12609
 return $_0 | 0; //@line 12612
}
function _pri_img_set_comment($img, $buf, $cnt) {
 $img = $img | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $3 = 0, $7 = 0, $10 = 0, $11 = 0, $_0 = 0;
 $1 = $img + 12 | 0; //@line 12624
 _free(HEAP32[$1 >> 2] | 0); //@line 12626
 $3 = $img + 8 | 0; //@line 12627
 HEAP32[$3 >> 2] = 0; //@line 12628
 HEAP32[$1 >> 2] = 0; //@line 12629
 if (($buf | 0) == 0 | ($cnt | 0) == 0) {
  $_0 = 0; //@line 12635
  return $_0 | 0; //@line 12638
 }
 $7 = _realloc(0, $cnt) | 0; //@line 12640
 if (($7 | 0) == 0) {
  $_0 = 1; //@line 12644
  return $_0 | 0; //@line 12647
 }
 $10 = HEAP32[$3 >> 2] | 0; //@line 12649
 $11 = $7 + $10 | 0; //@line 12650
 _memcpy($11 | 0, $buf | 0, $cnt) | 0; //@line 12651
 HEAP32[$3 >> 2] = $10 + $cnt; //@line 12653
 HEAP32[$1 >> 2] = $7; //@line 12654
 $_0 = 0; //@line 12656
 return $_0 | 0; //@line 12659
}
function _pri_load_pbit($fp) {
 $fp = $fp | 0;
 var $buf_i102_i = 0, $buf_i63_i = 0, $buf_i_i_i = 0, $c_i_i = 0, $buf_i_i = 0, $buf_i = 0, $1 = 0, $4 = 0, $11 = 0, $15 = 0, $i_017_i_i = 0, $17 = 0, $reg_1_i_i = 0, $20 = 0, $reg_1_1_i_i = 0, $23 = 0, $reg_1_2_i_i = 0, $26 = 0, $reg_1_3_i_i = 0, $29 = 0, $reg_1_4_i_i = 0, $32 = 0, $reg_1_5_i_i = 0, $35 = 0, $reg_1_6_i_i = 0, $38 = 0, $44 = 0, $48 = 0, $50 = 0, $57 = 0, $59 = 0, $66 = 0, $74 = 0, $76 = 0, $83 = 0, $85 = 0, $92 = 0, $94 = 0, $101 = 0, $109 = 0, $110 = 0, $i_017_i_i_i = 0, $117 = 0, $reg_1_i_i_i = 0, $120 = 0, $reg_1_1_i_i_i = 0, $123 = 0, $reg_1_2_i_i_i = 0, $126 = 0, $reg_1_3_i_i_i = 0, $129 = 0, $reg_1_4_i_i_i = 0, $132 = 0, $reg_1_5_i_i_i = 0, $135 = 0, $reg_1_6_i_i_i = 0, $138 = 0, $152 = 0, $161 = 0, $170 = 0, $179 = 0, $188 = 0, $197 = 0, $206 = 0, $212 = 0, $213 = 0, $216 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $trk_0_ph_i = 0, $228 = 0, $229 = 0, $230 = 0, $232 = 0, $233 = 0, $i_017_i31_i = 0, $235 = 0, $reg_1_i33_i = 0, $238 = 0, $reg_1_1_i34_i = 0, $241 = 0, $reg_1_2_i35_i = 0, $244 = 0, $reg_1_3_i36_i = 0, $247 = 0, $reg_1_4_i37_i = 0, $250 = 0, $reg_1_5_i38_i = 0, $253 = 0, $reg_1_6_i39_i = 0, $256 = 0, $265 = 0, $273 = 0, $281 = 0, $289 = 0, $297 = 0, $305 = 0, $313 = 0, $321 = 0, $334 = 0, $i_017_i_i49_i = 0, $342 = 0, $reg_1_i_i51_i = 0, $345 = 0, $reg_1_1_i_i52_i = 0, $348 = 0, $reg_1_2_i_i53_i = 0, $351 = 0, $reg_1_3_i_i54_i = 0, $354 = 0, $reg_1_4_i_i55_i = 0, $357 = 0, $reg_1_5_i_i56_i = 0, $360 = 0, $reg_1_6_i_i57_i = 0, $363 = 0, $src_013_i_i_i = 0, $_012_i_i_i = 0, $_01011_i_i_i = 0, $377 = 0, $378 = 0, $i_075_i_i = 0, $381 = 0, $i_0_lcssa_i_i = 0, $i_0_be_i_i = 0, $j_069_i_i = 0, $384 = 0, $386 = 0, $j_0_be_i_i = 0, $j_0_lcssa_i_i = 0, $d_067_i_i = 0, $k_066_i_i = 0, $402 = 0, $405 = 0, $k_1_i_i = 0, $d_1_i_i = 0, $418 = 0, $d_0_lcssa_i_i = 0, $429 = 0, $437 = 0, $i_017_i_i65_i = 0, $446 = 0, $reg_1_i_i67_i = 0, $449 = 0, $reg_1_1_i_i68_i = 0, $452 = 0, $reg_1_2_i_i69_i = 0, $455 = 0, $reg_1_3_i_i70_i = 0, $458 = 0, $reg_1_4_i_i71_i = 0, $461 = 0, $reg_1_5_i_i72_i = 0, $464 = 0, $reg_1_6_i_i73_i = 0, $467 = 0, $src_013_i_i76_i = 0, $_012_i_i77_i = 0, $_01011_i_i78_i = 0, $481 = 0, $482 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $501 = 0, $size__i_i = 0, $507 = 0, $i_017_i_i83_i = 0, $509 = 0, $reg_1_i_i85_i = 0, $512 = 0, $reg_1_1_i_i86_i = 0, $515 = 0, $reg_1_2_i_i87_i = 0, $518 = 0, $reg_1_3_i_i88_i = 0, $521 = 0, $reg_1_4_i_i89_i = 0, $524 = 0, $reg_1_5_i_i90_i = 0, $527 = 0, $reg_1_6_i_i91_i = 0, $530 = 0, $src_013_i_i94_i = 0, $_012_i_i95_i = 0, $_01011_i_i96_i = 0, $545 = 0, $546 = 0, $_0_lcssa_i_i_i = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 12743
 STACKTOP = STACKTOP + 560 | 0; //@line 12743
 $buf_i102_i = sp | 0; //@line 12744
 $buf_i63_i = sp + 256 | 0; //@line 12745
 $buf_i_i_i = sp + 280 | 0; //@line 12746
 $c_i_i = sp + 536 | 0; //@line 12747
 $buf_i_i = sp + 544 | 0; //@line 12748
 $buf_i = sp + 552 | 0; //@line 12749
 $1 = _pri_img_new() | 0; //@line 12750
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 12754
  STACKTOP = sp; //@line 12756
  return $_0 | 0; //@line 12757
 }
 $4 = $buf_i | 0; //@line 12759
 if ((_pri_read($fp, $4, 4) | 0) != 0) {
  $_0 = $1; //@line 12764
  STACKTOP = sp; //@line 12766
  return $_0 | 0; //@line 12767
 }
 L14414 : do {
  if ((_pri_get_uint32_be($4, 0) | 0) == 1346521428) {
   $11 = $buf_i + 4 | 0; //@line 12774
   if ((_pri_read($fp, $11, 4) | 0) != 0) {
    break;
   }
   $15 = _pri_get_uint32_be($4, 4) | 0; //@line 12781
   if (!(HEAP8[6704] | 0)) {
    $i_017_i_i = 0; //@line 12785
    do {
     $17 = $i_017_i_i << 25; //@line 12790
     $reg_1_i_i = ($i_017_i_i & 128 | 0) != 0 ? $17 ^ 517762881 : $17; //@line 12792
     $20 = $reg_1_i_i << 1; //@line 12794
     $reg_1_1_i_i = ($reg_1_i_i | 0) < 0 ? $20 ^ 517762881 : $20; //@line 12796
     $23 = $reg_1_1_i_i << 1; //@line 12798
     $reg_1_2_i_i = ($reg_1_1_i_i | 0) < 0 ? $23 ^ 517762881 : $23; //@line 12800
     $26 = $reg_1_2_i_i << 1; //@line 12802
     $reg_1_3_i_i = ($reg_1_2_i_i | 0) < 0 ? $26 ^ 517762881 : $26; //@line 12804
     $29 = $reg_1_3_i_i << 1; //@line 12806
     $reg_1_4_i_i = ($reg_1_3_i_i | 0) < 0 ? $29 ^ 517762881 : $29; //@line 12808
     $32 = $reg_1_4_i_i << 1; //@line 12810
     $reg_1_5_i_i = ($reg_1_4_i_i | 0) < 0 ? $32 ^ 517762881 : $32; //@line 12812
     $35 = $reg_1_5_i_i << 1; //@line 12814
     $reg_1_6_i_i = ($reg_1_5_i_i | 0) < 0 ? $35 ^ 517762881 : $35; //@line 12816
     $38 = $reg_1_6_i_i << 1; //@line 12818
     HEAP32[61320 + ($i_017_i_i << 2) >> 2] = ($reg_1_6_i_i | 0) < 0 ? $38 ^ 517762881 : $38; //@line 12822
     $i_017_i_i = $i_017_i_i + 1 | 0; //@line 12823
    } while ($i_017_i_i >>> 0 < 256);
    HEAP8[6704] = 1; //@line 12832
   }
   $44 = $buf_i + 1 | 0; //@line 12835
   $48 = HEAP32[61320 + (HEAPU8[$4] << 2) >> 2] | 0; //@line 12839
   $50 = $buf_i + 2 | 0; //@line 12841
   $57 = HEAP32[61320 + ((HEAPU8[$44] ^ $48 >>> 24) << 2) >> 2] ^ $48 << 8; //@line 12848
   $59 = $buf_i + 3 | 0; //@line 12850
   $66 = HEAP32[61320 + ((HEAPU8[$50] ^ $57 >>> 24) << 2) >> 2] ^ $57 << 8; //@line 12857
   $74 = HEAP32[61320 + ((HEAPU8[$59] ^ $66 >>> 24) << 2) >> 2] ^ $66 << 8; //@line 12865
   $76 = $buf_i + 5 | 0; //@line 12867
   $83 = HEAP32[61320 + ((HEAPU8[$11] ^ $74 >>> 24) << 2) >> 2] ^ $74 << 8; //@line 12874
   $85 = $buf_i + 6 | 0; //@line 12876
   $92 = HEAP32[61320 + ((HEAPU8[$76] ^ $83 >>> 24) << 2) >> 2] ^ $83 << 8; //@line 12883
   $94 = $buf_i + 7 | 0; //@line 12885
   $101 = HEAP32[61320 + ((HEAPU8[$85] ^ $92 >>> 24) << 2) >> 2] ^ $92 << 8; //@line 12892
   $109 = HEAP32[61320 + ((HEAPU8[$94] ^ $101 >>> 24) << 2) >> 2] ^ $101 << 8; //@line 12900
   $110 = $buf_i_i | 0; //@line 12901
   if ($15 >>> 0 < 8) {
    break;
   }
   if ((_pri_read($fp, $110, 8) | 0) != 0) {
    break;
   }
   if (!(HEAP8[6704] | 0)) {
    $i_017_i_i_i = 0; //@line 12916
    do {
     $117 = $i_017_i_i_i << 25; //@line 12921
     $reg_1_i_i_i = ($i_017_i_i_i & 128 | 0) != 0 ? $117 ^ 517762881 : $117; //@line 12923
     $120 = $reg_1_i_i_i << 1; //@line 12925
     $reg_1_1_i_i_i = ($reg_1_i_i_i | 0) < 0 ? $120 ^ 517762881 : $120; //@line 12927
     $123 = $reg_1_1_i_i_i << 1; //@line 12929
     $reg_1_2_i_i_i = ($reg_1_1_i_i_i | 0) < 0 ? $123 ^ 517762881 : $123; //@line 12931
     $126 = $reg_1_2_i_i_i << 1; //@line 12933
     $reg_1_3_i_i_i = ($reg_1_2_i_i_i | 0) < 0 ? $126 ^ 517762881 : $126; //@line 12935
     $129 = $reg_1_3_i_i_i << 1; //@line 12937
     $reg_1_4_i_i_i = ($reg_1_3_i_i_i | 0) < 0 ? $129 ^ 517762881 : $129; //@line 12939
     $132 = $reg_1_4_i_i_i << 1; //@line 12941
     $reg_1_5_i_i_i = ($reg_1_4_i_i_i | 0) < 0 ? $132 ^ 517762881 : $132; //@line 12943
     $135 = $reg_1_5_i_i_i << 1; //@line 12945
     $reg_1_6_i_i_i = ($reg_1_5_i_i_i | 0) < 0 ? $135 ^ 517762881 : $135; //@line 12947
     $138 = $reg_1_6_i_i_i << 1; //@line 12949
     HEAP32[61320 + ($i_017_i_i_i << 2) >> 2] = ($reg_1_6_i_i_i | 0) < 0 ? $138 ^ 517762881 : $138; //@line 12953
     $i_017_i_i_i = $i_017_i_i_i + 1 | 0; //@line 12954
    } while ($i_017_i_i_i >>> 0 < 256);
    HEAP8[6704] = 1; //@line 12963
   }
   $152 = HEAP32[61320 + ((HEAPU8[$110] ^ $109 >>> 24) << 2) >> 2] ^ $109 << 8; //@line 12974
   $161 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 1 | 0] ^ $152 >>> 24) << 2) >> 2] ^ $152 << 8; //@line 12983
   $170 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 2 | 0] ^ $161 >>> 24) << 2) >> 2] ^ $161 << 8; //@line 12992
   $179 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 3 | 0] ^ $170 >>> 24) << 2) >> 2] ^ $170 << 8; //@line 13001
   $188 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 4 | 0] ^ $179 >>> 24) << 2) >> 2] ^ $179 << 8; //@line 13010
   $197 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 5 | 0] ^ $188 >>> 24) << 2) >> 2] ^ $188 << 8; //@line 13019
   $206 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 6 | 0] ^ $197 >>> 24) << 2) >> 2] ^ $197 << 8; //@line 13028
   $212 = HEAP32[61320 + ((HEAPU8[$buf_i_i + 7 | 0] ^ $206 >>> 24) << 2) >> 2] | 0; //@line 13034
   $213 = _pri_get_uint32_be($110, 0) | 0; //@line 13035
   if (($213 | 0) != 0) {
    $216 = HEAP32[_stderr >> 2] | 0; //@line 13039
    _fprintf($216 | 0, 50176, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $213, tempInt) | 0) | 0; //@line 13040
    break;
   }
   if ((_pbit_skip_chunk($fp, $15 - 8 | 0, $212 ^ $206 << 8) | 0) != 0) {
    break;
   }
   $222 = $buf_i102_i | 0; //@line 13053
   $223 = $buf_i_i_i | 0; //@line 13054
   $224 = $1 + 8 | 0; //@line 13055
   $225 = $buf_i63_i | 0; //@line 13056
   $trk_0_ph_i = 0; //@line 13058
   L14433 : while (1) {
    if ((_pri_read($fp, $4, 8) | 0) != 0) {
     break L14414;
    }
    $228 = ($trk_0_ph_i | 0) == 0; //@line 13067
    $229 = $trk_0_ph_i + 4 | 0; //@line 13068
    $230 = $trk_0_ph_i + 8 | 0; //@line 13069
    L14436 : while (1) {
     $232 = _pri_get_uint32_be($4, 0) | 0; //@line 13072
     $233 = _pri_get_uint32_be($4, 4) | 0; //@line 13073
     if (!(HEAP8[6704] | 0)) {
      $i_017_i31_i = 0; //@line 13077
      do {
       $235 = $i_017_i31_i << 25; //@line 13082
       $reg_1_i33_i = ($i_017_i31_i & 128 | 0) != 0 ? $235 ^ 517762881 : $235; //@line 13084
       $238 = $reg_1_i33_i << 1; //@line 13086
       $reg_1_1_i34_i = ($reg_1_i33_i | 0) < 0 ? $238 ^ 517762881 : $238; //@line 13088
       $241 = $reg_1_1_i34_i << 1; //@line 13090
       $reg_1_2_i35_i = ($reg_1_1_i34_i | 0) < 0 ? $241 ^ 517762881 : $241; //@line 13092
       $244 = $reg_1_2_i35_i << 1; //@line 13094
       $reg_1_3_i36_i = ($reg_1_2_i35_i | 0) < 0 ? $244 ^ 517762881 : $244; //@line 13096
       $247 = $reg_1_3_i36_i << 1; //@line 13098
       $reg_1_4_i37_i = ($reg_1_3_i36_i | 0) < 0 ? $247 ^ 517762881 : $247; //@line 13100
       $250 = $reg_1_4_i37_i << 1; //@line 13102
       $reg_1_5_i38_i = ($reg_1_4_i37_i | 0) < 0 ? $250 ^ 517762881 : $250; //@line 13104
       $253 = $reg_1_5_i38_i << 1; //@line 13106
       $reg_1_6_i39_i = ($reg_1_5_i38_i | 0) < 0 ? $253 ^ 517762881 : $253; //@line 13108
       $256 = $reg_1_6_i39_i << 1; //@line 13110
       HEAP32[61320 + ($i_017_i31_i << 2) >> 2] = ($reg_1_6_i39_i | 0) < 0 ? $256 ^ 517762881 : $256; //@line 13114
       $i_017_i31_i = $i_017_i31_i + 1 | 0; //@line 13115
      } while ($i_017_i31_i >>> 0 < 256);
      HEAP8[6704] = 1; //@line 13124
     }
     $265 = HEAP32[61320 + (HEAPU8[$4] << 2) >> 2] | 0; //@line 13130
     $273 = HEAP32[61320 + ((HEAPU8[$44] ^ $265 >>> 24) << 2) >> 2] ^ $265 << 8; //@line 13138
     $281 = HEAP32[61320 + ((HEAPU8[$50] ^ $273 >>> 24) << 2) >> 2] ^ $273 << 8; //@line 13146
     $289 = HEAP32[61320 + ((HEAPU8[$59] ^ $281 >>> 24) << 2) >> 2] ^ $281 << 8; //@line 13154
     $297 = HEAP32[61320 + ((HEAPU8[$11] ^ $289 >>> 24) << 2) >> 2] ^ $289 << 8; //@line 13162
     $305 = HEAP32[61320 + ((HEAPU8[$76] ^ $297 >>> 24) << 2) >> 2] ^ $297 << 8; //@line 13170
     $313 = HEAP32[61320 + ((HEAPU8[$85] ^ $305 >>> 24) << 2) >> 2] ^ $305 << 8; //@line 13178
     $321 = HEAP32[61320 + ((HEAPU8[$94] ^ $313 >>> 24) << 2) >> 2] ^ $313 << 8; //@line 13186
     do {
      if (($232 | 0) == 1162757152) {
       label = 11582; //@line 13189
       break L14433;
      } else if (($232 | 0) == 1145132097) {
       if ($228) {
        break L14414;
       }
       $501 = ((HEAP32[$229 >> 2] | 0) + 7 | 0) >>> 3; //@line 13198
       $size__i_i = $501 >>> 0 < $233 >>> 0 ? $233 : $501; //@line 13200
       if ((_pri_read($fp, HEAP32[$230 >> 2] | 0, $size__i_i) | 0) != 0) {
        break L14414;
       }
       $507 = HEAP32[$230 >> 2] | 0; //@line 13208
       if (!(HEAP8[6704] | 0)) {
        $i_017_i_i83_i = 0; //@line 13212
        do {
         $509 = $i_017_i_i83_i << 25; //@line 13217
         $reg_1_i_i85_i = ($i_017_i_i83_i & 128 | 0) != 0 ? $509 ^ 517762881 : $509; //@line 13219
         $512 = $reg_1_i_i85_i << 1; //@line 13221
         $reg_1_1_i_i86_i = ($reg_1_i_i85_i | 0) < 0 ? $512 ^ 517762881 : $512; //@line 13223
         $515 = $reg_1_1_i_i86_i << 1; //@line 13225
         $reg_1_2_i_i87_i = ($reg_1_1_i_i86_i | 0) < 0 ? $515 ^ 517762881 : $515; //@line 13227
         $518 = $reg_1_2_i_i87_i << 1; //@line 13229
         $reg_1_3_i_i88_i = ($reg_1_2_i_i87_i | 0) < 0 ? $518 ^ 517762881 : $518; //@line 13231
         $521 = $reg_1_3_i_i88_i << 1; //@line 13233
         $reg_1_4_i_i89_i = ($reg_1_3_i_i88_i | 0) < 0 ? $521 ^ 517762881 : $521; //@line 13235
         $524 = $reg_1_4_i_i89_i << 1; //@line 13237
         $reg_1_5_i_i90_i = ($reg_1_4_i_i89_i | 0) < 0 ? $524 ^ 517762881 : $524; //@line 13239
         $527 = $reg_1_5_i_i90_i << 1; //@line 13241
         $reg_1_6_i_i91_i = ($reg_1_5_i_i90_i | 0) < 0 ? $527 ^ 517762881 : $527; //@line 13243
         $530 = $reg_1_6_i_i91_i << 1; //@line 13245
         HEAP32[61320 + ($i_017_i_i83_i << 2) >> 2] = ($reg_1_6_i_i91_i | 0) < 0 ? $530 ^ 517762881 : $530; //@line 13249
         $i_017_i_i83_i = $i_017_i_i83_i + 1 | 0; //@line 13250
        } while ($i_017_i_i83_i >>> 0 < 256);
        HEAP8[6704] = 1; //@line 13259
       }
       if (($size__i_i | 0) == 0) {
        $_0_lcssa_i_i_i = $321; //@line 13265
       } else {
        $_01011_i_i96_i = $size__i_i;
        $_012_i_i95_i = $321;
        $src_013_i_i94_i = $507;
        while (1) {
         $545 = HEAP32[61320 + ((HEAPU8[$src_013_i_i94_i] ^ $_012_i_i95_i >>> 24) << 2) >> 2] ^ $_012_i_i95_i << 8; //@line 13280
         $546 = $_01011_i_i96_i - 1 | 0; //@line 13281
         if (($546 | 0) == 0) {
          $_0_lcssa_i_i_i = $545; //@line 13285
          break;
         } else {
          $_01011_i_i96_i = $546;
          $_012_i_i95_i = $545;
          $src_013_i_i94_i = $src_013_i_i94_i + 1 | 0;
         }
        }
       }
       if ((_pbit_skip_chunk($fp, $233 - $size__i_i | 0, $_0_lcssa_i_i_i) | 0) != 0) {
        break L14414;
       }
      } else if (($232 | 0) == 1413830740) {
       if (($233 | 0) == 0) {
        if ((_pri_read($fp, $222, 4) | 0) != 0) {
         break L14414;
        }
        if ((_pri_get_uint32_be($222, 0) | 0) == ($321 | 0)) {
         break;
        } else {
         label = 11532; //@line 13316
         break L14433;
        }
       }
       $334 = _malloc($233) | 0; //@line 13320
       if (($334 | 0) == 0) {
        break L14414;
       }
       if ((_pri_read($fp, $334, $233) | 0) != 0) {
        label = 11535; //@line 13330
        break L14433;
       }
       if (HEAP8[6704] | 0) {
        $_01011_i_i_i = $233;
        $_012_i_i_i = $321;
        $src_013_i_i_i = $334;
       } else {
        $i_017_i_i49_i = 0; //@line 13338
        do {
         $342 = $i_017_i_i49_i << 25; //@line 13343
         $reg_1_i_i51_i = ($i_017_i_i49_i & 128 | 0) != 0 ? $342 ^ 517762881 : $342; //@line 13345
         $345 = $reg_1_i_i51_i << 1; //@line 13347
         $reg_1_1_i_i52_i = ($reg_1_i_i51_i | 0) < 0 ? $345 ^ 517762881 : $345; //@line 13349
         $348 = $reg_1_1_i_i52_i << 1; //@line 13351
         $reg_1_2_i_i53_i = ($reg_1_1_i_i52_i | 0) < 0 ? $348 ^ 517762881 : $348; //@line 13353
         $351 = $reg_1_2_i_i53_i << 1; //@line 13355
         $reg_1_3_i_i54_i = ($reg_1_2_i_i53_i | 0) < 0 ? $351 ^ 517762881 : $351; //@line 13357
         $354 = $reg_1_3_i_i54_i << 1; //@line 13359
         $reg_1_4_i_i55_i = ($reg_1_3_i_i54_i | 0) < 0 ? $354 ^ 517762881 : $354; //@line 13361
         $357 = $reg_1_4_i_i55_i << 1; //@line 13363
         $reg_1_5_i_i56_i = ($reg_1_4_i_i55_i | 0) < 0 ? $357 ^ 517762881 : $357; //@line 13365
         $360 = $reg_1_5_i_i56_i << 1; //@line 13367
         $reg_1_6_i_i57_i = ($reg_1_5_i_i56_i | 0) < 0 ? $360 ^ 517762881 : $360; //@line 13369
         $363 = $reg_1_6_i_i57_i << 1; //@line 13371
         HEAP32[61320 + ($i_017_i_i49_i << 2) >> 2] = ($reg_1_6_i_i57_i | 0) < 0 ? $363 ^ 517762881 : $363; //@line 13375
         $i_017_i_i49_i = $i_017_i_i49_i + 1 | 0; //@line 13376
        } while ($i_017_i_i49_i >>> 0 < 256);
        HEAP8[6704] = 1; //@line 13385
        $_01011_i_i_i = $233;
        $_012_i_i_i = $321;
        $src_013_i_i_i = $334;
       }
       while (1) {
        $377 = HEAP32[61320 + ((HEAPU8[$src_013_i_i_i] ^ $_012_i_i_i >>> 24) << 2) >> 2] ^ $_012_i_i_i << 8; //@line 13401
        $378 = $_01011_i_i_i - 1 | 0; //@line 13402
        if (($378 | 0) == 0) {
         $i_075_i_i = 0; //@line 13406
         break;
        } else {
         $_01011_i_i_i = $378;
         $_012_i_i_i = $377;
         $src_013_i_i_i = $src_013_i_i_i + 1 | 0;
        }
       }
       while (1) {
        $381 = HEAP8[$334 + $i_075_i_i | 0] | 0; //@line 13415
        if (!(($381 << 24 >> 24 | 0) == 13 | ($381 << 24 >> 24 | 0) == 10 | ($381 << 24 >> 24 | 0) == 0)) {
         $i_0_lcssa_i_i = $i_075_i_i; //@line 13417
         break;
        }
        $i_0_be_i_i = $i_075_i_i + 1 | 0; //@line 13420
        if ($i_0_be_i_i >>> 0 < $233 >>> 0) {
         $i_075_i_i = $i_0_be_i_i; //@line 13424
        } else {
         $i_0_lcssa_i_i = $i_0_be_i_i; //@line 13426
         break;
        }
       }
       L14473 : do {
        if ($i_0_lcssa_i_i >>> 0 < $233 >>> 0) {
         $j_069_i_i = $233; //@line 13435
         while (1) {
          $384 = $j_069_i_i - 1 | 0; //@line 13438
          $386 = HEAP8[$334 + $384 | 0] | 0; //@line 13440
          if (($386 << 24 >> 24 | 0) == 0) {
           $j_0_be_i_i = $j_069_i_i + 1 | 0; //@line 13443
          } else if (($386 << 24 >> 24 | 0) == 13 | ($386 << 24 >> 24 | 0) == 10) {
           $j_0_be_i_i = $384;
          } else {
           $j_0_lcssa_i_i = $j_069_i_i; //@line 13447
           break L14473;
          }
          if ($j_0_be_i_i >>> 0 > $i_0_lcssa_i_i >>> 0) {
           $j_069_i_i = $j_0_be_i_i; //@line 13454
          } else {
           $j_0_lcssa_i_i = $j_0_be_i_i; //@line 13456
           break;
          }
         }
        } else {
         $j_0_lcssa_i_i = $233; //@line 13461
        }
       } while (0);
       if (($i_0_lcssa_i_i | 0) == ($j_0_lcssa_i_i | 0)) {
        if ((_pri_read($fp, $223, 4) | 0) != 0) {
         break L14414;
        }
        if ((_pri_get_uint32_be($223, 0) | 0) == ($377 | 0)) {
         break;
        } else {
         label = 11550; //@line 13480
         break L14433;
        }
       }
       if ($i_0_lcssa_i_i >>> 0 < $j_0_lcssa_i_i >>> 0) {
        $k_066_i_i = $i_0_lcssa_i_i;
        $d_067_i_i = $i_0_lcssa_i_i;
        while (1) {
         $402 = HEAP8[$334 + $k_066_i_i | 0] | 0; //@line 13492
         do {
          if ($402 << 24 >> 24 == 13) {
           $405 = $k_066_i_i + 1 | 0; //@line 13497
           if ($405 >>> 0 < $j_0_lcssa_i_i >>> 0) {
            if ((HEAP8[$334 + $405 | 0] | 0) == 10) {
             $d_1_i_i = $d_067_i_i;
             $k_1_i_i = $405;
             break;
            }
           }
           HEAP8[$334 + $d_067_i_i | 0] = 10; //@line 13512
           $d_1_i_i = $d_067_i_i + 1 | 0;
           $k_1_i_i = $k_066_i_i;
          } else {
           HEAP8[$334 + $d_067_i_i | 0] = $402; //@line 13517
           $d_1_i_i = $d_067_i_i + 1 | 0;
           $k_1_i_i = $k_066_i_i;
          }
         } while (0);
         $418 = $k_1_i_i + 1 | 0; //@line 13523
         if ($418 >>> 0 < $j_0_lcssa_i_i >>> 0) {
          $k_066_i_i = $418;
          $d_067_i_i = $d_1_i_i;
         } else {
          $d_0_lcssa_i_i = $d_1_i_i; //@line 13529
          break;
         }
        }
       } else {
        $d_0_lcssa_i_i = $i_0_lcssa_i_i; //@line 13534
       }
       if ((HEAP32[$224 >> 2] | 0) != 0) {
        HEAP8[$c_i_i] = 10; //@line 13541
        if ((_pri_img_add_comment($1, $c_i_i, 1) | 0) != 0) {
         break L14414;
        }
       }
       $429 = (_pri_img_add_comment($1, $334 + $i_0_lcssa_i_i | 0, $d_0_lcssa_i_i - $i_0_lcssa_i_i | 0) | 0) == 0; //@line 13552
       _free($334); //@line 13553
       if (!$429) {
        break L14414;
       }
       if ((_pri_read($fp, $223, 4) | 0) != 0) {
        break L14414;
       }
       if ((_pri_get_uint32_be($223, 0) | 0) != ($377 | 0)) {
        label = 11562; //@line 13568
        break L14433;
       }
      } else if (($232 | 0) == 1414676811) {
       break L14436;
      } else {
       if ((_pbit_skip_chunk($fp, $233, $321) | 0) != 0) {
        break L14414;
       }
      }
     } while (0);
     if ((_pri_read($fp, $4, 8) | 0) != 0) {
      break L14414;
     }
    }
    if ($233 >>> 0 < 20) {
     break L14414;
    }
    if ((_pri_read($fp, $225, 20) | 0) != 0) {
     break L14414;
    }
    if (HEAP8[6704] | 0) {
     $_01011_i_i78_i = 20;
     $_012_i_i77_i = $321;
     $src_013_i_i76_i = $225;
    } else {
     $i_017_i_i65_i = 0; //@line 13605
     do {
      $446 = $i_017_i_i65_i << 25; //@line 13610
      $reg_1_i_i67_i = ($i_017_i_i65_i & 128 | 0) != 0 ? $446 ^ 517762881 : $446; //@line 13612
      $449 = $reg_1_i_i67_i << 1; //@line 13614
      $reg_1_1_i_i68_i = ($reg_1_i_i67_i | 0) < 0 ? $449 ^ 517762881 : $449; //@line 13616
      $452 = $reg_1_1_i_i68_i << 1; //@line 13618
      $reg_1_2_i_i69_i = ($reg_1_1_i_i68_i | 0) < 0 ? $452 ^ 517762881 : $452; //@line 13620
      $455 = $reg_1_2_i_i69_i << 1; //@line 13622
      $reg_1_3_i_i70_i = ($reg_1_2_i_i69_i | 0) < 0 ? $455 ^ 517762881 : $455; //@line 13624
      $458 = $reg_1_3_i_i70_i << 1; //@line 13626
      $reg_1_4_i_i71_i = ($reg_1_3_i_i70_i | 0) < 0 ? $458 ^ 517762881 : $458; //@line 13628
      $461 = $reg_1_4_i_i71_i << 1; //@line 13630
      $reg_1_5_i_i72_i = ($reg_1_4_i_i71_i | 0) < 0 ? $461 ^ 517762881 : $461; //@line 13632
      $464 = $reg_1_5_i_i72_i << 1; //@line 13634
      $reg_1_6_i_i73_i = ($reg_1_5_i_i72_i | 0) < 0 ? $464 ^ 517762881 : $464; //@line 13636
      $467 = $reg_1_6_i_i73_i << 1; //@line 13638
      HEAP32[61320 + ($i_017_i_i65_i << 2) >> 2] = ($reg_1_6_i_i73_i | 0) < 0 ? $467 ^ 517762881 : $467; //@line 13642
      $i_017_i_i65_i = $i_017_i_i65_i + 1 | 0; //@line 13643
     } while ($i_017_i_i65_i >>> 0 < 256);
     HEAP8[6704] = 1; //@line 13652
     $_01011_i_i78_i = 20;
     $_012_i_i77_i = $321;
     $src_013_i_i76_i = $225;
    }
    while (1) {
     $481 = HEAP32[61320 + ((HEAPU8[$src_013_i_i76_i] ^ $_012_i_i77_i >>> 24) << 2) >> 2] ^ $_012_i_i77_i << 8; //@line 13668
     $482 = $_01011_i_i78_i - 1 | 0; //@line 13669
     if (($482 | 0) == 0) {
      break;
     } else {
      $_01011_i_i78_i = $482;
      $_012_i_i77_i = $481;
      $src_013_i_i76_i = $src_013_i_i76_i + 1 | 0;
     }
    }
    $485 = _pri_get_uint32_be($225, 0) | 0; //@line 13679
    $486 = _pri_get_uint32_be($225, 4) | 0; //@line 13680
    $487 = _pri_get_uint32_be($225, 8) | 0; //@line 13681
    $488 = _pri_get_uint32_be($225, 12) | 0; //@line 13682
    $489 = _pri_img_get_track($1, $485, $486, 1) | 0; //@line 13683
    if (($489 | 0) == 0) {
     break L14414;
    }
    if ((_pri_trk_set_size($489, $487) | 0) != 0) {
     break L14414;
    }
    _pri_trk_set_clock($489, $488); //@line 13695
    $trk_0_ph_i = (_pbit_skip_chunk($fp, $233 - 20 | 0, $481) | 0) == 0 ? $489 : 0; //@line 13698
    if (($trk_0_ph_i | 0) == 0) {
     break L14414;
    }
   }
   if ((label | 0) == 11562) {
    $437 = HEAP32[_stderr >> 2] | 0; //@line 13708
    _fwrite(56664, 15, 1, $437 | 0) | 0; //@line 13709
    break;
   } else if ((label | 0) == 11582) {
    if ((_pbit_skip_chunk($fp, $233, $321) | 0) == 0) {
     $_0 = $1; //@line 13718
    } else {
     break;
    }
    STACKTOP = sp; //@line 13723
    return $_0 | 0; //@line 13724
   } else if ((label | 0) == 11550) {
    _fwrite(56664, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 13728
    break;
   } else if ((label | 0) == 11535) {
    _free($334); //@line 13733
    break;
   } else if ((label | 0) == 11532) {
    _fwrite(56664, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 13739
    break;
   }
  }
 } while (0);
 _pri_img_del($1); //@line 13745
 $_0 = 0; //@line 13747
 STACKTOP = sp; //@line 13749
 return $_0 | 0; //@line 13750
}
function _pri_save_pbit($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i54 = 0, $hdr_i = 0, $buf_i = 0, $1 = 0, $i_017_i_i = 0, $3 = 0, $reg_1_i_i = 0, $6 = 0, $reg_1_1_i_i = 0, $9 = 0, $reg_1_2_i_i = 0, $12 = 0, $reg_1_3_i_i = 0, $15 = 0, $reg_1_4_i_i = 0, $18 = 0, $reg_1_5_i_i = 0, $21 = 0, $reg_1_6_i_i = 0, $24 = 0, $src_013_i_i = 0, $_012_i_i = 0, $_01011_i_i = 0, $38 = 0, $39 = 0, $43 = 0, $45 = 0, $49 = 0, $52 = 0, $i_073_i = 0, $55 = 0, $i_0_lcssa_i = 0, $i_0_be_i = 0, $i_169_i = 0, $j_068_i = 0, $60 = 0, $63 = 0, $j_1_i = 0, $i_2_i = 0, $76 = 0, $j_265_i = 0, $78 = 0, $80 = 0, $j_2_lcssa_i = 0, $84 = 0, $i_017_i_i20 = 0, $87 = 0, $reg_1_i_i22 = 0, $90 = 0, $reg_1_1_i_i23 = 0, $93 = 0, $reg_1_2_i_i24 = 0, $96 = 0, $reg_1_3_i_i25 = 0, $99 = 0, $reg_1_4_i_i26 = 0, $102 = 0, $reg_1_5_i_i27 = 0, $105 = 0, $reg_1_6_i_i28 = 0, $108 = 0, $118 = 0, $127 = 0, $136 = 0, $145 = 0, $154 = 0, $163 = 0, $172 = 0, $180 = 0, $i_017_i47_i = 0, $185 = 0, $reg_1_i49_i = 0, $188 = 0, $reg_1_1_i50_i = 0, $191 = 0, $reg_1_2_i51_i = 0, $194 = 0, $reg_1_3_i52_i = 0, $197 = 0, $reg_1_4_i53_i = 0, $200 = 0, $reg_1_5_i54_i = 0, $203 = 0, $reg_1_6_i55_i = 0, $206 = 0, $src_013_i59_i = 0, $_012_i60_i = 0, $_01011_i61_i = 0, $221 = 0, $222 = 0, $_0_lcssa_i_i = 0, $227 = 0, $228 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $c_075 = 0, $241 = 0, $243 = 0, $246 = 0, $h_074 = 0, $249 = 0, $252 = 0, $i_017_i_i35 = 0, $257 = 0, $reg_1_i_i37 = 0, $260 = 0, $reg_1_1_i_i38 = 0, $263 = 0, $reg_1_2_i_i39 = 0, $266 = 0, $reg_1_3_i_i40 = 0, $269 = 0, $reg_1_4_i_i41 = 0, $272 = 0, $reg_1_5_i_i42 = 0, $275 = 0, $reg_1_6_i_i43 = 0, $278 = 0, $src_013_i_i46 = 0, $_012_i_i47 = 0, $_01011_i_i48 = 0, $292 = 0, $293 = 0, $298 = 0, $302 = 0, $i_017_i35_i = 0, $304 = 0, $reg_1_i37_i = 0, $307 = 0, $reg_1_1_i38_i = 0, $310 = 0, $reg_1_2_i39_i = 0, $313 = 0, $reg_1_3_i40_i = 0, $316 = 0, $reg_1_4_i41_i = 0, $319 = 0, $reg_1_5_i42_i = 0, $322 = 0, $reg_1_6_i43_i = 0, $325 = 0, $334 = 0, $342 = 0, $350 = 0, $358 = 0, $366 = 0, $374 = 0, $382 = 0, $390 = 0, $394 = 0, $395 = 0, $i_017_i17_i = 0, $397 = 0, $reg_1_i19_i = 0, $400 = 0, $reg_1_1_i20_i = 0, $403 = 0, $reg_1_2_i21_i = 0, $406 = 0, $reg_1_3_i22_i = 0, $409 = 0, $reg_1_4_i23_i = 0, $412 = 0, $reg_1_5_i24_i = 0, $415 = 0, $reg_1_6_i25_i = 0, $418 = 0, $src_013_i29_i = 0, $_012_i30_i = 0, $_01011_i31_i = 0, $433 = 0, $434 = 0, $_0_lcssa_i_i50 = 0, $443 = 0, $444 = 0, $446 = 0, $i_017_i_i56 = 0, $448 = 0, $reg_1_i_i58 = 0, $451 = 0, $reg_1_1_i_i59 = 0, $454 = 0, $reg_1_2_i_i60 = 0, $457 = 0, $reg_1_3_i_i61 = 0, $460 = 0, $reg_1_4_i_i62 = 0, $463 = 0, $reg_1_5_i_i63 = 0, $466 = 0, $reg_1_6_i_i64 = 0, $469 = 0, $479 = 0, $488 = 0, $497 = 0, $506 = 0, $515 = 0, $524 = 0, $533 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 13838
 STACKTOP = STACKTOP + 56 | 0; //@line 13838
 $buf_i54 = sp | 0; //@line 13839
 $hdr_i = sp + 16 | 0; //@line 13840
 $buf_i = sp + 24 | 0; //@line 13841
 $1 = $buf_i | 0; //@line 13842
 _pri_set_uint32_be($1, 0, 1346521428); //@line 13843
 _pri_set_uint32_be($1, 4, 8); //@line 13844
 _pri_set_uint32_be($1, 8, 0); //@line 13845
 _pri_set_uint32_be($1, 12, 0); //@line 13846
 if (HEAP8[6704] | 0) {
  $_01011_i_i = 16;
  $_012_i_i = 0;
  $src_013_i_i = $1;
 } else {
  $i_017_i_i = 0; //@line 13852
  do {
   $3 = $i_017_i_i << 25; //@line 13857
   $reg_1_i_i = ($i_017_i_i & 128 | 0) != 0 ? $3 ^ 517762881 : $3; //@line 13859
   $6 = $reg_1_i_i << 1; //@line 13861
   $reg_1_1_i_i = ($reg_1_i_i | 0) < 0 ? $6 ^ 517762881 : $6; //@line 13863
   $9 = $reg_1_1_i_i << 1; //@line 13865
   $reg_1_2_i_i = ($reg_1_1_i_i | 0) < 0 ? $9 ^ 517762881 : $9; //@line 13867
   $12 = $reg_1_2_i_i << 1; //@line 13869
   $reg_1_3_i_i = ($reg_1_2_i_i | 0) < 0 ? $12 ^ 517762881 : $12; //@line 13871
   $15 = $reg_1_3_i_i << 1; //@line 13873
   $reg_1_4_i_i = ($reg_1_3_i_i | 0) < 0 ? $15 ^ 517762881 : $15; //@line 13875
   $18 = $reg_1_4_i_i << 1; //@line 13877
   $reg_1_5_i_i = ($reg_1_4_i_i | 0) < 0 ? $18 ^ 517762881 : $18; //@line 13879
   $21 = $reg_1_5_i_i << 1; //@line 13881
   $reg_1_6_i_i = ($reg_1_5_i_i | 0) < 0 ? $21 ^ 517762881 : $21; //@line 13883
   $24 = $reg_1_6_i_i << 1; //@line 13885
   HEAP32[61320 + ($i_017_i_i << 2) >> 2] = ($reg_1_6_i_i | 0) < 0 ? $24 ^ 517762881 : $24; //@line 13889
   $i_017_i_i = $i_017_i_i + 1 | 0; //@line 13890
  } while ($i_017_i_i >>> 0 < 256);
  HEAP8[6704] = 1; //@line 13899
  $_01011_i_i = 16;
  $_012_i_i = 0;
  $src_013_i_i = $1;
 }
 while (1) {
  $38 = HEAP32[61320 + ((HEAPU8[$src_013_i_i] ^ $_012_i_i >>> 24) << 2) >> 2] ^ $_012_i_i << 8; //@line 13915
  $39 = $_01011_i_i - 1 | 0; //@line 13916
  if (($39 | 0) == 0) {
   break;
  } else {
   $_01011_i_i = $39;
   $_012_i_i = $38;
   $src_013_i_i = $src_013_i_i + 1 | 0;
  }
 }
 _pri_set_uint32_be($1, 16, $38); //@line 13925
 if ((_pri_write($fp, $1, 20) | 0) != 0) {
  $_0 = 1; //@line 13930
  STACKTOP = sp; //@line 13932
  return $_0 | 0; //@line 13933
 }
 $43 = $hdr_i | 0; //@line 13935
 $45 = HEAP32[$img + 8 >> 2] | 0; //@line 13937
 L14534 : do {
  if (($45 | 0) != 0) {
   $49 = _malloc($45 + 2 | 0) | 0; //@line 13943
   if (($49 | 0) == 0) {
    $_0 = 1; //@line 13947
    STACKTOP = sp; //@line 13949
    return $_0 | 0; //@line 13950
   }
   $52 = HEAP32[$img + 12 >> 2] | 0; //@line 13953
   HEAP8[$49] = 10; //@line 13954
   $i_073_i = 0; //@line 13956
   while (1) {
    $55 = HEAP8[$52 + $i_073_i | 0] | 0; //@line 13960
    if (!(($55 << 24 >> 24 | 0) == 13 | ($55 << 24 >> 24 | 0) == 10 | ($55 << 24 >> 24 | 0) == 0)) {
     $i_0_lcssa_i = $i_073_i; //@line 13962
     break;
    }
    $i_0_be_i = $i_073_i + 1 | 0; //@line 13965
    if ($i_0_be_i >>> 0 < $45 >>> 0) {
     $i_073_i = $i_0_be_i; //@line 13969
    } else {
     $i_0_lcssa_i = $i_0_be_i; //@line 13971
     break;
    }
   }
   do {
    if ($i_0_lcssa_i >>> 0 < $45 >>> 0) {
     $j_068_i = 1;
     $i_169_i = $i_0_lcssa_i;
     while (1) {
      $60 = HEAP8[$52 + $i_169_i | 0] | 0; //@line 13985
      do {
       if ($60 << 24 >> 24 == 13) {
        $63 = $i_169_i + 1 | 0; //@line 13990
        if ($63 >>> 0 < $45 >>> 0) {
         if ((HEAP8[$52 + $63 | 0] | 0) == 10) {
          $i_2_i = $63;
          $j_1_i = $j_068_i;
          break;
         }
        }
        HEAP8[$49 + $j_068_i | 0] = 10; //@line 14005
        $i_2_i = $i_169_i;
        $j_1_i = $j_068_i + 1 | 0;
       } else {
        HEAP8[$49 + $j_068_i | 0] = $60; //@line 14010
        $i_2_i = $i_169_i;
        $j_1_i = $j_068_i + 1 | 0;
       }
      } while (0);
      $76 = $i_2_i + 1 | 0; //@line 14016
      if ($76 >>> 0 < $45 >>> 0) {
       $j_068_i = $j_1_i;
       $i_169_i = $76;
      } else {
       break;
      }
     }
     L14554 : do {
      if ($j_1_i >>> 0 > 1) {
       $j_265_i = $j_1_i; //@line 14029
       while (1) {
        $78 = $j_265_i - 1 | 0; //@line 14032
        $80 = HEAP8[$49 + $78 | 0] | 0; //@line 14034
        if (!(($80 << 24 >> 24 | 0) == 10 | ($80 << 24 >> 24 | 0) == 0)) {
         $j_2_lcssa_i = $j_265_i; //@line 14036
         break L14554;
        }
        if ($78 >>> 0 > 1) {
         $j_265_i = $78; //@line 14042
        } else {
         $j_2_lcssa_i = $78; //@line 14044
         break;
        }
       }
      } else {
       $j_2_lcssa_i = $j_1_i; //@line 14049
      }
     } while (0);
     if (($j_2_lcssa_i | 0) == 1) {
      break;
     }
     $84 = $j_2_lcssa_i + 1 | 0; //@line 14058
     HEAP8[$49 + $j_2_lcssa_i | 0] = 10; //@line 14060
     _pri_set_uint32_be($43, 0, 1413830740); //@line 14061
     _pri_set_uint32_be($43, 4, $84); //@line 14062
     if (!(HEAP8[6704] | 0)) {
      $i_017_i_i20 = 0; //@line 14066
      do {
       $87 = $i_017_i_i20 << 25; //@line 14071
       $reg_1_i_i22 = ($i_017_i_i20 & 128 | 0) != 0 ? $87 ^ 517762881 : $87; //@line 14073
       $90 = $reg_1_i_i22 << 1; //@line 14075
       $reg_1_1_i_i23 = ($reg_1_i_i22 | 0) < 0 ? $90 ^ 517762881 : $90; //@line 14077
       $93 = $reg_1_1_i_i23 << 1; //@line 14079
       $reg_1_2_i_i24 = ($reg_1_1_i_i23 | 0) < 0 ? $93 ^ 517762881 : $93; //@line 14081
       $96 = $reg_1_2_i_i24 << 1; //@line 14083
       $reg_1_3_i_i25 = ($reg_1_2_i_i24 | 0) < 0 ? $96 ^ 517762881 : $96; //@line 14085
       $99 = $reg_1_3_i_i25 << 1; //@line 14087
       $reg_1_4_i_i26 = ($reg_1_3_i_i25 | 0) < 0 ? $99 ^ 517762881 : $99; //@line 14089
       $102 = $reg_1_4_i_i26 << 1; //@line 14091
       $reg_1_5_i_i27 = ($reg_1_4_i_i26 | 0) < 0 ? $102 ^ 517762881 : $102; //@line 14093
       $105 = $reg_1_5_i_i27 << 1; //@line 14095
       $reg_1_6_i_i28 = ($reg_1_5_i_i27 | 0) < 0 ? $105 ^ 517762881 : $105; //@line 14097
       $108 = $reg_1_6_i_i28 << 1; //@line 14099
       HEAP32[61320 + ($i_017_i_i20 << 2) >> 2] = ($reg_1_6_i_i28 | 0) < 0 ? $108 ^ 517762881 : $108; //@line 14103
       $i_017_i_i20 = $i_017_i_i20 + 1 | 0; //@line 14104
      } while ($i_017_i_i20 >>> 0 < 256);
      HEAP8[6704] = 1; //@line 14113
     }
     $118 = HEAP32[61320 + (HEAPU8[$43] << 2) >> 2] | 0; //@line 14120
     $127 = HEAP32[61320 + ((HEAPU8[$hdr_i + 1 | 0] ^ $118 >>> 24) << 2) >> 2] ^ $118 << 8; //@line 14129
     $136 = HEAP32[61320 + ((HEAPU8[$hdr_i + 2 | 0] ^ $127 >>> 24) << 2) >> 2] ^ $127 << 8; //@line 14138
     $145 = HEAP32[61320 + ((HEAPU8[$hdr_i + 3 | 0] ^ $136 >>> 24) << 2) >> 2] ^ $136 << 8; //@line 14147
     $154 = HEAP32[61320 + ((HEAPU8[$hdr_i + 4 | 0] ^ $145 >>> 24) << 2) >> 2] ^ $145 << 8; //@line 14156
     $163 = HEAP32[61320 + ((HEAPU8[$hdr_i + 5 | 0] ^ $154 >>> 24) << 2) >> 2] ^ $154 << 8; //@line 14165
     $172 = HEAP32[61320 + ((HEAPU8[$hdr_i + 6 | 0] ^ $163 >>> 24) << 2) >> 2] ^ $163 << 8; //@line 14174
     $180 = HEAP32[61320 + ((HEAPU8[$hdr_i + 7 | 0] ^ $172 >>> 24) << 2) >> 2] ^ $172 << 8; //@line 14182
     if ((_pri_write($fp, $43, 8) | 0) != 0) {
      $_0 = 1; //@line 14187
      STACKTOP = sp; //@line 14189
      return $_0 | 0; //@line 14190
     }
     if (!(HEAP8[6704] | 0)) {
      $i_017_i47_i = 0; //@line 14195
      do {
       $185 = $i_017_i47_i << 25; //@line 14200
       $reg_1_i49_i = ($i_017_i47_i & 128 | 0) != 0 ? $185 ^ 517762881 : $185; //@line 14202
       $188 = $reg_1_i49_i << 1; //@line 14204
       $reg_1_1_i50_i = ($reg_1_i49_i | 0) < 0 ? $188 ^ 517762881 : $188; //@line 14206
       $191 = $reg_1_1_i50_i << 1; //@line 14208
       $reg_1_2_i51_i = ($reg_1_1_i50_i | 0) < 0 ? $191 ^ 517762881 : $191; //@line 14210
       $194 = $reg_1_2_i51_i << 1; //@line 14212
       $reg_1_3_i52_i = ($reg_1_2_i51_i | 0) < 0 ? $194 ^ 517762881 : $194; //@line 14214
       $197 = $reg_1_3_i52_i << 1; //@line 14216
       $reg_1_4_i53_i = ($reg_1_3_i52_i | 0) < 0 ? $197 ^ 517762881 : $197; //@line 14218
       $200 = $reg_1_4_i53_i << 1; //@line 14220
       $reg_1_5_i54_i = ($reg_1_4_i53_i | 0) < 0 ? $200 ^ 517762881 : $200; //@line 14222
       $203 = $reg_1_5_i54_i << 1; //@line 14224
       $reg_1_6_i55_i = ($reg_1_5_i54_i | 0) < 0 ? $203 ^ 517762881 : $203; //@line 14226
       $206 = $reg_1_6_i55_i << 1; //@line 14228
       HEAP32[61320 + ($i_017_i47_i << 2) >> 2] = ($reg_1_6_i55_i | 0) < 0 ? $206 ^ 517762881 : $206; //@line 14232
       $i_017_i47_i = $i_017_i47_i + 1 | 0; //@line 14233
      } while ($i_017_i47_i >>> 0 < 256);
      HEAP8[6704] = 1; //@line 14242
     }
     if (($84 | 0) == 0) {
      $_0_lcssa_i_i = $180; //@line 14248
     } else {
      $_01011_i61_i = $84;
      $_012_i60_i = $180;
      $src_013_i59_i = $49;
      while (1) {
       $221 = HEAP32[61320 + ((HEAPU8[$src_013_i59_i] ^ $_012_i60_i >>> 24) << 2) >> 2] ^ $_012_i60_i << 8; //@line 14263
       $222 = $_01011_i61_i - 1 | 0; //@line 14264
       if (($222 | 0) == 0) {
        $_0_lcssa_i_i = $221; //@line 14268
        break;
       } else {
        $_01011_i61_i = $222;
        $_012_i60_i = $221;
        $src_013_i59_i = $src_013_i59_i + 1 | 0;
       }
      }
     }
     if ((_pri_write($fp, $49, $84) | 0) != 0) {
      $_0 = 1; //@line 14280
      STACKTOP = sp; //@line 14282
      return $_0 | 0; //@line 14283
     }
     _pri_set_uint32_be($43, 0, $_0_lcssa_i_i); //@line 14285
     if ((_pri_write($fp, $43, 4) | 0) == 0) {
      break L14534;
     } else {
      $_0 = 1; //@line 14292
     }
     STACKTOP = sp; //@line 14295
     return $_0 | 0; //@line 14296
    }
   } while (0);
   _free($49); //@line 14299
  }
 } while (0);
 $227 = $img | 0; //@line 14303
 $228 = HEAP32[$227 >> 2] | 0; //@line 14304
 L14583 : do {
  if (($228 | 0) != 0) {
   $230 = $img + 4 | 0; //@line 14309
   $231 = $buf_i + 1 | 0; //@line 14310
   $232 = $buf_i + 2 | 0; //@line 14311
   $233 = $buf_i + 3 | 0; //@line 14312
   $234 = $buf_i + 4 | 0; //@line 14313
   $235 = $buf_i + 5 | 0; //@line 14314
   $236 = $buf_i + 6 | 0; //@line 14315
   $237 = $buf_i + 7 | 0; //@line 14316
   $c_075 = 0;
   $238 = $228;
   L14585 : while (1) {
    $241 = HEAP32[(HEAP32[$230 >> 2] | 0) + ($c_075 << 2) >> 2] | 0; //@line 14324
    do {
     if (($241 | 0) == 0) {
      $443 = $238; //@line 14329
     } else {
      $243 = $241 | 0; //@line 14331
      if ((HEAP32[$243 >> 2] | 0) == 0) {
       $443 = $238; //@line 14336
       break;
      }
      $246 = $241 + 4 | 0; //@line 14339
      $h_074 = 0; //@line 14341
      do {
       $249 = HEAP32[(HEAP32[$246 >> 2] | 0) + ($h_074 << 2) >> 2] | 0; //@line 14346
       do {
        if (($249 | 0) != 0) {
         _pri_set_uint32_be($1, 0, 1414676811); //@line 14351
         _pri_set_uint32_be($1, 4, 20); //@line 14352
         _pri_set_uint32_be($1, 8, $c_075); //@line 14353
         _pri_set_uint32_be($1, 12, $h_074); //@line 14354
         $252 = $249 + 4 | 0; //@line 14355
         _pri_set_uint32_be($1, 16, HEAP32[$252 >> 2] | 0); //@line 14357
         _pri_set_uint32_be($1, 20, HEAP32[$249 >> 2] | 0); //@line 14360
         _pri_set_uint32_be($1, 24, 0); //@line 14361
         if (HEAP8[6704] | 0) {
          $_01011_i_i48 = 28;
          $_012_i_i47 = 0;
          $src_013_i_i46 = $1;
         } else {
          $i_017_i_i35 = 0; //@line 14367
          do {
           $257 = $i_017_i_i35 << 25; //@line 14372
           $reg_1_i_i37 = ($i_017_i_i35 & 128 | 0) != 0 ? $257 ^ 517762881 : $257; //@line 14374
           $260 = $reg_1_i_i37 << 1; //@line 14376
           $reg_1_1_i_i38 = ($reg_1_i_i37 | 0) < 0 ? $260 ^ 517762881 : $260; //@line 14378
           $263 = $reg_1_1_i_i38 << 1; //@line 14380
           $reg_1_2_i_i39 = ($reg_1_1_i_i38 | 0) < 0 ? $263 ^ 517762881 : $263; //@line 14382
           $266 = $reg_1_2_i_i39 << 1; //@line 14384
           $reg_1_3_i_i40 = ($reg_1_2_i_i39 | 0) < 0 ? $266 ^ 517762881 : $266; //@line 14386
           $269 = $reg_1_3_i_i40 << 1; //@line 14388
           $reg_1_4_i_i41 = ($reg_1_3_i_i40 | 0) < 0 ? $269 ^ 517762881 : $269; //@line 14390
           $272 = $reg_1_4_i_i41 << 1; //@line 14392
           $reg_1_5_i_i42 = ($reg_1_4_i_i41 | 0) < 0 ? $272 ^ 517762881 : $272; //@line 14394
           $275 = $reg_1_5_i_i42 << 1; //@line 14396
           $reg_1_6_i_i43 = ($reg_1_5_i_i42 | 0) < 0 ? $275 ^ 517762881 : $275; //@line 14398
           $278 = $reg_1_6_i_i43 << 1; //@line 14400
           HEAP32[61320 + ($i_017_i_i35 << 2) >> 2] = ($reg_1_6_i_i43 | 0) < 0 ? $278 ^ 517762881 : $278; //@line 14404
           $i_017_i_i35 = $i_017_i_i35 + 1 | 0; //@line 14405
          } while ($i_017_i_i35 >>> 0 < 256);
          HEAP8[6704] = 1; //@line 14414
          $_01011_i_i48 = 28;
          $_012_i_i47 = 0;
          $src_013_i_i46 = $1;
         }
         while (1) {
          $292 = HEAP32[61320 + ((HEAPU8[$src_013_i_i46] ^ $_012_i_i47 >>> 24) << 2) >> 2] ^ $_012_i_i47 << 8; //@line 14430
          $293 = $_01011_i_i48 - 1 | 0; //@line 14431
          if (($293 | 0) == 0) {
           break;
          } else {
           $_01011_i_i48 = $293;
           $_012_i_i47 = $292;
           $src_013_i_i46 = $src_013_i_i46 + 1 | 0;
          }
         }
         _pri_set_uint32_be($1, 28, $292); //@line 14440
         if ((_pri_write($fp, $1, 32) | 0) != 0) {
          $_0 = 1; //@line 14445
          label = 11661; //@line 14446
          break L14585;
         }
         $298 = HEAP32[$252 >> 2] | 0; //@line 14449
         if (($298 | 0) == 0) {
          break;
         }
         $302 = ($298 + 7 | 0) >>> 3; //@line 14456
         _pri_set_uint32_be($1, 0, 1145132097); //@line 14457
         _pri_set_uint32_be($1, 4, $302); //@line 14458
         if (!(HEAP8[6704] | 0)) {
          $i_017_i35_i = 0; //@line 14462
          do {
           $304 = $i_017_i35_i << 25; //@line 14467
           $reg_1_i37_i = ($i_017_i35_i & 128 | 0) != 0 ? $304 ^ 517762881 : $304; //@line 14469
           $307 = $reg_1_i37_i << 1; //@line 14471
           $reg_1_1_i38_i = ($reg_1_i37_i | 0) < 0 ? $307 ^ 517762881 : $307; //@line 14473
           $310 = $reg_1_1_i38_i << 1; //@line 14475
           $reg_1_2_i39_i = ($reg_1_1_i38_i | 0) < 0 ? $310 ^ 517762881 : $310; //@line 14477
           $313 = $reg_1_2_i39_i << 1; //@line 14479
           $reg_1_3_i40_i = ($reg_1_2_i39_i | 0) < 0 ? $313 ^ 517762881 : $313; //@line 14481
           $316 = $reg_1_3_i40_i << 1; //@line 14483
           $reg_1_4_i41_i = ($reg_1_3_i40_i | 0) < 0 ? $316 ^ 517762881 : $316; //@line 14485
           $319 = $reg_1_4_i41_i << 1; //@line 14487
           $reg_1_5_i42_i = ($reg_1_4_i41_i | 0) < 0 ? $319 ^ 517762881 : $319; //@line 14489
           $322 = $reg_1_5_i42_i << 1; //@line 14491
           $reg_1_6_i43_i = ($reg_1_5_i42_i | 0) < 0 ? $322 ^ 517762881 : $322; //@line 14493
           $325 = $reg_1_6_i43_i << 1; //@line 14495
           HEAP32[61320 + ($i_017_i35_i << 2) >> 2] = ($reg_1_6_i43_i | 0) < 0 ? $325 ^ 517762881 : $325; //@line 14499
           $i_017_i35_i = $i_017_i35_i + 1 | 0; //@line 14500
          } while ($i_017_i35_i >>> 0 < 256);
          HEAP8[6704] = 1; //@line 14509
         }
         $334 = HEAP32[61320 + (HEAPU8[$1] << 2) >> 2] | 0; //@line 14515
         $342 = HEAP32[61320 + ((HEAPU8[$231] ^ $334 >>> 24) << 2) >> 2] ^ $334 << 8; //@line 14523
         $350 = HEAP32[61320 + ((HEAPU8[$232] ^ $342 >>> 24) << 2) >> 2] ^ $342 << 8; //@line 14531
         $358 = HEAP32[61320 + ((HEAPU8[$233] ^ $350 >>> 24) << 2) >> 2] ^ $350 << 8; //@line 14539
         $366 = HEAP32[61320 + ((HEAPU8[$234] ^ $358 >>> 24) << 2) >> 2] ^ $358 << 8; //@line 14547
         $374 = HEAP32[61320 + ((HEAPU8[$235] ^ $366 >>> 24) << 2) >> 2] ^ $366 << 8; //@line 14555
         $382 = HEAP32[61320 + ((HEAPU8[$236] ^ $374 >>> 24) << 2) >> 2] ^ $374 << 8; //@line 14563
         $390 = HEAP32[61320 + ((HEAPU8[$237] ^ $382 >>> 24) << 2) >> 2] ^ $382 << 8; //@line 14571
         if ((_pri_write($fp, $1, 8) | 0) != 0) {
          $_0 = 1; //@line 14576
          label = 11662; //@line 14577
          break L14585;
         }
         $394 = $249 + 8 | 0; //@line 14580
         $395 = HEAP32[$394 >> 2] | 0; //@line 14581
         if (!(HEAP8[6704] | 0)) {
          $i_017_i17_i = 0; //@line 14585
          do {
           $397 = $i_017_i17_i << 25; //@line 14590
           $reg_1_i19_i = ($i_017_i17_i & 128 | 0) != 0 ? $397 ^ 517762881 : $397; //@line 14592
           $400 = $reg_1_i19_i << 1; //@line 14594
           $reg_1_1_i20_i = ($reg_1_i19_i | 0) < 0 ? $400 ^ 517762881 : $400; //@line 14596
           $403 = $reg_1_1_i20_i << 1; //@line 14598
           $reg_1_2_i21_i = ($reg_1_1_i20_i | 0) < 0 ? $403 ^ 517762881 : $403; //@line 14600
           $406 = $reg_1_2_i21_i << 1; //@line 14602
           $reg_1_3_i22_i = ($reg_1_2_i21_i | 0) < 0 ? $406 ^ 517762881 : $406; //@line 14604
           $409 = $reg_1_3_i22_i << 1; //@line 14606
           $reg_1_4_i23_i = ($reg_1_3_i22_i | 0) < 0 ? $409 ^ 517762881 : $409; //@line 14608
           $412 = $reg_1_4_i23_i << 1; //@line 14610
           $reg_1_5_i24_i = ($reg_1_4_i23_i | 0) < 0 ? $412 ^ 517762881 : $412; //@line 14612
           $415 = $reg_1_5_i24_i << 1; //@line 14614
           $reg_1_6_i25_i = ($reg_1_5_i24_i | 0) < 0 ? $415 ^ 517762881 : $415; //@line 14616
           $418 = $reg_1_6_i25_i << 1; //@line 14618
           HEAP32[61320 + ($i_017_i17_i << 2) >> 2] = ($reg_1_6_i25_i | 0) < 0 ? $418 ^ 517762881 : $418; //@line 14622
           $i_017_i17_i = $i_017_i17_i + 1 | 0; //@line 14623
          } while ($i_017_i17_i >>> 0 < 256);
          HEAP8[6704] = 1; //@line 14632
         }
         if (($302 | 0) == 0) {
          $_0_lcssa_i_i50 = $390; //@line 14638
         } else {
          $_01011_i31_i = $302;
          $_012_i30_i = $390;
          $src_013_i29_i = $395;
          while (1) {
           $433 = HEAP32[61320 + ((HEAPU8[$src_013_i29_i] ^ $_012_i30_i >>> 24) << 2) >> 2] ^ $_012_i30_i << 8; //@line 14653
           $434 = $_01011_i31_i - 1 | 0; //@line 14654
           if (($434 | 0) == 0) {
            $_0_lcssa_i_i50 = $433; //@line 14658
            break;
           } else {
            $_01011_i31_i = $434;
            $_012_i30_i = $433;
            $src_013_i29_i = $src_013_i29_i + 1 | 0;
           }
          }
         }
         if ((_pri_write($fp, HEAP32[$394 >> 2] | 0, $302) | 0) != 0) {
          $_0 = 1; //@line 14671
          label = 11660; //@line 14672
          break L14585;
         }
         _pri_set_uint32_be($1, 0, $_0_lcssa_i_i50); //@line 14675
         if ((_pri_write($fp, $1, 4) | 0) != 0) {
          $_0 = 1; //@line 14680
          label = 11656; //@line 14681
          break L14585;
         }
        }
       } while (0);
       $h_074 = $h_074 + 1 | 0; //@line 14686
      } while ($h_074 >>> 0 < (HEAP32[$243 >> 2] | 0) >>> 0);
      $443 = HEAP32[$227 >> 2] | 0; //@line 14698
     }
    } while (0);
    $444 = $c_075 + 1 | 0; //@line 14702
    if ($444 >>> 0 < $443 >>> 0) {
     $c_075 = $444;
     $238 = $443;
    } else {
     break L14583;
    }
   }
   if ((label | 0) == 11656) {
    STACKTOP = sp; //@line 14713
    return $_0 | 0; //@line 14714
   } else if ((label | 0) == 11660) {
    STACKTOP = sp; //@line 14718
    return $_0 | 0; //@line 14719
   } else if ((label | 0) == 11661) {
    STACKTOP = sp; //@line 14723
    return $_0 | 0; //@line 14724
   } else if ((label | 0) == 11662) {
    STACKTOP = sp; //@line 14728
    return $_0 | 0; //@line 14729
   }
  }
 } while (0);
 $446 = $buf_i54 | 0; //@line 14733
 _pri_set_uint32_be($446, 0, 1162757152); //@line 14734
 _pri_set_uint32_be($446, 4, 0); //@line 14735
 if (!(HEAP8[6704] | 0)) {
  $i_017_i_i56 = 0; //@line 14739
  do {
   $448 = $i_017_i_i56 << 25; //@line 14744
   $reg_1_i_i58 = ($i_017_i_i56 & 128 | 0) != 0 ? $448 ^ 517762881 : $448; //@line 14746
   $451 = $reg_1_i_i58 << 1; //@line 14748
   $reg_1_1_i_i59 = ($reg_1_i_i58 | 0) < 0 ? $451 ^ 517762881 : $451; //@line 14750
   $454 = $reg_1_1_i_i59 << 1; //@line 14752
   $reg_1_2_i_i60 = ($reg_1_1_i_i59 | 0) < 0 ? $454 ^ 517762881 : $454; //@line 14754
   $457 = $reg_1_2_i_i60 << 1; //@line 14756
   $reg_1_3_i_i61 = ($reg_1_2_i_i60 | 0) < 0 ? $457 ^ 517762881 : $457; //@line 14758
   $460 = $reg_1_3_i_i61 << 1; //@line 14760
   $reg_1_4_i_i62 = ($reg_1_3_i_i61 | 0) < 0 ? $460 ^ 517762881 : $460; //@line 14762
   $463 = $reg_1_4_i_i62 << 1; //@line 14764
   $reg_1_5_i_i63 = ($reg_1_4_i_i62 | 0) < 0 ? $463 ^ 517762881 : $463; //@line 14766
   $466 = $reg_1_5_i_i63 << 1; //@line 14768
   $reg_1_6_i_i64 = ($reg_1_5_i_i63 | 0) < 0 ? $466 ^ 517762881 : $466; //@line 14770
   $469 = $reg_1_6_i_i64 << 1; //@line 14772
   HEAP32[61320 + ($i_017_i_i56 << 2) >> 2] = ($reg_1_6_i_i64 | 0) < 0 ? $469 ^ 517762881 : $469; //@line 14776
   $i_017_i_i56 = $i_017_i_i56 + 1 | 0; //@line 14777
  } while ($i_017_i_i56 >>> 0 < 256);
  HEAP8[6704] = 1; //@line 14786
 }
 $479 = HEAP32[61320 + (HEAPU8[$446] << 2) >> 2] | 0; //@line 14793
 $488 = HEAP32[61320 + ((HEAPU8[$buf_i54 + 1 | 0] ^ $479 >>> 24) << 2) >> 2] ^ $479 << 8; //@line 14802
 $497 = HEAP32[61320 + ((HEAPU8[$buf_i54 + 2 | 0] ^ $488 >>> 24) << 2) >> 2] ^ $488 << 8; //@line 14811
 $506 = HEAP32[61320 + ((HEAPU8[$buf_i54 + 3 | 0] ^ $497 >>> 24) << 2) >> 2] ^ $497 << 8; //@line 14820
 $515 = HEAP32[61320 + ((HEAPU8[$buf_i54 + 4 | 0] ^ $506 >>> 24) << 2) >> 2] ^ $506 << 8; //@line 14829
 $524 = HEAP32[61320 + ((HEAPU8[$buf_i54 + 5 | 0] ^ $515 >>> 24) << 2) >> 2] ^ $515 << 8; //@line 14838
 $533 = HEAP32[61320 + ((HEAPU8[$buf_i54 + 6 | 0] ^ $524 >>> 24) << 2) >> 2] ^ $524 << 8; //@line 14847
 _pri_set_uint32_be($446, 8, HEAP32[61320 + ((HEAPU8[$buf_i54 + 7 | 0] ^ $533 >>> 24) << 2) >> 2] ^ $533 << 8); //@line 14856
 $_0 = (_pri_write($fp, $446, 12) | 0) != 0 | 0; //@line 14861
 STACKTOP = sp; //@line 14863
 return $_0 | 0; //@line 14864
}
function _pbit_skip_chunk($fp, $size, $crc) {
 $fp = $fp | 0;
 $size = $size | 0;
 $crc = $crc | 0;
 var $_pre = 0, $_01115 = 0, $_01214 = 0, $3 = 0, $i_017_i = 0, $8 = 0, $reg_1_i = 0, $11 = 0, $reg_1_1_i = 0, $14 = 0, $reg_1_2_i = 0, $17 = 0, $reg_1_3_i = 0, $20 = 0, $reg_1_4_i = 0, $23 = 0, $reg_1_5_i = 0, $26 = 0, $reg_1_6_i = 0, $29 = 0, $src_013_i = 0, $_012_i = 0, $_01011_i = 0, $44 = 0, $45 = 0, $_0_lcssa_i = 0, $_011_lcssa = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 14883
 STACKTOP = STACKTOP + 256 | 0; //@line 14883
 $_pre = sp | 0; //@line 14886
 L14635 : do {
  if (($size | 0) == 0) {
   $_011_lcssa = $crc; //@line 14890
  } else {
   $_01214 = $size;
   $_01115 = $crc;
   while (1) {
    $3 = $_01214 >>> 0 < 256 ? $_01214 : 256; //@line 14897
    if ((_pri_read($fp, $_pre, $3) | 0) != 0) {
     $_0 = 1; //@line 14902
     break;
    }
    if (!(HEAP8[6704] | 0)) {
     $i_017_i = 0; //@line 14908
     do {
      $8 = $i_017_i << 25; //@line 14913
      $reg_1_i = ($i_017_i & 128 | 0) != 0 ? $8 ^ 517762881 : $8; //@line 14915
      $11 = $reg_1_i << 1; //@line 14917
      $reg_1_1_i = ($reg_1_i | 0) < 0 ? $11 ^ 517762881 : $11; //@line 14919
      $14 = $reg_1_1_i << 1; //@line 14921
      $reg_1_2_i = ($reg_1_1_i | 0) < 0 ? $14 ^ 517762881 : $14; //@line 14923
      $17 = $reg_1_2_i << 1; //@line 14925
      $reg_1_3_i = ($reg_1_2_i | 0) < 0 ? $17 ^ 517762881 : $17; //@line 14927
      $20 = $reg_1_3_i << 1; //@line 14929
      $reg_1_4_i = ($reg_1_3_i | 0) < 0 ? $20 ^ 517762881 : $20; //@line 14931
      $23 = $reg_1_4_i << 1; //@line 14933
      $reg_1_5_i = ($reg_1_4_i | 0) < 0 ? $23 ^ 517762881 : $23; //@line 14935
      $26 = $reg_1_5_i << 1; //@line 14937
      $reg_1_6_i = ($reg_1_5_i | 0) < 0 ? $26 ^ 517762881 : $26; //@line 14939
      $29 = $reg_1_6_i << 1; //@line 14941
      HEAP32[61320 + ($i_017_i << 2) >> 2] = ($reg_1_6_i | 0) < 0 ? $29 ^ 517762881 : $29; //@line 14945
      $i_017_i = $i_017_i + 1 | 0; //@line 14946
     } while ($i_017_i >>> 0 < 256);
     HEAP8[6704] = 1; //@line 14955
    }
    if (($3 | 0) == 0) {
     $_0_lcssa_i = $_01115; //@line 14961
    } else {
     $_01011_i = $3;
     $_012_i = $_01115;
     $src_013_i = $_pre;
     while (1) {
      $44 = HEAP32[61320 + (((HEAPU8[$src_013_i] | 0) ^ $_012_i >>> 24) << 2) >> 2] ^ $_012_i << 8; //@line 14976
      $45 = $_01011_i - 1 | 0; //@line 14977
      if (($45 | 0) == 0) {
       $_0_lcssa_i = $44; //@line 14981
       break;
      } else {
       $_01011_i = $45;
       $_012_i = $44;
       $src_013_i = $src_013_i + 1 | 0;
      }
     }
    }
    if (($_01214 | 0) == ($3 | 0)) {
     $_011_lcssa = $_0_lcssa_i; //@line 14993
     break L14635;
    } else {
     $_01214 = $_01214 - $3 | 0;
     $_01115 = $_0_lcssa_i;
    }
   }
   STACKTOP = sp; //@line 15000
   return $_0 | 0; //@line 15001
  }
 } while (0);
 if ((_pri_read($fp, $_pre, 4) | 0) != 0) {
  $_0 = 1; //@line 15009
  STACKTOP = sp; //@line 15011
  return $_0 | 0; //@line 15012
 }
 if ((_pri_get_uint32_be($_pre, 0) | 0) == ($_011_lcssa | 0)) {
  $_0 = 0; //@line 15018
  STACKTOP = sp; //@line 15020
  return $_0 | 0; //@line 15021
 }
 _fwrite(56664, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 15024
 $_0 = 1; //@line 15026
 STACKTOP = sp; //@line 15028
 return $_0 | 0; //@line 15029
}
function _pri_load_pri($fp) {
 $fp = $fp | 0;
 var $buf_i80_i = 0, $buf_i_i_i = 0, $buf_i_i = 0, $buf_i = 0, $1 = 0, $4 = 0, $i_017_i_i = 0, $9 = 0, $reg_1_i_i = 0, $12 = 0, $reg_1_1_i_i = 0, $15 = 0, $reg_1_2_i_i = 0, $18 = 0, $reg_1_3_i_i = 0, $21 = 0, $reg_1_4_i_i = 0, $24 = 0, $reg_1_5_i_i = 0, $27 = 0, $reg_1_6_i_i = 0, $30 = 0, $36 = 0, $40 = 0, $42 = 0, $49 = 0, $51 = 0, $58 = 0, $66 = 0, $70 = 0, $i_017_i23_i = 0, $75 = 0, $reg_1_i25_i = 0, $78 = 0, $reg_1_1_i26_i = 0, $81 = 0, $reg_1_2_i27_i = 0, $84 = 0, $reg_1_3_i28_i = 0, $87 = 0, $reg_1_4_i29_i = 0, $90 = 0, $reg_1_5_i30_i = 0, $93 = 0, $reg_1_6_i31_i = 0, $96 = 0, $103 = 0, $110 = 0, $112 = 0, $119 = 0, $121 = 0, $128 = 0, $136 = 0, $137 = 0, $138 = 0, $i_017_i_i_i = 0, $145 = 0, $reg_1_i_i_i = 0, $148 = 0, $reg_1_1_i_i_i = 0, $151 = 0, $reg_1_2_i_i_i = 0, $154 = 0, $reg_1_3_i_i_i = 0, $157 = 0, $reg_1_4_i_i_i = 0, $160 = 0, $reg_1_5_i_i_i = 0, $163 = 0, $reg_1_6_i_i_i = 0, $166 = 0, $180 = 0, $189 = 0, $198 = 0, $206 = 0, $207 = 0, $210 = 0, $213 = 0, $214 = 0, $_08_i34_i_i = 0, $crc262833_i_i = 0, $217 = 0, $i_017_i5_i_i = 0, $222 = 0, $reg_1_i7_i_i = 0, $225 = 0, $reg_1_1_i8_i_i = 0, $228 = 0, $reg_1_2_i9_i_i = 0, $231 = 0, $reg_1_3_i10_i_i = 0, $234 = 0, $reg_1_4_i11_i_i = 0, $237 = 0, $reg_1_5_i12_i_i = 0, $240 = 0, $reg_1_6_i13_i_i = 0, $243 = 0, $src_013_i17_i_i = 0, $_012_i18_i_i = 0, $_01011_i19_i_i = 0, $258 = 0, $259 = 0, $crc2627_ph_i_i = 0, $crc2628_lcssa_i_i = 0, $268 = 0, $270 = 0, $i_017_i45_i = 0, $274 = 0, $reg_1_i47_i = 0, $277 = 0, $reg_1_1_i48_i = 0, $280 = 0, $reg_1_2_i49_i = 0, $283 = 0, $reg_1_3_i50_i = 0, $286 = 0, $reg_1_4_i51_i = 0, $289 = 0, $reg_1_5_i52_i = 0, $292 = 0, $reg_1_6_i53_i = 0, $295 = 0, $304 = 0, $312 = 0, $320 = 0, $328 = 0, $336 = 0, $344 = 0, $352 = 0, $360 = 0, $361 = 0, $362 = 0, $_08_i216_i = 0, $365 = 0, $367 = 0, $i_017_i147_i = 0, $372 = 0, $reg_1_i149_i = 0, $375 = 0, $reg_1_1_i150_i = 0, $378 = 0, $reg_1_2_i151_i = 0, $381 = 0, $reg_1_3_i152_i = 0, $384 = 0, $reg_1_4_i153_i = 0, $387 = 0, $reg_1_5_i154_i = 0, $390 = 0, $reg_1_6_i155_i = 0, $393 = 0, $src_013_i159_i = 0, $_012_i160_i = 0, $_01011_i161_i = 0, $408 = 0, $409 = 0, $_ph_i = 0, $_lcssa214_i = 0, $419 = 0, $433 = 0, $i_017_i_i67_i = 0, $440 = 0, $reg_1_i_i69_i = 0, $443 = 0, $reg_1_1_i_i70_i = 0, $446 = 0, $reg_1_2_i_i71_i = 0, $449 = 0, $reg_1_3_i_i72_i = 0, $452 = 0, $reg_1_4_i_i73_i = 0, $455 = 0, $reg_1_5_i_i74_i = 0, $458 = 0, $reg_1_6_i_i75_i = 0, $461 = 0, $src_013_i_i_i = 0, $_012_i_i_i = 0, $_01011_i_i_i = 0, $475 = 0, $476 = 0, $480 = 0, $_size_i_i = 0, $484 = 0, $n_1_i_i = 0, $490 = 0, $497 = 0, $_0_i23_i_i = 0, $i_017_i_i82_i = 0, $510 = 0, $reg_1_i_i84_i = 0, $513 = 0, $reg_1_1_i_i85_i = 0, $516 = 0, $reg_1_2_i_i86_i = 0, $519 = 0, $reg_1_3_i_i87_i = 0, $522 = 0, $reg_1_4_i_i88_i = 0, $525 = 0, $reg_1_5_i_i89_i = 0, $528 = 0, $reg_1_6_i_i90_i = 0, $531 = 0, $src_013_i_i93_i = 0, $_012_i_i94_i = 0, $_01011_i_i95_i = 0, $545 = 0, $546 = 0, $549 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $559 = 0, $_08_i42_i_i = 0, $crc343641_i_i = 0, $562 = 0, $i_017_i13_i_i = 0, $567 = 0, $reg_1_i15_i_i = 0, $570 = 0, $reg_1_1_i16_i_i = 0, $573 = 0, $reg_1_2_i17_i_i = 0, $576 = 0, $reg_1_3_i18_i_i = 0, $579 = 0, $reg_1_4_i19_i_i = 0, $582 = 0, $reg_1_5_i20_i_i = 0, $585 = 0, $reg_1_6_i21_i_i = 0, $588 = 0, $src_013_i25_i_i = 0, $_012_i26_i_i = 0, $_01011_i27_i_i = 0, $603 = 0, $604 = 0, $crc3435_ph_i_i = 0, $crc3436_lcssa_i_i = 0, $_ph235_i = 0, $615 = 0, $616 = 0, $617 = 0, $625 = 0, $size__i_i = 0, $627 = 0, $i_017_i_i102_i = 0, $632 = 0, $reg_1_i_i104_i = 0, $635 = 0, $reg_1_1_i_i105_i = 0, $638 = 0, $reg_1_2_i_i106_i = 0, $641 = 0, $reg_1_3_i_i107_i = 0, $644 = 0, $reg_1_4_i_i108_i = 0, $647 = 0, $reg_1_5_i_i109_i = 0, $650 = 0, $reg_1_6_i_i110_i = 0, $653 = 0, $src_013_i_i113_i = 0, $_012_i_i114_i = 0, $_01011_i_i115_i = 0, $668 = 0, $669 = 0, $crc27_ph_i_i = 0, $_08_i35_i_i = 0, $crc272934_i_i = 0, $675 = 0, $i_017_i5_i120_i = 0, $680 = 0, $reg_1_i7_i122_i = 0, $683 = 0, $reg_1_1_i8_i123_i = 0, $686 = 0, $reg_1_2_i9_i124_i = 0, $689 = 0, $reg_1_3_i10_i125_i = 0, $692 = 0, $reg_1_4_i11_i126_i = 0, $695 = 0, $reg_1_5_i12_i127_i = 0, $698 = 0, $reg_1_6_i13_i128_i = 0, $701 = 0, $src_013_i17_i132_i = 0, $_012_i18_i133_i = 0, $_01011_i19_i134_i = 0, $716 = 0, $717 = 0, $crc2728_ph_i_i = 0, $crc2729_lcssa_i_i = 0, $_08_i140229_i = 0, $731 = 0, $733 = 0, $i_017_i168_i = 0, $738 = 0, $reg_1_i170_i = 0, $741 = 0, $reg_1_1_i171_i = 0, $744 = 0, $reg_1_2_i172_i = 0, $747 = 0, $reg_1_3_i173_i = 0, $750 = 0, $reg_1_4_i174_i = 0, $753 = 0, $reg_1_5_i175_i = 0, $756 = 0, $reg_1_6_i176_i = 0, $759 = 0, $src_013_i180_i = 0, $_012_i181_i = 0, $_01011_i182_i = 0, $774 = 0, $775 = 0, $_ph211_i = 0, $_lcssa227_i = 0, $785 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 15151
 STACKTOP = STACKTOP + 288 | 0; //@line 15151
 $buf_i80_i = sp | 0; //@line 15152
 $buf_i_i_i = sp + 16 | 0; //@line 15153
 $buf_i_i = sp + 272 | 0; //@line 15154
 $buf_i = sp + 280 | 0; //@line 15155
 $1 = _pri_img_new() | 0; //@line 15156
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 15160
  STACKTOP = sp; //@line 15162
  return $_0 | 0; //@line 15163
 }
 $4 = $buf_i | 0; //@line 15165
 if ((_pri_read($fp, $4, 4) | 0) != 0) {
  $_0 = $1; //@line 15170
  STACKTOP = sp; //@line 15172
  return $_0 | 0; //@line 15173
 }
 if (!(HEAP8[6656] | 0)) {
  $i_017_i_i = 0; //@line 15178
  do {
   $9 = $i_017_i_i << 25; //@line 15183
   $reg_1_i_i = ($i_017_i_i & 128 | 0) != 0 ? $9 ^ 517762881 : $9; //@line 15185
   $12 = $reg_1_i_i << 1; //@line 15187
   $reg_1_1_i_i = ($reg_1_i_i | 0) < 0 ? $12 ^ 517762881 : $12; //@line 15189
   $15 = $reg_1_1_i_i << 1; //@line 15191
   $reg_1_2_i_i = ($reg_1_1_i_i | 0) < 0 ? $15 ^ 517762881 : $15; //@line 15193
   $18 = $reg_1_2_i_i << 1; //@line 15195
   $reg_1_3_i_i = ($reg_1_2_i_i | 0) < 0 ? $18 ^ 517762881 : $18; //@line 15197
   $21 = $reg_1_3_i_i << 1; //@line 15199
   $reg_1_4_i_i = ($reg_1_3_i_i | 0) < 0 ? $21 ^ 517762881 : $21; //@line 15201
   $24 = $reg_1_4_i_i << 1; //@line 15203
   $reg_1_5_i_i = ($reg_1_4_i_i | 0) < 0 ? $24 ^ 517762881 : $24; //@line 15205
   $27 = $reg_1_5_i_i << 1; //@line 15207
   $reg_1_6_i_i = ($reg_1_5_i_i | 0) < 0 ? $27 ^ 517762881 : $27; //@line 15209
   $30 = $reg_1_6_i_i << 1; //@line 15211
   HEAP32[59240 + ($i_017_i_i << 2) >> 2] = ($reg_1_6_i_i | 0) < 0 ? $30 ^ 517762881 : $30; //@line 15215
   $i_017_i_i = $i_017_i_i + 1 | 0; //@line 15216
  } while ($i_017_i_i >>> 0 < 256);
  HEAP8[6656] = 1; //@line 15225
 }
 $36 = $buf_i + 1 | 0; //@line 15228
 $40 = HEAP32[59240 + (HEAPU8[$4] << 2) >> 2] | 0; //@line 15232
 $42 = $buf_i + 2 | 0; //@line 15234
 $49 = HEAP32[59240 + ((HEAPU8[$36] ^ $40 >>> 24) << 2) >> 2] ^ $40 << 8; //@line 15241
 $51 = $buf_i + 3 | 0; //@line 15243
 $58 = HEAP32[59240 + ((HEAPU8[$42] ^ $49 >>> 24) << 2) >> 2] ^ $49 << 8; //@line 15250
 $66 = HEAP32[59240 + ((HEAPU8[$51] ^ $58 >>> 24) << 2) >> 2] ^ $58 << 8; //@line 15258
 L14669 : do {
  if ((_pri_get_uint32_be($4, 0) | 0) == 1347569952) {
   $70 = $buf_i + 4 | 0; //@line 15264
   if ((_pri_read($fp, $70, 4) | 0) != 0) {
    break;
   }
   if (!(HEAP8[6656] | 0)) {
    $i_017_i23_i = 0; //@line 15274
    do {
     $75 = $i_017_i23_i << 25; //@line 15279
     $reg_1_i25_i = ($i_017_i23_i & 128 | 0) != 0 ? $75 ^ 517762881 : $75; //@line 15281
     $78 = $reg_1_i25_i << 1; //@line 15283
     $reg_1_1_i26_i = ($reg_1_i25_i | 0) < 0 ? $78 ^ 517762881 : $78; //@line 15285
     $81 = $reg_1_1_i26_i << 1; //@line 15287
     $reg_1_2_i27_i = ($reg_1_1_i26_i | 0) < 0 ? $81 ^ 517762881 : $81; //@line 15289
     $84 = $reg_1_2_i27_i << 1; //@line 15291
     $reg_1_3_i28_i = ($reg_1_2_i27_i | 0) < 0 ? $84 ^ 517762881 : $84; //@line 15293
     $87 = $reg_1_3_i28_i << 1; //@line 15295
     $reg_1_4_i29_i = ($reg_1_3_i28_i | 0) < 0 ? $87 ^ 517762881 : $87; //@line 15297
     $90 = $reg_1_4_i29_i << 1; //@line 15299
     $reg_1_5_i30_i = ($reg_1_4_i29_i | 0) < 0 ? $90 ^ 517762881 : $90; //@line 15301
     $93 = $reg_1_5_i30_i << 1; //@line 15303
     $reg_1_6_i31_i = ($reg_1_5_i30_i | 0) < 0 ? $93 ^ 517762881 : $93; //@line 15305
     $96 = $reg_1_6_i31_i << 1; //@line 15307
     HEAP32[59240 + ($i_017_i23_i << 2) >> 2] = ($reg_1_6_i31_i | 0) < 0 ? $96 ^ 517762881 : $96; //@line 15311
     $i_017_i23_i = $i_017_i23_i + 1 | 0; //@line 15312
    } while ($i_017_i23_i >>> 0 < 256);
    HEAP8[6656] = 1; //@line 15321
   }
   $103 = $buf_i + 5 | 0; //@line 15325
   $110 = HEAP32[59240 + ((HEAPU8[$70] ^ $66 >>> 24) << 2) >> 2] ^ $66 << 8; //@line 15332
   $112 = $buf_i + 6 | 0; //@line 15334
   $119 = HEAP32[59240 + ((HEAPU8[$103] ^ $110 >>> 24) << 2) >> 2] ^ $110 << 8; //@line 15341
   $121 = $buf_i + 7 | 0; //@line 15343
   $128 = HEAP32[59240 + ((HEAPU8[$112] ^ $119 >>> 24) << 2) >> 2] ^ $119 << 8; //@line 15350
   $136 = HEAP32[59240 + ((HEAPU8[$121] ^ $128 >>> 24) << 2) >> 2] ^ $128 << 8; //@line 15358
   $137 = _pri_get_uint32_be($4, 4) | 0; //@line 15359
   $138 = $buf_i_i | 0; //@line 15360
   if ($137 >>> 0 < 4) {
    break;
   }
   if ((_pri_read($fp, $138, 4) | 0) != 0) {
    break;
   }
   if (!(HEAP8[6656] | 0)) {
    $i_017_i_i_i = 0; //@line 15375
    do {
     $145 = $i_017_i_i_i << 25; //@line 15380
     $reg_1_i_i_i = ($i_017_i_i_i & 128 | 0) != 0 ? $145 ^ 517762881 : $145; //@line 15382
     $148 = $reg_1_i_i_i << 1; //@line 15384
     $reg_1_1_i_i_i = ($reg_1_i_i_i | 0) < 0 ? $148 ^ 517762881 : $148; //@line 15386
     $151 = $reg_1_1_i_i_i << 1; //@line 15388
     $reg_1_2_i_i_i = ($reg_1_1_i_i_i | 0) < 0 ? $151 ^ 517762881 : $151; //@line 15390
     $154 = $reg_1_2_i_i_i << 1; //@line 15392
     $reg_1_3_i_i_i = ($reg_1_2_i_i_i | 0) < 0 ? $154 ^ 517762881 : $154; //@line 15394
     $157 = $reg_1_3_i_i_i << 1; //@line 15396
     $reg_1_4_i_i_i = ($reg_1_3_i_i_i | 0) < 0 ? $157 ^ 517762881 : $157; //@line 15398
     $160 = $reg_1_4_i_i_i << 1; //@line 15400
     $reg_1_5_i_i_i = ($reg_1_4_i_i_i | 0) < 0 ? $160 ^ 517762881 : $160; //@line 15402
     $163 = $reg_1_5_i_i_i << 1; //@line 15404
     $reg_1_6_i_i_i = ($reg_1_5_i_i_i | 0) < 0 ? $163 ^ 517762881 : $163; //@line 15406
     $166 = $reg_1_6_i_i_i << 1; //@line 15408
     HEAP32[59240 + ($i_017_i_i_i << 2) >> 2] = ($reg_1_6_i_i_i | 0) < 0 ? $166 ^ 517762881 : $166; //@line 15412
     $i_017_i_i_i = $i_017_i_i_i + 1 | 0; //@line 15413
    } while ($i_017_i_i_i >>> 0 < 256);
    HEAP8[6656] = 1; //@line 15422
   }
   $180 = HEAP32[59240 + ((HEAPU8[$138] ^ $136 >>> 24) << 2) >> 2] ^ $136 << 8; //@line 15433
   $189 = HEAP32[59240 + ((HEAPU8[$buf_i_i + 1 | 0] ^ $180 >>> 24) << 2) >> 2] ^ $180 << 8; //@line 15442
   $198 = HEAP32[59240 + ((HEAPU8[$buf_i_i + 2 | 0] ^ $189 >>> 24) << 2) >> 2] ^ $189 << 8; //@line 15451
   $206 = HEAP32[59240 + ((HEAPU8[$buf_i_i + 3 | 0] ^ $198 >>> 24) << 2) >> 2] ^ $198 << 8; //@line 15459
   $207 = _pri_get_uint16_be($138, 0) | 0; //@line 15460
   if (($207 | 0) != 0) {
    $210 = HEAP32[_stderr >> 2] | 0; //@line 15464
    _fprintf($210 | 0, 50120, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $207, tempInt) | 0) | 0; //@line 15465
    break;
   }
   $213 = $137 - 4 | 0; //@line 15469
   $214 = $buf_i_i_i | 0; //@line 15470
   if (($213 | 0) == 0) {
    $crc2628_lcssa_i_i = $206; //@line 15474
   } else {
    $crc262833_i_i = $206;
    $_08_i34_i_i = $213;
    while (1) {
     $217 = $_08_i34_i_i >>> 0 < 256 ? $_08_i34_i_i : 256; //@line 15481
     if ((_pri_read($fp, $214, $217) | 0) != 0) {
      break L14669;
     }
     if (!(HEAP8[6656] | 0)) {
      $i_017_i5_i_i = 0; //@line 15491
      do {
       $222 = $i_017_i5_i_i << 25; //@line 15496
       $reg_1_i7_i_i = ($i_017_i5_i_i & 128 | 0) != 0 ? $222 ^ 517762881 : $222; //@line 15498
       $225 = $reg_1_i7_i_i << 1; //@line 15500
       $reg_1_1_i8_i_i = ($reg_1_i7_i_i | 0) < 0 ? $225 ^ 517762881 : $225; //@line 15502
       $228 = $reg_1_1_i8_i_i << 1; //@line 15504
       $reg_1_2_i9_i_i = ($reg_1_1_i8_i_i | 0) < 0 ? $228 ^ 517762881 : $228; //@line 15506
       $231 = $reg_1_2_i9_i_i << 1; //@line 15508
       $reg_1_3_i10_i_i = ($reg_1_2_i9_i_i | 0) < 0 ? $231 ^ 517762881 : $231; //@line 15510
       $234 = $reg_1_3_i10_i_i << 1; //@line 15512
       $reg_1_4_i11_i_i = ($reg_1_3_i10_i_i | 0) < 0 ? $234 ^ 517762881 : $234; //@line 15514
       $237 = $reg_1_4_i11_i_i << 1; //@line 15516
       $reg_1_5_i12_i_i = ($reg_1_4_i11_i_i | 0) < 0 ? $237 ^ 517762881 : $237; //@line 15518
       $240 = $reg_1_5_i12_i_i << 1; //@line 15520
       $reg_1_6_i13_i_i = ($reg_1_5_i12_i_i | 0) < 0 ? $240 ^ 517762881 : $240; //@line 15522
       $243 = $reg_1_6_i13_i_i << 1; //@line 15524
       HEAP32[59240 + ($i_017_i5_i_i << 2) >> 2] = ($reg_1_6_i13_i_i | 0) < 0 ? $243 ^ 517762881 : $243; //@line 15528
       $i_017_i5_i_i = $i_017_i5_i_i + 1 | 0; //@line 15529
      } while ($i_017_i5_i_i >>> 0 < 256);
      HEAP8[6656] = 1; //@line 15538
     }
     if (($217 | 0) == 0) {
      $crc2627_ph_i_i = $crc262833_i_i; //@line 15544
     } else {
      $_01011_i19_i_i = $217;
      $_012_i18_i_i = $crc262833_i_i;
      $src_013_i17_i_i = $214;
      while (1) {
       $258 = HEAP32[59240 + ((HEAPU8[$src_013_i17_i_i] ^ $_012_i18_i_i >>> 24) << 2) >> 2] ^ $_012_i18_i_i << 8; //@line 15559
       $259 = $_01011_i19_i_i - 1 | 0; //@line 15560
       if (($259 | 0) == 0) {
        $crc2627_ph_i_i = $258; //@line 15564
        break;
       } else {
        $_01011_i19_i_i = $259;
        $_012_i18_i_i = $258;
        $src_013_i17_i_i = $src_013_i17_i_i + 1 | 0;
       }
      }
     }
     if (($_08_i34_i_i | 0) == ($217 | 0)) {
      $crc2628_lcssa_i_i = $crc2627_ph_i_i; //@line 15576
      break;
     } else {
      $crc262833_i_i = $crc2627_ph_i_i;
      $_08_i34_i_i = $_08_i34_i_i - $217 | 0;
     }
    }
   }
   if ((_pri_read($fp, $214, 4) | 0) != 0) {
    break;
   }
   if ((_pri_get_uint32_be($214, 0) | 0) != ($crc2628_lcssa_i_i | 0)) {
    $270 = HEAP32[_stderr >> 2] | 0; //@line 15594
    _fwrite(56632, 15, 1, $270 | 0) | 0; //@line 15595
    break;
   }
   $268 = $buf_i80_i | 0; //@line 15599
   $_ph235_i = 0; //@line 15601
   L14705 : while (1) {
    if ((_pri_read($fp, $4, 8) | 0) != 0) {
     break L14669;
    }
    $615 = ($_ph235_i | 0) == 0; //@line 15610
    $616 = $_ph235_i + 4 | 0; //@line 15611
    $617 = $_ph235_i + 8 | 0; //@line 15612
    L14708 : while (1) {
     if (!(HEAP8[6656] | 0)) {
      $i_017_i45_i = 0; //@line 15618
      do {
       $274 = $i_017_i45_i << 25; //@line 15623
       $reg_1_i47_i = ($i_017_i45_i & 128 | 0) != 0 ? $274 ^ 517762881 : $274; //@line 15625
       $277 = $reg_1_i47_i << 1; //@line 15627
       $reg_1_1_i48_i = ($reg_1_i47_i | 0) < 0 ? $277 ^ 517762881 : $277; //@line 15629
       $280 = $reg_1_1_i48_i << 1; //@line 15631
       $reg_1_2_i49_i = ($reg_1_1_i48_i | 0) < 0 ? $280 ^ 517762881 : $280; //@line 15633
       $283 = $reg_1_2_i49_i << 1; //@line 15635
       $reg_1_3_i50_i = ($reg_1_2_i49_i | 0) < 0 ? $283 ^ 517762881 : $283; //@line 15637
       $286 = $reg_1_3_i50_i << 1; //@line 15639
       $reg_1_4_i51_i = ($reg_1_3_i50_i | 0) < 0 ? $286 ^ 517762881 : $286; //@line 15641
       $289 = $reg_1_4_i51_i << 1; //@line 15643
       $reg_1_5_i52_i = ($reg_1_4_i51_i | 0) < 0 ? $289 ^ 517762881 : $289; //@line 15645
       $292 = $reg_1_5_i52_i << 1; //@line 15647
       $reg_1_6_i53_i = ($reg_1_5_i52_i | 0) < 0 ? $292 ^ 517762881 : $292; //@line 15649
       $295 = $reg_1_6_i53_i << 1; //@line 15651
       HEAP32[59240 + ($i_017_i45_i << 2) >> 2] = ($reg_1_6_i53_i | 0) < 0 ? $295 ^ 517762881 : $295; //@line 15655
       $i_017_i45_i = $i_017_i45_i + 1 | 0; //@line 15656
      } while ($i_017_i45_i >>> 0 < 256);
      HEAP8[6656] = 1; //@line 15665
     }
     $304 = HEAP32[59240 + (HEAPU8[$4] << 2) >> 2] | 0; //@line 15671
     $312 = HEAP32[59240 + ((HEAPU8[$36] ^ $304 >>> 24) << 2) >> 2] ^ $304 << 8; //@line 15679
     $320 = HEAP32[59240 + ((HEAPU8[$42] ^ $312 >>> 24) << 2) >> 2] ^ $312 << 8; //@line 15687
     $328 = HEAP32[59240 + ((HEAPU8[$51] ^ $320 >>> 24) << 2) >> 2] ^ $320 << 8; //@line 15695
     $336 = HEAP32[59240 + ((HEAPU8[$70] ^ $328 >>> 24) << 2) >> 2] ^ $328 << 8; //@line 15703
     $344 = HEAP32[59240 + ((HEAPU8[$103] ^ $336 >>> 24) << 2) >> 2] ^ $336 << 8; //@line 15711
     $352 = HEAP32[59240 + ((HEAPU8[$112] ^ $344 >>> 24) << 2) >> 2] ^ $344 << 8; //@line 15719
     $360 = HEAP32[59240 + ((HEAPU8[$121] ^ $352 >>> 24) << 2) >> 2] ^ $352 << 8; //@line 15727
     $361 = _pri_get_uint32_be($4, 0) | 0; //@line 15728
     $362 = _pri_get_uint32_be($4, 4) | 0; //@line 15729
     do {
      if (($361 | 0) == 1414676811) {
       break L14708;
      } else if (($361 | 0) == 1145132097) {
       if ($615) {
        break L14669;
       }
       $625 = ((HEAP32[$616 >> 2] | 0) + 7 | 0) >>> 3; //@line 15740
       $size__i_i = $625 >>> 0 > $362 >>> 0 ? $362 : $625; //@line 15742
       $627 = HEAP32[$617 >> 2] | 0; //@line 15743
       if ((_pri_read($fp, $627, $size__i_i) | 0) != 0) {
        break L14669;
       }
       if (!(HEAP8[6656] | 0)) {
        $i_017_i_i102_i = 0; //@line 15753
        do {
         $632 = $i_017_i_i102_i << 25; //@line 15758
         $reg_1_i_i104_i = ($i_017_i_i102_i & 128 | 0) != 0 ? $632 ^ 517762881 : $632; //@line 15760
         $635 = $reg_1_i_i104_i << 1; //@line 15762
         $reg_1_1_i_i105_i = ($reg_1_i_i104_i | 0) < 0 ? $635 ^ 517762881 : $635; //@line 15764
         $638 = $reg_1_1_i_i105_i << 1; //@line 15766
         $reg_1_2_i_i106_i = ($reg_1_1_i_i105_i | 0) < 0 ? $638 ^ 517762881 : $638; //@line 15768
         $641 = $reg_1_2_i_i106_i << 1; //@line 15770
         $reg_1_3_i_i107_i = ($reg_1_2_i_i106_i | 0) < 0 ? $641 ^ 517762881 : $641; //@line 15772
         $644 = $reg_1_3_i_i107_i << 1; //@line 15774
         $reg_1_4_i_i108_i = ($reg_1_3_i_i107_i | 0) < 0 ? $644 ^ 517762881 : $644; //@line 15776
         $647 = $reg_1_4_i_i108_i << 1; //@line 15778
         $reg_1_5_i_i109_i = ($reg_1_4_i_i108_i | 0) < 0 ? $647 ^ 517762881 : $647; //@line 15780
         $650 = $reg_1_5_i_i109_i << 1; //@line 15782
         $reg_1_6_i_i110_i = ($reg_1_5_i_i109_i | 0) < 0 ? $650 ^ 517762881 : $650; //@line 15784
         $653 = $reg_1_6_i_i110_i << 1; //@line 15786
         HEAP32[59240 + ($i_017_i_i102_i << 2) >> 2] = ($reg_1_6_i_i110_i | 0) < 0 ? $653 ^ 517762881 : $653; //@line 15790
         $i_017_i_i102_i = $i_017_i_i102_i + 1 | 0; //@line 15791
        } while ($i_017_i_i102_i >>> 0 < 256);
        HEAP8[6656] = 1; //@line 15800
       }
       if (($size__i_i | 0) == 0) {
        $crc27_ph_i_i = $360; //@line 15806
       } else {
        $_01011_i_i115_i = $size__i_i;
        $_012_i_i114_i = $360;
        $src_013_i_i113_i = $627;
        while (1) {
         $668 = HEAP32[59240 + ((HEAPU8[$src_013_i_i113_i] ^ $_012_i_i114_i >>> 24) << 2) >> 2] ^ $_012_i_i114_i << 8; //@line 15821
         $669 = $_01011_i_i115_i - 1 | 0; //@line 15822
         if (($669 | 0) == 0) {
          $crc27_ph_i_i = $668; //@line 15826
          break;
         } else {
          $_01011_i_i115_i = $669;
          $_012_i_i114_i = $668;
          $src_013_i_i113_i = $src_013_i_i113_i + 1 | 0;
         }
        }
       }
       if (($size__i_i | 0) == ($362 | 0)) {
        $crc2729_lcssa_i_i = $crc27_ph_i_i; //@line 15837
       } else {
        $crc272934_i_i = $crc27_ph_i_i;
        $_08_i35_i_i = $362 - $size__i_i | 0;
        while (1) {
         $675 = $_08_i35_i_i >>> 0 < 256 ? $_08_i35_i_i : 256; //@line 15846
         if ((_pri_read($fp, $214, $675) | 0) != 0) {
          break L14669;
         }
         if (!(HEAP8[6656] | 0)) {
          $i_017_i5_i120_i = 0; //@line 15856
          do {
           $680 = $i_017_i5_i120_i << 25; //@line 15861
           $reg_1_i7_i122_i = ($i_017_i5_i120_i & 128 | 0) != 0 ? $680 ^ 517762881 : $680; //@line 15863
           $683 = $reg_1_i7_i122_i << 1; //@line 15865
           $reg_1_1_i8_i123_i = ($reg_1_i7_i122_i | 0) < 0 ? $683 ^ 517762881 : $683; //@line 15867
           $686 = $reg_1_1_i8_i123_i << 1; //@line 15869
           $reg_1_2_i9_i124_i = ($reg_1_1_i8_i123_i | 0) < 0 ? $686 ^ 517762881 : $686; //@line 15871
           $689 = $reg_1_2_i9_i124_i << 1; //@line 15873
           $reg_1_3_i10_i125_i = ($reg_1_2_i9_i124_i | 0) < 0 ? $689 ^ 517762881 : $689; //@line 15875
           $692 = $reg_1_3_i10_i125_i << 1; //@line 15877
           $reg_1_4_i11_i126_i = ($reg_1_3_i10_i125_i | 0) < 0 ? $692 ^ 517762881 : $692; //@line 15879
           $695 = $reg_1_4_i11_i126_i << 1; //@line 15881
           $reg_1_5_i12_i127_i = ($reg_1_4_i11_i126_i | 0) < 0 ? $695 ^ 517762881 : $695; //@line 15883
           $698 = $reg_1_5_i12_i127_i << 1; //@line 15885
           $reg_1_6_i13_i128_i = ($reg_1_5_i12_i127_i | 0) < 0 ? $698 ^ 517762881 : $698; //@line 15887
           $701 = $reg_1_6_i13_i128_i << 1; //@line 15889
           HEAP32[59240 + ($i_017_i5_i120_i << 2) >> 2] = ($reg_1_6_i13_i128_i | 0) < 0 ? $701 ^ 517762881 : $701; //@line 15893
           $i_017_i5_i120_i = $i_017_i5_i120_i + 1 | 0; //@line 15894
          } while ($i_017_i5_i120_i >>> 0 < 256);
          HEAP8[6656] = 1; //@line 15903
         }
         if (($675 | 0) == 0) {
          $crc2728_ph_i_i = $crc272934_i_i; //@line 15909
         } else {
          $_01011_i19_i134_i = $675;
          $_012_i18_i133_i = $crc272934_i_i;
          $src_013_i17_i132_i = $214;
          while (1) {
           $716 = HEAP32[59240 + ((HEAPU8[$src_013_i17_i132_i] ^ $_012_i18_i133_i >>> 24) << 2) >> 2] ^ $_012_i18_i133_i << 8; //@line 15924
           $717 = $_01011_i19_i134_i - 1 | 0; //@line 15925
           if (($717 | 0) == 0) {
            $crc2728_ph_i_i = $716; //@line 15929
            break;
           } else {
            $_01011_i19_i134_i = $717;
            $_012_i18_i133_i = $716;
            $src_013_i17_i132_i = $src_013_i17_i132_i + 1 | 0;
           }
          }
         }
         if (($_08_i35_i_i | 0) == ($675 | 0)) {
          $crc2729_lcssa_i_i = $crc2728_ph_i_i; //@line 15941
          break;
         } else {
          $crc272934_i_i = $crc2728_ph_i_i;
          $_08_i35_i_i = $_08_i35_i_i - $675 | 0;
         }
        }
       }
       if ((_pri_read($fp, $214, 4) | 0) != 0) {
        break L14669;
       }
       if ((_pri_get_uint32_be($214, 0) | 0) != ($crc2729_lcssa_i_i | 0)) {
        label = 11780; //@line 15959
        break L14705;
       }
      } else if (($361 | 0) == 1162757152) {
       label = 11712; //@line 15963
       break L14705;
      } else if (($361 | 0) == 1413830740) {
       if (($362 | 0) == 0) {
        if ((_pri_read($fp, $214, 4) | 0) != 0) {
         break L14669;
        }
        if ((_pri_get_uint32_be($214, 0) | 0) == ($360 | 0)) {
         break;
        } else {
         label = 11726; //@line 15981
         break L14705;
        }
       }
       $433 = _malloc($362) | 0; //@line 15985
       if (($433 | 0) == 0) {
        break L14669;
       }
       if ((_pri_read($fp, $433, $362) | 0) != 0) {
        label = 11733; //@line 15995
        break L14705;
       }
       if (HEAP8[6656] | 0) {
        $_01011_i_i_i = $362;
        $_012_i_i_i = $360;
        $src_013_i_i_i = $433;
       } else {
        $i_017_i_i67_i = 0; //@line 16003
        do {
         $440 = $i_017_i_i67_i << 25; //@line 16008
         $reg_1_i_i69_i = ($i_017_i_i67_i & 128 | 0) != 0 ? $440 ^ 517762881 : $440; //@line 16010
         $443 = $reg_1_i_i69_i << 1; //@line 16012
         $reg_1_1_i_i70_i = ($reg_1_i_i69_i | 0) < 0 ? $443 ^ 517762881 : $443; //@line 16014
         $446 = $reg_1_1_i_i70_i << 1; //@line 16016
         $reg_1_2_i_i71_i = ($reg_1_1_i_i70_i | 0) < 0 ? $446 ^ 517762881 : $446; //@line 16018
         $449 = $reg_1_2_i_i71_i << 1; //@line 16020
         $reg_1_3_i_i72_i = ($reg_1_2_i_i71_i | 0) < 0 ? $449 ^ 517762881 : $449; //@line 16022
         $452 = $reg_1_3_i_i72_i << 1; //@line 16024
         $reg_1_4_i_i73_i = ($reg_1_3_i_i72_i | 0) < 0 ? $452 ^ 517762881 : $452; //@line 16026
         $455 = $reg_1_4_i_i73_i << 1; //@line 16028
         $reg_1_5_i_i74_i = ($reg_1_4_i_i73_i | 0) < 0 ? $455 ^ 517762881 : $455; //@line 16030
         $458 = $reg_1_5_i_i74_i << 1; //@line 16032
         $reg_1_6_i_i75_i = ($reg_1_5_i_i74_i | 0) < 0 ? $458 ^ 517762881 : $458; //@line 16034
         $461 = $reg_1_6_i_i75_i << 1; //@line 16036
         HEAP32[59240 + ($i_017_i_i67_i << 2) >> 2] = ($reg_1_6_i_i75_i | 0) < 0 ? $461 ^ 517762881 : $461; //@line 16040
         $i_017_i_i67_i = $i_017_i_i67_i + 1 | 0; //@line 16041
        } while ($i_017_i_i67_i >>> 0 < 256);
        HEAP8[6656] = 1; //@line 16050
        $_01011_i_i_i = $362;
        $_012_i_i_i = $360;
        $src_013_i_i_i = $433;
       }
       while (1) {
        $475 = HEAP32[59240 + ((HEAPU8[$src_013_i_i_i] ^ $_012_i_i_i >>> 24) << 2) >> 2] ^ $_012_i_i_i << 8; //@line 16066
        $476 = $_01011_i_i_i - 1 | 0; //@line 16067
        if (($476 | 0) == 0) {
         break;
        } else {
         $_01011_i_i_i = $476;
         $_012_i_i_i = $475;
         $src_013_i_i_i = $src_013_i_i_i + 1 | 0;
        }
       }
       $480 = (HEAP8[$433] | 0) == 10; //@line 16077
       $_size_i_i = ($480 << 31 >> 31) + $362 | 0; //@line 16080
       if (($_size_i_i | 0) == 0) {
        $n_1_i_i = 0; //@line 16084
       } else {
        $484 = $_size_i_i - 1 | 0; //@line 16086
        $n_1_i_i = (HEAP8[$433 + $484 | 0] | 0) == 10 ? $484 : $_size_i_i; //@line 16092
       }
       $490 = _pri_img_add_comment($1, $433 + ($480 & 1) | 0, $n_1_i_i) | 0; //@line 16096
       _free($433); //@line 16097
       do {
        if ((_pri_read($fp, $214, 4) | 0) == 0) {
         if ((_pri_get_uint32_be($214, 0) | 0) == ($475 | 0)) {
          $_0_i23_i_i = 0; //@line 16107
          break;
         }
         $497 = HEAP32[_stderr >> 2] | 0; //@line 16110
         _fwrite(56632, 15, 1, $497 | 0) | 0; //@line 16111
         $_0_i23_i_i = 1; //@line 16113
        } else {
         $_0_i23_i_i = 1; //@line 16115
        }
       } while (0);
       if (($_0_i23_i_i | $490 | 0) != 0) {
        break L14669;
       }
      } else {
       if (($362 | 0) == 0) {
        $_lcssa227_i = $360; //@line 16129
       } else {
        $731 = $360;
        $_08_i140229_i = $362;
        while (1) {
         $733 = $_08_i140229_i >>> 0 < 256 ? $_08_i140229_i : 256; //@line 16136
         if ((_pri_read($fp, $214, $733) | 0) != 0) {
          break L14669;
         }
         if (!(HEAP8[6656] | 0)) {
          $i_017_i168_i = 0; //@line 16146
          do {
           $738 = $i_017_i168_i << 25; //@line 16151
           $reg_1_i170_i = ($i_017_i168_i & 128 | 0) != 0 ? $738 ^ 517762881 : $738; //@line 16153
           $741 = $reg_1_i170_i << 1; //@line 16155
           $reg_1_1_i171_i = ($reg_1_i170_i | 0) < 0 ? $741 ^ 517762881 : $741; //@line 16157
           $744 = $reg_1_1_i171_i << 1; //@line 16159
           $reg_1_2_i172_i = ($reg_1_1_i171_i | 0) < 0 ? $744 ^ 517762881 : $744; //@line 16161
           $747 = $reg_1_2_i172_i << 1; //@line 16163
           $reg_1_3_i173_i = ($reg_1_2_i172_i | 0) < 0 ? $747 ^ 517762881 : $747; //@line 16165
           $750 = $reg_1_3_i173_i << 1; //@line 16167
           $reg_1_4_i174_i = ($reg_1_3_i173_i | 0) < 0 ? $750 ^ 517762881 : $750; //@line 16169
           $753 = $reg_1_4_i174_i << 1; //@line 16171
           $reg_1_5_i175_i = ($reg_1_4_i174_i | 0) < 0 ? $753 ^ 517762881 : $753; //@line 16173
           $756 = $reg_1_5_i175_i << 1; //@line 16175
           $reg_1_6_i176_i = ($reg_1_5_i175_i | 0) < 0 ? $756 ^ 517762881 : $756; //@line 16177
           $759 = $reg_1_6_i176_i << 1; //@line 16179
           HEAP32[59240 + ($i_017_i168_i << 2) >> 2] = ($reg_1_6_i176_i | 0) < 0 ? $759 ^ 517762881 : $759; //@line 16183
           $i_017_i168_i = $i_017_i168_i + 1 | 0; //@line 16184
          } while ($i_017_i168_i >>> 0 < 256);
          HEAP8[6656] = 1; //@line 16193
         }
         if (($733 | 0) == 0) {
          $_ph211_i = $731; //@line 16199
         } else {
          $_01011_i182_i = $733;
          $_012_i181_i = $731;
          $src_013_i180_i = $214;
          while (1) {
           $774 = HEAP32[59240 + ((HEAPU8[$src_013_i180_i] ^ $_012_i181_i >>> 24) << 2) >> 2] ^ $_012_i181_i << 8; //@line 16214
           $775 = $_01011_i182_i - 1 | 0; //@line 16215
           if (($775 | 0) == 0) {
            $_ph211_i = $774; //@line 16219
            break;
           } else {
            $_01011_i182_i = $775;
            $_012_i181_i = $774;
            $src_013_i180_i = $src_013_i180_i + 1 | 0;
           }
          }
         }
         if (($_08_i140229_i | 0) == ($733 | 0)) {
          $_lcssa227_i = $_ph211_i; //@line 16231
          break;
         } else {
          $731 = $_ph211_i;
          $_08_i140229_i = $_08_i140229_i - $733 | 0;
         }
        }
       }
       if ((_pri_read($fp, $214, 4) | 0) != 0) {
        break L14669;
       }
       if ((_pri_get_uint32_be($214, 0) | 0) != ($_lcssa227_i | 0)) {
        label = 11791; //@line 16249
        break L14705;
       }
      }
     } while (0);
     if ((_pri_read($fp, $4, 8) | 0) != 0) {
      break L14669;
     }
    }
    if ($362 >>> 0 < 16) {
     break L14669;
    }
    if ((_pri_read($fp, $268, 16) | 0) != 0) {
     break L14669;
    }
    if (HEAP8[6656] | 0) {
     $_01011_i_i95_i = 16;
     $_012_i_i94_i = $360;
     $src_013_i_i93_i = $268;
    } else {
     $i_017_i_i82_i = 0; //@line 16277
     do {
      $510 = $i_017_i_i82_i << 25; //@line 16282
      $reg_1_i_i84_i = ($i_017_i_i82_i & 128 | 0) != 0 ? $510 ^ 517762881 : $510; //@line 16284
      $513 = $reg_1_i_i84_i << 1; //@line 16286
      $reg_1_1_i_i85_i = ($reg_1_i_i84_i | 0) < 0 ? $513 ^ 517762881 : $513; //@line 16288
      $516 = $reg_1_1_i_i85_i << 1; //@line 16290
      $reg_1_2_i_i86_i = ($reg_1_1_i_i85_i | 0) < 0 ? $516 ^ 517762881 : $516; //@line 16292
      $519 = $reg_1_2_i_i86_i << 1; //@line 16294
      $reg_1_3_i_i87_i = ($reg_1_2_i_i86_i | 0) < 0 ? $519 ^ 517762881 : $519; //@line 16296
      $522 = $reg_1_3_i_i87_i << 1; //@line 16298
      $reg_1_4_i_i88_i = ($reg_1_3_i_i87_i | 0) < 0 ? $522 ^ 517762881 : $522; //@line 16300
      $525 = $reg_1_4_i_i88_i << 1; //@line 16302
      $reg_1_5_i_i89_i = ($reg_1_4_i_i88_i | 0) < 0 ? $525 ^ 517762881 : $525; //@line 16304
      $528 = $reg_1_5_i_i89_i << 1; //@line 16306
      $reg_1_6_i_i90_i = ($reg_1_5_i_i89_i | 0) < 0 ? $528 ^ 517762881 : $528; //@line 16308
      $531 = $reg_1_6_i_i90_i << 1; //@line 16310
      HEAP32[59240 + ($i_017_i_i82_i << 2) >> 2] = ($reg_1_6_i_i90_i | 0) < 0 ? $531 ^ 517762881 : $531; //@line 16314
      $i_017_i_i82_i = $i_017_i_i82_i + 1 | 0; //@line 16315
     } while ($i_017_i_i82_i >>> 0 < 256);
     HEAP8[6656] = 1; //@line 16324
     $_01011_i_i95_i = 16;
     $_012_i_i94_i = $360;
     $src_013_i_i93_i = $268;
    }
    while (1) {
     $545 = HEAP32[59240 + ((HEAPU8[$src_013_i_i93_i] ^ $_012_i_i94_i >>> 24) << 2) >> 2] ^ $_012_i_i94_i << 8; //@line 16340
     $546 = $_01011_i_i95_i - 1 | 0; //@line 16341
     if (($546 | 0) == 0) {
      break;
     } else {
      $_01011_i_i95_i = $546;
      $_012_i_i94_i = $545;
      $src_013_i_i93_i = $src_013_i_i93_i + 1 | 0;
     }
    }
    $549 = _pri_get_uint32_be($268, 0) | 0; //@line 16350
    $550 = _pri_get_uint32_be($268, 4) | 0; //@line 16351
    $551 = _pri_get_uint32_be($268, 8) | 0; //@line 16352
    $552 = _pri_get_uint32_be($268, 12) | 0; //@line 16353
    $553 = _pri_img_get_track($1, $549, $550, 1) | 0; //@line 16354
    if (($553 | 0) == 0) {
     break L14669;
    }
    if ((_pri_trk_set_size($553, $551) | 0) != 0) {
     break L14669;
    }
    _pri_trk_set_clock($553, $552); //@line 16366
    $559 = $362 - 16 | 0; //@line 16367
    if (($559 | 0) == 0) {
     $crc3436_lcssa_i_i = $545; //@line 16371
    } else {
     $crc343641_i_i = $545;
     $_08_i42_i_i = $559;
     while (1) {
      $562 = $_08_i42_i_i >>> 0 < 256 ? $_08_i42_i_i : 256; //@line 16378
      if ((_pri_read($fp, $214, $562) | 0) != 0) {
       break L14669;
      }
      if (!(HEAP8[6656] | 0)) {
       $i_017_i13_i_i = 0; //@line 16388
       do {
        $567 = $i_017_i13_i_i << 25; //@line 16393
        $reg_1_i15_i_i = ($i_017_i13_i_i & 128 | 0) != 0 ? $567 ^ 517762881 : $567; //@line 16395
        $570 = $reg_1_i15_i_i << 1; //@line 16397
        $reg_1_1_i16_i_i = ($reg_1_i15_i_i | 0) < 0 ? $570 ^ 517762881 : $570; //@line 16399
        $573 = $reg_1_1_i16_i_i << 1; //@line 16401
        $reg_1_2_i17_i_i = ($reg_1_1_i16_i_i | 0) < 0 ? $573 ^ 517762881 : $573; //@line 16403
        $576 = $reg_1_2_i17_i_i << 1; //@line 16405
        $reg_1_3_i18_i_i = ($reg_1_2_i17_i_i | 0) < 0 ? $576 ^ 517762881 : $576; //@line 16407
        $579 = $reg_1_3_i18_i_i << 1; //@line 16409
        $reg_1_4_i19_i_i = ($reg_1_3_i18_i_i | 0) < 0 ? $579 ^ 517762881 : $579; //@line 16411
        $582 = $reg_1_4_i19_i_i << 1; //@line 16413
        $reg_1_5_i20_i_i = ($reg_1_4_i19_i_i | 0) < 0 ? $582 ^ 517762881 : $582; //@line 16415
        $585 = $reg_1_5_i20_i_i << 1; //@line 16417
        $reg_1_6_i21_i_i = ($reg_1_5_i20_i_i | 0) < 0 ? $585 ^ 517762881 : $585; //@line 16419
        $588 = $reg_1_6_i21_i_i << 1; //@line 16421
        HEAP32[59240 + ($i_017_i13_i_i << 2) >> 2] = ($reg_1_6_i21_i_i | 0) < 0 ? $588 ^ 517762881 : $588; //@line 16425
        $i_017_i13_i_i = $i_017_i13_i_i + 1 | 0; //@line 16426
       } while ($i_017_i13_i_i >>> 0 < 256);
       HEAP8[6656] = 1; //@line 16435
      }
      if (($562 | 0) == 0) {
       $crc3435_ph_i_i = $crc343641_i_i; //@line 16441
      } else {
       $_01011_i27_i_i = $562;
       $_012_i26_i_i = $crc343641_i_i;
       $src_013_i25_i_i = $214;
       while (1) {
        $603 = HEAP32[59240 + ((HEAPU8[$src_013_i25_i_i] ^ $_012_i26_i_i >>> 24) << 2) >> 2] ^ $_012_i26_i_i << 8; //@line 16456
        $604 = $_01011_i27_i_i - 1 | 0; //@line 16457
        if (($604 | 0) == 0) {
         $crc3435_ph_i_i = $603; //@line 16461
         break;
        } else {
         $_01011_i27_i_i = $604;
         $_012_i26_i_i = $603;
         $src_013_i25_i_i = $src_013_i25_i_i + 1 | 0;
        }
       }
      }
      if (($_08_i42_i_i | 0) == ($562 | 0)) {
       $crc3436_lcssa_i_i = $crc3435_ph_i_i; //@line 16473
       break;
      } else {
       $crc343641_i_i = $crc3435_ph_i_i;
       $_08_i42_i_i = $_08_i42_i_i - $562 | 0;
      }
     }
    }
    if ((_pri_read($fp, $214, 4) | 0) != 0) {
     break L14669;
    }
    if ((_pri_get_uint32_be($214, 0) | 0) == ($crc3436_lcssa_i_i | 0)) {
     $_ph235_i = $553; //@line 16491
    } else {
     label = 11761; //@line 16493
     break;
    }
   }
   if ((label | 0) == 11791) {
    $785 = HEAP32[_stderr >> 2] | 0; //@line 16498
    _fwrite(56632, 15, 1, $785 | 0) | 0; //@line 16499
    break;
   } else if ((label | 0) == 11726) {
    _fwrite(56632, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 16505
    break;
   } else if ((label | 0) == 11780) {
    _fwrite(56632, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 16511
    break;
   } else if ((label | 0) == 11712) {
    if (($362 | 0) == 0) {
     $_lcssa214_i = $360; //@line 16519
    } else {
     $365 = $360;
     $_08_i216_i = $362;
     while (1) {
      $367 = $_08_i216_i >>> 0 < 256 ? $_08_i216_i : 256; //@line 16526
      if ((_pri_read($fp, $214, $367) | 0) != 0) {
       break L14669;
      }
      if (!(HEAP8[6656] | 0)) {
       $i_017_i147_i = 0; //@line 16536
       do {
        $372 = $i_017_i147_i << 25; //@line 16541
        $reg_1_i149_i = ($i_017_i147_i & 128 | 0) != 0 ? $372 ^ 517762881 : $372; //@line 16543
        $375 = $reg_1_i149_i << 1; //@line 16545
        $reg_1_1_i150_i = ($reg_1_i149_i | 0) < 0 ? $375 ^ 517762881 : $375; //@line 16547
        $378 = $reg_1_1_i150_i << 1; //@line 16549
        $reg_1_2_i151_i = ($reg_1_1_i150_i | 0) < 0 ? $378 ^ 517762881 : $378; //@line 16551
        $381 = $reg_1_2_i151_i << 1; //@line 16553
        $reg_1_3_i152_i = ($reg_1_2_i151_i | 0) < 0 ? $381 ^ 517762881 : $381; //@line 16555
        $384 = $reg_1_3_i152_i << 1; //@line 16557
        $reg_1_4_i153_i = ($reg_1_3_i152_i | 0) < 0 ? $384 ^ 517762881 : $384; //@line 16559
        $387 = $reg_1_4_i153_i << 1; //@line 16561
        $reg_1_5_i154_i = ($reg_1_4_i153_i | 0) < 0 ? $387 ^ 517762881 : $387; //@line 16563
        $390 = $reg_1_5_i154_i << 1; //@line 16565
        $reg_1_6_i155_i = ($reg_1_5_i154_i | 0) < 0 ? $390 ^ 517762881 : $390; //@line 16567
        $393 = $reg_1_6_i155_i << 1; //@line 16569
        HEAP32[59240 + ($i_017_i147_i << 2) >> 2] = ($reg_1_6_i155_i | 0) < 0 ? $393 ^ 517762881 : $393; //@line 16573
        $i_017_i147_i = $i_017_i147_i + 1 | 0; //@line 16574
       } while ($i_017_i147_i >>> 0 < 256);
       HEAP8[6656] = 1; //@line 16583
      }
      if (($367 | 0) == 0) {
       $_ph_i = $365; //@line 16589
      } else {
       $_01011_i161_i = $367;
       $_012_i160_i = $365;
       $src_013_i159_i = $214;
       while (1) {
        $408 = HEAP32[59240 + ((HEAPU8[$src_013_i159_i] ^ $_012_i160_i >>> 24) << 2) >> 2] ^ $_012_i160_i << 8; //@line 16604
        $409 = $_01011_i161_i - 1 | 0; //@line 16605
        if (($409 | 0) == 0) {
         $_ph_i = $408; //@line 16609
         break;
        } else {
         $_01011_i161_i = $409;
         $_012_i160_i = $408;
         $src_013_i159_i = $src_013_i159_i + 1 | 0;
        }
       }
      }
      if (($_08_i216_i | 0) == ($367 | 0)) {
       $_lcssa214_i = $_ph_i; //@line 16621
       break;
      } else {
       $365 = $_ph_i;
       $_08_i216_i = $_08_i216_i - $367 | 0;
      }
     }
    }
    if ((_pri_read($fp, $214, 4) | 0) != 0) {
     break;
    }
    if ((_pri_get_uint32_be($214, 0) | 0) == ($_lcssa214_i | 0)) {
     $_0 = $1; //@line 16639
     STACKTOP = sp; //@line 16641
     return $_0 | 0; //@line 16642
    } else {
     $419 = HEAP32[_stderr >> 2] | 0; //@line 16644
     _fwrite(56632, 15, 1, $419 | 0) | 0; //@line 16645
     break;
    }
   } else if ((label | 0) == 11761) {
    _fwrite(56632, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 16652
    break;
   } else if ((label | 0) == 11733) {
    _free($433); //@line 16657
    break;
   }
  }
 } while (0);
 _pri_img_del($1); //@line 16663
 $_0 = 0; //@line 16665
 STACKTOP = sp; //@line 16667
 return $_0 | 0; //@line 16668
}
function _pri_save_tc($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 return 1; //@line 16678
}
function _pri_save_pri($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $crc_i18 = 0, $crc_i_i = 0, $buf_i7_i = 0, $crc_i = 0, $buf_i16 = 0, $1 = 0, $5 = 0, $6 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $24 = 0, $25 = 0, $27 = 0, $29 = 0, $30 = 0, $c_027 = 0, $33 = 0, $35 = 0, $38 = 0, $h_026 = 0, $41 = 0, $44 = 0, $50 = 0, $54 = 0, $67 = 0, $68 = 0, $_pre_phi = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 16697
 STACKTOP = STACKTOP + 56 | 0; //@line 16697
 $crc_i18 = sp | 0; //@line 16698
 $crc_i_i = sp + 8 | 0; //@line 16699
 $buf_i7_i = sp + 16 | 0; //@line 16700
 $crc_i = sp + 24 | 0; //@line 16701
 $buf_i16 = sp + 32 | 0; //@line 16702
 $1 = sp + 48 | 0; //@line 16704
 _pri_set_uint32_be($1, 0, 0); //@line 16705
 if ((_pri_save_chunk($fp, 1347569952, 4, $1) | 0) != 0) {
  $_0 = 1; //@line 16710
  STACKTOP = sp; //@line 16712
  return $_0 | 0; //@line 16713
 }
 $5 = $buf_i16 | 0; //@line 16716
 $6 = $img + 8 | 0; //@line 16717
 do {
  if ((HEAP32[$6 >> 2] | 0) != 0) {
   _pri_set_uint32_be($5, 0, 1413830740); //@line 16723
   _pri_set_uint32_be($5, 4, (HEAP32[$6 >> 2] | 0) + 2 | 0); //@line 16726
   $11 = $buf_i16 + 8 | 0; //@line 16727
   HEAP8[$11] = 10; //@line 16728
   HEAP32[$crc_i >> 2] = 0; //@line 16729
   $12 = _pri_write_crc($fp, $5, 9, $crc_i) | 0; //@line 16730
   $17 = _pri_write_crc($fp, HEAP32[$img + 12 >> 2] | 0, HEAP32[$6 >> 2] | 0, $crc_i) | 0 | $12; //@line 16735
   $19 = $17 | (_pri_write_crc($fp, $11, 1, $crc_i) | 0); //@line 16737
   _pri_set_uint32_be($5, 0, HEAP32[$crc_i >> 2] | 0); //@line 16739
   if (($19 | (_pri_write($fp, $5, 4) | 0) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 16747
   }
   STACKTOP = sp; //@line 16750
   return $_0 | 0; //@line 16751
  }
 } while (0);
 $24 = $img | 0; //@line 16754
 $25 = HEAP32[$24 >> 2] | 0; //@line 16755
 L14845 : do {
  if (($25 | 0) == 0) {
   $_pre_phi = $buf_i7_i | 0; //@line 16762
  } else {
   $27 = $img + 4 | 0; //@line 16764
   $29 = $buf_i7_i | 0; //@line 16766
   $c_027 = 0;
   $30 = $25;
   L14848 : while (1) {
    $33 = HEAP32[(HEAP32[$27 >> 2] | 0) + ($c_027 << 2) >> 2] | 0; //@line 16774
    do {
     if (($33 | 0) == 0) {
      $67 = $30; //@line 16779
     } else {
      $35 = $33 | 0; //@line 16781
      if ((HEAP32[$35 >> 2] | 0) == 0) {
       $67 = $30; //@line 16786
       break;
      }
      $38 = $33 + 4 | 0; //@line 16789
      $h_026 = 0; //@line 16791
      do {
       $41 = HEAP32[(HEAP32[$38 >> 2] | 0) + ($h_026 << 2) >> 2] | 0; //@line 16796
       do {
        if (($41 | 0) != 0) {
         _pri_set_uint32_be($5, 0, $c_027); //@line 16801
         _pri_set_uint32_be($5, 4, $h_026); //@line 16802
         $44 = $41 + 4 | 0; //@line 16803
         _pri_set_uint32_be($5, 8, HEAP32[$44 >> 2] | 0); //@line 16805
         _pri_set_uint32_be($5, 12, HEAP32[$41 >> 2] | 0); //@line 16808
         if ((_pri_save_chunk($fp, 1414676811, 16, $5) | 0) != 0) {
          $_0 = 1; //@line 16813
          label = 11820; //@line 16814
          break L14848;
         }
         $50 = HEAP32[$44 >> 2] | 0; //@line 16817
         if (($50 | 0) == 0) {
          break;
         }
         HEAP32[$crc_i_i >> 2] = 0; //@line 16823
         $54 = ($50 + 7 | 0) >>> 3; //@line 16825
         _pri_set_uint32_be($29, 0, 1145132097); //@line 16826
         _pri_set_uint32_be($29, 4, $54); //@line 16827
         if ((_pri_write_crc($fp, $29, 8, $crc_i_i) | 0) != 0) {
          $_0 = 1; //@line 16832
          label = 11823; //@line 16833
          break L14848;
         }
         if ((_pri_write_crc($fp, HEAP32[$41 + 8 >> 2] | 0, $54, $crc_i_i) | 0) != 0) {
          $_0 = 1; //@line 16842
          label = 11825; //@line 16843
          break L14848;
         }
         _pri_set_uint32_be($29, 0, HEAP32[$crc_i_i >> 2] | 0); //@line 16847
         if ((_pri_write($fp, $29, 4) | 0) != 0) {
          $_0 = 1; //@line 16852
          label = 11826; //@line 16853
          break L14848;
         }
        }
       } while (0);
       $h_026 = $h_026 + 1 | 0; //@line 16858
      } while ($h_026 >>> 0 < (HEAP32[$35 >> 2] | 0) >>> 0);
      $67 = HEAP32[$24 >> 2] | 0; //@line 16870
     }
    } while (0);
    $68 = $c_027 + 1 | 0; //@line 16874
    if ($68 >>> 0 < $67 >>> 0) {
     $c_027 = $68;
     $30 = $67;
    } else {
     $_pre_phi = $29; //@line 16880
     break L14845;
    }
   }
   if ((label | 0) == 11826) {
    STACKTOP = sp; //@line 16886
    return $_0 | 0; //@line 16887
   } else if ((label | 0) == 11825) {
    STACKTOP = sp; //@line 16891
    return $_0 | 0; //@line 16892
   } else if ((label | 0) == 11820) {
    STACKTOP = sp; //@line 16896
    return $_0 | 0; //@line 16897
   } else if ((label | 0) == 11823) {
    STACKTOP = sp; //@line 16901
    return $_0 | 0; //@line 16902
   }
  }
 } while (0);
 _pri_set_uint32_be($_pre_phi, 0, 1162757152); //@line 16908
 _pri_set_uint32_be($_pre_phi, 4, 0); //@line 16909
 HEAP32[$crc_i18 >> 2] = 0; //@line 16910
 if ((_pri_write_crc($fp, $_pre_phi, 8, $crc_i18) | 0) != 0) {
  $_0 = 1; //@line 16915
  STACKTOP = sp; //@line 16917
  return $_0 | 0; //@line 16918
 }
 _pri_set_uint32_be($_pre_phi, 0, HEAP32[$crc_i18 >> 2] | 0); //@line 16921
 $_0 = (_pri_write($fp, $_pre_phi, 4) | 0) != 0 | 0; //@line 16926
 STACKTOP = sp; //@line 16928
 return $_0 | 0; //@line 16929
}
function _pri_save_chunk($fp, $ckid, $size, $data) {
 $fp = $fp | 0;
 $ckid = $ckid | 0;
 $size = $size | 0;
 $data = $data | 0;
 var $crc = 0, $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 16941
 STACKTOP = STACKTOP + 16 | 0; //@line 16941
 $crc = sp | 0; //@line 16942
 $1 = sp + 8 | 0; //@line 16944
 _pri_set_uint32_be($1, 0, $ckid); //@line 16945
 _pri_set_uint32_be($1, 4, $size); //@line 16946
 HEAP32[$crc >> 2] = 0; //@line 16947
 if ((_pri_write_crc($fp, $1, 8, $crc) | 0) != 0) {
  $_0 = 1; //@line 16952
  STACKTOP = sp; //@line 16954
  return $_0 | 0; //@line 16955
 }
 do {
  if (($size | 0) != 0) {
   if ((_pri_write_crc($fp, $data, $size, $crc) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 16967
   }
   STACKTOP = sp; //@line 16970
   return $_0 | 0; //@line 16971
  }
 } while (0);
 _pri_set_uint32_be($1, 0, HEAP32[$crc >> 2] | 0); //@line 16975
 $_0 = (_pri_write($fp, $1, 4) | 0) != 0 | 0; //@line 16980
 STACKTOP = sp; //@line 16982
 return $_0 | 0; //@line 16983
}
function _pri_write_crc($fp, $buf, $cnt, $crc) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $crc = $crc | 0;
 var $3 = 0, $i_017_i = 0, $5 = 0, $reg_1_i = 0, $8 = 0, $reg_1_1_i = 0, $11 = 0, $reg_1_2_i = 0, $14 = 0, $reg_1_3_i = 0, $17 = 0, $reg_1_4_i = 0, $20 = 0, $reg_1_5_i = 0, $23 = 0, $reg_1_6_i = 0, $26 = 0, $src_013_i = 0, $_012_i = 0, $_01011_i = 0, $41 = 0, $42 = 0, $_0_lcssa_i = 0, $45 = 0, $not_ = 0, $_ = 0;
 if (($crc | 0) == 0) {
  $45 = _pri_write($fp, $buf, $cnt) | 0; //@line 17005
  $not_ = ($45 | 0) != 0; //@line 17006
  $_ = $not_ & 1; //@line 17007
  return $_ | 0; //@line 17009
 }
 $3 = HEAP32[$crc >> 2] | 0; //@line 17011
 if (!(HEAP8[6656] | 0)) {
  $i_017_i = 0; //@line 17015
  do {
   $5 = $i_017_i << 25; //@line 17020
   $reg_1_i = ($i_017_i & 128 | 0) != 0 ? $5 ^ 517762881 : $5; //@line 17022
   $8 = $reg_1_i << 1; //@line 17024
   $reg_1_1_i = ($reg_1_i | 0) < 0 ? $8 ^ 517762881 : $8; //@line 17026
   $11 = $reg_1_1_i << 1; //@line 17028
   $reg_1_2_i = ($reg_1_1_i | 0) < 0 ? $11 ^ 517762881 : $11; //@line 17030
   $14 = $reg_1_2_i << 1; //@line 17032
   $reg_1_3_i = ($reg_1_2_i | 0) < 0 ? $14 ^ 517762881 : $14; //@line 17034
   $17 = $reg_1_3_i << 1; //@line 17036
   $reg_1_4_i = ($reg_1_3_i | 0) < 0 ? $17 ^ 517762881 : $17; //@line 17038
   $20 = $reg_1_4_i << 1; //@line 17040
   $reg_1_5_i = ($reg_1_4_i | 0) < 0 ? $20 ^ 517762881 : $20; //@line 17042
   $23 = $reg_1_5_i << 1; //@line 17044
   $reg_1_6_i = ($reg_1_5_i | 0) < 0 ? $23 ^ 517762881 : $23; //@line 17046
   $26 = $reg_1_6_i << 1; //@line 17048
   HEAP32[59240 + ($i_017_i << 2) >> 2] = ($reg_1_6_i | 0) < 0 ? $26 ^ 517762881 : $26; //@line 17052
   $i_017_i = $i_017_i + 1 | 0; //@line 17053
  } while ($i_017_i >>> 0 < 256);
  HEAP8[6656] = 1; //@line 17062
 }
 if (($cnt | 0) == 0) {
  $_0_lcssa_i = $3; //@line 17068
 } else {
  $_01011_i = $cnt;
  $_012_i = $3;
  $src_013_i = $buf;
  while (1) {
   $41 = HEAP32[59240 + (((HEAPU8[$src_013_i] | 0) ^ $_012_i >>> 24) << 2) >> 2] ^ $_012_i << 8; //@line 17083
   $42 = $_01011_i - 1 | 0; //@line 17084
   if (($42 | 0) == 0) {
    $_0_lcssa_i = $41; //@line 17088
    break;
   } else {
    $_01011_i = $42;
    $_012_i = $41;
    $src_013_i = $src_013_i + 1 | 0;
   }
  }
 }
 HEAP32[$crc >> 2] = $_0_lcssa_i; //@line 17096
 $45 = _pri_write($fp, $buf, $cnt) | 0; //@line 17098
 $not_ = ($45 | 0) != 0; //@line 17099
 $_ = $not_ & 1; //@line 17100
 return $_ | 0; //@line 17102
}
function _pri_load_tc($fp) {
 $fp = $fp | 0;
 var $buf_i = 0, $ofs = 0, $len = 0, $1 = 0, $4 = 0, $14 = 0, $16 = 0, $17 = 0, $i_0_i = 0, $27 = 0, $28 = 0, $i_124_i = 0, $i_222_i = 0, $54 = 0, $t_030_us = 0, $h_029_us = 0, $60 = 0, $64 = 0, $67 = 0, $84 = 0, $c_031_us = 0, $c_031 = 0, $89 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 17120
 STACKTOP = STACKTOP + 2048 | 0; //@line 17120
 $buf_i = sp | 0; //@line 17121
 $ofs = sp + 512 | 0; //@line 17122
 $len = sp + 1536 | 0; //@line 17123
 $1 = _pri_img_new() | 0; //@line 17124
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 17128
  STACKTOP = sp; //@line 17130
  return $_0 | 0; //@line 17131
 }
 $4 = $buf_i | 0; //@line 17133
 do {
  if ((_pri_read_ofs($fp, 0, $4, 512) | 0) == 0) {
   if ((_pri_get_uint16_be($4, 0) | 0) != 23205) {
    break;
   }
   $14 = (HEAPU8[$buf_i + 258 | 0] | 0) + 1 | 0; //@line 17148
   $16 = HEAP8[$buf_i + 259 | 0] | 0; //@line 17150
   $17 = $16 & 255; //@line 17151
   $i_0_i = 2; //@line 17153
   while (1) {
    if ($i_0_i >>> 0 >= 66) {
     label = 11853; //@line 17159
     break;
    }
    if ((HEAP8[$buf_i + $i_0_i | 0] | 0) == 0) {
     label = 11852; //@line 17168
     break;
    } else {
     $i_0_i = $i_0_i + 1 | 0; //@line 17171
    }
   }
   if ((label | 0) == 11852) {
    if ($i_0_i >>> 0 > 2) {
     label = 11853; //@line 17178
    }
   }
   if ((label | 0) == 11853) {
    $27 = $buf_i + 2 | 0; //@line 17182
    $28 = $i_0_i - 2 | 0; //@line 17183
    _pri_img_set_comment($1, $27, $28) | 0; //@line 17184
   }
   if ((_pri_read_ofs($fp, 773, $4, 512) | 0) == 0) {
    $i_124_i = 0; //@line 17191
   } else {
    break;
   }
   do {
    HEAP32[$ofs + ($i_124_i << 2) >> 2] = (_pri_get_uint16_be($4, $i_124_i << 1) | 0) << 8; //@line 17201
    $i_124_i = $i_124_i + 1 | 0; //@line 17202
   } while ($i_124_i >>> 0 < 256);
   if ((_pri_read_ofs($fp, 1285, $4, 512) | 0) == 0) {
    $i_222_i = 0; //@line 17215
   } else {
    break;
   }
   do {
    HEAP16[$len + ($i_222_i << 1) >> 1] = (_pri_get_uint16_le($4, $i_222_i << 1) | 0) & 65535; //@line 17225
    $i_222_i = $i_222_i + 1 | 0; //@line 17226
   } while ($i_222_i >>> 0 < 256);
   if ($14 >>> 0 > 99 | ($16 & 255) > 2) {
    _pri_img_del($1); //@line 17240
    $_0 = 0; //@line 17242
    STACKTOP = sp; //@line 17244
    return $_0 | 0; //@line 17245
   }
   if ($16 << 24 >> 24 == 0) {
    $c_031 = 0; //@line 17249
    while (1) {
     $89 = $c_031 + 1 | 0; //@line 17252
     if ($89 >>> 0 < $14 >>> 0) {
      $c_031 = $89; //@line 17256
     } else {
      $_0 = $1; //@line 17258
      break;
     }
    }
    STACKTOP = sp; //@line 17263
    return $_0 | 0; //@line 17264
   } else {
    $c_031_us = 0; //@line 17266
   }
   L14926 : while (1) {
    $h_029_us = 0;
    $t_030_us = $c_031_us << 1;
    while (1) {
     if ($t_030_us >>> 0 > 255) {
      label = 11871; //@line 17279
      break L14926;
     }
     $60 = HEAP32[$ofs + ($t_030_us << 2) >> 2] | 0; //@line 17283
     do {
      if (($60 | 0) != 0) {
       $64 = HEAP16[$len + ($t_030_us << 1) >> 1] | 0; //@line 17289
       if ($64 << 16 >> 16 == 0) {
        break;
       }
       $67 = _pri_img_get_track($1, $c_031_us, $h_029_us, 1) | 0; //@line 17295
       if (($67 | 0) == 0) {
        label = 11872; //@line 17299
        break L14926;
       }
       if ((_pri_trk_set_size($67, ($64 & 65535) << 3) | 0) != 0) {
        label = 11872; //@line 17308
        break L14926;
       }
       _pri_trk_set_clock($67, ($64 & 65535) < 8e3 ? 25e4 : 5e5); //@line 17313
       if ((_pri_read_ofs($fp, $60, HEAP32[$67 + 8 >> 2] | 0, ((HEAP32[$67 + 4 >> 2] | 0) + 7 | 0) >>> 3) | 0) != 0) {
        label = 11872; //@line 17324
        break L14926;
       }
      }
     } while (0);
     $84 = $h_029_us + 1 | 0; //@line 17330
     if ($84 >>> 0 < $17 >>> 0) {
      $h_029_us = $84;
      $t_030_us = $t_030_us + 1 | 0;
     } else {
      break;
     }
    }
    $54 = $c_031_us + 1 | 0; //@line 17339
    if ($54 >>> 0 < $14 >>> 0) {
     $c_031_us = $54; //@line 17343
    } else {
     $_0 = $1; //@line 17345
     label = 11877; //@line 17346
     break;
    }
   }
   if ((label | 0) == 11877) {
    STACKTOP = sp; //@line 17352
    return $_0 | 0; //@line 17353
   } else if ((label | 0) == 11872) {
    _pri_img_del($1); //@line 17356
    $_0 = 0; //@line 17358
    STACKTOP = sp; //@line 17360
    return $_0 | 0; //@line 17361
   } else if ((label | 0) == 11871) {
    _pri_img_del($1); //@line 17364
    $_0 = 0; //@line 17366
    STACKTOP = sp; //@line 17368
    return $_0 | 0; //@line 17369
   }
  }
 } while (0);
 _pri_img_del($1); //@line 17373
 $_0 = 0; //@line 17375
 STACKTOP = sp; //@line 17377
 return $_0 | 0; //@line 17378
}
function _psi_guess_type($fname) {
 $fname = $fname | 0;
 var $_0_i = 0, $ext_0_i = 0, $2 = 0, $ext_1_i = 0, $_0 = 0;
 $ext_0_i = 62880;
 $_0_i = $fname;
 while (1) {
  $2 = HEAP8[$_0_i] | 0; //@line 17396
  if (($2 << 24 >> 24 | 0) == 46) {
   $ext_1_i = $_0_i; //@line 17399
  } else if (($2 << 24 >> 24 | 0) == 0) {
   break;
  } else {
   $ext_1_i = $ext_0_i; //@line 17403
  }
  $ext_0_i = $ext_1_i;
  $_0_i = $_0_i + 1 | 0;
 }
 do {
  if ((_strcasecmp($ext_0_i | 0, 53936) | 0) == 0) {
   $_0 = 1; //@line 17415
  } else {
   if ((_strcasecmp($ext_0_i | 0, 56624) | 0) == 0) {
    $_0 = 2; //@line 17421
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 50112) | 0) == 0) {
    $_0 = 3; //@line 17428
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 46216) | 0) == 0) {
    $_0 = 12; //@line 17435
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 42688) | 0) == 0) {
    $_0 = 4; //@line 17442
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 39584) | 0) == 0) {
    $_0 = 12; //@line 17449
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 36664) | 0) == 0) {
    $_0 = 5; //@line 17456
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 33680) | 0) == 0) {
    $_0 = 6; //@line 17463
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 31824) | 0) == 0) {
    $_0 = 11; //@line 17470
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 30880) | 0) == 0) {
    $_0 = 12; //@line 17477
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 58032) | 0) == 0) {
    $_0 = 13; //@line 17484
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 57240) | 0) == 0) {
    $_0 = 14; //@line 17491
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 56016) | 0) == 0) {
    $_0 = 15; //@line 17498
    break;
   }
   if ((_strcasecmp($ext_0_i | 0, 55280) | 0) == 0) {
    $_0 = 16; //@line 17505
    break;
   }
   $_0 = (_strcasecmp($ext_0_i | 0, 54616) | 0) == 0 ? 17 : 11; //@line 17512
  }
 } while (0);
 return $_0 | 0; //@line 17517
}
function _psi_load_fp($fp, $type) {
 $fp = $fp | 0;
 $type = $type | 0;
 var $_0 = 0;
 if (($type | 0) == 2) {
  $_0 = _psi_load_cp2($fp) | 0; //@line 17531
 } else if (($type | 0) == 6 | ($type | 0) == 7 | ($type | 0) == 8 | ($type | 0) == 9 | ($type | 0) == 10) {
  $_0 = _psi_load_pfdc($fp) | 0; //@line 17535
 } else if (($type | 0) == 12) {
  $_0 = _psi_load_raw($fp) | 0; //@line 17539
 } else if (($type | 0) == 4) {
  $_0 = _psi_load_imd($fp) | 0; //@line 17543
 } else if (($type | 0) == 14) {
  $_0 = _psi_load_stx($fp) | 0; //@line 17547
 } else if (($type | 0) == 1) {
  $_0 = _psi_load_anadisk($fp) | 0; //@line 17551
 } else if (($type | 0) == 17) {
  $_0 = _psi_load_xdf($fp) | 0; //@line 17555
 } else if (($type | 0) == 11) {
  $_0 = _psi_load_psi($fp) | 0; //@line 17559
 } else if (($type | 0) == 5) {
  $_0 = _psi_load_msa($fp) | 0; //@line 17563
 } else if (($type | 0) == 3) {
  $_0 = _psi_load_dc42($fp) | 0; //@line 17567
 } else if (($type | 0) == 13) {
  $_0 = _psi_load_st($fp) | 0; //@line 17571
 } else if (($type | 0) == 15) {
  $_0 = _psi_load_tc($fp) | 0; //@line 17575
 } else if (($type | 0) == 16) {
  $_0 = _psi_load_td0($fp) | 0; //@line 17579
 } else {
  $_0 = 0; //@line 17581
 }
 return $_0 | 0; //@line 17585
}
function _psi_probe($fname) {
 $fname = $fname | 0;
 var $1 = 0, $4 = 0, $_0_i = 0, $ext_0_i = 0, $7 = 0, $ext_1_i = 0, $_0 = 0;
 $1 = _fopen($fname | 0, 53920) | 0; //@line 17595
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 17599
  return $_0 | 0; //@line 17602
 }
 $4 = _psi_probe_fp($1) | 0; //@line 17604
 _fclose($1 | 0) | 0; //@line 17605
 if (($4 | 0) == 12) {
  $ext_0_i = 62880;
  $_0_i = $fname;
 } else {
  $_0 = $4; //@line 17611
  return $_0 | 0; //@line 17614
 }
 while (1) {
  $7 = HEAP8[$_0_i] | 0; //@line 17619
  if (($7 << 24 >> 24 | 0) == 46) {
   $ext_1_i = $_0_i; //@line 17622
  } else if (($7 << 24 >> 24 | 0) == 0) {
   break;
  } else {
   $ext_1_i = $ext_0_i; //@line 17626
  }
  $ext_0_i = $ext_1_i;
  $_0_i = $_0_i + 1 | 0;
 }
 return ((_strcasecmp($ext_0_i | 0, 58032) | 0) == 0 ? 13 : 12) | 0; //@line 17637
}
function _psi_save_fp($fp, $img, $type) {
 $fp = $fp | 0;
 $img = $img | 0;
 $type = $type | 0;
 var $_0 = 0;
 if (($type | 0) == 4) {
  $_0 = _psi_save_imd($fp, $img) | 0; //@line 17653
 } else if (($type | 0) == 12) {
  $_0 = _psi_save_raw($fp, $img) | 0; //@line 17657
 } else if (($type | 0) == 14) {
  $_0 = _psi_save_stx($fp, $img) | 0; //@line 17661
 } else if (($type | 0) == 2) {
  $_0 = _psi_save_cp2($fp, $img) | 0; //@line 17665
 } else if (($type | 0) == 17) {
  $_0 = _psi_save_xdf($fp, $img) | 0; //@line 17669
 } else if (($type | 0) == 16) {
  $_0 = _psi_save_td0($fp, $img) | 0; //@line 17673
 } else if (($type | 0) == 5) {
  $_0 = _psi_save_msa($fp, $img) | 0; //@line 17677
 } else if (($type | 0) == 3) {
  $_0 = _psi_save_dc42($fp, $img) | 0; //@line 17681
 } else if (($type | 0) == 1) {
  $_0 = _psi_save_anadisk($fp, $img) | 0; //@line 17685
 } else if (($type | 0) == 11) {
  $_0 = _psi_save_psi($fp, $img) | 0; //@line 17689
 } else if (($type | 0) == 13) {
  $_0 = _psi_save_st($fp, $img) | 0; //@line 17693
 } else if (($type | 0) == 10) {
  $_0 = _psi_save_pfdc($fp, $img, 4) | 0; //@line 17697
 } else if (($type | 0) == 6) {
  $_0 = _psi_save_pfdc($fp, $img, -1) | 0; //@line 17701
 } else if (($type | 0) == 9) {
  $_0 = _psi_save_pfdc($fp, $img, 2) | 0; //@line 17705
 } else if (($type | 0) == 7) {
  $_0 = _psi_save_pfdc($fp, $img, 0) | 0; //@line 17709
 } else if (($type | 0) == 8) {
  $_0 = _psi_save_pfdc($fp, $img, 1) | 0; //@line 17713
 } else {
  $_0 = 1; //@line 17715
 }
 return $_0 | 0; //@line 17719
}
function _psi_sct_add_alternate($sct, $alt) {
 $sct = $sct | 0;
 $alt = $alt | 0;
 var $_0 = 0, $2 = 0;
 $_0 = $sct; //@line 17730
 do {
  $2 = $_0 | 0; //@line 17733
  $_0 = HEAP32[$2 >> 2] | 0; //@line 17734
 } while (($_0 | 0) != 0);
 HEAP32[$2 >> 2] = $alt; //@line 17743
 return;
}
function _psi_sct_get_alternate($sct, $idx) {
 $sct = $sct | 0;
 $idx = $idx | 0;
 var $_08 = 0, $_057 = 0, $5 = 0, $6 = 0, $_06 = 0;
 L15021 : do {
  if (($idx | 0) == 0) {
   $_06 = $sct; //@line 17760
  } else {
   $_057 = $sct;
   $_08 = $idx;
   while (1) {
    if (($_057 | 0) == 0) {
     $_06 = 0; //@line 17769
     break L15021;
    }
    $5 = HEAP32[$_057 >> 2] | 0; //@line 17773
    $6 = $_08 - 1 | 0; //@line 17774
    if (($6 | 0) == 0) {
     $_06 = $5; //@line 17778
     break;
    } else {
     $_057 = $5;
     $_08 = $6;
    }
   }
  }
 } while (0);
 return $_06 | 0; //@line 17788
}
function _psi_sct_fill($sct, $val) {
 $sct = $sct | 0;
 $val = $val | 0;
 var $1 = 0, $4 = 0, $5 = 0, $i_05 = 0;
 $1 = $sct + 10 | 0; //@line 17799
 if ((HEAP16[$1 >> 1] | 0) == 0) {
  return;
 }
 $4 = $val & 255; //@line 17807
 $5 = $sct + 24 | 0; //@line 17808
 $i_05 = 0; //@line 17810
 do {
  HEAP8[(HEAP32[$5 >> 2] | 0) + $i_05 | 0] = $4; //@line 17815
  $i_05 = $i_05 + 1 | 0; //@line 17816
 } while ($i_05 >>> 0 < (HEAPU16[$1 >> 1] | 0) >>> 0);
 return;
}
function _psi_sct_uniform($sct) {
 $sct = $sct | 0;
 var $1 = 0, $4 = 0, $i_0 = 0, $8 = 0, $_0 = 0, label = 0;
 $1 = $sct + 24 | 0; //@line 17838
 $4 = HEAPU16[$sct + 10 >> 1] | 0; //@line 17841
 $i_0 = 1; //@line 17843
 while (1) {
  if ($i_0 >>> 0 >= $4 >>> 0) {
   $_0 = 1; //@line 17849
   label = 11961; //@line 17850
   break;
  }
  $8 = HEAP32[$1 >> 2] | 0; //@line 17853
  if ((HEAP8[$8] | 0) == (HEAP8[$8 + $i_0 | 0] | 0)) {
   $i_0 = $i_0 + 1 | 0; //@line 17861
  } else {
   $_0 = 0; //@line 17863
   label = 11962; //@line 17864
   break;
  }
 }
 if ((label | 0) == 11962) {
  return $_0 | 0; //@line 17871
 } else if ((label | 0) == 11961) {
  return $_0 | 0; //@line 17876
 }
 return 0;
}
function _psi_sct_set_flags($sct, $flags, $set) {
 $sct = $sct | 0;
 $flags = $flags | 0;
 $set = $set | 0;
 var $3 = 0, $8 = 0;
 if (($set | 0) == 0) {
  $8 = $sct + 12 | 0; //@line 17892
  HEAP32[$8 >> 2] = HEAP32[$8 >> 2] & ~$flags; //@line 17895
  return;
 } else {
  $3 = $sct + 12 | 0; //@line 17899
  HEAP32[$3 >> 2] = HEAP32[$3 >> 2] | $flags; //@line 17902
  return;
 }
}
function _psi_sct_set_encoding($sct, $enc) {
 $sct = $sct | 0;
 $enc = $enc | 0;
 var $2 = 0, $_04 = 0;
 if (($sct | 0) == 0) {
  return;
 }
 $2 = $enc & 65535; //@line 17922
 $_04 = $sct; //@line 17924
 do {
  HEAP16[$_04 + 16 >> 1] = $2; //@line 17928
  $_04 = HEAP32[$_04 >> 2] | 0; //@line 17930
 } while (($_04 | 0) != 0);
 return;
}
function _psi_sct_set_position($sct, $val) {
 $sct = $sct | 0;
 $val = $val | 0;
 HEAP32[$sct + 48 >> 2] = $val; //@line 17951
 return;
}
function _psi_sct_get_position($sct) {
 $sct = $sct | 0;
 return HEAP32[$sct + 48 >> 2] | 0; //@line 17965
}
function _psi_sct_set_read_time($sct, $val) {
 $sct = $sct | 0;
 $val = $val | 0;
 HEAP32[$sct + 52 >> 2] = $val; //@line 17976
 return;
}
function _psi_sct_get_read_time($sct) {
 $sct = $sct | 0;
 return HEAP32[$sct + 52 >> 2] | 0; //@line 17990
}
function _psi_sct_set_mfm_size($sct, $val) {
 $sct = $sct | 0;
 $val = $val | 0;
 HEAP8[$sct + 56 | 0] = 1; //@line 18001
 HEAP8[$sct + 57 | 0] = $val; //@line 18003
 return;
}
function _psi_sct_get_mfm_size($sct) {
 $sct = $sct | 0;
 var $6 = 0, $n_0 = 0, $_0 = 0;
 if ((HEAP8[$sct + 56 | 0] | 0) != 0) {
  $_0 = HEAPU8[$sct + 57 | 0] | 0; //@line 18024
  return $_0 | 0; //@line 18027
 }
 $6 = HEAPU16[$sct + 10 >> 1] | 0; //@line 18031
 $n_0 = 0; //@line 18033
 while (1) {
  if ((128 << $n_0 | 0) < ($6 | 0)) {
   $n_0 = $n_0 + 1 | 0; //@line 18041
  } else {
   $_0 = $n_0; //@line 18043
   break;
  }
 }
 return $_0 | 0; //@line 18049
}
function _psi_sct_set_gcr_format($sct, $val) {
 $sct = $sct | 0;
 $val = $val | 0;
 HEAP8[$sct + 58 | 0] = 1; //@line 18060
 HEAP8[$sct + 59 | 0] = $val; //@line 18062
 return;
}
function _psi_sct_get_gcr_format($sct) {
 $sct = $sct | 0;
 var $_0 = 0;
 if ((HEAP8[$sct + 58 | 0] | 0) == 0) {
  $_0 = 0; //@line 18078
  return $_0 | 0; //@line 18081
 }
 $_0 = HEAPU8[$sct + 59 | 0] | 0; //@line 18087
 return $_0 | 0; //@line 18090
}
function _psi_sct_set_tags($sct, $buf, $cnt) {
 $sct = $sct | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $_cnt = 0, $i_010 = 0;
 $_cnt = $cnt >>> 0 > 16 ? 16 : $cnt; //@line 18103
 HEAP16[$sct + 28 >> 1] = $_cnt & 65535; //@line 18106
 if (($_cnt | 0) == 0) {
  return $_cnt | 0; //@line 18111
 } else {
  $i_010 = 0; //@line 18113
 }
 do {
  HEAP8[$sct + 30 + $i_010 | 0] = HEAP8[$buf + $i_010 | 0] | 0; //@line 18120
  $i_010 = $i_010 + 1 | 0; //@line 18121
 } while ($i_010 >>> 0 < $_cnt >>> 0);
 return $_cnt | 0; //@line 18131
}
function _psi_trk_get_indexed_sector($trk, $idx, $phy) {
 $trk = $trk | 0;
 $idx = $idx | 0;
 $phy = $phy | 0;
 var $2 = 0, $3 = 0, $7 = 0, $14 = 0, $_3_us = 0, $i_145_us = 0, $_144_us = 0, $24 = 0, $_2_us = 0, $33 = 0, $min_cnt_040_us = 0, $min_idx_039_us = 0, $i_038_us = 0, $39 = 0, $48 = 0, $min_idx_1_us = 0, $min_cnt_1_us = 0, $54 = 0, $56 = 0, $_037_us = 0, $min_sct_0_us = 0, $57 = 0, $58 = 0, $60 = 0, $64 = 0, $_0 = 0, label = 0;
 $2 = HEAP16[$trk + 2 >> 1] | 0; //@line 18151
 $3 = $2 & 65535; //@line 18152
 if ($2 << 16 >> 16 == 0) {
  $_0 = 0; //@line 18156
  return $_0 | 0; //@line 18159
 }
 if (($phy | 0) != 0) {
  if ($3 >>> 0 <= $idx >>> 0) {
   $_0 = 0; //@line 18167
   return $_0 | 0; //@line 18170
  }
  $_0 = HEAP32[(HEAP32[$trk + 4 >> 2] | 0) + ($idx << 2) >> 2] | 0; //@line 18177
  return $_0 | 0; //@line 18180
 }
 $7 = $trk + 4 | 0; //@line 18182
 $min_sct_0_us = 0;
 $_037_us = $idx;
 $56 = $2;
 L15089 : while (1) {
  $57 = HEAP32[$7 >> 2] | 0; //@line 18189
  $58 = $56 & 65535; //@line 18190
  $i_038_us = 0;
  $min_idx_039_us = 0;
  $min_cnt_040_us = 0;
  while (1) {
   $39 = HEAP16[(HEAP32[$57 + ($i_038_us << 2) >> 2] | 0) + 8 >> 1] | 0; //@line 18200
   do {
    if (($39 & 65535) >>> 0 < $min_sct_0_us >>> 0) {
     $min_cnt_1_us = $min_cnt_040_us;
     $min_idx_1_us = $min_idx_039_us;
    } else {
     if (($min_cnt_040_us | 0) == 0) {
      $min_cnt_1_us = 1;
      $min_idx_1_us = $i_038_us;
      break;
     }
     $48 = HEAP16[(HEAP32[$57 + ($min_idx_039_us << 2) >> 2] | 0) + 8 >> 1] | 0; //@line 18217
     if (($39 & 65535) < ($48 & 65535)) {
      $min_cnt_1_us = 1;
      $min_idx_1_us = $i_038_us;
      break;
     }
     $min_cnt_1_us = ($39 << 16 >> 16 == $48 << 16 >> 16) + $min_cnt_040_us | 0;
     $min_idx_1_us = $min_idx_039_us;
    }
   } while (0);
   $54 = $i_038_us + 1 | 0; //@line 18233
   if ($54 >>> 0 < $58 >>> 0) {
    $i_038_us = $54;
    $min_idx_039_us = $min_idx_1_us;
    $min_cnt_040_us = $min_cnt_1_us;
   } else {
    break;
   }
  }
  if (($min_cnt_1_us | 0) == 0) {
   $_0 = 0; //@line 18245
   label = 12022; //@line 18246
   break;
  }
  do {
   if ($_037_us >>> 0 < $min_cnt_1_us >>> 0) {
    if ($56 << 16 >> 16 == 0) {
     $_3_us = $_037_us;
     $14 = 0;
     break;
    }
    $60 = HEAP32[$7 >> 2] | 0; //@line 18259
    $64 = HEAP16[(HEAP32[$60 + ($min_idx_1_us << 2) >> 2] | 0) + 8 >> 1] | 0; //@line 18263
    $_144_us = $_037_us;
    $i_145_us = 0;
    while (1) {
     $24 = HEAP32[$60 + ($i_145_us << 2) >> 2] | 0; //@line 18270
     if ((HEAP16[$24 + 8 >> 1] | 0) == $64 << 16 >> 16) {
      if (($_144_us | 0) == 0) {
       $_0 = $24; //@line 18279
       label = 12020; //@line 18280
       break L15089;
      }
      $_2_us = $_144_us - 1 | 0; //@line 18285
     } else {
      $_2_us = $_144_us; //@line 18287
     }
     $33 = $i_145_us + 1 | 0; //@line 18290
     if ($33 >>> 0 < $3 >>> 0) {
      $_144_us = $_2_us;
      $i_145_us = $33;
     } else {
      $_3_us = $_2_us;
      $14 = $2;
      break;
     }
    }
   } else {
    $_3_us = $_037_us - $min_cnt_1_us | 0;
    $14 = $56;
   }
  } while (0);
  $min_sct_0_us = (HEAPU16[(HEAP32[(HEAP32[$7 >> 2] | 0) + ($min_idx_1_us << 2) >> 2] | 0) + 8 >> 1] | 0) + 1 | 0;
  $_037_us = $_3_us;
  $56 = $14;
 }
 if ((label | 0) == 12022) {
  return $_0 | 0; //@line 18320
 } else if ((label | 0) == 12020) {
  return $_0 | 0; //@line 18325
 }
 return 0;
}
function _psi_save($fname, $img, $type) {
 $fname = $fname | 0;
 $img = $img | 0;
 $type = $type | 0;
 var $_08 = 0, $5 = 0, $8 = 0, $_0 = 0;
 if (($type | 0) == 0) {
  $_08 = _psi_guess_type($fname) | 0; //@line 18342
 } else {
  $_08 = $type; //@line 18344
 }
 $5 = _fopen($fname | 0, 53312 | 0) | 0; //@line 18347
 if (($5 | 0) == 0) {
  $_0 = 1; //@line 18351
  return $_0 | 0; //@line 18354
 }
 $8 = _psi_save_fp($5, $img, $_08) | 0; //@line 18356
 _fclose($5 | 0) | 0; //@line 18357
 $_0 = $8; //@line 18359
 return $_0 | 0; //@line 18362
}
function _psi_probe_fp($fp) {
 $fp = $fp | 0;
 var $_0 = 0;
 do {
  if ((_psi_probe_psi_fp($fp) | 0) == 0) {
   if ((_psi_probe_pfdc_fp($fp) | 0) != 0) {
    $_0 = 6; //@line 18382
    break;
   }
   if ((_psi_probe_td0_fp($fp) | 0) != 0) {
    $_0 = 16; //@line 18389
    break;
   }
   if ((_psi_probe_imd_fp($fp) | 0) != 0) {
    $_0 = 4; //@line 18396
    break;
   }
   if ((_psi_probe_dc42_fp($fp) | 0) != 0) {
    $_0 = 3; //@line 18403
    break;
   }
   if ((_psi_probe_msa_fp($fp) | 0) != 0) {
    $_0 = 5; //@line 18410
    break;
   }
   if ((_psi_probe_stx_fp($fp) | 0) != 0) {
    $_0 = 14; //@line 18417
    break;
   }
   $_0 = (_psi_probe_raw_fp($fp) | 0) == 0 ? 0 : 12; //@line 18424
  } else {
   $_0 = 11; //@line 18426
  }
 } while (0);
 return $_0 | 0; //@line 18431
}
function _psi_sct_new($c, $h, $s, $n) {
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $n = $n | 0;
 var $1 = 0, $2 = 0, $26 = 0, $_0 = 0;
 $1 = _malloc(60) | 0; //@line 18447
 $2 = $1; //@line 18448
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 18452
  return $_0 | 0; //@line 18455
 }
 HEAP32[$1 >> 2] = 0; //@line 18458
 HEAP16[$1 + 4 >> 1] = $c & 65535; //@line 18462
 HEAP16[$1 + 6 >> 1] = $h & 65535; //@line 18466
 HEAP16[$1 + 8 >> 1] = $s & 65535; //@line 18470
 HEAP16[$1 + 10 >> 1] = $n & 65535; //@line 18474
 HEAP32[$1 + 12 >> 2] = 0; //@line 18477
 HEAP16[$1 + 16 >> 1] = 2; //@line 18480
 HEAP32[$1 + 20 >> 2] = 0; //@line 18483
 do {
  if (($n | 0) == 0) {
   HEAP32[$1 + 24 >> 2] = 0; //@line 18490
  } else {
   $26 = _malloc($n) | 0; //@line 18492
   HEAP32[$1 + 24 >> 2] = $26; //@line 18495
   if (($26 | 0) != 0) {
    break;
   }
   _free($1); //@line 18501
   $_0 = 0; //@line 18503
   return $_0 | 0; //@line 18506
  }
 } while (0);
 HEAP16[$1 + 28 >> 1] = 0; //@line 18511
 HEAP32[$1 + 48 >> 2] = -1; //@line 18514
 HEAP32[$1 + 52 >> 2] = 0; //@line 18517
 HEAP8[$1 + 56 | 0] = 0; //@line 18519
 HEAP8[$1 + 58 | 0] = 0; //@line 18521
 $_0 = $2; //@line 18523
 return $_0 | 0; //@line 18526
}
function _psi_sct_del($sct) {
 $sct = $sct | 0;
 var $_04 = 0, $3 = 0;
 if (($sct | 0) == 0) {
  return;
 } else {
  $_04 = $sct; //@line 18541
 }
 while (1) {
  $3 = HEAP32[$_04 >> 2] | 0; //@line 18546
  _free(HEAP32[$_04 + 24 >> 2] | 0); //@line 18549
  _free($_04); //@line 18551
  if (($3 | 0) == 0) {
   break;
  } else {
   $_04 = $3; //@line 18557
  }
 }
 return;
}
function _psi_sct_clone($sct, $deep) {
 $sct = $sct | 0;
 $deep = $deep | 0;
 var $2 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $14 = 0, $24 = 0, $26 = 0, $28 = 0, $31 = 0, $40 = 0, $42 = 0, $44 = 0, $46 = 0, $47 = 0, $48 = 0, $54 = 0, $56 = 0, $59 = 0, $60 = 0, $61 = 0, $sct_pn = 0, $_042 = 0, $91 = 0, $_04_i = 0, $94 = 0, $_0 = 0, label = 0;
 $2 = HEAP16[$sct + 4 >> 1] | 0; //@line 18582
 $4 = HEAP16[$sct + 6 >> 1] | 0; //@line 18584
 $6 = HEAP16[$sct + 8 >> 1] | 0; //@line 18586
 $8 = HEAP16[$sct + 10 >> 1] | 0; //@line 18588
 $9 = $8 & 65535; //@line 18589
 $10 = _malloc(60) | 0; //@line 18590
 $11 = $10; //@line 18591
 if (($10 | 0) == 0) {
  $_0 = 0; //@line 18595
  return $_0 | 0; //@line 18598
 }
 $14 = $10; //@line 18600
 HEAP32[$14 >> 2] = 0; //@line 18601
 HEAP16[$10 + 4 >> 1] = $2; //@line 18604
 HEAP16[$10 + 6 >> 1] = $4; //@line 18607
 HEAP16[$10 + 8 >> 1] = $6; //@line 18610
 HEAP16[$10 + 10 >> 1] = $8; //@line 18613
 $24 = $10 + 12 | 0; //@line 18615
 HEAP32[$24 >> 2] = 0; //@line 18616
 $26 = $10 + 16 | 0; //@line 18618
 HEAP16[$26 >> 1] = 2; //@line 18619
 $28 = $10 + 20 | 0; //@line 18621
 HEAP32[$28 >> 2] = 0; //@line 18622
 do {
  if ($8 << 16 >> 16 == 0) {
   HEAP32[$10 + 24 >> 2] = 0; //@line 18629
   $40 = 0; //@line 18630
  } else {
   $31 = _malloc($9) | 0; //@line 18632
   HEAP32[$10 + 24 >> 2] = $31; //@line 18635
   if (($31 | 0) != 0) {
    $40 = $31; //@line 18639
    break;
   }
   _free($10); //@line 18642
   $_0 = 0; //@line 18644
   return $_0 | 0; //@line 18647
  }
 } while (0);
 $42 = $10 + 28 | 0; //@line 18652
 HEAP16[$42 >> 1] = 0; //@line 18653
 $44 = $10 + 48 | 0; //@line 18655
 HEAP32[$44 >> 2] = -1; //@line 18656
 $46 = $10 + 52 | 0; //@line 18658
 HEAP32[$46 >> 2] = 0; //@line 18659
 $47 = $10 + 56 | 0; //@line 18660
 HEAP8[$47] = 0; //@line 18661
 $48 = $10 + 58 | 0; //@line 18662
 HEAP8[$48] = 0; //@line 18663
 HEAP32[$24 >> 2] = HEAP32[$sct + 12 >> 2]; //@line 18666
 HEAP16[$26 >> 1] = HEAP16[$sct + 16 >> 1] | 0; //@line 18669
 $54 = HEAP32[$sct + 24 >> 2] | 0; //@line 18671
 _memcpy($40 | 0, $54 | 0, $9) | 0; //@line 18672
 $56 = HEAP16[$sct + 28 >> 1] | 0; //@line 18674
 HEAP16[$42 >> 1] = $56; //@line 18675
 if ($56 << 16 >> 16 != 0) {
  $59 = $56 & 65535; //@line 18679
  $60 = $10 + 30 | 0; //@line 18680
  $61 = $sct + 30 | 0; //@line 18681
  _memcpy($60 | 0, $61 | 0, $59) | 0; //@line 18682
 }
 HEAP32[$44 >> 2] = HEAP32[$sct + 48 >> 2]; //@line 18687
 HEAP32[$46 >> 2] = HEAP32[$sct + 52 >> 2]; //@line 18690
 if ((HEAP8[$sct + 56 | 0] | 0) != 0) {
  HEAP8[$47] = 1; //@line 18696
  HEAP8[$10 + 57 | 0] = HEAP8[$sct + 57 | 0] | 0; //@line 18700
 }
 if ((HEAP8[$sct + 58 | 0] | 0) != 0) {
  HEAP8[$48] = 1; //@line 18708
  HEAP8[$10 + 59 | 0] = HEAP8[$sct + 59 | 0] | 0; //@line 18712
 }
 if (($deep | 0) == 0) {
  HEAP32[$28 >> 2] = 0; //@line 18718
  $_0 = $11; //@line 18720
  return $_0 | 0; //@line 18723
 }
 HEAP32[$28 >> 2] = HEAP32[$sct + 20 >> 2]; //@line 18727
 $sct_pn = $sct; //@line 18729
 while (1) {
  $_042 = HEAP32[$sct_pn >> 2] | 0; //@line 18733
  if (($_042 | 0) == 0) {
   $_0 = $11; //@line 18737
   label = 12076; //@line 18738
   break;
  }
  $91 = _psi_sct_clone($_042, 0) | 0; //@line 18741
  HEAP32[$14 >> 2] = $91; //@line 18742
  if (($91 | 0) == 0) {
   $_04_i = $11; //@line 18746
   break;
  } else {
   $sct_pn = $_042; //@line 18749
  }
 }
 if ((label | 0) == 12076) {
  return $_0 | 0; //@line 18755
 }
 while (1) {
  $94 = HEAP32[$_04_i >> 2] | 0; //@line 18760
  _free(HEAP32[$_04_i + 24 >> 2] | 0); //@line 18763
  _free($_04_i); //@line 18765
  if (($94 | 0) == 0) {
   $_0 = 0; //@line 18769
   break;
  } else {
   $_04_i = $94; //@line 18772
  }
 }
 return $_0 | 0; //@line 18777
}
function _psi_sct_set_size($sct, $size, $filler) {
 $sct = $sct | 0;
 $size = $size | 0;
 $filler = $filler | 0;
 var $1 = 0, $8 = 0, $10 = 0, $14 = 0, $_0 = 0;
 $1 = $sct + 10 | 0; //@line 18790
 if ((HEAPU16[$1 >> 1] | 0) >>> 0 >= $size >>> 0) {
  HEAP16[$1 >> 1] = $size & 65535; //@line 18797
  $_0 = 0; //@line 18799
  return $_0 | 0; //@line 18802
 }
 $8 = $sct + 24 | 0; //@line 18804
 $10 = _realloc(HEAP32[$8 >> 2] | 0, $size) | 0; //@line 18806
 if (($10 | 0) == 0) {
  $_0 = 1; //@line 18810
  return $_0 | 0; //@line 18813
 }
 $14 = HEAPU16[$1 >> 1] | 0; //@line 18816
 if ($14 >>> 0 < $size >>> 0) {
  _memset($10 + $14 | 0, $filler & 255 | 0, $size - $14 | 0); //@line 18823
 }
 HEAP16[$1 >> 1] = $size & 65535; //@line 18827
 HEAP32[$8 >> 2] = $10; //@line 18828
 $_0 = 0; //@line 18830
 return $_0 | 0; //@line 18833
}
function _psi_sct_get_tags($sct, $buf, $cnt) {
 $sct = $sct | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $3 = 0, $cnt_ = 0, $7 = 0, $8 = 0, $umax = 0, $i_017 = 0;
 $3 = HEAPU16[$sct + 28 >> 1] | 0; //@line 18848
 $cnt_ = $3 >>> 0 > $cnt >>> 0 ? $cnt : $3; //@line 18850
 if (($cnt_ | 0) != 0) {
  $i_017 = 0; //@line 18854
  do {
   HEAP8[$buf + $i_017 | 0] = HEAP8[$sct + 30 + $i_017 | 0] | 0; //@line 18860
   $i_017 = $i_017 + 1 | 0; //@line 18861
  } while ($i_017 >>> 0 < $cnt_ >>> 0);
 }
 if ($cnt_ >>> 0 >= $cnt >>> 0) {
  return $cnt_ | 0; //@line 18875
 }
 $7 = ~$cnt; //@line 18877
 $8 = ~$3; //@line 18878
 $umax = $7 >>> 0 > $8 >>> 0 ? $7 : $8; //@line 18880
 _memset($buf + ~$umax | 0, 0, $umax + $cnt + 1 | 0); //@line 18885
 return $cnt_ | 0; //@line 18888
}
function _psi_trk_new($h) {
 $h = $h | 0;
 var $1 = 0, $_0 = 0;
 $1 = _malloc(8) | 0; //@line 18898
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 18902
  return $_0 | 0; //@line 18905
 }
 HEAP16[$1 >> 1] = $h & 65535; //@line 18910
 HEAP16[$1 + 2 >> 1] = 0; //@line 18913
 HEAP32[$1 + 4 >> 2] = 0; //@line 18916
 $_0 = $1; //@line 18918
 return $_0 | 0; //@line 18921
}
function _psi_trk_del($trk) {
 $trk = $trk | 0;
 var $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i_09_i = 0, $11 = 0, $_04_i_i = 0, $14 = 0, $19 = 0, $20 = 0, $21 = 0, $_lcssa8_i = 0;
 if (($trk | 0) == 0) {
  return;
 }
 $3 = $trk + 2 | 0; //@line 18939
 $4 = HEAP16[$3 >> 1] | 0; //@line 18940
 $6 = $trk + 4 | 0; //@line 18942
 $7 = HEAP32[$6 >> 2] | 0; //@line 18943
 if ($4 << 16 >> 16 == 0) {
  $_lcssa8_i = $7; //@line 18946
 } else {
  $i_09_i = 0;
  $9 = $7;
  $8 = $4;
  while (1) {
   $11 = HEAP32[$9 + ($i_09_i << 2) >> 2] | 0; //@line 18954
   if (($11 | 0) == 0) {
    $20 = $8;
    $19 = $9;
   } else {
    $_04_i_i = $11; //@line 18960
    while (1) {
     $14 = HEAP32[$_04_i_i >> 2] | 0; //@line 18964
     _free(HEAP32[$_04_i_i + 24 >> 2] | 0); //@line 18967
     _free($_04_i_i); //@line 18969
     if (($14 | 0) == 0) {
      break;
     } else {
      $_04_i_i = $14; //@line 18975
     }
    }
    $20 = HEAP16[$3 >> 1] | 0;
    $19 = HEAP32[$6 >> 2] | 0;
   }
   $21 = $i_09_i + 1 | 0; //@line 18984
   if ($21 >>> 0 < ($20 & 65535) >>> 0) {
    $i_09_i = $21;
    $9 = $19;
    $8 = $20;
   } else {
    $_lcssa8_i = $19; //@line 18991
    break;
   }
  }
 }
 _free($_lcssa8_i); //@line 18998
 _free($trk); //@line 19000
 return;
}
function _psi_trk_add_sector($trk, $sct) {
 $trk = $trk | 0;
 $sct = $sct | 0;
 var $1 = 0, $4 = 0, $9 = 0, $10 = 0, $13 = 0, $_0 = 0;
 $1 = $trk + 4 | 0; //@line 19014
 $4 = $trk + 2 | 0; //@line 19017
 $9 = _realloc(HEAP32[$1 >> 2] | 0, ((HEAPU16[$4 >> 1] | 0) << 2) + 4 | 0) | 0; //@line 19022
 $10 = $9; //@line 19023
 if (($9 | 0) == 0) {
  $_0 = 1; //@line 19027
  return $_0 | 0; //@line 19030
 }
 HEAP32[$1 >> 2] = $10; //@line 19032
 $13 = HEAP16[$4 >> 1] | 0; //@line 19033
 HEAP32[$10 + (($13 & 65535) << 2) >> 2] = $sct; //@line 19036
 HEAP16[$4 >> 1] = $13 + 1 & 65535; //@line 19038
 $_0 = 0; //@line 19040
 return $_0 | 0; //@line 19043
}
function _psi_img_remove_sector($img, $sct) {
 $img = $img | 0;
 $sct = $sct | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $c_023 = 0, $8 = 0, $9 = 0, $12 = 0, $h_019 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $d_017 = 0, $s_016 = 0, $22 = 0, $24 = 0, $30 = 0, $d_1 = 0, $31 = 0, $d_0_lcssa_off0 = 0, $40 = 0, $41 = 0;
 $1 = $img | 0; //@line 19058
 $2 = HEAP16[$1 >> 1] | 0; //@line 19059
 if ($2 << 16 >> 16 == 0) {
  return;
 }
 $4 = $img + 4 | 0; //@line 19066
 $c_023 = 0;
 $5 = $2;
 while (1) {
  $8 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($c_023 << 2) >> 2] | 0; //@line 19074
  $9 = $8 + 2 | 0; //@line 19075
  if ((HEAP16[$9 >> 1] | 0) == 0) {
   $40 = $5; //@line 19080
  } else {
   $12 = $8 + 4 | 0; //@line 19082
   $h_019 = 0; //@line 19084
   do {
    $16 = HEAP32[(HEAP32[$12 >> 2] | 0) + ($h_019 << 2) >> 2] | 0; //@line 19089
    $17 = $16 + 2 | 0; //@line 19090
    $18 = HEAP16[$17 >> 1] | 0; //@line 19091
    if ($18 << 16 >> 16 == 0) {
     $d_0_lcssa_off0 = 0; //@line 19095
    } else {
     $20 = $16 + 4 | 0; //@line 19097
     $s_016 = 0;
     $d_017 = 0;
     $21 = $18;
     while (1) {
      $22 = HEAP32[$20 >> 2] | 0; //@line 19104
      $24 = HEAP32[$22 + ($s_016 << 2) >> 2] | 0; //@line 19106
      if (($24 | 0) == ($sct | 0)) {
       $d_1 = $d_017;
       $30 = $21;
      } else {
       HEAP32[$22 + ($d_017 << 2) >> 2] = $24; //@line 19114
       $d_1 = $d_017 + 1 | 0;
       $30 = HEAP16[$17 >> 1] | 0;
      }
      $31 = $s_016 + 1 | 0; //@line 19121
      if ($31 >>> 0 < ($30 & 65535) >>> 0) {
       $s_016 = $31;
       $d_017 = $d_1;
       $21 = $30;
      } else {
       break;
      }
     }
     $d_0_lcssa_off0 = $d_1 & 65535; //@line 19133
    }
    HEAP16[$17 >> 1] = $d_0_lcssa_off0; //@line 19136
    $h_019 = $h_019 + 1 | 0; //@line 19137
   } while ($h_019 >>> 0 < (HEAPU16[$9 >> 1] | 0) >>> 0);
   $40 = HEAP16[$1 >> 1] | 0; //@line 19150
  }
  $41 = $c_023 + 1 | 0; //@line 19153
  if ($41 >>> 0 < ($40 & 65535) >>> 0) {
   $c_023 = $41;
   $5 = $40;
  } else {
   break;
  }
 }
 return;
}
function _psi_img_get_sector($img, $c, $h, $s, $phy) {
 $img = $img | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $phy = $phy | 0;
 var $_0_i_i = 0, $17 = 0, $21 = 0, $24 = 0, $i_0 = 0, $40 = 0, $_0 = 0, label = 0;
 if ((HEAPU16[$img >> 1] | 0) >>> 0 <= $c >>> 0) {
  $_0 = 0; //@line 19188
  return $_0 | 0; //@line 19191
 }
 $_0_i_i = HEAP32[(HEAP32[$img + 4 >> 2] | 0) + ($c << 2) >> 2] | 0; //@line 19196
 if (($_0_i_i | 0) == 0) {
  $_0 = 0; //@line 19200
  return $_0 | 0; //@line 19203
 }
 if ((HEAPU16[$_0_i_i + 2 >> 1] | 0) >>> 0 <= $h >>> 0) {
  $_0 = 0; //@line 19211
  return $_0 | 0; //@line 19214
 }
 $17 = HEAP32[(HEAP32[$_0_i_i + 4 >> 2] | 0) + ($h << 2) >> 2] | 0; //@line 19219
 if (($17 | 0) == 0) {
  $_0 = 0; //@line 19223
  return $_0 | 0; //@line 19226
 }
 if (($phy | 0) != 0) {
  if ((HEAPU16[$17 + 2 >> 1] | 0) >>> 0 <= $s >>> 0) {
   $_0 = 0; //@line 19237
   return $_0 | 0; //@line 19240
  }
  $_0 = HEAP32[(HEAP32[$17 + 4 >> 2] | 0) + ($s << 2) >> 2] | 0; //@line 19247
  return $_0 | 0; //@line 19250
 }
 $21 = $17 + 4 | 0; //@line 19252
 $24 = HEAPU16[$17 + 2 >> 1] | 0; //@line 19255
 $i_0 = 0; //@line 19257
 while (1) {
  if ($i_0 >>> 0 >= $24 >>> 0) {
   $_0 = 0; //@line 19263
   label = 12144; //@line 19264
   break;
  }
  $40 = HEAP32[(HEAP32[$21 >> 2] | 0) + ($i_0 << 2) >> 2] | 0; //@line 19269
  if ((HEAPU16[$40 + 8 >> 1] | 0 | 0) == ($s | 0)) {
   $_0 = $40; //@line 19277
   label = 12143; //@line 19278
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 19281
  }
 }
 if ((label | 0) == 12143) {
  return $_0 | 0; //@line 19287
 } else if ((label | 0) == 12144) {
  return $_0 | 0; //@line 19292
 }
 return 0;
}
function _psi_trk_interleave($trk, $il) {
 $trk = $trk | 0;
 $il = $il | 0;
 var $2 = 0, $3 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $i_046 = 0, $14 = 0, $15 = 0, $18 = 0, $j_041 = 0, $20 = 0, $22 = 0, $j_0_lcssa = 0, $i_139 = 0, $j_138 = 0, $32 = 0, $33 = 0, $j_235 = 0, $37 = 0, $38 = 0, $_lcssa = 0, $j_2_lcssa = 0, $45 = 0, $_0 = 0;
 $2 = HEAP16[$trk + 2 >> 1] | 0; //@line 19310
 $3 = $2 & 65535; //@line 19311
 if (($2 & 65535) < 2) {
  $_0 = 0; //@line 19315
  return $_0 | 0; //@line 19318
 }
 $7 = _malloc($3 << 2) | 0; //@line 19321
 $8 = $7; //@line 19322
 if (($7 | 0) == 0) {
  $_0 = 1; //@line 19326
  return $_0 | 0; //@line 19329
 }
 $10 = $trk + 4 | 0; //@line 19331
 $i_046 = 0; //@line 19333
 do {
  $14 = (HEAP32[$10 >> 2] | 0) + ($i_046 << 2) | 0; //@line 19337
  $15 = HEAP32[$14 >> 2] | 0; //@line 19338
  HEAP32[$14 >> 2] = 0; //@line 19339
  L15282 : do {
   if (($i_046 | 0) == 0) {
    $j_0_lcssa = 0; //@line 19344
   } else {
    $18 = HEAP16[$15 + 8 >> 1] | 0; //@line 19347
    $j_041 = $i_046; //@line 19349
    while (1) {
     $20 = $j_041 - 1 | 0; //@line 19352
     $22 = HEAP32[$8 + ($20 << 2) >> 2] | 0; //@line 19354
     if (($18 & 65535) >= (HEAPU16[$22 + 8 >> 1] | 0)) {
      $j_0_lcssa = $j_041; //@line 19359
      break L15282;
     }
     HEAP32[$8 + ($j_041 << 2) >> 2] = $22; //@line 19363
     if (($20 | 0) == 0) {
      $j_0_lcssa = 0; //@line 19367
      break;
     } else {
      $j_041 = $20; //@line 19370
     }
    }
   }
  } while (0);
  HEAP32[$8 + ($j_0_lcssa << 2) >> 2] = $15; //@line 19377
  $i_046 = $i_046 + 1 | 0; //@line 19378
 } while ($i_046 >>> 0 < $3 >>> 0);
 $11 = $trk + 4 | 0; //@line 19387
 $j_138 = 0;
 $i_139 = 0;
 while (1) {
  $32 = HEAP32[$11 >> 2] | 0; //@line 19393
  $33 = $32 + ($j_138 << 2) | 0; //@line 19394
  if ((HEAP32[$33 >> 2] | 0) == 0) {
   $j_2_lcssa = $j_138;
   $_lcssa = $33;
  } else {
   $j_235 = $j_138; //@line 19401
   while (1) {
    $37 = (($j_235 + 1 | 0) >>> 0) % ($3 >>> 0) | 0; //@line 19405
    $38 = $32 + ($37 << 2) | 0; //@line 19406
    if ((HEAP32[$38 >> 2] | 0) == 0) {
     $j_2_lcssa = $37;
     $_lcssa = $38;
     break;
    } else {
     $j_235 = $37; //@line 19414
    }
   }
  }
  HEAP32[$_lcssa >> 2] = HEAP32[$8 + ($i_139 << 2) >> 2]; //@line 19422
  $45 = $i_139 + 1 | 0; //@line 19425
  if ($45 >>> 0 < $3 >>> 0) {
   $j_138 = (($j_2_lcssa + $il | 0) >>> 0) % ($3 >>> 0) | 0;
   $i_139 = $45;
  } else {
   break;
  }
 }
 _free($7); //@line 19434
 $_0 = 0; //@line 19436
 return $_0 | 0; //@line 19439
}
function _psi_cyl_free($cyl) {
 $cyl = $cyl | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i_010 = 0, $9 = 0, $12 = 0, $13 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $i_09_i_i = 0, $20 = 0, $_04_i_i_i = 0, $23 = 0, $28 = 0, $29 = 0, $30 = 0, $_lcssa8_i_i = 0, $35 = 0, $36 = 0, $37 = 0, $_lcssa9 = 0, $40 = 0;
 $1 = $cyl + 2 | 0; //@line 19453
 $2 = HEAP16[$1 >> 1] | 0; //@line 19454
 $4 = $cyl + 4 | 0; //@line 19456
 $5 = HEAP32[$4 >> 2] | 0; //@line 19457
 if ($2 << 16 >> 16 == 0) {
  $_lcssa9 = $5; //@line 19460
  $40 = $_lcssa9; //@line 19462
  _free($40); //@line 19463
  HEAP16[$1 >> 1] = 0; //@line 19464
  HEAP32[$4 >> 2] = 0; //@line 19465
  return;
 } else {
  $i_010 = 0;
  $7 = $5;
  $6 = $2;
 }
 while (1) {
  $9 = HEAP32[$7 + ($i_010 << 2) >> 2] | 0; //@line 19476
  if (($9 | 0) == 0) {
   $36 = $6;
   $35 = $7;
  } else {
   $12 = $9 + 2 | 0; //@line 19482
   $13 = HEAP16[$12 >> 1] | 0; //@line 19483
   $15 = $9 + 4 | 0; //@line 19485
   $16 = HEAP32[$15 >> 2] | 0; //@line 19486
   if ($13 << 16 >> 16 == 0) {
    $_lcssa8_i_i = $16; //@line 19489
   } else {
    $i_09_i_i = 0;
    $18 = $16;
    $17 = $13;
    while (1) {
     $20 = HEAP32[$18 + ($i_09_i_i << 2) >> 2] | 0; //@line 19497
     if (($20 | 0) == 0) {
      $29 = $17;
      $28 = $18;
     } else {
      $_04_i_i_i = $20; //@line 19503
      while (1) {
       $23 = HEAP32[$_04_i_i_i >> 2] | 0; //@line 19507
       _free(HEAP32[$_04_i_i_i + 24 >> 2] | 0); //@line 19510
       _free($_04_i_i_i); //@line 19512
       if (($23 | 0) == 0) {
        break;
       } else {
        $_04_i_i_i = $23; //@line 19518
       }
      }
      $29 = HEAP16[$12 >> 1] | 0;
      $28 = HEAP32[$15 >> 2] | 0;
     }
     $30 = $i_09_i_i + 1 | 0; //@line 19527
     if ($30 >>> 0 < ($29 & 65535) >>> 0) {
      $i_09_i_i = $30;
      $18 = $28;
      $17 = $29;
     } else {
      $_lcssa8_i_i = $28; //@line 19534
      break;
     }
    }
   }
   _free($_lcssa8_i_i); //@line 19541
   _free($9); //@line 19543
   $36 = HEAP16[$1 >> 1] | 0;
   $35 = HEAP32[$4 >> 2] | 0;
  }
  $37 = $i_010 + 1 | 0; //@line 19551
  if ($37 >>> 0 < ($36 & 65535) >>> 0) {
   $i_010 = $37;
   $7 = $35;
   $6 = $36;
  } else {
   $_lcssa9 = $35; //@line 19558
   break;
  }
 }
 $40 = $_lcssa9; //@line 19563
 _free($40); //@line 19564
 HEAP16[$1 >> 1] = 0; //@line 19565
 HEAP32[$4 >> 2] = 0; //@line 19566
 return;
}
function _psi_img_new() {
 var $1 = 0, $_0 = 0;
 $1 = _malloc(16) | 0; //@line 19577
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 19581
  return $_0 | 0; //@line 19584
 }
 HEAP16[$1 >> 1] = 0; //@line 19588
 HEAP32[$1 + 4 >> 2] = 0; //@line 19591
 HEAP32[$1 + 8 >> 2] = 0; //@line 19594
 HEAP32[$1 + 12 >> 2] = 0; //@line 19597
 $_0 = $1; //@line 19599
 return $_0 | 0; //@line 19602
}
function _psi_img_del($img) {
 $img = $img | 0;
 var $3 = 0, $4 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i_010_i = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $_lcssa9_i = 0;
 if (($img | 0) == 0) {
  return;
 }
 $3 = $img | 0; //@line 19620
 $4 = HEAP16[$3 >> 1] | 0; //@line 19621
 $6 = $img + 4 | 0; //@line 19623
 $7 = HEAP32[$6 >> 2] | 0; //@line 19624
 if ($4 << 16 >> 16 == 0) {
  $_lcssa9_i = $7; //@line 19627
 } else {
  $i_010_i = 0;
  $9 = $7;
  $8 = $4;
  while (1) {
   $11 = HEAP32[$9 + ($i_010_i << 2) >> 2] | 0; //@line 19635
   if (($11 | 0) == 0) {
    $16 = $8;
    $15 = $9;
   } else {
    _psi_cyl_free($11); //@line 19641
    _free($11); //@line 19643
    $16 = HEAP16[$3 >> 1] | 0;
    $15 = HEAP32[$6 >> 2] | 0;
   }
   $17 = $i_010_i + 1 | 0; //@line 19651
   if ($17 >>> 0 < ($16 & 65535) >>> 0) {
    $i_010_i = $17;
    $9 = $15;
    $8 = $16;
   } else {
    $_lcssa9_i = $15; //@line 19658
    break;
   }
  }
 }
 _free($_lcssa9_i); //@line 19665
 HEAP16[$3 >> 1] = 0; //@line 19666
 HEAP32[$6 >> 2] = 0; //@line 19667
 _free(HEAP32[$img + 12 >> 2] | 0); //@line 19670
 _free($img); //@line 19672
 return;
}
function _psi_img_erase($img) {
 $img = $img | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i_012 = 0, $9 = 0, $13 = 0, $14 = 0, $15 = 0, $_lcssa11 = 0, $19 = 0;
 $1 = $img | 0; //@line 19686
 $2 = HEAP16[$1 >> 1] | 0; //@line 19687
 $4 = $img + 4 | 0; //@line 19689
 $5 = HEAP32[$4 >> 2] | 0; //@line 19690
 if ($2 << 16 >> 16 == 0) {
  $_lcssa11 = $5; //@line 19693
 } else {
  $i_012 = 0;
  $7 = $5;
  $6 = $2;
  while (1) {
   $9 = HEAP32[$7 + ($i_012 << 2) >> 2] | 0; //@line 19701
   if (($9 | 0) == 0) {
    $14 = $6;
    $13 = $7;
   } else {
    _psi_cyl_free($9); //@line 19707
    _free($9); //@line 19709
    $14 = HEAP16[$1 >> 1] | 0;
    $13 = HEAP32[$4 >> 2] | 0;
   }
   $15 = $i_012 + 1 | 0; //@line 19717
   if ($15 >>> 0 < ($14 & 65535) >>> 0) {
    $i_012 = $15;
    $7 = $13;
    $6 = $14;
   } else {
    $_lcssa11 = $13; //@line 19724
    break;
   }
  }
 }
 _free($_lcssa11); //@line 19731
 HEAP16[$1 >> 1] = 0; //@line 19732
 HEAP32[$4 >> 2] = 0; //@line 19733
 $19 = $img + 12 | 0; //@line 19734
 _free(HEAP32[$19 >> 2] | 0); //@line 19736
 HEAP32[$img + 8 >> 2] = 0; //@line 19738
 HEAP32[$19 >> 2] = 0; //@line 19739
 return;
}
function _psi_img_add_track($img, $trk, $c) {
 $img = $img | 0;
 $trk = $trk | 0;
 $c = $c | 0;
 var $1 = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $12 = 0, $15 = 0, $16 = 0, $17 = 0, $27 = 0, $28 = 0, $_pn = 0, $_0_i = 0, $32 = 0, $35 = 0, $40 = 0, $43 = 0, $45 = 0, $47 = 0, $_012_i = 0, $_0 = 0, label = 0;
 $1 = $img | 0; //@line 19759
 $3 = HEAPU16[$1 >> 1] | 0; //@line 19761
 $5 = $img + 4 | 0; //@line 19763
 $6 = HEAP32[$5 >> 2] | 0; //@line 19764
 L15341 : do {
  if ($3 >>> 0 > $c >>> 0) {
   $_pn = $6; //@line 19768
  } else {
   $8 = $3;
   $7 = $6;
   while (1) {
    $12 = _realloc($7, ($8 << 2) + 4 | 0) | 0; //@line 19777
    if (($12 | 0) == 0) {
     $_0 = 1; //@line 19781
     label = 12211; //@line 19782
     break;
    }
    $15 = $12; //@line 19785
    HEAP32[$5 >> 2] = $15; //@line 19786
    $16 = HEAP16[$1 >> 1] | 0; //@line 19787
    $17 = _malloc(8) | 0; //@line 19788
    if (($17 | 0) == 0) {
     $_0 = 1; //@line 19792
     label = 12215; //@line 19793
     break;
    }
    HEAP16[$17 >> 1] = $16; //@line 19798
    HEAP16[$17 + 2 >> 1] = 0; //@line 19801
    HEAP32[$17 + 4 >> 2] = 0; //@line 19804
    HEAP32[$15 + (($16 & 65535) << 2) >> 2] = $17; //@line 19807
    $27 = $16 + 1 & 65535; //@line 19808
    HEAP16[$1 >> 1] = $27; //@line 19809
    $28 = $27 & 65535; //@line 19810
    if ($28 >>> 0 > $c >>> 0) {
     $_pn = $15; //@line 19814
     break L15341;
    } else {
     $8 = $28;
     $7 = $15;
    }
   }
   if ((label | 0) == 12211) {
    return $_0 | 0; //@line 19823
   } else if ((label | 0) == 12215) {
    return $_0 | 0; //@line 19828
   }
  }
 } while (0);
 $_0_i = HEAP32[$_pn + ($c << 2) >> 2] | 0; //@line 19834
 if (($_0_i | 0) == 0) {
  $_0 = 1; //@line 19838
  return $_0 | 0; //@line 19841
 }
 $32 = $_0_i + 4 | 0; //@line 19843
 $35 = $_0_i + 2 | 0; //@line 19846
 $40 = _realloc(HEAP32[$32 >> 2] | 0, ((HEAPU16[$35 >> 1] | 0) << 2) + 4 | 0) | 0; //@line 19851
 if (($40 | 0) == 0) {
  $_0 = 1; //@line 19855
  return $_0 | 0; //@line 19858
 }
 $43 = $40; //@line 19860
 HEAP32[$32 >> 2] = $43; //@line 19861
 $45 = HEAP16[$35 >> 1] | 0; //@line 19863
 do {
  if (($trk | 0) == 0) {
   $47 = _malloc(8) | 0; //@line 19867
   if (($47 | 0) == 0) {
    $_0 = 1; //@line 19871
    return $_0 | 0; //@line 19874
   } else {
    HEAP16[$47 >> 1] = $45; //@line 19878
    HEAP16[$47 + 2 >> 1] = 0; //@line 19881
    HEAP32[$47 + 4 >> 2] = 0; //@line 19884
    $_012_i = $47; //@line 19886
    break;
   }
  } else {
   $_012_i = $trk; //@line 19890
  }
 } while (0);
 HEAP32[$43 + (($45 & 65535) << 2) >> 2] = $_012_i; //@line 19896
 HEAP16[$35 >> 1] = $45 + 1 & 65535; //@line 19898
 $_0 = 0; //@line 19900
 return $_0 | 0; //@line 19903
}
function _psi_img_get_cylinder($img, $c, $alloc) {
 $img = $img | 0;
 $c = $c | 0;
 $alloc = $alloc | 0;
 var $1 = 0, $3 = 0, $12 = 0, $15 = 0, $16 = 0, $20 = 0, $23 = 0, $24 = 0, $25 = 0, $35 = 0, $36 = 0, $_0 = 0, label = 0;
 $1 = $img | 0; //@line 19918
 $3 = HEAPU16[$1 >> 1] | 0; //@line 19920
 if ($3 >>> 0 > $c >>> 0) {
  $_0 = HEAP32[(HEAP32[$img + 4 >> 2] | 0) + ($c << 2) >> 2] | 0; //@line 19929
  return $_0 | 0; //@line 19932
 }
 if (($alloc | 0) == 0) {
  $_0 = 0; //@line 19937
  return $_0 | 0; //@line 19940
 }
 $12 = $img + 4 | 0; //@line 19942
 $16 = $3;
 $15 = HEAP32[$12 >> 2] | 0;
 while (1) {
  $20 = _realloc($15, ($16 << 2) + 4 | 0) | 0; //@line 19952
  if (($20 | 0) == 0) {
   $_0 = 0; //@line 19956
   label = 12225; //@line 19957
   break;
  }
  $23 = $20; //@line 19960
  HEAP32[$12 >> 2] = $23; //@line 19961
  $24 = HEAP16[$1 >> 1] | 0; //@line 19962
  $25 = _malloc(8) | 0; //@line 19963
  if (($25 | 0) == 0) {
   $_0 = 0; //@line 19967
   label = 12227; //@line 19968
   break;
  }
  HEAP16[$25 >> 1] = $24; //@line 19973
  HEAP16[$25 + 2 >> 1] = 0; //@line 19976
  HEAP32[$25 + 4 >> 2] = 0; //@line 19979
  HEAP32[$23 + (($24 & 65535) << 2) >> 2] = $25; //@line 19982
  $35 = $24 + 1 & 65535; //@line 19983
  HEAP16[$1 >> 1] = $35; //@line 19984
  $36 = $35 & 65535; //@line 19985
  if ($36 >>> 0 > $c >>> 0) {
   label = 12223; //@line 19989
   break;
  } else {
   $16 = $36;
   $15 = $23;
  }
 }
 if ((label | 0) == 12225) {
  return $_0 | 0; //@line 19998
 } else if ((label | 0) == 12223) {
  $_0 = HEAP32[$23 + ($c << 2) >> 2] | 0; //@line 20004
  return $_0 | 0; //@line 20007
 } else if ((label | 0) == 12227) {
  return $_0 | 0; //@line 20012
 }
 return 0;
}
function _psi_img_add_sector($img, $sct, $c, $h) {
 $img = $img | 0;
 $sct = $sct | 0;
 $c = $c | 0;
 $h = $h | 0;
 var $1 = 0, $4 = 0, $7 = 0, $12 = 0, $13 = 0, $16 = 0, $_0 = 0;
 $1 = _psi_img_get_track($img, $c, $h, 1) | 0; //@line 20027
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 20031
  return $_0 | 0; //@line 20034
 }
 $4 = $1 + 4 | 0; //@line 20036
 $7 = $1 + 2 | 0; //@line 20039
 $12 = _realloc(HEAP32[$4 >> 2] | 0, ((HEAPU16[$7 >> 1] | 0) << 2) + 4 | 0) | 0; //@line 20044
 $13 = $12; //@line 20045
 if (($12 | 0) == 0) {
  $_0 = 1; //@line 20049
  return $_0 | 0; //@line 20052
 }
 HEAP32[$4 >> 2] = $13; //@line 20054
 $16 = HEAP16[$7 >> 1] | 0; //@line 20055
 HEAP32[$13 + (($16 & 65535) << 2) >> 2] = $sct; //@line 20058
 HEAP16[$7 >> 1] = $16 + 1 & 65535; //@line 20060
 $_0 = 0; //@line 20062
 return $_0 | 0; //@line 20065
}
function _psi_img_get_track($img, $c, $h, $alloc) {
 $img = $img | 0;
 $c = $c | 0;
 $h = $h | 0;
 $alloc = $alloc | 0;
 var $1 = 0, $3 = 0, $10 = 0, $13 = 0, $14 = 0, $18 = 0, $21 = 0, $22 = 0, $23 = 0, $33 = 0, $34 = 0, $_pn = 0, $_0_i = 0, $38 = 0, $40 = 0, $49 = 0, $52 = 0, $53 = 0, $57 = 0, $60 = 0, $61 = 0, $62 = 0, $72 = 0, $73 = 0, $_0 = 0, label = 0;
 $1 = $img | 0; //@line 20085
 $3 = HEAPU16[$1 >> 1] | 0; //@line 20087
 L15389 : do {
  if ($3 >>> 0 > $c >>> 0) {
   $_pn = HEAP32[$img + 4 >> 2] | 0; //@line 20095
  } else {
   if (($alloc | 0) == 0) {
    $_0 = 0; //@line 20100
    return $_0 | 0; //@line 20103
   }
   $10 = $img + 4 | 0; //@line 20105
   $14 = $3;
   $13 = HEAP32[$10 >> 2] | 0;
   while (1) {
    $18 = _realloc($13, ($14 << 2) + 4 | 0) | 0; //@line 20115
    if (($18 | 0) == 0) {
     $_0 = 0; //@line 20119
     label = 12262; //@line 20120
     break;
    }
    $21 = $18; //@line 20123
    HEAP32[$10 >> 2] = $21; //@line 20124
    $22 = HEAP16[$1 >> 1] | 0; //@line 20125
    $23 = _malloc(8) | 0; //@line 20126
    if (($23 | 0) == 0) {
     $_0 = 0; //@line 20130
     label = 12254; //@line 20131
     break;
    }
    HEAP16[$23 >> 1] = $22; //@line 20136
    HEAP16[$23 + 2 >> 1] = 0; //@line 20139
    HEAP32[$23 + 4 >> 2] = 0; //@line 20142
    HEAP32[$21 + (($22 & 65535) << 2) >> 2] = $23; //@line 20145
    $33 = $22 + 1 & 65535; //@line 20146
    HEAP16[$1 >> 1] = $33; //@line 20147
    $34 = $33 & 65535; //@line 20148
    if ($34 >>> 0 > $c >>> 0) {
     $_pn = $21; //@line 20152
     break L15389;
    } else {
     $14 = $34;
     $13 = $21;
    }
   }
   if ((label | 0) == 12262) {
    return $_0 | 0; //@line 20161
   } else if ((label | 0) == 12254) {
    return $_0 | 0; //@line 20166
   }
  }
 } while (0);
 $_0_i = HEAP32[$_pn + ($c << 2) >> 2] | 0; //@line 20172
 if (($_0_i | 0) == 0) {
  $_0 = 0; //@line 20176
  return $_0 | 0; //@line 20179
 }
 $38 = $_0_i + 2 | 0; //@line 20181
 $40 = HEAPU16[$38 >> 1] | 0; //@line 20183
 if ($40 >>> 0 > $h >>> 0) {
  $_0 = HEAP32[(HEAP32[$_0_i + 4 >> 2] | 0) + ($h << 2) >> 2] | 0; //@line 20192
  return $_0 | 0; //@line 20195
 }
 if (($alloc | 0) == 0) {
  $_0 = 0; //@line 20200
  return $_0 | 0; //@line 20203
 }
 $49 = $_0_i + 4 | 0; //@line 20205
 $53 = $40;
 $52 = HEAP32[$49 >> 2] | 0;
 while (1) {
  $57 = _realloc($52, ($53 << 2) + 4 | 0) | 0; //@line 20215
  if (($57 | 0) == 0) {
   $_0 = 0; //@line 20219
   label = 12261; //@line 20220
   break;
  }
  $60 = $57; //@line 20223
  HEAP32[$49 >> 2] = $60; //@line 20224
  $61 = HEAP16[$38 >> 1] | 0; //@line 20225
  $62 = _malloc(8) | 0; //@line 20226
  if (($62 | 0) == 0) {
   $_0 = 0; //@line 20230
   label = 12260; //@line 20231
   break;
  }
  HEAP16[$62 >> 1] = $61; //@line 20236
  HEAP16[$62 + 2 >> 1] = 0; //@line 20239
  HEAP32[$62 + 4 >> 2] = 0; //@line 20242
  HEAP32[$60 + (($61 & 65535) << 2) >> 2] = $62; //@line 20245
  $72 = $61 + 1 & 65535; //@line 20246
  HEAP16[$38 >> 1] = $72; //@line 20247
  $73 = $72 & 65535; //@line 20248
  if ($73 >>> 0 > $h >>> 0) {
   label = 12252; //@line 20252
   break;
  } else {
   $53 = $73;
   $52 = $60;
  }
 }
 if ((label | 0) == 12261) {
  return $_0 | 0; //@line 20261
 } else if ((label | 0) == 12260) {
  return $_0 | 0; //@line 20266
 } else if ((label | 0) == 12252) {
  $_0 = HEAP32[$60 + ($h << 2) >> 2] | 0; //@line 20272
  return $_0 | 0; //@line 20275
 }
 return 0;
}
function _psi_img_get_sector_count($img) {
 $img = $img | 0;
 var $2 = 0, $5 = 0, $6 = 0, $cnt_028 = 0, $c_027 = 0, $9 = 0, $11 = 0, $14 = 0, $15 = 0, $cnt_122 = 0, $h_021 = 0, $18 = 0, $20 = 0, $23 = 0, $24 = 0, $cnt_216 = 0, $s_015 = 0, $sct_012 = 0, $sct_014 = 0, $cnt_313 = 0, $29 = 0, $sct_0 = 0, $cnt_3_lcssa = 0, $31 = 0, $cnt_2_lcssa = 0, $33 = 0, $cnt_1_lcssa = 0, $35 = 0, $cnt_0_lcssa = 0;
 $2 = HEAP16[$img >> 1] | 0; //@line 20291
 if ($2 << 16 >> 16 == 0) {
  $cnt_0_lcssa = 0; //@line 20295
  return $cnt_0_lcssa | 0; //@line 20298
 }
 $5 = HEAP32[$img + 4 >> 2] | 0; //@line 20301
 $6 = $2 & 65535; //@line 20302
 $c_027 = 0;
 $cnt_028 = 0;
 while (1) {
  $9 = HEAP32[$5 + ($c_027 << 2) >> 2] | 0; //@line 20309
  $11 = HEAP16[$9 + 2 >> 1] | 0; //@line 20311
  if ($11 << 16 >> 16 == 0) {
   $cnt_1_lcssa = $cnt_028; //@line 20315
  } else {
   $14 = HEAP32[$9 + 4 >> 2] | 0; //@line 20318
   $15 = $11 & 65535; //@line 20319
   $h_021 = 0;
   $cnt_122 = $cnt_028;
   while (1) {
    $18 = HEAP32[$14 + ($h_021 << 2) >> 2] | 0; //@line 20326
    $20 = HEAP16[$18 + 2 >> 1] | 0; //@line 20328
    if ($20 << 16 >> 16 == 0) {
     $cnt_2_lcssa = $cnt_122; //@line 20332
    } else {
     $23 = HEAP32[$18 + 4 >> 2] | 0; //@line 20335
     $24 = $20 & 65535; //@line 20336
     $s_015 = 0;
     $cnt_216 = $cnt_122;
     while (1) {
      $sct_012 = HEAP32[$23 + ($s_015 << 2) >> 2] | 0; //@line 20343
      if (($sct_012 | 0) == 0) {
       $cnt_3_lcssa = $cnt_216; //@line 20347
      } else {
       $cnt_313 = $cnt_216;
       $sct_014 = $sct_012;
       while (1) {
        $29 = $cnt_313 + 1 | 0; //@line 20354
        $sct_0 = HEAP32[$sct_014 >> 2] | 0; //@line 20355
        if (($sct_0 | 0) == 0) {
         $cnt_3_lcssa = $29; //@line 20359
         break;
        } else {
         $cnt_313 = $29;
         $sct_014 = $sct_0;
        }
       }
      }
      $31 = $s_015 + 1 | 0; //@line 20367
      if ($31 >>> 0 < $24 >>> 0) {
       $s_015 = $31;
       $cnt_216 = $cnt_3_lcssa;
      } else {
       $cnt_2_lcssa = $cnt_3_lcssa; //@line 20373
       break;
      }
     }
    }
    $33 = $h_021 + 1 | 0; //@line 20379
    if ($33 >>> 0 < $15 >>> 0) {
     $h_021 = $33;
     $cnt_122 = $cnt_2_lcssa;
    } else {
     $cnt_1_lcssa = $cnt_2_lcssa; //@line 20385
     break;
    }
   }
  }
  $35 = $c_027 + 1 | 0; //@line 20391
  if ($35 >>> 0 < $6 >>> 0) {
   $c_027 = $35;
   $cnt_028 = $cnt_1_lcssa;
  } else {
   $cnt_0_lcssa = $cnt_1_lcssa; //@line 20397
   break;
  }
 }
 return $cnt_0_lcssa | 0; //@line 20403
}
function _psi_img_map_sector($img, $idx, $pc, $ph, $ps) {
 $img = $img | 0;
 $idx = $idx | 0;
 $pc = $pc | 0;
 $ph = $ph | 0;
 $ps = $ps | 0;
 var $2 = 0, $5 = 0, $_02336 = 0, $i_034 = 0, $8 = 0, $10 = 0, $13 = 0, $_129 = 0, $j_028 = 0, $16 = 0, $17 = 0, $19 = 0, $22 = 0, $25 = 0, $28 = 0, $k_024 = 0, $34 = 0, $35 = 0, $40 = 0, $41 = 0, $_1_lcssa = 0, $44 = 0, $_0 = 0, label = 0;
 $2 = HEAP16[$img >> 1] | 0; //@line 20422
 if ($2 << 16 >> 16 == 0) {
  $_0 = 1; //@line 20426
  return $_0 | 0; //@line 20429
 }
 $5 = HEAP32[$img + 4 >> 2] | 0; //@line 20432
 $i_034 = 0;
 $_02336 = $idx;
 L15447 : while (1) {
  $8 = HEAP32[$5 + ($i_034 << 2) >> 2] | 0; //@line 20439
  $10 = HEAP16[$8 + 2 >> 1] | 0; //@line 20441
  if ($10 << 16 >> 16 == 0) {
   $_1_lcssa = $_02336; //@line 20445
  } else {
   $13 = HEAP32[$8 + 4 >> 2] | 0; //@line 20448
   $j_028 = 0;
   $_129 = $_02336;
   while (1) {
    $16 = HEAP32[$13 + ($j_028 << 2) >> 2] | 0; //@line 20455
    $17 = $16 + 2 | 0; //@line 20456
    $19 = HEAPU16[$17 >> 1] | 0; //@line 20458
    if ($_129 >>> 0 < $19 >>> 0) {
     break L15447;
    }
    $40 = $_129 - $19 | 0; //@line 20464
    $41 = $j_028 + 1 | 0; //@line 20465
    if ($41 >>> 0 < ($10 & 65535) >>> 0) {
     $j_028 = $41;
     $_129 = $40;
    } else {
     $_1_lcssa = $40; //@line 20472
     break;
    }
   }
  }
  $44 = $i_034 + 1 | 0; //@line 20478
  if ($44 >>> 0 < ($2 & 65535) >>> 0) {
   $i_034 = $44;
   $_02336 = $_1_lcssa;
  } else {
   $_0 = 1; //@line 20485
   label = 12291; //@line 20486
   break;
  }
 }
 if ((label | 0) == 12291) {
  return $_0 | 0; //@line 20493
 }
 $22 = _psi_trk_get_indexed_sector($16, $_129, 0) | 0; //@line 20495
 if (($22 | 0) == 0) {
  $_0 = 1; //@line 20499
  return $_0 | 0; //@line 20502
 }
 HEAP32[$pc >> 2] = $i_034; //@line 20504
 HEAP32[$ph >> 2] = $j_028; //@line 20505
 HEAP32[$ps >> 2] = 0; //@line 20506
 $25 = $16 + 4 | 0; //@line 20507
 if ((HEAP16[$17 >> 1] | 0) == 0) {
  $_0 = 1; //@line 20512
  return $_0 | 0; //@line 20515
 } else {
  $k_024 = 0;
  $28 = 0;
 }
 while (1) {
  if ((HEAP32[(HEAP32[$25 >> 2] | 0) + ($k_024 << 2) >> 2] | 0) == ($22 | 0)) {
   $_0 = 0; //@line 20528
   label = 12294; //@line 20529
   break;
  }
  $34 = $28 + 1 | 0; //@line 20532
  HEAP32[$ps >> 2] = $34; //@line 20533
  $35 = $k_024 + 1 | 0; //@line 20534
  if ($35 >>> 0 < (HEAPU16[$17 >> 1] | 0) >>> 0) {
   $k_024 = $35;
   $28 = $34;
  } else {
   $_0 = 1; //@line 20542
   label = 12290; //@line 20543
   break;
  }
 }
 if ((label | 0) == 12294) {
  return $_0 | 0; //@line 20550
 } else if ((label | 0) == 12290) {
  return $_0 | 0; //@line 20555
 }
 return 0;
}
function _psi_img_add_comment($img, $buf, $cnt) {
 $img = $img | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $3 = 0, $6 = 0, $9 = 0, $10 = 0, $_0 = 0;
 $1 = $img + 12 | 0; //@line 20568
 $3 = $img + 8 | 0; //@line 20570
 $6 = _realloc(HEAP32[$1 >> 2] | 0, (HEAP32[$3 >> 2] | 0) + $cnt | 0) | 0; //@line 20573
 if (($6 | 0) == 0) {
  $_0 = 1; //@line 20577
  return $_0 | 0; //@line 20580
 }
 $9 = HEAP32[$3 >> 2] | 0; //@line 20582
 $10 = $6 + $9 | 0; //@line 20583
 _memcpy($10 | 0, $buf | 0, $cnt) | 0; //@line 20584
 HEAP32[$3 >> 2] = $9 + $cnt; //@line 20586
 HEAP32[$1 >> 2] = $6; //@line 20587
 $_0 = 0; //@line 20589
 return $_0 | 0; //@line 20592
}
function _psi_img_set_comment($img, $buf, $cnt) {
 $img = $img | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $3 = 0, $7 = 0, $10 = 0, $11 = 0, $_0 = 0;
 $1 = $img + 12 | 0; //@line 20604
 _free(HEAP32[$1 >> 2] | 0); //@line 20606
 $3 = $img + 8 | 0; //@line 20607
 HEAP32[$3 >> 2] = 0; //@line 20608
 HEAP32[$1 >> 2] = 0; //@line 20609
 if (($buf | 0) == 0 | ($cnt | 0) == 0) {
  $_0 = 0; //@line 20615
  return $_0 | 0; //@line 20618
 }
 $7 = _realloc(0, $cnt) | 0; //@line 20620
 if (($7 | 0) == 0) {
  $_0 = 1; //@line 20624
  return $_0 | 0; //@line 20627
 }
 $10 = HEAP32[$3 >> 2] | 0; //@line 20629
 $11 = $7 + $10 | 0; //@line 20630
 _memcpy($11 | 0, $buf | 0, $cnt) | 0; //@line 20631
 HEAP32[$3 >> 2] = $10 + $cnt; //@line 20633
 HEAP32[$1 >> 2] = $7; //@line 20634
 $_0 = 0; //@line 20636
 return $_0 | 0; //@line 20639
}
function _psi_img_clean_comment($img) {
 $img = $img | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $i_0 = 0, $i_135 = 0, $j_034 = 0, $13 = 0, $15 = 0, $17 = 0, $j_1 = 0, $i_2 = 0, $29 = 0, $j_2 = 0, $33 = 0, label = 0;
 $1 = $img + 8 | 0; //@line 20652
 $2 = HEAP32[$1 >> 2] | 0; //@line 20653
 $3 = $img + 12 | 0; //@line 20654
 $4 = HEAP32[$3 >> 2] | 0; //@line 20655
 $i_0 = 0; //@line 20657
 while (1) {
  if ($i_0 >>> 0 >= $2 >>> 0) {
   $j_2 = 0; //@line 20663
   break;
  }
  if ((HEAP8[$4 + $i_0 | 0] | 0) == 10) {
   $i_0 = $i_0 + 1 | 0; //@line 20671
  } else {
   $j_034 = 0;
   $i_135 = $i_0;
   label = 12310; //@line 20674
   break;
  }
 }
 if ((label | 0) == 12310) {
  while (1) {
   label = 0; //@line 20680
   $13 = HEAP8[$4 + $i_135 | 0] | 0; //@line 20684
   do {
    if (($13 << 24 >> 24 | 0) == 13) {
     $15 = $j_034 + 1 | 0; //@line 20687
     HEAP8[$4 + $j_034 | 0] = 10; //@line 20689
     $17 = $i_135 + 1 | 0; //@line 20690
     if ($17 >>> 0 >= $2 >>> 0) {
      $i_2 = $i_135;
      $j_1 = $15;
      break;
     }
     $i_2 = (HEAP8[$4 + $17 | 0] | 0) == 10 ? $17 : $i_135;
     $j_1 = $15;
    } else if (($13 << 24 >> 24 | 0) == 0) {
     HEAP8[$4 + $j_034 | 0] = 10; //@line 20706
     $i_2 = $i_135;
     $j_1 = $j_034 + 1 | 0;
    } else {
     HEAP8[$4 + $j_034 | 0] = $13; //@line 20712
     $i_2 = $i_135;
     $j_1 = $j_034 + 1 | 0;
    }
   } while (0);
   $29 = $i_2 + 1 | 0; //@line 20718
   if ($29 >>> 0 < $2 >>> 0) {
    $j_034 = $j_1;
    $i_135 = $29;
    label = 12310; //@line 20723
   } else {
    $j_2 = $j_1; //@line 20725
    break;
   }
  }
 }
 while (1) {
  if (($j_2 | 0) == 0) {
   label = 12319; //@line 20735
   break;
  }
  $33 = $j_2 - 1 | 0; //@line 20738
  if ((HEAP8[$4 + $33 | 0] | 0) == 10) {
   $j_2 = $33; //@line 20743
  } else {
   label = 12318; //@line 20745
   break;
  }
 }
 if ((label | 0) == 12318) {
  HEAP32[$1 >> 2] = $j_2; //@line 20750
  return;
 } else if ((label | 0) == 12319) {
  HEAP32[$1 >> 2] = 0; //@line 20756
  _free(HEAP32[$3 >> 2] | 0); //@line 20758
  HEAP32[$3 >> 2] = 0; //@line 20759
  return;
 }
}
function _psi_load_anadisk($fp) {
 $fp = $fp | 0;
 var $buf_i = 0, $1 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $13 = 0, $15 = 0, $16 = 0, $22 = 0, $29 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 20775
 STACKTOP = STACKTOP + 8 | 0; //@line 20775
 $buf_i = sp | 0; //@line 20776
 $1 = _psi_img_new() | 0; //@line 20777
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 20781
  STACKTOP = sp; //@line 20783
  return $_0 | 0; //@line 20784
 }
 $4 = $buf_i | 0; //@line 20786
 $5 = $buf_i + 1 | 0; //@line 20787
 $6 = $buf_i + 7 | 0; //@line 20788
 $7 = $buf_i + 6 | 0; //@line 20789
 $8 = $buf_i + 2 | 0; //@line 20790
 $9 = $buf_i + 3 | 0; //@line 20791
 $10 = $buf_i + 4 | 0; //@line 20792
 $11 = $buf_i + 5 | 0; //@line 20793
 do {
  $13 = _fread($4 | 0, 1, 8, $fp | 0) | 0; //@line 20796
  if (($13 | 0) == 0) {
   $_0 = $1; //@line 20798
   label = 12334; //@line 20799
   break;
  } else if (($13 | 0) != 8) {
   break;
  }
  $15 = HEAP8[$4] | 0; //@line 20804
  $16 = HEAP8[$5] | 0; //@line 20805
  $22 = (HEAPU8[$6] | 0) << 8 | (HEAPU8[$7] | 0); //@line 20811
  $29 = _psi_sct_new(HEAPU8[$8] | 0, HEAPU8[$9] | 0, HEAPU8[$10] | 0, $22) | 0; //@line 20818
  if (($29 | 0) == 0) {
   break;
  }
  _psi_sct_set_mfm_size($29, HEAP8[$11] | 0); //@line 20827
  if ((_psi_img_add_sector($1, $29, $15 & 255, $16 & 255) | 0) != 0) {
   label = 12328; //@line 20832
   break;
  }
 } while ((_fread(HEAP32[$29 + 24 >> 2] | 0, 1, $22 | 0, $fp | 0) | 0) == ($22 | 0));
 if ((label | 0) == 12328) {
  _psi_sct_del($29); //@line 20845
 } else if ((label | 0) == 12334) {
  STACKTOP = sp; //@line 20850
  return $_0 | 0; //@line 20851
 }
 _psi_img_del($1); //@line 20853
 $_0 = 0; //@line 20855
 STACKTOP = sp; //@line 20857
 return $_0 | 0; //@line 20858
}
function _psi_save_anadisk($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $c_016 = 0, $16 = 0, $17 = 0, $20 = 0, $21 = 0, $h_015 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $s_0 = 0, $35 = 0, $36 = 0, $47 = 0, $48 = 0, $58 = 0, $68 = 0, $69 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 20876
 STACKTOP = STACKTOP + 8 | 0; //@line 20876
 $buf_i = sp | 0; //@line 20877
 $1 = $img | 0; //@line 20878
 $2 = HEAP16[$1 >> 1] | 0; //@line 20879
 L15518 : do {
  if ($2 << 16 >> 16 != 0) {
   $4 = $img + 4 | 0; //@line 20884
   $5 = $buf_i | 0; //@line 20885
   $6 = $buf_i + 1 | 0; //@line 20886
   $7 = $buf_i + 2 | 0; //@line 20887
   $8 = $buf_i + 3 | 0; //@line 20888
   $9 = $buf_i + 4 | 0; //@line 20889
   $10 = $buf_i + 5 | 0; //@line 20890
   $11 = $buf_i + 6 | 0; //@line 20891
   $12 = $buf_i + 7 | 0; //@line 20892
   $c_016 = 0;
   $13 = $2;
   L15520 : while (1) {
    $16 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($c_016 << 2) >> 2] | 0; //@line 20900
    $17 = $16 + 2 | 0; //@line 20901
    if ((HEAP16[$17 >> 1] | 0) == 0) {
     $68 = $13; //@line 20906
    } else {
     $20 = $16 + 4 | 0; //@line 20908
     $21 = $c_016 & 255; //@line 20909
     $h_015 = 0; //@line 20911
     do {
      $24 = HEAP32[(HEAP32[$20 >> 2] | 0) + ($h_015 << 2) >> 2] | 0; //@line 20916
      $25 = $24 + 2 | 0; //@line 20917
      $26 = $24 + 4 | 0; //@line 20918
      $27 = $h_015 & 255; //@line 20919
      $s_0 = 0; //@line 20921
      while (1) {
       if ($s_0 >>> 0 >= (HEAPU16[$25 >> 1] | 0) >>> 0) {
        break;
       }
       $35 = HEAP32[(HEAP32[$26 >> 2] | 0) + ($s_0 << 2) >> 2] | 0; //@line 20933
       $36 = _psi_sct_get_mfm_size($35) | 0; //@line 20934
       HEAP8[$5] = $21; //@line 20935
       HEAP8[$6] = $27; //@line 20936
       HEAP8[$7] = HEAP16[$35 + 4 >> 1] & 255; //@line 20940
       HEAP8[$8] = HEAP16[$35 + 6 >> 1] & 255; //@line 20944
       HEAP8[$9] = HEAP16[$35 + 8 >> 1] & 255; //@line 20948
       HEAP8[$10] = $36 & 255; //@line 20950
       $47 = $35 + 10 | 0; //@line 20951
       $48 = HEAP16[$47 >> 1] | 0; //@line 20952
       HEAP8[$11] = $48 & 255; //@line 20954
       HEAP8[$12] = ($48 & 65535) >>> 8 & 255; //@line 20957
       if ((_fwrite($5 | 0, 1, 8, $fp | 0) | 0) != 8) {
        $_0 = 1; //@line 20962
        label = 12349; //@line 20963
        break L15520;
       }
       $58 = _fwrite(HEAP32[$35 + 24 >> 2] | 0, 1, HEAPU16[$47 >> 1] | 0, $fp | 0) | 0; //@line 20970
       if (($58 | 0) == (HEAPU16[$47 >> 1] | 0)) {
        $s_0 = $s_0 + 1 | 0; //@line 20977
       } else {
        $_0 = 1; //@line 20979
        label = 12350; //@line 20980
        break L15520;
       }
      }
      $h_015 = $h_015 + 1 | 0; //@line 20984
     } while ($h_015 >>> 0 < (HEAPU16[$17 >> 1] | 0) >>> 0);
     $68 = HEAP16[$1 >> 1] | 0; //@line 20997
    }
    $69 = $c_016 + 1 | 0; //@line 21000
    if ($69 >>> 0 < ($68 & 65535) >>> 0) {
     $c_016 = $69;
     $13 = $68;
    } else {
     break L15518;
    }
   }
   if ((label | 0) == 12349) {
    STACKTOP = sp; //@line 21012
    return $_0 | 0; //@line 21013
   } else if ((label | 0) == 12350) {
    STACKTOP = sp; //@line 21017
    return $_0 | 0; //@line 21018
   }
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 21022
 $_0 = 0; //@line 21024
 STACKTOP = sp; //@line 21026
 return $_0 | 0; //@line 21027
}
function _psi_save_cp2($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 return 1; //@line 21037
}
function _psi_load_cp2($fp) {
 $fp = $fp | 0;
 var $buf_i_i_i = 0, $buf_i4_i = 0, $buf_i_i = 0, $1 = 0, $4 = 0, $10 = 0, $12 = 0, $i_0_i_i = 0, $22 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $39 = 0, $42 = 0, $51 = 0, $_pre_i_i = 0, $53 = 0, $54 = 0, $ofs1_033_i_i = 0, $59 = 0, $60 = 0, $62 = 0, $71 = 0, $i_03_i_i_i = 0, $sh_01_i_i_i = 0, $73 = 0, $74 = 0, $75 = 0, $79 = 0, $82 = 0, $83 = 0, $106 = 0, $109 = 0, $111 = 0, $i_030_i_i_i_i = 0, $130 = 0, $ssize_0_i_i_i = 0, $146 = 0, $159 = 0, $166 = 0, $178 = 0, $182 = 0, $184 = 0, $186 = 0, $_pre7_i_pre_phi_i_i = 0, $204 = 0, $209 = 0, $216 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 21069
 STACKTOP = STACKTOP + 432 | 0; //@line 21069
 $buf_i_i_i = sp | 0; //@line 21070
 $buf_i4_i = sp + 8 | 0; //@line 21071
 $buf_i_i = sp + 400 | 0; //@line 21072
 $1 = _psi_img_new() | 0; //@line 21073
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 21077
  STACKTOP = sp; //@line 21079
  return $_0 | 0; //@line 21080
 }
 $4 = $buf_i_i | 0; //@line 21082
 L15543 : do {
  if ((_psi_read_ofs($fp, 0, $4, 30) | 0) == 0) {
   if ((_memcmp($4 | 0, 6736, 16) | 0) != 0) {
    $12 = HEAP32[_stderr >> 2] | 0; //@line 21092
    _fwrite(36640, 20, 1, $12 | 0) | 0; //@line 21093
    break;
   }
   $10 = $buf_i_i + 16 | 0; //@line 21097
   $i_0_i_i = 0; //@line 21099
   while (1) {
    if (($i_0_i_i | 0) == 5) {
     label = 12359; //@line 21105
     break;
    }
    if ((_memcmp($10 | 0, HEAP32[6712 + ($i_0_i_i << 2) >> 2] | 0, 14) | 0) == 0) {
     break;
    } else {
     $i_0_i_i = $i_0_i_i + 1 | 0; //@line 21117
    }
   }
   if ((label | 0) == 12359) {
    $22 = HEAP32[_stderr >> 2] | 0; //@line 21121
    _fwrite(33640, 34, 1, $22 | 0) | 0; //@line 21122
   }
   $24 = $buf_i4_i | 0; //@line 21125
   $25 = $buf_i_i_i | 0; //@line 21126
   $26 = $buf_i_i_i + 1 | 0; //@line 21127
   $27 = $buf_i4_i + 3 | 0; //@line 21128
   $28 = $buf_i4_i + 2 | 0; //@line 21129
   $29 = $buf_i4_i + 1 | 0; //@line 21130
   $30 = 30; //@line 21132
   L15554 : while (1) {
    if ((_psi_read_ofs($fp, $30, $25, 2) | 0) != 0) {
     $_0 = $1; //@line 21139
     label = 12414; //@line 21140
     break;
    }
    $39 = HEAPU8[$26] << 8 | HEAPU8[$25]; //@line 21148
    if (($39 | 0) == 0) {
     $_0 = $1; //@line 21152
     label = 12412; //@line 21153
     break;
    }
    $42 = $30 + 2 | 0; //@line 21156
    if ((_psi_read_ofs($fp, $39 + $42 | 0, $25, 2) | 0) != 0) {
     break L15543;
    }
    $51 = HEAPU8[$26] << 8 | HEAPU8[$25]; //@line 21169
    $_pre_i_i = $39 + 4 | 0; //@line 21171
    if ($39 >>> 0 >= 387) {
     $53 = $_pre_i_i + $30 | 0; //@line 21174
     $ofs1_033_i_i = 0;
     $54 = 387;
     while (1) {
      if ((_psi_read_ofs($fp, $ofs1_033_i_i + $42 | 0, $24, 387) | 0) != 0) {
       break L15543;
      }
      $59 = HEAP8[$28] | 0; //@line 21187
      $60 = $59 & 255; //@line 21188
      if ($59 << 24 >> 24 != 0) {
       if (($59 & 255) > 24) {
        break L15543;
       }
       $71 = _psi_img_get_track($1, HEAPU8[$24] | 0, HEAPU8[$29] | 0, 1) | 0; //@line 21201
       if (($71 | 0) == 0) {
        break L15543;
       } else {
        $sh_01_i_i_i = $27;
        $i_03_i_i_i = 0;
       }
       while (1) {
        $73 = HEAP32[_stderr >> 2] | 0; //@line 21212
        $74 = $i_03_i_i_i + 1 | 0; //@line 21213
        $75 = $sh_01_i_i_i + 9 | 0; //@line 21214
        $79 = $sh_01_i_i_i + 8 | 0; //@line 21218
        $82 = HEAPU8[$75] << 8 | HEAPU8[$79]; //@line 21221
        $83 = $sh_01_i_i_i + 2 | 0; //@line 21222
        do {
         if ((HEAP8[$83] & -106) << 24 >> 24 == 0) {
          if ((HEAP8[$sh_01_i_i_i + 10 | 0] | 0) != 0) {
           label = 12377; //@line 21234
           break;
          }
          if ((HEAP8[$sh_01_i_i_i + 11 | 0] | 0) != 0) {
           label = 12377; //@line 21242
           break;
          }
          if ((HEAP8[$sh_01_i_i_i + 14 | 0] & 127) != 0) {
           label = 12377; //@line 21251
           break;
          }
          if ((HEAP8[$sh_01_i_i_i + 15 | 0] | 0) != 0) {
           label = 12377; //@line 21259
           break;
          }
          $106 = HEAP8[$sh_01_i_i_i + 7 | 0] | 0; //@line 21263
          if (($106 & 255) < 7 & $82 >>> 0 > 5804) {
           $130 = $106; //@line 21269
          } else {
           label = 12377; //@line 21271
          }
         } else {
          label = 12377; //@line 21274
         }
        } while (0);
        if ((label | 0) == 12377) {
         label = 0; //@line 21278
         $109 = HEAPU8[$24] | 0; //@line 21280
         $111 = HEAPU8[$29] | 0; //@line 21282
         _fprintf($73 | 0, 56592, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $109, HEAP32[tempInt + 8 >> 2] = $111, HEAP32[tempInt + 16 >> 2] = $74, tempInt) | 0) | 0; //@line 21283
         $i_030_i_i_i_i = 0; //@line 21285
         do {
          do {
           if (($i_030_i_i_i_i | 0) == 8) {
            _fwrite(50080, 2, 1, $73 | 0) | 0; //@line 21292
           } else {
            if (($i_030_i_i_i_i & 3 | 0) != 0) {
             break;
            }
            _fputc(32, $73 | 0) | 0; //@line 21301
           }
          } while (0);
          _fprintf($73 | 0, 42680, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAPU8[$sh_01_i_i_i + $i_030_i_i_i_i | 0] | 0, tempInt) | 0) | 0; //@line 21308
          $i_030_i_i_i_i = $i_030_i_i_i_i + 1 | 0; //@line 21309
         } while ($i_030_i_i_i_i >>> 0 < 16);
         _fputc(10, $73 | 0) | 0; //@line 21318
         _fflush($73 | 0) | 0; //@line 21319
         $130 = HEAP8[$sh_01_i_i_i + 7 | 0] | 0; //@line 21323
        }
        if (($130 & 255) < 7) {
         $ssize_0_i_i_i = 128 << ($130 & 255); //@line 21333
        } else {
         $ssize_0_i_i_i = 0; //@line 21335
        }
        $146 = _psi_sct_new(HEAPU8[$sh_01_i_i_i + 4 | 0] | 0, HEAPU8[$sh_01_i_i_i + 5 | 0] | 0, HEAPU8[$sh_01_i_i_i + 6 | 0] | 0, $ssize_0_i_i_i) | 0; //@line 21347
        if (($146 | 0) == 0) {
         break L15543;
        }
        _psi_sct_set_mfm_size($146, HEAP8[$sh_01_i_i_i + 7 | 0] | 0); //@line 21354
        if ((_psi_trk_add_sector($71, $146) | 0) != 0) {
         label = 12388; //@line 21359
         break L15554;
        }
        $159 = HEAPU8[$75] << 8 | HEAPU8[$79]; //@line 21367
        do {
         if ((HEAP8[$sh_01_i_i_i + 14 | 0] & 50) == 0) {
          $166 = $sh_01_i_i_i + 3 | 0; //@line 21375
          if ((HEAP8[$166] & 1) != 0) {
           _psi_sct_fill($146, 0); //@line 21381
           $_pre7_i_pre_phi_i_i = $166; //@line 21383
           break;
          }
          if (($ssize_0_i_i_i - 256 | 0) >>> 0 > 3840) {
           _psi_sct_fill($146, 0); //@line 21390
           $_pre7_i_pre_phi_i_i = $166; //@line 21392
           break;
          }
          if ($159 >>> 0 < 5805) {
           _psi_sct_fill($146, 0); //@line 21398
           $_pre7_i_pre_phi_i_i = $166; //@line 21400
           break;
          }
          $178 = $159 - 5805 | 0; //@line 21403
          if (($178 + $ssize_0_i_i_i | 0) >>> 0 > $51 >>> 0) {
           $182 = HEAP32[_stderr >> 2] | 0; //@line 21408
           $184 = HEAPU8[$24] | 0; //@line 21410
           $186 = HEAPU8[$29] | 0; //@line 21412
           _fprintf($182 | 0, 53448, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $184, HEAP32[tempInt + 8 >> 2] = $186, HEAP32[tempInt + 16 >> 2] = $74, HEAP32[tempInt + 24 >> 2] = $ssize_0_i_i_i, tempInt) | 0) | 0; //@line 21413
           _psi_sct_fill($146, 0); //@line 21414
           $_pre7_i_pre_phi_i_i = $166; //@line 21416
           break;
          } else {
           if ((_psi_read_ofs($fp, $53 + $178 | 0, HEAP32[$146 + 24 >> 2] | 0, $ssize_0_i_i_i) | 0) == 0) {
            $_pre7_i_pre_phi_i_i = $166; //@line 21426
            break;
           } else {
            break L15543;
           }
          }
         } else {
          _psi_sct_fill($146, 0); //@line 21433
          $_pre7_i_pre_phi_i_i = $sh_01_i_i_i + 3 | 0; //@line 21436
         }
        } while (0);
        do {
         if ((HEAP8[$83] & 32) != 0) {
          if ((HEAP8[$_pre7_i_pre_phi_i_i] & 32) == 0) {
           _psi_sct_set_flags($146, 1, 1); //@line 21451
           break;
          } else {
           _psi_sct_set_flags($146, 2, 1); //@line 21454
           break;
          }
         }
        } while (0);
        $204 = HEAP8[$_pre7_i_pre_phi_i_i] | 0; //@line 21460
        if (($204 & 1) == 0) {
         $209 = $204; //@line 21465
        } else {
         _psi_sct_set_flags($146, 8, 1); //@line 21467
         $209 = HEAP8[$_pre7_i_pre_phi_i_i] | 0; //@line 21470
        }
        if (($209 & 64) != 0) {
         _psi_sct_set_flags($146, 4, 1); //@line 21477
        }
        if ($74 >>> 0 < $60 >>> 0) {
         $sh_01_i_i_i = $sh_01_i_i_i + 16 | 0;
         $i_03_i_i_i = $74;
        } else {
         break;
        }
       }
      }
      $62 = $54 + 387 | 0; //@line 21490
      if ($62 >>> 0 > $39 >>> 0) {
       break;
      } else {
       $ofs1_033_i_i = $54;
       $54 = $62;
      }
     }
    }
    $216 = $51 + $_pre_i_i | 0; //@line 21500
    if (($216 | 0) == 0) {
     $_0 = $1; //@line 21505
     label = 12415; //@line 21506
     break;
    } else {
     $30 = $216 + $30 | 0; //@line 21509
    }
   }
   if ((label | 0) == 12388) {
    _psi_sct_del($146); //@line 21513
    break;
   } else if ((label | 0) == 12412) {
    STACKTOP = sp; //@line 21519
    return $_0 | 0; //@line 21520
   } else if ((label | 0) == 12414) {
    STACKTOP = sp; //@line 21524
    return $_0 | 0; //@line 21525
   } else if ((label | 0) == 12415) {
    STACKTOP = sp; //@line 21529
    return $_0 | 0; //@line 21530
   }
  }
 } while (0);
 _psi_img_del($1); //@line 21534
 $_0 = 0; //@line 21536
 STACKTOP = sp; //@line 21538
 return $_0 | 0; //@line 21539
}
function _psi_load_dc42($fp) {
 $fp = $fp | 0;
 var $buf_i_i = 0, $check_i = 0, $buf_i = 0, $1 = 0, $5 = 0, $10 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $19 = 0, $r_0_i = 0, $36 = 0, $41 = 0, $42 = 0, $43 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $_02440_i_i = 0, $c_038_i_i = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $66 = 0, $67 = 0, $_132_i_i = 0, $h_031_i_i = 0, $71 = 0, $74 = 0, $76 = 0, $_229_i_i = 0, $s_028_i_i = 0, $77 = 0, $93 = 0, $103 = 0, $113 = 0, $123 = 0, $133 = 0, $143 = 0, $146 = 0, $148 = 0, $149 = 0, $150 = 0, $155 = 0, $156 = 0, $_2_lcssa_i_i = 0, $157 = 0, $161 = 0, $162 = 0, $_1_lcssa_i_i = 0, $163 = 0, $166 = 0, $_024_lcssa_i_i = 0, $170 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 21568
 STACKTOP = STACKTOP + 152 | 0; //@line 21568
 $buf_i_i = sp | 0; //@line 21569
 $check_i = sp + 16 | 0; //@line 21570
 $buf_i = sp + 24 | 0; //@line 21571
 $1 = _psi_img_new() | 0; //@line 21572
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 21576
  STACKTOP = sp; //@line 21578
  return $_0 | 0; //@line 21579
 }
 $5 = $buf_i | 0; //@line 21582
 L15632 : do {
  if ((_psi_read($fp, $5, 84) | 0) == 0) {
   $10 = (_psi_get_uint16_be($5, 82) | 0) != 256; //@line 21589
   if ($10 | (HEAPU8[$5] | 0) > 63) {
    break;
   }
   $14 = _psi_get_uint32_be($5, 64) | 0; //@line 21597
   $15 = _psi_get_uint32_be($5, 68) | 0; //@line 21598
   $16 = _psi_get_uint32_be($5, 72) | 0; //@line 21599
   $17 = _psi_get_uint32_be($5, 76) | 0; //@line 21600
   $19 = HEAP8[$buf_i + 81 | 0] | 0; //@line 21602
   if (($14 | 0) == 737280) {
    $r_0_i = _dc42_load_mfm($fp, $1, 9, $check_i) | 0; //@line 21606
   } else if (($14 | 0) == 409600) {
    $r_0_i = _dc42_load_gcr($fp, $1, 1, $check_i, $19 & 255) | 0; //@line 21611
   } else if (($14 | 0) == 819200) {
    $r_0_i = _dc42_load_gcr($fp, $1, 2, $check_i, $19 & 255) | 0; //@line 21616
   } else if (($14 | 0) == 1474560) {
    $r_0_i = _dc42_load_mfm($fp, $1, 18, $check_i) | 0; //@line 21620
   } else {
    break;
   }
   if (($r_0_i | 0) != 0) {
    break;
   }
   if (($16 | 0) != (HEAP32[$check_i >> 2] | 0)) {
    $36 = HEAP32[_stderr >> 2] | 0; //@line 21634
    _fwrite(50024, 26, 1, $36 | 0) | 0; //@line 21635
    break;
   }
   if (($15 | 0) == 0) {
    $_0 = $1; //@line 21642
    STACKTOP = sp; //@line 21644
    return $_0 | 0; //@line 21645
   }
   $41 = $buf_i_i | 0; //@line 21647
   HEAP32[$check_i >> 2] = 0; //@line 21648
   $42 = $1 | 0; //@line 21649
   $43 = HEAP16[$42 >> 1] | 0; //@line 21650
   if ($43 << 16 >> 16 == 0) {
    $_024_lcssa_i_i = $15;
    $166 = 0;
   } else {
    $45 = $1 + 4 | 0; //@line 21656
    $46 = $buf_i_i + 1 | 0; //@line 21657
    $47 = $buf_i_i + 2 | 0; //@line 21658
    $48 = $buf_i_i + 3 | 0; //@line 21659
    $49 = $buf_i_i + 4 | 0; //@line 21660
    $50 = $buf_i_i + 5 | 0; //@line 21661
    $51 = $buf_i_i + 6 | 0; //@line 21662
    $52 = $buf_i_i + 7 | 0; //@line 21663
    $53 = $buf_i_i + 8 | 0; //@line 21664
    $54 = $buf_i_i + 9 | 0; //@line 21665
    $55 = $buf_i_i + 10 | 0; //@line 21666
    $56 = $buf_i_i + 11 | 0; //@line 21667
    $c_038_i_i = 0;
    $_02440_i_i = $15;
    $58 = $43;
    $57 = 0;
    while (1) {
     $61 = HEAP32[(HEAP32[$45 >> 2] | 0) + ($c_038_i_i << 2) >> 2] | 0; //@line 21677
     $62 = $61 + 2 | 0; //@line 21678
     $63 = HEAP16[$62 >> 1] | 0; //@line 21679
     if ($63 << 16 >> 16 == 0) {
      $_1_lcssa_i_i = $_02440_i_i;
      $162 = $58;
      $161 = $57;
     } else {
      $65 = $61 + 4 | 0; //@line 21685
      $h_031_i_i = 0;
      $_132_i_i = $_02440_i_i;
      $67 = $63;
      $66 = $57;
      while (1) {
       $71 = (HEAP32[(HEAP32[$65 >> 2] | 0) + ($h_031_i_i << 2) >> 2] | 0) + 2 | 0; //@line 21696
       if ((HEAP16[$71 >> 1] | 0) == 0) {
        $_2_lcssa_i_i = $_132_i_i;
        $156 = $67;
        $155 = $66;
       } else {
        $74 = $h_031_i_i | $c_038_i_i; //@line 21703
        $s_028_i_i = 0;
        $_229_i_i = $_132_i_i;
        $76 = $66;
        while (1) {
         $77 = _psi_img_get_sector($1, $c_038_i_i, $h_031_i_i, $s_028_i_i, 0) | 0; //@line 21710
         if (($77 | 0) == 0 | $_229_i_i >>> 0 < 12) {
          break L15632;
         }
         if ((_psi_read($fp, $41, 12) | 0) != 0) {
          break L15632;
         }
         _psi_sct_set_tags($77, $41, 12) | 0; //@line 21724
         if (($74 | $s_028_i_i | 0) == 0) {
          $148 = $76; //@line 21729
         } else {
          $93 = (HEAPU8[$41] << 8 | HEAPU8[$46]) + $76 | 0; //@line 21737
          $103 = ($93 >>> 1 | $93 << 31) + (HEAPU8[$47] << 8 | HEAPU8[$48]) | 0; //@line 21747
          $113 = ($103 >>> 1 | $103 << 31) + (HEAPU8[$49] << 8 | HEAPU8[$50]) | 0; //@line 21757
          $123 = ($113 >>> 1 | $113 << 31) + (HEAPU8[$51] << 8 | HEAPU8[$52]) | 0; //@line 21767
          $133 = ($123 >>> 1 | $123 << 31) + (HEAPU8[$53] << 8 | HEAPU8[$54]) | 0; //@line 21777
          $143 = ($133 >>> 1 | $133 << 31) + (HEAPU8[$55] << 8 | HEAPU8[$56]) | 0; //@line 21787
          $146 = $143 >>> 1 | $143 << 31; //@line 21790
          HEAP32[$check_i >> 2] = $146; //@line 21791
          $148 = $146; //@line 21793
         }
         $149 = $_229_i_i - 12 | 0; //@line 21796
         $150 = $s_028_i_i + 1 | 0; //@line 21797
         if ($150 >>> 0 < (HEAPU16[$71 >> 1] | 0) >>> 0) {
          $s_028_i_i = $150;
          $_229_i_i = $149;
          $76 = $148;
         } else {
          break;
         }
        }
        $_2_lcssa_i_i = $149;
        $156 = HEAP16[$62 >> 1] | 0;
        $155 = $148;
       }
       $157 = $h_031_i_i + 1 | 0; //@line 21815
       if ($157 >>> 0 < ($156 & 65535) >>> 0) {
        $h_031_i_i = $157;
        $_132_i_i = $_2_lcssa_i_i;
        $67 = $156;
        $66 = $155;
       } else {
        break;
       }
      }
      $_1_lcssa_i_i = $_2_lcssa_i_i;
      $162 = HEAP16[$42 >> 1] | 0;
      $161 = $155;
     }
     $163 = $c_038_i_i + 1 | 0; //@line 21832
     if ($163 >>> 0 < ($162 & 65535) >>> 0) {
      $c_038_i_i = $163;
      $_02440_i_i = $_1_lcssa_i_i;
      $58 = $162;
      $57 = $161;
     } else {
      $_024_lcssa_i_i = $_1_lcssa_i_i;
      $166 = $161;
      break;
     }
    }
   }
   if (($_024_lcssa_i_i | 0) != 0) {
    break;
   }
   if (($17 | 0) == ($166 | 0)) {
    $_0 = $1; //@line 21854
    STACKTOP = sp; //@line 21856
    return $_0 | 0; //@line 21857
   } else {
    $170 = HEAP32[_stderr >> 2] | 0; //@line 21859
    _fwrite(46168, 25, 1, $170 | 0) | 0; //@line 21860
    break;
   }
  }
 } while (0);
 _psi_img_del($1); //@line 21866
 $_0 = 0; //@line 21868
 STACKTOP = sp; //@line 21870
 return $_0 | 0; //@line 21871
}
function _psi_save_dc42($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i = 0, $buf = 0, $5 = 0, $c_022_i = 0, $8 = 0, $14 = 0, $17 = 0, $22 = 0, $s_0_i = 0, $28 = 0, $38 = 0, $c_013_i = 0, $41 = 0, $43 = 0, $46 = 0, $47 = 0, $h_011_i = 0, $50 = 0, $53 = 0, $54 = 0, $s_0_i30 = 0, $68 = 0, $c_022_i34 = 0, $71 = 0, $77 = 0, $79 = 0, $80 = 0, $85 = 0, $s_0_i38 = 0, $91 = 0, $103 = 0, $c_013_i43 = 0, $109 = 0, $111 = 0, $114 = 0, $115 = 0, $h_011_i45 = 0, $118 = 0, $121 = 0, $122 = 0, $s_0_i46 = 0, $136 = 0, $c_07_i = 0, $139 = 0, $144 = 0, $145 = 0, $149 = 0, $s_0_i58 = 0, $155 = 0, $161 = 0, $167 = 0, $171 = 0, $s_0_1_i = 0, $175 = 0, $180 = 0, $186 = 0, $c_07_i61 = 0, $191 = 0, $196 = 0, $197 = 0, $201 = 0, $s_0_i64 = 0, $207 = 0, $213 = 0, $219 = 0, $223 = 0, $s_0_1_i68 = 0, $227 = 0, $232 = 0, $238 = 0, $hn_0 = 0, $sn_0 = 0, $enc_0 = 0, $data_size_0 = 0, $tags_size_0 = 0, $242 = 0, $243 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $data_check_0_load8091 = 0, $tags_check_0_load7986 = 0, $c_013_i72 = 0, $263 = 0, $264 = 0, $data_check_0_load8090 = 0, $tags_check_0_load7985 = 0, $h_010_i = 0, $265 = 0, $data_check_0_load8089 = 0, $tags_check_0_load7984 = 0, $s_09_i = 0, $267 = 0, $273 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_01112_i_i = 0, $284 = 0, $287 = 0, $288 = 0, $_011_lcssa_i_i = 0, $300 = 0, $310 = 0, $320 = 0, $330 = 0, $340 = 0, $350 = 0, $tags_check_0_load7983 = 0, $355 = 0, $data_check_0_load8088 = 0, $tags_check_0_load7982 = 0, $357 = 0, $359 = 0, $362 = 0, $364 = 0, $368 = 0, $369 = 0, $src_0_i = 0, $380 = 0, $_1_i = 0, $i_02_i = 0, $c_03_us_i = 0, $394 = 0, $s_0_us_i = 0, $403 = 0, $h_01_us_i = 0, $c_03_i50 = 0, $h_01_i51 = 0, $s_0_i53 = 0, $417 = 0, $c_03_i = 0, $438 = 0, $h_01_i = 0, $s_0_i27 = 0, $442 = 0, $_0 = 0, $455 = 0, $s_0_i38_1 = 0, $458 = 0, $463 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 21938
 STACKTOP = STACKTOP + 144 | 0; //@line 21938
 $buf_i = sp | 0; //@line 21939
 $buf = sp + 16 | 0; //@line 21940
 if ((HEAP16[$img >> 1] | 0) != 80) {
  $_0 = 1; //@line 21946
  STACKTOP = sp; //@line 21948
  return $_0 | 0; //@line 21949
 }
 $5 = HEAP32[$img + 4 >> 2] | 0; //@line 21952
 $c_022_i = 0; //@line 21954
 L15680 : while (1) {
  $8 = HEAP32[$5 + ($c_022_i << 2) >> 2] | 0; //@line 21958
  if ((HEAP16[$8 + 2 >> 1] | 0) != 1) {
   $c_022_i34 = 0; //@line 21964
   label = 12469; //@line 21965
   break;
  }
  $14 = 12 - ($c_022_i >>> 4) | 0; //@line 21969
  $17 = HEAP32[HEAP32[$8 + 4 >> 2] >> 2] | 0; //@line 21972
  if ((HEAPU16[$17 + 2 >> 1] | 0) != ($14 | 0)) {
   $c_022_i34 = 0; //@line 21979
   label = 12469; //@line 21980
   break;
  }
  $22 = $17 + 4 | 0; //@line 21983
  $s_0_i = 0; //@line 21985
  while (1) {
   if ($s_0_i >>> 0 >= $14 >>> 0) {
    break;
   }
   $28 = HEAP32[(HEAP32[$22 >> 2] | 0) + ($s_0_i << 2) >> 2] | 0; //@line 21995
   if ((HEAP16[$28 + 10 >> 1] | 0) != 512) {
    $c_022_i34 = 0; //@line 22001
    label = 12469; //@line 22002
    break L15680;
   }
   if ((HEAPU16[$28 + 8 >> 1] | 0) >>> 0 < $14 >>> 0) {
    $s_0_i = $s_0_i + 1 | 0; //@line 22012
   } else {
    $c_022_i34 = 0; //@line 22014
    label = 12469; //@line 22015
    break L15680;
   }
  }
  $38 = $c_022_i + 1 | 0; //@line 22019
  if ($38 >>> 0 < 80) {
   $c_022_i = $38; //@line 22023
  } else {
   $c_013_i = 0; //@line 22025
   label = 12462; //@line 22026
   break;
  }
 }
 L15689 : do {
  if ((label | 0) == 12462) {
   while (1) {
    label = 0; //@line 22033
    $41 = HEAP32[$5 + ($c_013_i << 2) >> 2] | 0; //@line 22036
    $43 = HEAP16[$41 + 2 >> 1] | 0; //@line 22038
    if ($43 << 16 >> 16 != 0) {
     $46 = HEAP32[$41 + 4 >> 2] | 0; //@line 22043
     $47 = $43 & 65535; //@line 22044
     $h_011_i = 0; //@line 22046
     do {
      $50 = HEAP32[$46 + ($h_011_i << 2) >> 2] | 0; //@line 22050
      $53 = HEAPU16[$50 + 2 >> 1] | 0; //@line 22053
      $54 = $50 + 4 | 0; //@line 22054
      $s_0_i30 = 0; //@line 22056
      while (1) {
       if ($s_0_i30 >>> 0 >= $53 >>> 0) {
        break;
       }
       if ((HEAP16[(HEAP32[(HEAP32[$54 >> 2] | 0) + ($s_0_i30 << 2) >> 2] | 0) + 28 >> 1] | 0) == 0) {
        $s_0_i30 = $s_0_i30 + 1 | 0; //@line 22073
       } else {
        $tags_size_0 = 9600;
        $data_size_0 = 409600;
        $enc_0 = 2;
        $sn_0 = 0;
        $hn_0 = 1;
        break L15689;
       }
      }
      $h_011_i = $h_011_i + 1 | 0; //@line 22079
     } while ($h_011_i >>> 0 < $47 >>> 0);
    }
    $68 = $c_013_i + 1 | 0; //@line 22089
    if ($68 >>> 0 < 80) {
     $c_013_i = $68; //@line 22093
     label = 12462; //@line 22094
    } else {
     $tags_size_0 = 0;
     $data_size_0 = 409600;
     $enc_0 = 2;
     $sn_0 = 0;
     $hn_0 = 1;
     break;
    }
   }
  } else if ((label | 0) == 12469) {
   L15701 : while (1) {
    label = 0; //@line 22103
    $71 = HEAP32[$5 + ($c_022_i34 << 2) >> 2] | 0; //@line 22106
    if ((HEAP16[$71 + 2 >> 1] | 0) != 2) {
     $c_07_i = 0; //@line 22112
     break;
    }
    $77 = 12 - ($c_022_i34 >>> 4) | 0; //@line 22116
    $79 = HEAP32[$71 + 4 >> 2] | 0; //@line 22118
    $80 = HEAP32[$79 >> 2] | 0; //@line 22119
    if ((HEAPU16[$80 + 2 >> 1] | 0) != ($77 | 0)) {
     $c_07_i = 0; //@line 22126
     break;
    }
    $85 = $80 + 4 | 0; //@line 22129
    $s_0_i38 = 0; //@line 22131
    while (1) {
     if ($s_0_i38 >>> 0 >= $77 >>> 0) {
      break;
     }
     $91 = HEAP32[(HEAP32[$85 >> 2] | 0) + ($s_0_i38 << 2) >> 2] | 0; //@line 22141
     if ((HEAP16[$91 + 10 >> 1] | 0) != 512) {
      $c_07_i = 0; //@line 22147
      break L15701;
     }
     if ((HEAPU16[$91 + 8 >> 1] | 0) >>> 0 < $77 >>> 0) {
      $s_0_i38 = $s_0_i38 + 1 | 0; //@line 22157
     } else {
      $c_07_i = 0; //@line 22159
      break L15701;
     }
    }
    $103 = HEAP32[$79 + 4 >> 2] | 0; //@line 22164
    if ((HEAPU16[$103 + 2 >> 1] | 0) != ($77 | 0)) {
     $c_07_i = 0; //@line 22171
     break;
    }
    $455 = $103 + 4 | 0; //@line 22174
    $s_0_i38_1 = 0; //@line 22176
    while (1) {
     if ($s_0_i38_1 >>> 0 >= $77 >>> 0) {
      break;
     }
     $463 = HEAP32[(HEAP32[$455 >> 2] | 0) + ($s_0_i38_1 << 2) >> 2] | 0; //@line 22186
     if ((HEAP16[$463 + 10 >> 1] | 0) != 512) {
      $c_07_i = 0; //@line 22192
      break L15701;
     }
     if ((HEAPU16[$463 + 8 >> 1] | 0) >>> 0 < $77 >>> 0) {
      $s_0_i38_1 = $s_0_i38_1 + 1 | 0; //@line 22202
     } else {
      $c_07_i = 0; //@line 22204
      break L15701;
     }
    }
    $458 = $c_022_i34 + 1 | 0; //@line 22208
    if ($458 >>> 0 < 80) {
     $c_022_i34 = $458; //@line 22212
     label = 12469; //@line 22213
    } else {
     $c_013_i43 = 0; //@line 22215
     label = 12476; //@line 22216
     break;
    }
   }
   if ((label | 0) == 12476) {
    while (1) {
     label = 0; //@line 22222
     $109 = HEAP32[$5 + ($c_013_i43 << 2) >> 2] | 0; //@line 22225
     $111 = HEAP16[$109 + 2 >> 1] | 0; //@line 22227
     if ($111 << 16 >> 16 != 0) {
      $114 = HEAP32[$109 + 4 >> 2] | 0; //@line 22232
      $115 = $111 & 65535; //@line 22233
      $h_011_i45 = 0; //@line 22235
      do {
       $118 = HEAP32[$114 + ($h_011_i45 << 2) >> 2] | 0; //@line 22239
       $121 = HEAPU16[$118 + 2 >> 1] | 0; //@line 22242
       $122 = $118 + 4 | 0; //@line 22243
       $s_0_i46 = 0; //@line 22245
       while (1) {
        if ($s_0_i46 >>> 0 >= $121 >>> 0) {
         break;
        }
        if ((HEAP16[(HEAP32[(HEAP32[$122 >> 2] | 0) + ($s_0_i46 << 2) >> 2] | 0) + 28 >> 1] | 0) == 0) {
         $s_0_i46 = $s_0_i46 + 1 | 0; //@line 22262
        } else {
         $tags_size_0 = 19200;
         $data_size_0 = 819200;
         $enc_0 = 290;
         $sn_0 = 0;
         $hn_0 = 2;
         break L15689;
        }
       }
       $h_011_i45 = $h_011_i45 + 1 | 0; //@line 22268
      } while ($h_011_i45 >>> 0 < $115 >>> 0);
     }
     $136 = $c_013_i43 + 1 | 0; //@line 22278
     if ($136 >>> 0 < 80) {
      $c_013_i43 = $136; //@line 22282
      label = 12476; //@line 22283
     } else {
      $tags_size_0 = 0;
      $data_size_0 = 819200;
      $enc_0 = 290;
      $sn_0 = 0;
      $hn_0 = 2;
      break L15689;
     }
    }
   }
   L15728 : while (1) {
    $139 = HEAP32[$5 + ($c_07_i << 2) >> 2] | 0; //@line 22293
    if ((HEAP16[$139 + 2 >> 1] | 0) != 2) {
     $c_07_i61 = 0; //@line 22299
     break;
    }
    $144 = HEAP32[$139 + 4 >> 2] | 0; //@line 22303
    $145 = HEAP32[$144 >> 2] | 0; //@line 22304
    if ((HEAP16[$145 + 2 >> 1] | 0) != 9) {
     $c_07_i61 = 0; //@line 22310
     break;
    }
    $149 = $145 + 4 | 0; //@line 22313
    $s_0_i58 = 0; //@line 22315
    while (1) {
     if ($s_0_i58 >>> 0 >= 9) {
      break;
     }
     $155 = HEAP32[(HEAP32[$149 >> 2] | 0) + ($s_0_i58 << 2) >> 2] | 0; //@line 22325
     if ((HEAP16[$155 + 10 >> 1] | 0) != 512) {
      $c_07_i61 = 0; //@line 22331
      break L15728;
     }
     $161 = HEAP16[$155 + 8 >> 1] | 0; //@line 22335
     if ($161 << 16 >> 16 == 0 | ($161 & 65535) > 9) {
      $c_07_i61 = 0; //@line 22342
      break L15728;
     } else {
      $s_0_i58 = $s_0_i58 + 1 | 0; //@line 22345
     }
    }
    $167 = HEAP32[$144 + 4 >> 2] | 0; //@line 22349
    if ((HEAP16[$167 + 2 >> 1] | 0) != 9) {
     $c_07_i61 = 0; //@line 22355
     break;
    }
    $171 = $167 + 4 | 0; //@line 22358
    $s_0_1_i = 0; //@line 22360
    while (1) {
     if ($s_0_1_i >>> 0 >= 9) {
      break;
     }
     $180 = HEAP32[(HEAP32[$171 >> 2] | 0) + ($s_0_1_i << 2) >> 2] | 0; //@line 22370
     if ((HEAP16[$180 + 10 >> 1] | 0) != 512) {
      $c_07_i61 = 0; //@line 22376
      break L15728;
     }
     $186 = HEAP16[$180 + 8 >> 1] | 0; //@line 22380
     if ($186 << 16 >> 16 == 0 | ($186 & 65535) > 9) {
      $c_07_i61 = 0; //@line 22387
      break L15728;
     } else {
      $s_0_1_i = $s_0_1_i + 1 | 0; //@line 22390
     }
    }
    $175 = $c_07_i + 1 | 0; //@line 22393
    if ($175 >>> 0 < 80) {
     $c_07_i = $175; //@line 22397
    } else {
     $tags_size_0 = 0;
     $data_size_0 = 737280;
     $enc_0 = 546;
     $sn_0 = 9;
     $hn_0 = 2;
     break L15689;
    }
   }
   L15743 : while (1) {
    $191 = HEAP32[$5 + ($c_07_i61 << 2) >> 2] | 0; //@line 22406
    if ((HEAP16[$191 + 2 >> 1] | 0) != 2) {
     $_0 = 1; //@line 22412
     label = 12561; //@line 22413
     break;
    }
    $196 = HEAP32[$191 + 4 >> 2] | 0; //@line 22417
    $197 = HEAP32[$196 >> 2] | 0; //@line 22418
    if ((HEAP16[$197 + 2 >> 1] | 0) != 18) {
     $_0 = 1; //@line 22424
     label = 12562; //@line 22425
     break;
    }
    $201 = $197 + 4 | 0; //@line 22428
    $s_0_i64 = 0; //@line 22430
    while (1) {
     if ($s_0_i64 >>> 0 >= 18) {
      break;
     }
     $207 = HEAP32[(HEAP32[$201 >> 2] | 0) + ($s_0_i64 << 2) >> 2] | 0; //@line 22440
     if ((HEAP16[$207 + 10 >> 1] | 0) != 512) {
      $_0 = 1; //@line 22446
      label = 12566; //@line 22447
      break L15743;
     }
     $213 = HEAP16[$207 + 8 >> 1] | 0; //@line 22451
     if ($213 << 16 >> 16 == 0 | ($213 & 65535) > 18) {
      $_0 = 1; //@line 22458
      label = 12567; //@line 22459
      break L15743;
     } else {
      $s_0_i64 = $s_0_i64 + 1 | 0; //@line 22462
     }
    }
    $219 = HEAP32[$196 + 4 >> 2] | 0; //@line 22466
    if ((HEAP16[$219 + 2 >> 1] | 0) != 18) {
     $_0 = 1; //@line 22472
     label = 12574; //@line 22473
     break;
    }
    $223 = $219 + 4 | 0; //@line 22476
    $s_0_1_i68 = 0; //@line 22478
    while (1) {
     if ($s_0_1_i68 >>> 0 >= 18) {
      break;
     }
     $232 = HEAP32[(HEAP32[$223 >> 2] | 0) + ($s_0_1_i68 << 2) >> 2] | 0; //@line 22488
     if ((HEAP16[$232 + 10 >> 1] | 0) != 512) {
      $_0 = 1; //@line 22494
      label = 12572; //@line 22495
      break L15743;
     }
     $238 = HEAP16[$232 + 8 >> 1] | 0; //@line 22499
     if ($238 << 16 >> 16 == 0 | ($238 & 65535) > 18) {
      $_0 = 1; //@line 22506
      label = 12573; //@line 22507
      break L15743;
     } else {
      $s_0_1_i68 = $s_0_1_i68 + 1 | 0; //@line 22510
     }
    }
    $227 = $c_07_i61 + 1 | 0; //@line 22513
    if ($227 >>> 0 < 80) {
     $c_07_i61 = $227; //@line 22517
    } else {
     $tags_size_0 = 0;
     $data_size_0 = 1474560;
     $enc_0 = 802;
     $sn_0 = 18;
     $hn_0 = 2;
     break L15689;
    }
   }
   if ((label | 0) == 12566) {
    STACKTOP = sp; //@line 22525
    return $_0 | 0; //@line 22526
   } else if ((label | 0) == 12567) {
    STACKTOP = sp; //@line 22530
    return $_0 | 0; //@line 22531
   } else if ((label | 0) == 12572) {
    STACKTOP = sp; //@line 22535
    return $_0 | 0; //@line 22536
   } else if ((label | 0) == 12573) {
    STACKTOP = sp; //@line 22540
    return $_0 | 0; //@line 22541
   } else if ((label | 0) == 12574) {
    STACKTOP = sp; //@line 22545
    return $_0 | 0; //@line 22546
   } else if ((label | 0) == 12561) {
    STACKTOP = sp; //@line 22550
    return $_0 | 0; //@line 22551
   } else if ((label | 0) == 12562) {
    STACKTOP = sp; //@line 22555
    return $_0 | 0; //@line 22556
   }
  }
 } while (0);
 $242 = $buf_i | 0; //@line 22565
 $243 = ($sn_0 | 0) == 0; //@line 22566
 $245 = $243 & 1 ^ 1; //@line 22568
 $246 = $sn_0 + 1 | 0; //@line 22569
 $247 = $buf_i + 1 | 0; //@line 22570
 $248 = $buf_i + 2 | 0; //@line 22571
 $249 = $buf_i + 3 | 0; //@line 22572
 $250 = $buf_i + 4 | 0; //@line 22573
 $251 = $buf_i + 5 | 0; //@line 22574
 $252 = $buf_i + 6 | 0; //@line 22575
 $253 = $buf_i + 7 | 0; //@line 22576
 $254 = $buf_i + 8 | 0; //@line 22577
 $255 = $buf_i + 9 | 0; //@line 22578
 $256 = $buf_i + 10 | 0; //@line 22579
 $257 = $buf_i + 11 | 0; //@line 22580
 $c_013_i72 = 0;
 $tags_check_0_load7986 = 0;
 $data_check_0_load8091 = 0;
 L15767 : while (1) {
  if ($243) {
   $263 = 12 - ($c_013_i72 >>> 4) | 0; //@line 22592
  } else {
   $263 = $246; //@line 22594
  }
  $264 = $245 >>> 0 < $263 >>> 0; //@line 22597
  $h_010_i = 0;
  $tags_check_0_load7985 = $tags_check_0_load7986;
  $data_check_0_load8090 = $data_check_0_load8091;
  while (1) {
   if ($264) {
    $265 = $h_010_i | $c_013_i72; //@line 22606
    $s_09_i = $245;
    $tags_check_0_load7984 = $tags_check_0_load7985;
    $data_check_0_load8089 = $data_check_0_load8090;
    while (1) {
     $267 = _psi_img_get_sector($img, $c_013_i72, $h_010_i, $s_09_i, 0) | 0; //@line 22613
     if (($267 | 0) == 0) {
      $_0 = 1; //@line 22617
      label = 12571; //@line 22618
      break L15767;
     }
     $273 = (HEAPU16[$267 + 10 >> 1] | 0) >>> 1; //@line 22624
     if (($273 | 0) == 0) {
      $_011_lcssa_i_i = $data_check_0_load8089; //@line 22628
     } else {
      $_01112_i_i = $data_check_0_load8089;
      $_013_i_i = $273;
      $tmp_014_i_i = HEAP32[$267 + 24 >> 2] | 0;
      while (1) {
       $284 = (HEAPU8[$tmp_014_i_i] << 8 | HEAPU8[$tmp_014_i_i + 1 | 0]) + $_01112_i_i | 0; //@line 22645
       $287 = $284 >>> 1 | $284 << 31; //@line 22648
       $288 = $_013_i_i - 1 | 0; //@line 22649
       if (($288 | 0) == 0) {
        $_011_lcssa_i_i = $287; //@line 22654
        break;
       } else {
        $_01112_i_i = $287;
        $_013_i_i = $288;
        $tmp_014_i_i = $tmp_014_i_i + 2 | 0;
       }
      }
     }
     if (($265 | $s_09_i | 0) == 0) {
      $tags_check_0_load7983 = $tags_check_0_load7984; //@line 22666
     } else {
      _psi_sct_get_tags($267, $242, 12) | 0; //@line 22668
      $300 = (HEAPU8[$242] << 8 | HEAPU8[$247]) + $tags_check_0_load7984 | 0; //@line 22675
      $310 = ($300 >>> 1 | $300 << 31) + (HEAPU8[$248] << 8 | HEAPU8[$249]) | 0; //@line 22685
      $320 = ($310 >>> 1 | $310 << 31) + (HEAPU8[$250] << 8 | HEAPU8[$251]) | 0; //@line 22695
      $330 = ($320 >>> 1 | $320 << 31) + (HEAPU8[$252] << 8 | HEAPU8[$253]) | 0; //@line 22705
      $340 = ($330 >>> 1 | $330 << 31) + (HEAPU8[$254] << 8 | HEAPU8[$255]) | 0; //@line 22715
      $350 = ($340 >>> 1 | $340 << 31) + (HEAPU8[$256] << 8 | HEAPU8[$257]) | 0; //@line 22725
      $tags_check_0_load7983 = $350 >>> 1 | $350 << 31; //@line 22730
     }
     $355 = $s_09_i + 1 | 0; //@line 22733
     if ($355 >>> 0 < $263 >>> 0) {
      $s_09_i = $355;
      $tags_check_0_load7984 = $tags_check_0_load7983;
      $data_check_0_load8089 = $_011_lcssa_i_i;
     } else {
      $tags_check_0_load7982 = $tags_check_0_load7983;
      $data_check_0_load8088 = $_011_lcssa_i_i;
      break;
     }
    }
   } else {
    $tags_check_0_load7982 = $tags_check_0_load7985;
    $data_check_0_load8088 = $data_check_0_load8090;
   }
   $357 = $h_010_i + 1 | 0; //@line 22748
   if ($357 >>> 0 < $hn_0 >>> 0) {
    $h_010_i = $357;
    $tags_check_0_load7985 = $tags_check_0_load7982;
    $data_check_0_load8090 = $data_check_0_load8088;
   } else {
    break;
   }
  }
  $359 = $c_013_i72 + 1 | 0; //@line 22757
  if ($359 >>> 0 < 80) {
   $c_013_i72 = $359;
   $tags_check_0_load7986 = $tags_check_0_load7982;
   $data_check_0_load8091 = $data_check_0_load8088;
  } else {
   break;
  }
 }
 if ((label | 0) == 12571) {
  STACKTOP = sp; //@line 22768
  return $_0 | 0; //@line 22769
 }
 $362 = $buf | 0; //@line 22771
 _memset($362 | 0, 0, 128); //@line 22772
 $364 = _psi_img_get_sector($img, 0, 0, $243 ? 2 : 3, 0) | 0; //@line 22774
 do {
  if (($364 | 0) == 0) {
   $src_0_i = 56568; //@line 22779
  } else {
   $368 = HEAP32[$364 + 24 >> 2] | 0; //@line 22782
   $369 = HEAP8[$368] | 0; //@line 22783
   if (($369 << 24 >> 24 | 0) == (-46 | 0)) {
    $src_0_i = (HEAP8[$368 + 1 | 0] | 0) == -41 ? $368 + 36 | 0 : 56568; //@line 22791
    break;
   } else if (($369 << 24 >> 24 | 0) == 66) {
    $src_0_i = (HEAP8[$368 + 1 | 0] | 0) == 68 ? $368 + 36 | 0 : 56568; //@line 22800
    break;
   } else {
    $src_0_i = 56568; //@line 22803
    break;
   }
  }
 } while (0);
 $380 = HEAP8[$src_0_i] | 0; //@line 22809
 $_1_i = ($380 & 255) > 63 ? 63 : $380 & 255; //@line 22812
 if (($_1_i | 0) != 0) {
  $i_02_i = 0; //@line 22816
  do {
   $i_02_i = $i_02_i + 1 | 0; //@line 22819
   HEAP8[$buf + $i_02_i | 0] = HEAP8[$src_0_i + $i_02_i | 0] | 0; //@line 22823
  } while ($i_02_i >>> 0 < $_1_i >>> 0);
 }
 HEAP8[$362] = $_1_i & 255; //@line 22834
 _psi_set_uint32_be($362, 64, $data_size_0); //@line 22835
 _psi_set_uint32_be($362, 68, $tags_size_0); //@line 22836
 _psi_set_uint32_be($362, 72, $data_check_0_load8088); //@line 22837
 _psi_set_uint32_be($362, 76, $tags_check_0_load7982); //@line 22838
 _psi_set_uint16_be($362, 80, $enc_0); //@line 22839
 _psi_set_uint16_be($362, 82, 256); //@line 22840
 if ((_psi_write($fp, $362, 84) | 0) != 0) {
  $_0 = 1; //@line 22845
  STACKTOP = sp; //@line 22847
  return $_0 | 0; //@line 22848
 }
 L15805 : do {
  if ($243) {
   $c_03_us_i = 0; //@line 22852
   L15806 : while (1) {
    $394 = 12 - ($c_03_us_i >>> 4) | 0; //@line 22856
    $h_01_us_i = 0; //@line 22857
    do {
     $s_0_us_i = $245; //@line 22861
     while (1) {
      if ($s_0_us_i >>> 0 >= $394 >>> 0) {
       break;
      }
      $403 = _psi_img_get_sector($img, $c_03_us_i, $h_01_us_i, $s_0_us_i, 0) | 0; //@line 22869
      if (($403 | 0) == 0) {
       $_0 = 1; //@line 22873
       label = 12575; //@line 22874
       break L15806;
      }
      if ((_psi_write($fp, HEAP32[$403 + 24 >> 2] | 0, HEAPU16[$403 + 10 >> 1] | 0) | 0) == 0) {
       $s_0_us_i = $s_0_us_i + 1 | 0; //@line 22887
      } else {
       $_0 = 1; //@line 22889
       label = 12576; //@line 22890
       break L15806;
      }
     }
     $h_01_us_i = $h_01_us_i + 1 | 0; //@line 22894
    } while ($h_01_us_i >>> 0 < $hn_0 >>> 0);
    $c_03_us_i = $c_03_us_i + 1 | 0; //@line 22903
    if ($c_03_us_i >>> 0 >= 80) {
     break L15805;
    }
   }
   if ((label | 0) == 12575) {
    STACKTOP = sp; //@line 22914
    return $_0 | 0; //@line 22915
   } else if ((label | 0) == 12576) {
    STACKTOP = sp; //@line 22919
    return $_0 | 0; //@line 22920
   }
  } else {
   $c_03_i50 = 0; //@line 22923
   L15819 : while (1) {
    $h_01_i51 = 0; //@line 22926
    do {
     $s_0_i53 = $245; //@line 22930
     while (1) {
      if ($s_0_i53 >>> 0 >= $246 >>> 0) {
       break;
      }
      $417 = _psi_img_get_sector($img, $c_03_i50, $h_01_i51, $s_0_i53, 0) | 0; //@line 22938
      if (($417 | 0) == 0) {
       $_0 = 1; //@line 22942
       label = 12569; //@line 22943
       break L15819;
      }
      if ((_psi_write($fp, HEAP32[$417 + 24 >> 2] | 0, HEAPU16[$417 + 10 >> 1] | 0) | 0) == 0) {
       $s_0_i53 = $s_0_i53 + 1 | 0; //@line 22956
      } else {
       $_0 = 1; //@line 22958
       label = 12570; //@line 22959
       break L15819;
      }
     }
     $h_01_i51 = $h_01_i51 + 1 | 0; //@line 22963
    } while ($h_01_i51 >>> 0 < $hn_0 >>> 0);
    $c_03_i50 = $c_03_i50 + 1 | 0; //@line 22972
    if ($c_03_i50 >>> 0 >= 80) {
     break L15805;
    }
   }
   if ((label | 0) == 12569) {
    STACKTOP = sp; //@line 22983
    return $_0 | 0; //@line 22984
   } else if ((label | 0) == 12570) {
    STACKTOP = sp; //@line 22988
    return $_0 | 0; //@line 22989
   }
  }
 } while (0);
 L15833 : do {
  if (($tags_size_0 | 0) != 0) {
   $c_03_i = 0; //@line 22997
   L15834 : while (1) {
    if ($243) {
     $438 = 12 - ($c_03_i >>> 4) | 0; //@line 23005
    } else {
     $438 = $246; //@line 23007
    }
    $h_01_i = 0; //@line 23010
    do {
     $s_0_i27 = $245; //@line 23014
     while (1) {
      if ($s_0_i27 >>> 0 >= $438 >>> 0) {
       break;
      }
      $442 = _psi_img_get_sector($img, $c_03_i, $h_01_i, $s_0_i27, 0) | 0; //@line 23022
      if (($442 | 0) == 0) {
       $_0 = 1; //@line 23026
       label = 12563; //@line 23027
       break L15834;
      }
      _psi_sct_get_tags($442, $242, 12) | 0; //@line 23030
      if ((_psi_write($fp, $242, 12) | 0) == 0) {
       $s_0_i27 = $s_0_i27 + 1 | 0; //@line 23036
      } else {
       $_0 = 1; //@line 23038
       label = 12564; //@line 23039
       break L15834;
      }
     }
     $h_01_i = $h_01_i + 1 | 0; //@line 23043
    } while ($h_01_i >>> 0 < $hn_0 >>> 0);
    $c_03_i = $c_03_i + 1 | 0; //@line 23052
    if ($c_03_i >>> 0 >= 80) {
     break L15833;
    }
   }
   if ((label | 0) == 12563) {
    STACKTOP = sp; //@line 23063
    return $_0 | 0; //@line 23064
   } else if ((label | 0) == 12564) {
    STACKTOP = sp; //@line 23068
    return $_0 | 0; //@line 23069
   }
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 23073
 $_0 = 0; //@line 23075
 STACKTOP = sp; //@line 23077
 return $_0 | 0; //@line 23078
}
function _psi_probe_dc42_fp($fp) {
 $fp = $fp | 0;
 var $4 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 23087
 STACKTOP = STACKTOP + 128 | 0; //@line 23087
 do {
  if ((_fseek($fp | 0, 0, 0) | 0) == 0) {
   $4 = sp | 0; //@line 23094
   if ((_psi_read($fp, $4, 84) | 0) != 0) {
    $_0 = 0; //@line 23099
    break;
   }
   if ((_psi_get_uint16_be($4, 82) | 0) != 256) {
    $_0 = 0; //@line 23106
    break;
   }
   $_0 = (HEAPU8[$4] | 0) < 64 | 0; //@line 23113
  } else {
   $_0 = 0; //@line 23115
  }
 } while (0);
 STACKTOP = sp; //@line 23119
 return $_0 | 0; //@line 23120
}
function _dc42_load_gcr($fp, $img, $hcnt, $check, $fmt) {
 $fp = $fp | 0;
 $img = $img | 0;
 $hcnt = $hcnt | 0;
 $check = $check | 0;
 $fmt = $fmt | 0;
 var $1 = 0, $2 = 0, $c_033 = 0, $4 = 0, $5 = 0, $8 = 0, $s_029_us = 0, $16 = 0, $22 = 0, $tmp_014_i_us = 0, $_013_i_us = 0, $_01112_i_us = 0, $36 = 0, $39 = 0, $40 = 0, $h_030_us = 0, $h_030 = 0, $46 = 0, $53 = 0, $_0 = 0, label = 0;
 HEAP32[$check >> 2] = 0; //@line 23139
 $1 = ($hcnt | 0) == 0; //@line 23140
 $2 = $fmt & 255; //@line 23141
 $c_033 = 0; //@line 23143
 L15859 : while (1) {
  $4 = $c_033 >>> 4; //@line 23146
  $5 = 12 - $4 | 0; //@line 23147
  L15861 : do {
   if (!$1) {
    if (($4 | 0) == 12) {
     $h_030 = 0; //@line 23153
     while (1) {
      $46 = _psi_img_get_track($img, $c_033, $h_030, 0) | 0; //@line 23156
      if (($46 | 0) != 0) {
       _psi_trk_interleave($46, 2) | 0; //@line 23160
      }
      $h_030 = $h_030 + 1 | 0; //@line 23163
      if ($h_030 >>> 0 >= $hcnt >>> 0) {
       break L15861;
      }
     }
    } else {
     $h_030_us = 0; //@line 23173
    }
    do {
     $s_029_us = 0; //@line 23178
     do {
      $16 = _psi_sct_new($c_033, $h_030_us, $s_029_us, 512) | 0; //@line 23181
      if (($16 | 0) == 0) {
       $_0 = 1; //@line 23185
       label = 12604; //@line 23186
       break L15859;
      }
      _psi_sct_set_gcr_format($16, $2); //@line 23189
      _psi_sct_set_encoding($16, 3); //@line 23190
      if ((_psi_img_add_sector($img, $16, $c_033, $h_030_us) | 0) != 0) {
       label = 12596; //@line 23195
       break L15859;
      }
      $22 = $16 + 24 | 0; //@line 23198
      if ((_psi_read($fp, HEAP32[$22 >> 2] | 0, 512) | 0) != 0) {
       $_0 = 1; //@line 23204
       label = 12603; //@line 23205
       break L15859;
      }
      $_01112_i_us = HEAP32[$check >> 2] | 0;
      $_013_i_us = 256;
      $tmp_014_i_us = HEAP32[$22 >> 2] | 0;
      while (1) {
       $36 = ((HEAPU8[$tmp_014_i_us] | 0) << 8 | (HEAPU8[$tmp_014_i_us + 1 | 0] | 0)) + $_01112_i_us | 0; //@line 23222
       $39 = $36 >>> 1 | $36 << 31; //@line 23225
       $40 = $_013_i_us - 1 | 0; //@line 23226
       if (($40 | 0) == 0) {
        break;
       } else {
        $_01112_i_us = $39;
        $_013_i_us = $40;
        $tmp_014_i_us = $tmp_014_i_us + 2 | 0;
       }
      }
      HEAP32[$check >> 2] = $39; //@line 23236
      $s_029_us = $s_029_us + 1 | 0; //@line 23237
     } while ($s_029_us >>> 0 < $5 >>> 0);
     $8 = _psi_img_get_track($img, $c_033, $h_030_us, 0) | 0; //@line 23246
     if (($8 | 0) != 0) {
      _psi_trk_interleave($8, 2) | 0; //@line 23250
     }
     $h_030_us = $h_030_us + 1 | 0; //@line 23253
    } while ($h_030_us >>> 0 < $hcnt >>> 0);
   }
  } while (0);
  $53 = $c_033 + 1 | 0; //@line 23264
  if ($53 >>> 0 < 80) {
   $c_033 = $53; //@line 23268
  } else {
   $_0 = 0; //@line 23270
   label = 12602; //@line 23271
   break;
  }
 }
 if ((label | 0) == 12602) {
  return $_0 | 0; //@line 23278
 } else if ((label | 0) == 12603) {
  return $_0 | 0; //@line 23283
 } else if ((label | 0) == 12604) {
  return $_0 | 0; //@line 23288
 } else if ((label | 0) == 12596) {
  _psi_sct_del($16); //@line 23291
  $_0 = 1; //@line 23293
  return $_0 | 0; //@line 23296
 }
 return 0;
}
function _dc42_load_mfm($fp, $img, $scnt, $check) {
 $fp = $fp | 0;
 $img = $img | 0;
 $scnt = $scnt | 0;
 $check = $check | 0;
 var $2 = 0, $3 = 0, $c_027 = 0, $s_023 = 0, $5 = 0, $_lcssa29 = 0, $12 = 0, $tmp_014_i = 0, $_013_i = 0, $_01112_i = 0, $26 = 0, $29 = 0, $30 = 0, $_0 = 0, $s_023_1 = 0, $35 = 0, $41 = 0, $tmp_014_i_1 = 0, $_013_i_1 = 0, $_01112_i_1 = 0, $55 = 0, $58 = 0, $59 = 0, $63 = 0, label = 0;
 HEAP32[$check >> 2] = 0; //@line 23317
 $2 = $scnt >>> 0 < 14 ? 2 : 32770; //@line 23319
 $3 = ($scnt | 0) == 0; //@line 23320
 $c_027 = 0; //@line 23322
 L15891 : while (1) {
  do {
   if (!$3) {
    $s_023 = 0; //@line 23328
    do {
     $s_023 = $s_023 + 1 | 0; //@line 23331
     $5 = _psi_sct_new($c_027, 0, $s_023, 512) | 0; //@line 23332
     if (($5 | 0) == 0) {
      $_0 = 1; //@line 23336
      label = 12628; //@line 23337
      break L15891;
     }
     _psi_sct_set_encoding($5, $2); //@line 23340
     if ((_psi_img_add_sector($img, $5, $c_027, 0) | 0) != 0) {
      $_lcssa29 = $5; //@line 23345
      label = 12610; //@line 23346
      break L15891;
     }
     $12 = $5 + 24 | 0; //@line 23349
     if ((_psi_read($fp, HEAP32[$12 >> 2] | 0, 512) | 0) != 0) {
      $_0 = 1; //@line 23355
      label = 12629; //@line 23356
      break L15891;
     }
     $_01112_i = HEAP32[$check >> 2] | 0;
     $_013_i = 256;
     $tmp_014_i = HEAP32[$12 >> 2] | 0;
     while (1) {
      $26 = ((HEAPU8[$tmp_014_i] | 0) << 8 | (HEAPU8[$tmp_014_i + 1 | 0] | 0)) + $_01112_i | 0; //@line 23373
      $29 = $26 >>> 1 | $26 << 31; //@line 23376
      $30 = $_013_i - 1 | 0; //@line 23377
      if (($30 | 0) == 0) {
       break;
      } else {
       $_01112_i = $29;
       $_013_i = $30;
       $tmp_014_i = $tmp_014_i + 2 | 0;
      }
     }
     HEAP32[$check >> 2] = $29; //@line 23387
    } while ($s_023 >>> 0 < $scnt >>> 0);
    if ($3) {
     break;
    } else {
     $s_023_1 = 0; //@line 23400
    }
    do {
     $s_023_1 = $s_023_1 + 1 | 0; //@line 23404
     $35 = _psi_sct_new($c_027, 1, $s_023_1, 512) | 0; //@line 23405
     if (($35 | 0) == 0) {
      $_0 = 1; //@line 23409
      label = 12624; //@line 23410
      break L15891;
     }
     _psi_sct_set_encoding($35, $2); //@line 23413
     if ((_psi_img_add_sector($img, $35, $c_027, 1) | 0) != 0) {
      $_lcssa29 = $35; //@line 23418
      label = 12610; //@line 23419
      break L15891;
     }
     $41 = $35 + 24 | 0; //@line 23422
     if ((_psi_read($fp, HEAP32[$41 >> 2] | 0, 512) | 0) != 0) {
      $_0 = 1; //@line 23428
      label = 12626; //@line 23429
      break L15891;
     }
     $_01112_i_1 = HEAP32[$check >> 2] | 0;
     $_013_i_1 = 256;
     $tmp_014_i_1 = HEAP32[$41 >> 2] | 0;
     while (1) {
      $55 = ((HEAPU8[$tmp_014_i_1] | 0) << 8 | (HEAPU8[$tmp_014_i_1 + 1 | 0] | 0)) + $_01112_i_1 | 0; //@line 23446
      $58 = $55 >>> 1 | $55 << 31; //@line 23449
      $59 = $_013_i_1 - 1 | 0; //@line 23450
      if (($59 | 0) == 0) {
       break;
      } else {
       $_01112_i_1 = $58;
       $_013_i_1 = $59;
       $tmp_014_i_1 = $tmp_014_i_1 + 2 | 0;
      }
     }
     HEAP32[$check >> 2] = $58; //@line 23460
    } while ($s_023_1 >>> 0 < $scnt >>> 0);
   }
  } while (0);
  $63 = $c_027 + 1 | 0; //@line 23471
  if ($63 >>> 0 < 80) {
   $c_027 = $63; //@line 23475
  } else {
   $_0 = 0; //@line 23477
   label = 12625; //@line 23478
   break;
  }
 }
 if ((label | 0) == 12624) {
  return $_0 | 0; //@line 23485
 } else if ((label | 0) == 12625) {
  return $_0 | 0; //@line 23490
 } else if ((label | 0) == 12626) {
  return $_0 | 0; //@line 23495
 } else if ((label | 0) == 12628) {
  return $_0 | 0; //@line 23500
 } else if ((label | 0) == 12629) {
  return $_0 | 0; //@line 23505
 } else if ((label | 0) == 12610) {
  _psi_sct_del($_lcssa29); //@line 23509
  $_0 = 1; //@line 23511
  return $_0 | 0; //@line 23514
 }
 return 0;
}
function _psi_load_imd($fp) {
 $fp = $fp | 0;
 var $dat_i_i = 0, $smap_i_i = 0, $cmap_i_i = 0, $hmap_i_i = 0, $buf_i = 0, $1 = 0, $4 = 0, $13 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $28 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $40 = 0, $44 = 0, $50 = 0, $i_044_i_i = 0, $56 = 0, $63 = 0, $71 = 0, $73 = 0, $78 = 0, $85 = 0, $enc_0_i_i_i = 0, $92 = 0, $106 = 0, $109 = 0, $114 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 23534
 STACKTOP = STACKTOP + 784 | 0; //@line 23534
 $dat_i_i = sp | 0; //@line 23535
 $smap_i_i = sp + 8 | 0; //@line 23536
 $cmap_i_i = sp + 264 | 0; //@line 23537
 $hmap_i_i = sp + 520 | 0; //@line 23538
 $buf_i = sp + 776 | 0; //@line 23539
 $1 = _psi_img_new() | 0; //@line 23540
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 23544
  STACKTOP = sp; //@line 23546
  return $_0 | 0; //@line 23547
 }
 $4 = $buf_i | 0; //@line 23549
 L15924 : do {
  if ((_fread($4 | 0, 1, 4, $fp | 0) | 0) == 4) {
   if ((_psi_get_uint32_be($4, 0) | 0) != 1229800480) {
    break;
   }
   _psi_img_add_comment($1, $4, 4) | 0; //@line 23561
   while (1) {
    $13 = _fgetc($fp | 0) | 0; //@line 23564
    if (($13 | 0) == 26) {
     break;
    } else if (($13 | 0) == (-1 | 0)) {
     break L15924;
    }
    HEAP8[$4] = $13 & 255; //@line 23571
    _psi_img_add_comment($1, $4, 1) | 0; //@line 23572
   }
   _psi_img_clean_comment($1); //@line 23575
   $18 = $smap_i_i | 0; //@line 23576
   $19 = $cmap_i_i | 0; //@line 23577
   $20 = $hmap_i_i | 0; //@line 23578
   $21 = $buf_i + 1 | 0; //@line 23579
   $22 = $buf_i + 2 | 0; //@line 23580
   $23 = $buf_i + 3 | 0; //@line 23581
   $24 = $buf_i + 4 | 0; //@line 23582
   L15931 : while (1) {
    $25 = _fread($4 | 0, 1, 5, $fp | 0) | 0; //@line 23585
    if (($25 | 0) == 0) {
     $_0 = $1; //@line 23587
     label = 12672; //@line 23588
     break;
    } else if (($25 | 0) != 5) {
     break L15924;
    }
    $28 = HEAPU8[$21] | 0; //@line 23594
    $31 = HEAP8[$22] & 1; //@line 23597
    $32 = HEAP8[$23] | 0; //@line 23598
    $33 = $32 & 255; //@line 23599
    $34 = HEAP8[$24] | 0; //@line 23600
    if ($32 << 24 >> 24 == 0) {
     continue;
    }
    if (($34 & 255) > 6) {
     break L15924;
    }
    $40 = 128 << ($34 & 255); //@line 23612
    if ((_fread($18 | 0, 1, $33 | 0, $fp | 0) | 0) != ($33 | 0)) {
     break L15924;
    }
    $44 = HEAP8[$22] | 0; //@line 23619
    if ($44 << 24 >> 24 < 0) {
     if ((_fread($19 | 0, 1, $33 | 0, $fp | 0) | 0) != ($33 | 0)) {
      break L15924;
     }
     $50 = HEAP8[$22] | 0; //@line 23631
    } else {
     $50 = $44; //@line 23633
    }
    if (($50 & 64) == 0) {
     $i_044_i_i = 0; //@line 23640
    } else {
     if ((_fread($20 | 0, 1, $33 | 0, $fp | 0) | 0) == ($33 | 0)) {
      $i_044_i_i = 0; //@line 23646
     } else {
      break L15924;
     }
    }
    while (1) {
     $56 = HEAP8[$22] | 0; //@line 23653
     if ($56 << 24 >> 24 < 0) {
      $63 = HEAPU8[$cmap_i_i + $i_044_i_i | 0] | 0; //@line 23661
     } else {
      $63 = $28; //@line 23663
     }
     if (($56 & 64) == 0) {
      $71 = $31; //@line 23670
     } else {
      $71 = HEAPU8[$hmap_i_i + $i_044_i_i | 0] | 0; //@line 23676
     }
     $73 = HEAP8[$smap_i_i + $i_044_i_i | 0] | 0; //@line 23680
     if ((_fread($dat_i_i | 0, 1, 1, $fp | 0) | 0) != 1) {
      break L15924;
     }
     $78 = _psi_sct_new($63, $71, $73 & 255, $40) | 0; //@line 23688
     if (($78 | 0) == 0) {
      break L15924;
     }
     _psi_sct_set_mfm_size($78, $34); //@line 23694
     if ((_psi_img_add_sector($1, $78, $28, $31) | 0) != 0) {
      label = 12653; //@line 23699
      break L15931;
     }
     $85 = HEAPU8[$4] | 0; //@line 23703
     if (($85 | 0) == 1) {
      $enc_0_i_i_i = 1; //@line 23706
     } else if (($85 | 0) == 2) {
      $enc_0_i_i_i = 1; //@line 23709
     } else if (($85 | 0) == 5) {
      $enc_0_i_i_i = 2; //@line 23712
     } else if (($85 | 0) == 4) {
      $enc_0_i_i_i = 2; //@line 23715
     } else if (($85 | 0) == 3) {
      $enc_0_i_i_i = 32770; //@line 23718
     } else if (($85 | 0) == 0) {
      $enc_0_i_i_i = 32769; //@line 23720
     } else {
      break L15924;
     }
     _psi_sct_set_encoding($78, $enc_0_i_i_i); //@line 23725
     $92 = HEAP8[$dat_i_i] | 0; //@line 23726
     if (($92 - 5 & 255) < 4) {
      _psi_sct_set_flags($78, 2, 1); //@line 23731
     }
     if (($92 << 24 >> 24 | 0) == 3 | ($92 << 24 >> 24 | 0) == 4 | ($92 << 24 >> 24 | 0) == 7 | ($92 << 24 >> 24 | 0) == 8) {
      _psi_sct_set_flags($78, 4, 1); //@line 23735
      if (($92 << 24 >> 24 | 0) == 4 | ($92 << 24 >> 24 | 0) == 6 | ($92 << 24 >> 24 | 0) == 8) {
       label = 12665; //@line 23737
      } else if (($92 << 24 >> 24 | 0) == 3 | ($92 << 24 >> 24 | 0) == 5 | ($92 << 24 >> 24 | 0) == 7) {
       label = 12667; //@line 23739
      } else {
       break L15924;
      }
     } else if (($92 << 24 >> 24 | 0) == 0) {
      _psi_sct_set_flags($78, 2, 1); //@line 23744
      _psi_sct_fill($78, 0); //@line 23745
     } else if (($92 << 24 >> 24 | 0) == 2 | ($92 << 24 >> 24 | 0) == 6) {
      label = 12665; //@line 23748
     } else if (($92 << 24 >> 24 | 0) == 1 | ($92 << 24 >> 24 | 0) == 5) {
      label = 12667; //@line 23750
     } else {
      break L15924;
     }
     if ((label | 0) == 12665) {
      label = 0; //@line 23755
      if ((_fread($dat_i_i | 0, 1, 1, $fp | 0) | 0) != 1) {
       break L15924;
      }
      _psi_sct_fill($78, HEAPU8[$dat_i_i] | 0); //@line 23764
     } else if ((label | 0) == 12667) {
      label = 0; //@line 23768
      $106 = $78 + 10 | 0; //@line 23771
      $109 = _fread(HEAP32[$78 + 24 >> 2] | 0, 1, HEAPU16[$106 >> 1] | 0 | 0, $fp | 0) | 0; //@line 23774
      if (($109 | 0) != (HEAPU16[$106 >> 1] | 0 | 0)) {
       break L15924;
      }
     }
     $114 = $i_044_i_i + 1 | 0; //@line 23783
     if ($114 >>> 0 < $33 >>> 0) {
      $i_044_i_i = $114; //@line 23787
     } else {
      continue L15931;
     }
    }
   }
   if ((label | 0) == 12653) {
    _psi_sct_del($78); //@line 23794
    break;
   } else if ((label | 0) == 12672) {
    STACKTOP = sp; //@line 23799
    return $_0 | 0; //@line 23800
   }
  }
 } while (0);
 _psi_img_del($1); //@line 23804
 $_0 = 0; //@line 23806
 STACKTOP = sp; //@line 23808
 return $_0 | 0; //@line 23809
}
function _psi_save_imd($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i = 0, $t_i = 0, $2 = 0, $3 = 0, $4 = 0, $39 = 0, $41 = 0, $44 = 0, $47 = 0, $49 = 0, $51 = 0, $53 = 0, $i_0_i = 0, $i_11_i = 0, $62 = 0, $68 = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $c_030 = 0, $87 = 0, $88 = 0, $91 = 0, $92 = 0, $h_028 = 0, $96 = 0, $98 = 0, $99 = 0, $101 = 0, $102 = 0, $i_0_i14 = 0, $need_cmap_0_i = 0, $need_hmap_0_i = 0, $107 = 0, $110 = 0, $130 = 0, $131 = 0, $137 = 0, $_idx49_val_i = 0, $139 = 0, $146 = 0, $size_01_i_i = 0, $147 = 0, $151 = 0, $156 = 0, $158 = 0, $bcnt_0_i = 0, $cmap_0_i = 0, $bcnt_1_i = 0, $hmap_0_i = 0, $165 = 0, $i_154_us_us_i = 0, $i_154_us_i = 0, $175 = 0, $i_154_us56_i = 0, $187 = 0, $i_154_i = 0, $199 = 0, $i_253_i = 0, $218 = 0, $226 = 0, $228 = 0, $or_cond_not_i_i = 0, $mode_0_i_i = 0, $239 = 0, $242 = 0, $245 = 0, $248 = 0, $260 = 0, $261 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 23851
 STACKTOP = STACKTOP + 784 | 0; //@line 23851
 $buf_i = sp | 0; //@line 23852
 $t_i = sp + 776 | 0; //@line 23853
 $2 = $img + 12 | 0; //@line 23855
 $3 = HEAP32[$2 >> 2] | 0; //@line 23856
 $4 = $img + 8 | 0; //@line 23857
 do {
  if ((HEAP32[$4 >> 2] | 0) >>> 0 < 29) {
   label = 12683; //@line 23863
  } else {
   if ((HEAP8[$3] | 0) != 73) {
    label = 12683; //@line 23869
    break;
   }
   if ((HEAP8[$3 + 1 | 0] | 0) != 77) {
    label = 12683; //@line 23877
    break;
   }
   if ((HEAP8[$3 + 2 | 0] | 0) != 68) {
    label = 12683; //@line 23885
    break;
   }
   if ((HEAP8[$3 + 12 | 0] | 0) != 47) {
    label = 12683; //@line 23893
    break;
   }
   if ((HEAP8[$3 + 15 | 0] | 0) != 47) {
    label = 12683; //@line 23901
    break;
   }
   if ((HEAP8[$3 + 20 | 0] | 0) != 32) {
    label = 12683; //@line 23909
    break;
   }
   _psi_write($fp, $3, 29) | 0; //@line 23912
   if ((HEAP32[$4 >> 2] | 0) >>> 0 <= 29) {
    $i_0_i = 29; //@line 23917
    break;
   }
   $i_0_i = (HEAP8[(HEAP32[$2 >> 2] | 0) + 29 | 0] | 0) == 10 ? 30 : 29; //@line 23926
  }
 } while (0);
 if ((label | 0) == 12683) {
  HEAP32[$t_i >> 2] = _time(0) | 0; //@line 23931
  $39 = _localtime($t_i | 0) | 0; //@line 23932
  $41 = HEAP32[$39 + 12 >> 2] | 0; //@line 23934
  $44 = (HEAP32[$39 + 16 >> 2] | 0) + 1 | 0; //@line 23937
  $47 = (HEAP32[$39 + 20 >> 2] | 0) + 1900 | 0; //@line 23940
  $49 = HEAP32[$39 + 8 >> 2] | 0; //@line 23942
  $51 = HEAP32[$39 + 4 >> 2] | 0; //@line 23944
  $53 = HEAP32[$39 >> 2] | 0; //@line 23946
  _fprintf($fp | 0, 56528, (tempInt = STACKTOP, STACKTOP = STACKTOP + 48 | 0, HEAP32[tempInt >> 2] = $41, HEAP32[tempInt + 8 >> 2] = $44, HEAP32[tempInt + 16 >> 2] = $47, HEAP32[tempInt + 24 >> 2] = $49, HEAP32[tempInt + 32 >> 2] = $51, HEAP32[tempInt + 40 >> 2] = $53, tempInt) | 0) | 0; //@line 23947
  $i_0_i = 0; //@line 23948
 }
 _fputc(13, $fp | 0) | 0; //@line 23951
 _fputc(10, $fp | 0) | 0; //@line 23952
 if ($i_0_i >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0) {
  $i_11_i = $i_0_i; //@line 23957
  do {
   $62 = HEAP8[(HEAP32[$2 >> 2] | 0) + $i_11_i | 0] | 0; //@line 23962
   if ($62 << 24 >> 24 == 10) {
    _fputc(13, $fp | 0) | 0; //@line 23966
    _fputc(10, $fp | 0) | 0; //@line 23967
   } else {
    $68 = $62 & 255; //@line 23970
    _fputc($68 | 0, $fp | 0) | 0; //@line 23971
   }
   $i_11_i = $i_11_i + 1 | 0; //@line 23973
  } while ($i_11_i >>> 0 < (HEAP32[$4 >> 2] | 0) >>> 0);
 }
 _fputc(26, $fp | 0) | 0; //@line 23984
 $75 = $img | 0; //@line 23985
 $76 = HEAP16[$75 >> 1] | 0; //@line 23986
 L15998 : do {
  if ($76 << 16 >> 16 != 0) {
   $78 = $img + 4 | 0; //@line 23991
   $79 = $buf_i | 0; //@line 23992
   $80 = $buf_i + 1 | 0; //@line 23993
   $81 = $buf_i + 2 | 0; //@line 23994
   $82 = $buf_i + 3 | 0; //@line 23995
   $83 = $buf_i + 4 | 0; //@line 23996
   $c_030 = 0;
   $84 = $76;
   L16000 : while (1) {
    $87 = HEAP32[(HEAP32[$78 >> 2] | 0) + ($c_030 << 2) >> 2] | 0; //@line 24004
    $88 = $87 + 2 | 0; //@line 24005
    if ((HEAP16[$88 >> 1] | 0) == 0) {
     $260 = $84; //@line 24010
    } else {
     $91 = $87 + 4 | 0; //@line 24012
     $92 = $c_030 & 255; //@line 24013
     $h_028 = 0; //@line 24015
     do {
      $96 = HEAP32[(HEAP32[$91 >> 2] | 0) + ($h_028 << 2) >> 2] | 0; //@line 24020
      $98 = HEAP16[$96 + 2 >> 1] | 0; //@line 24022
      $99 = $98 & 65535; //@line 24023
      if ($98 << 16 >> 16 != 0) {
       $101 = $96 + 4 | 0; //@line 24027
       $102 = HEAP32[$101 >> 2] | 0; //@line 24028
       $need_hmap_0_i = 0;
       $need_cmap_0_i = 0;
       $i_0_i14 = 1;
       while (1) {
        if ($i_0_i14 >>> 0 >= $99 >>> 0) {
         break;
        }
        $107 = HEAP32[$102 + ($i_0_i14 << 2) >> 2] | 0; //@line 24041
        $110 = HEAP32[$102 >> 2] | 0; //@line 24044
        if ((HEAP16[$107 + 10 >> 1] | 0) != (HEAP16[$110 + 10 >> 1] | 0)) {
         $_0 = 1; //@line 24050
         label = 12734; //@line 24051
         break L16000;
        }
        if ((HEAP16[$107 + 16 >> 1] | 0) == (HEAP16[$110 + 16 >> 1] | 0)) {
         $need_hmap_0_i = (HEAPU16[$107 + 6 >> 1] | 0) == ($h_028 | 0) ? $need_hmap_0_i : 1;
         $need_cmap_0_i = (HEAPU16[$107 + 4 >> 1] | 0) == ($c_030 | 0) ? $need_cmap_0_i : 1;
         $i_0_i14 = $i_0_i14 + 1 | 0;
        } else {
         $_0 = 1; //@line 24074
         label = 12735; //@line 24075
         break L16000;
        }
       }
       $130 = HEAP32[$102 >> 2] | 0; //@line 24079
       $131 = HEAPU16[$130 + 16 >> 1] | 0; //@line 24082
       if (($131 | 0) == 32770) {
        HEAP8[$79] = 3; //@line 24084
       } else if (($131 | 0) == 1) {
        HEAP8[$79] = 2; //@line 24087
       } else if (($131 | 0) == 32769) {
        HEAP8[$79] = 0; //@line 24090
       } else if (($131 | 0) == 2) {
        HEAP8[$79] = 5; //@line 24093
       } else {
        HEAP8[$79] = 5; //@line 24096
       }
       HEAP8[$80] = $92; //@line 24099
       $137 = $h_028 & 255; //@line 24100
       HEAP8[$81] = $137; //@line 24101
       HEAP8[$82] = $98 & 255; //@line 24103
       $_idx49_val_i = HEAP16[$130 + 10 >> 1] | 0; //@line 24105
       $139 = $_idx49_val_i & 65535; //@line 24106
       if (($139 + 65535 & $139 | 0) != 0 | ($_idx49_val_i & 65535) > 8192) {
        $_0 = 1; //@line 24114
        label = 12737; //@line 24115
        break L16000;
       }
       HEAP8[$83] = 0; //@line 24118
       if (($_idx49_val_i & 65535) > 255) {
        $size_01_i_i = $139;
        $146 = 0;
        while (1) {
         $147 = $146 + 1 & 255; //@line 24126
         if ($size_01_i_i >>> 0 > 511) {
          $size_01_i_i = $size_01_i_i >>> 1;
          $146 = $147;
         } else {
          break;
         }
        }
        HEAP8[$83] = $147; //@line 24136
       }
       $151 = $99 + 5 | 0; //@line 24139
       if (($need_cmap_0_i | 0) == 0) {
        $cmap_0_i = 0;
        $bcnt_0_i = $151;
        $158 = $137;
       } else {
        $156 = $137 | -128; //@line 24147
        HEAP8[$81] = $156; //@line 24148
        $cmap_0_i = $buf_i + $151 | 0;
        $bcnt_0_i = $151 + $99 | 0;
        $158 = $156;
       }
       if (($need_hmap_0_i | 0) == 0) {
        $hmap_0_i = 0;
        $bcnt_1_i = $bcnt_0_i;
       } else {
        HEAP8[$81] = $158 | 64; //@line 24163
        $hmap_0_i = $buf_i + $bcnt_0_i | 0;
        $bcnt_1_i = $bcnt_0_i + $99 | 0;
       }
       $165 = ($hmap_0_i | 0) == 0; //@line 24170
       if (($cmap_0_i | 0) == 0) {
        if ($165) {
         $i_154_us_us_i = 0; //@line 24173
         do {
          HEAP8[$buf_i + ($i_154_us_us_i + 5) | 0] = HEAP16[(HEAP32[$102 + ($i_154_us_us_i << 2) >> 2] | 0) + 8 >> 1] & 255; //@line 24183
          $i_154_us_us_i = $i_154_us_us_i + 1 | 0; //@line 24184
         } while ($i_154_us_us_i >>> 0 < $99 >>> 0);
        } else {
         $i_154_us_i = 0; //@line 24194
         do {
          $175 = HEAP32[$102 + ($i_154_us_i << 2) >> 2] | 0; //@line 24198
          HEAP8[$buf_i + ($i_154_us_i + 5) | 0] = HEAP16[$175 + 8 >> 1] & 255; //@line 24204
          HEAP8[$hmap_0_i + $i_154_us_i | 0] = HEAP16[$175 + 6 >> 1] & 255; //@line 24209
          $i_154_us_i = $i_154_us_i + 1 | 0; //@line 24210
         } while ($i_154_us_i >>> 0 < $99 >>> 0);
        }
       } else {
        if ($165) {
         $i_154_us56_i = 0; //@line 24222
         do {
          $187 = HEAP32[$102 + ($i_154_us56_i << 2) >> 2] | 0; //@line 24226
          HEAP8[$buf_i + ($i_154_us56_i + 5) | 0] = HEAP16[$187 + 8 >> 1] & 255; //@line 24232
          HEAP8[$cmap_0_i + $i_154_us56_i | 0] = HEAP16[$187 + 4 >> 1] & 255; //@line 24237
          $i_154_us56_i = $i_154_us56_i + 1 | 0; //@line 24238
         } while ($i_154_us56_i >>> 0 < $99 >>> 0);
        } else {
         $i_154_i = 0; //@line 24248
         do {
          $199 = HEAP32[$102 + ($i_154_i << 2) >> 2] | 0; //@line 24252
          HEAP8[$buf_i + ($i_154_i + 5) | 0] = HEAP16[$199 + 8 >> 1] & 255; //@line 24258
          HEAP8[$cmap_0_i + $i_154_i | 0] = HEAP16[$199 + 4 >> 1] & 255; //@line 24263
          HEAP8[$hmap_0_i + $i_154_i | 0] = HEAP16[$199 + 6 >> 1] & 255; //@line 24268
          $i_154_i = $i_154_i + 1 | 0; //@line 24269
         } while ($i_154_i >>> 0 < $99 >>> 0);
        }
       }
       if ((_fwrite($79 | 0, 1, $bcnt_1_i | 0, $fp | 0) | 0) == ($bcnt_1_i | 0)) {
        $i_253_i = 0; //@line 24284
       } else {
        $_0 = 1; //@line 24286
        label = 12733; //@line 24287
        break L16000;
       }
       do {
        $218 = HEAP32[(HEAP32[$101 >> 2] | 0) + ($i_253_i << 2) >> 2] | 0; //@line 24294
        if ((_psi_sct_uniform($218) | 0) == 0) {
         $226 = 0; //@line 24299
        } else {
         $226 = (HEAP16[$218 + 10 >> 1] | 0) != 0; //@line 24304
        }
        $228 = HEAP32[$218 + 12 >> 2] | 0; //@line 24308
        $or_cond_not_i_i = ($228 & 6 | 0) == 6; //@line 24311
        if ($or_cond_not_i_i | ($228 & 2 | 0) != 0) {
         $mode_0_i_i = $or_cond_not_i_i ? 7 : 5; //@line 24317
        } else {
         $mode_0_i_i = $228 >>> 1 & 2 | 1; //@line 24322
        }
        _fputc($mode_0_i_i + ($226 & 1) | 0, $fp | 0) | 0; //@line 24327
        $239 = HEAP32[$218 + 24 >> 2] | 0; //@line 24329
        if ($226) {
         $242 = HEAPU8[$239] | 0; //@line 24333
         _fputc($242 | 0, $fp | 0) | 0; //@line 24334
        } else {
         $245 = $218 + 10 | 0; //@line 24337
         $248 = _fwrite($239 | 0, 1, HEAPU16[$245 >> 1] | 0, $fp | 0) | 0; //@line 24340
         if (($248 | 0) != (HEAPU16[$245 >> 1] | 0)) {
          $_0 = 1; //@line 24346
          label = 12736; //@line 24347
          break L16000;
         }
        }
        $i_253_i = $i_253_i + 1 | 0; //@line 24351
       } while ($i_253_i >>> 0 < $99 >>> 0);
      }
      $h_028 = $h_028 + 1 | 0; //@line 24361
     } while ($h_028 >>> 0 < (HEAPU16[$88 >> 1] | 0) >>> 0);
     $260 = HEAP16[$75 >> 1] | 0; //@line 24374
    }
    $261 = $c_030 + 1 | 0; //@line 24377
    if ($261 >>> 0 < ($260 & 65535) >>> 0) {
     $c_030 = $261;
     $84 = $260;
    } else {
     break L15998;
    }
   }
   if ((label | 0) == 12733) {
    STACKTOP = sp; //@line 24389
    return $_0 | 0; //@line 24390
   } else if ((label | 0) == 12734) {
    STACKTOP = sp; //@line 24394
    return $_0 | 0; //@line 24395
   } else if ((label | 0) == 12735) {
    STACKTOP = sp; //@line 24399
    return $_0 | 0; //@line 24400
   } else if ((label | 0) == 12736) {
    STACKTOP = sp; //@line 24404
    return $_0 | 0; //@line 24405
   } else if ((label | 0) == 12737) {
    STACKTOP = sp; //@line 24409
    return $_0 | 0; //@line 24410
   }
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 24414
 $_0 = 0; //@line 24416
 STACKTOP = sp; //@line 24418
 return $_0 | 0; //@line 24419
}
function _psi_probe_imd_fp($fp) {
 $fp = $fp | 0;
 var $4 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 24428
 STACKTOP = STACKTOP + 16 | 0; //@line 24428
 if ((_fseek($fp | 0, 0, 0) | 0) != 0) {
  $_0 = 0; //@line 24434
  STACKTOP = sp; //@line 24436
  return $_0 | 0; //@line 24437
 }
 $4 = sp | 0; //@line 24439
 if ((_fread($4 | 0, 1, 4, $fp | 0) | 0) != 4) {
  $_0 = 0; //@line 24444
  STACKTOP = sp; //@line 24446
  return $_0 | 0; //@line 24447
 }
 $_0 = (_psi_get_uint32_be($4, 0) | 0) == 1229800480 | 0; //@line 24453
 STACKTOP = sp; //@line 24455
 return $_0 | 0; //@line 24456
}
function _psi_load_msa($fp) {
 $fp = $fp | 0;
 var $1 = 0, $4 = 0, $11 = 0, $13 = 0, $14 = 0, $15 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $c_039_i = 0, $h_036_i = 0, $27 = 0, $34 = 0, $fcnt_040_i_i = 0, $_02839_i_i = 0, $_02938_i_i = 0, $38 = 0, $41 = 0, $46 = 0, $47 = 0, $48 = 0, $56 = 0, $60 = 0, $61 = 0, $umax_i_i = 0, $63 = 0, $_1_lcssa_i_i = 0, $_130_lcssa_i_i = 0, $_029_be_i_i = 0, $_028_be_i_i = 0, $fcnt_0_be_i_i = 0, $s_034_i = 0, $72 = 0, $73 = 0, $81 = 0, $83 = 0, $87 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 24475
 STACKTOP = STACKTOP + 16 | 0; //@line 24475
 $1 = _psi_img_new() | 0; //@line 24477
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 24481
  STACKTOP = sp; //@line 24483
  return $_0 | 0; //@line 24484
 }
 $4 = sp | 0; //@line 24486
 if ((_psi_read_ofs($fp, 0, $4, 10) | 0) != 0) {
  $_0 = $1; //@line 24491
  STACKTOP = sp; //@line 24493
  return $_0 | 0; //@line 24494
 }
 if ((_psi_get_uint16_be($4, 0) | 0) != 3599) {
  $_0 = $1; //@line 24500
  STACKTOP = sp; //@line 24502
  return $_0 | 0; //@line 24503
 }
 $11 = _psi_get_uint16_be($4, 2) | 0; //@line 24505
 $13 = (_psi_get_uint16_be($4, 4) | 0) + 1 | 0; //@line 24507
 $14 = _psi_get_uint16_be($4, 6) | 0; //@line 24508
 $15 = _psi_get_uint16_be($4, 8) | 0; //@line 24509
 do {
  if (!(($11 | 0) == 0 | $11 >>> 0 > 127)) {
   if ($13 >>> 0 > 16 | $15 >>> 0 < $14 >>> 0) {
    break;
   }
   $22 = $11 << 9; //@line 24523
   $23 = _malloc($22) | 0; //@line 24524
   if (($23 | 0) == 0) {
    break;
   }
   $25 = ($13 | 0) == 0; //@line 24530
   $26 = ($22 | 0) == 0; //@line 24531
   $c_039_i = $14; //@line 24533
   L16091 : while (1) {
    if (!$25) {
     $h_036_i = 0; //@line 24538
     do {
      $27 = _psi_img_get_track($1, $c_039_i, $h_036_i, 1) | 0; //@line 24541
      if (($27 | 0) == 0) {
       label = 12755; //@line 24545
       break L16091;
      }
      if ((_psi_read($fp, $23, 2) | 0) != 0) {
       label = 12770; //@line 24552
       break L16091;
      }
      $34 = _psi_get_uint16_be($23, 0) | 0; //@line 24555
      do {
       if (($34 | 0) == ($22 | 0)) {
        if ((_psi_read($fp, $23, $22) | 0) == 0) {
         $s_034_i = 0; //@line 24564
        } else {
         label = 12770; //@line 24566
         break L16091;
        }
       } else {
        if ($26) {
         $s_034_i = 0; //@line 24572
         break;
        } else {
         $_02938_i_i = $22;
         $_02839_i_i = $23;
         $fcnt_040_i_i = $34;
        }
        while (1) {
         if (($fcnt_040_i_i | 0) == 0) {
          label = 12770; //@line 24584
          break L16091;
         }
         $38 = _fgetc($fp | 0) | 0; //@line 24587
         if (($38 | 0) == -1) {
          label = 12770; //@line 24591
          break L16091;
         }
         $41 = $fcnt_040_i_i - 1 | 0; //@line 24594
         if (($38 | 0) == 229) {
          if ($41 >>> 0 < 3) {
           label = 12770; //@line 24601
           break L16091;
          }
          $46 = _fgetc($fp | 0) | 0; //@line 24604
          $47 = _fgetc($fp | 0) | 0; //@line 24605
          $48 = _fgetc($fp | 0) | 0; //@line 24606
          if (($46 | 0) == -1 | ($47 | 0) == -1 | ($48 | 0) == -1) {
           label = 12770; //@line 24614
           break L16091;
          }
          $56 = $47 << 8 & 65280 | $48 & 255; //@line 24620
          if (($_02938_i_i | 0) == 0 | ($56 | 0) == 0) {
           $_130_lcssa_i_i = $_02938_i_i;
           $_1_lcssa_i_i = $_02839_i_i;
          } else {
           $60 = -$_02938_i_i | 0; //@line 24629
           $61 = -$56 | 0; //@line 24630
           $umax_i_i = $60 >>> 0 > $61 >>> 0 ? $60 : $61; //@line 24632
           $63 = -$umax_i_i | 0; //@line 24633
           _memset($_02839_i_i | 0, $46 & 255 | 0, $63 | 0); //@line 24634
           $_130_lcssa_i_i = $umax_i_i + $_02938_i_i | 0;
           $_1_lcssa_i_i = $_02839_i_i + $63 | 0;
          }
          $fcnt_0_be_i_i = $fcnt_040_i_i - 4 | 0;
          $_028_be_i_i = $_1_lcssa_i_i;
          $_029_be_i_i = $_130_lcssa_i_i;
         } else {
          HEAP8[$_02839_i_i] = $38 & 255; //@line 24648
          $fcnt_0_be_i_i = $41;
          $_028_be_i_i = $_02839_i_i + 1 | 0;
          $_029_be_i_i = $_02938_i_i - 1 | 0;
         }
         if (($_029_be_i_i | 0) == 0) {
          $s_034_i = 0; //@line 24658
          break;
         } else {
          $_02938_i_i = $_029_be_i_i;
          $_02839_i_i = $_028_be_i_i;
          $fcnt_040_i_i = $fcnt_0_be_i_i;
         }
        }
       }
      } while (0);
      while (1) {
       $72 = $s_034_i + 1 | 0; //@line 24668
       $73 = _psi_sct_new($c_039_i, $h_036_i, $72, 512) | 0; //@line 24669
       if (($73 | 0) == 0) {
        label = 12772; //@line 24673
        break L16091;
       }
       _psi_sct_set_encoding($73, 2); //@line 24676
       if ((_psi_trk_add_sector($27, $73) | 0) != 0) {
        label = 12774; //@line 24681
        break L16091;
       }
       $81 = HEAP32[$73 + 24 >> 2] | 0; //@line 24685
       $83 = $23 + ($s_034_i << 9) | 0; //@line 24687
       _memcpy($81 | 0, $83 | 0, 512) | 0; //@line 24688
       if ($72 >>> 0 < $11 >>> 0) {
        $s_034_i = $72; //@line 24692
       } else {
        break;
       }
      }
      $h_036_i = $h_036_i + 1 | 0; //@line 24697
     } while ($h_036_i >>> 0 < $13 >>> 0);
    }
    $87 = $c_039_i + 1 | 0; //@line 24707
    if ($87 >>> 0 > $15 >>> 0) {
     label = 12778; //@line 24711
     break;
    } else {
     $c_039_i = $87; //@line 24714
    }
   }
   if ((label | 0) == 12755) {
    _free($23); //@line 24718
    break;
   } else if ((label | 0) == 12772) {
    _free($23); //@line 24723
    break;
   } else if ((label | 0) == 12778) {
    _free($23); //@line 24728
    $_0 = $1; //@line 24730
    STACKTOP = sp; //@line 24732
    return $_0 | 0; //@line 24733
   } else if ((label | 0) == 12770) {
    _free($23); //@line 24736
    break;
   } else if ((label | 0) == 12774) {
    _psi_sct_del($73); //@line 24741
    break;
   }
  }
 } while (0);
 _psi_img_del($1); //@line 24747
 $_0 = 0; //@line 24749
 STACKTOP = sp; //@line 24751
 return $_0 | 0; //@line 24752
}
function _psi_save_msa($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $1 = 0, $4 = 0, $7 = 0, $8 = 0, $11 = 0, $15 = 0, $25 = 0, $27 = 0, $28 = 0, $c_024 = 0, $h_023 = 0, $s_0 = 0, $36 = 0, $37 = 0, $50 = 0, $54 = 0, $55 = 0, $56 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 24768
 STACKTOP = STACKTOP + 16 | 0; //@line 24768
 $1 = _psi_img_get_cylinder($img, 0, 0) | 0; //@line 24770
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 24774
  STACKTOP = sp; //@line 24776
  return $_0 | 0; //@line 24777
 }
 $4 = _psi_img_get_track($img, 0, 0, 0) | 0; //@line 24779
 if (($4 | 0) == 0) {
  $_0 = 1; //@line 24783
  STACKTOP = sp; //@line 24785
  return $_0 | 0; //@line 24786
 }
 $7 = sp | 0; //@line 24788
 _psi_set_uint16_be($7, 0, 3599); //@line 24789
 $8 = $4 + 2 | 0; //@line 24790
 _psi_set_uint16_be($7, 2, HEAPU16[$8 >> 1] | 0); //@line 24793
 $11 = $1 + 2 | 0; //@line 24794
 _psi_set_uint16_be($7, 4, (HEAPU16[$11 >> 1] | 0) - 1 | 0); //@line 24798
 _psi_set_uint16_be($7, 6, 0); //@line 24799
 $15 = $img | 0; //@line 24800
 _psi_set_uint16_be($7, 8, (HEAPU16[$15 >> 1] | 0) - 1 | 0); //@line 24804
 if ((_psi_write($fp, $7, 10) | 0) != 0) {
  $_0 = 1; //@line 24809
  STACKTOP = sp; //@line 24811
  return $_0 | 0; //@line 24812
 }
 _psi_set_uint16_be($7, 0, HEAPU16[$8 >> 1] << 9); //@line 24817
 $25 = HEAP16[$15 >> 1] | 0; //@line 24818
 L16139 : do {
  if ($25 << 16 >> 16 != 0) {
   $c_024 = 0;
   $28 = HEAP16[$11 >> 1] | 0;
   $27 = $25;
   L16141 : while (1) {
    if ($28 << 16 >> 16 == 0) {
     $55 = 0;
     $54 = $27;
    } else {
     $h_023 = 0; //@line 24835
     do {
      if ((_psi_write($fp, $7, 2) | 0) == 0) {
       $s_0 = 0; //@line 24842
      } else {
       $_0 = 1; //@line 24844
       label = 12808; //@line 24845
       break L16141;
      }
      while (1) {
       if ($s_0 >>> 0 >= (HEAPU16[$8 >> 1] | 0) >>> 0) {
        break;
       }
       $36 = $s_0 + 1 | 0; //@line 24857
       $37 = _psi_img_get_sector($img, $c_024, $h_023, $36, 0) | 0; //@line 24858
       if (($37 | 0) == 0) {
        $_0 = 1; //@line 24862
        label = 12802; //@line 24863
        break L16141;
       }
       if ((HEAP16[$37 + 10 >> 1] | 0) != 512) {
        $_0 = 1; //@line 24871
        label = 12809; //@line 24872
        break L16141;
       }
       if ((_psi_write($fp, HEAP32[$37 + 24 >> 2] | 0, 512) | 0) == 0) {
        $s_0 = $36; //@line 24881
       } else {
        $_0 = 1; //@line 24883
        label = 12806; //@line 24884
        break L16141;
       }
      }
      $h_023 = $h_023 + 1 | 0; //@line 24888
      $50 = HEAP16[$11 >> 1] | 0; //@line 24889
     } while ($h_023 >>> 0 < ($50 & 65535) >>> 0);
     $55 = $50;
     $54 = HEAP16[$15 >> 1] | 0;
    }
    $56 = $c_024 + 1 | 0; //@line 24905
    if ($56 >>> 0 < ($54 & 65535) >>> 0) {
     $c_024 = $56;
     $28 = $55;
     $27 = $54;
    } else {
     break L16139;
    }
   }
   if ((label | 0) == 12806) {
    STACKTOP = sp; //@line 24917
    return $_0 | 0; //@line 24918
   } else if ((label | 0) == 12808) {
    STACKTOP = sp; //@line 24922
    return $_0 | 0; //@line 24923
   } else if ((label | 0) == 12802) {
    STACKTOP = sp; //@line 24927
    return $_0 | 0; //@line 24928
   } else if ((label | 0) == 12809) {
    STACKTOP = sp; //@line 24932
    return $_0 | 0; //@line 24933
   }
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 24937
 $_0 = 0; //@line 24939
 STACKTOP = sp; //@line 24941
 return $_0 | 0; //@line 24942
}
function _psi_probe_msa_fp($fp) {
 $fp = $fp | 0;
 var $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 24950
 STACKTOP = STACKTOP + 16 | 0; //@line 24950
 $1 = sp | 0; //@line 24952
 if ((_psi_read_ofs($fp, 0, $1, 10) | 0) != 0) {
  $_0 = 0; //@line 24957
  STACKTOP = sp; //@line 24959
  return $_0 | 0; //@line 24960
 }
 $_0 = (_psi_get_uint16_be($1, 0) | 0) == 3599 | 0; //@line 24966
 STACKTOP = sp; //@line 24968
 return $_0 | 0; //@line 24969
}
function _psi_load_pfdc($fp) {
 $fp = $fp | 0;
 var $1 = 0, $4 = 0, $8 = 0, $9 = 0, $_0_i = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 24978
 STACKTOP = STACKTOP + 8 | 0; //@line 24978
 $1 = _psi_img_new() | 0; //@line 24980
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 24984
  STACKTOP = sp; //@line 24986
  return $_0 | 0; //@line 24987
 }
 $4 = sp | 0; //@line 24989
 do {
  if ((_psi_read($fp, $4, 8) | 0) == 0) {
   $8 = _psi_get_uint32_be($4, 0) | 0; //@line 24995
   $9 = _psi_get_uint32_be($4, 4) | 0; //@line 24996
   if (($8 | 0) != 1346782275) {
    break;
   }
   if (($9 | 0) == 131072) {
    $_0_i = _pfdc2_load_fp($fp, $1, 1346782275, 131072) | 0; //@line 25005
   } else if (($9 | 0) == 65536) {
    $_0_i = _pfdc1_load_fp($fp, $1, 1346782275, 65536) | 0; //@line 25009
   } else if (($9 | 0) == 0) {
    $_0_i = _pfdc0_load_fp($fp, $1, 1346782275, 0) | 0; //@line 25013
   } else {
    $_0_i = _pfdc4_load_fp($fp, $1, 1346782275, $9) | 0; //@line 25017
   }
   if (($_0_i | 0) == 0) {
    $_0 = $1; //@line 25023
   } else {
    break;
   }
   STACKTOP = sp; //@line 25028
   return $_0 | 0; //@line 25029
  }
 } while (0);
 _psi_img_del($1); //@line 25032
 $_0 = 0; //@line 25034
 STACKTOP = sp; //@line 25036
 return $_0 | 0; //@line 25037
}
function _psi_save_pfdc($fp, $img, $vers) {
 $fp = $fp | 0;
 $img = $img | 0;
 $vers = $vers | 0;
 var $_0 = 0;
 if (($vers | 0) == 2) {
  $_0 = _pfdc2_save_fp($fp, $img) | 0; //@line 25051
 } else if (($vers | 0) == 0) {
  $_0 = _pfdc0_save_fp($fp, $img) | 0; //@line 25055
 } else if (($vers | 0) == 1) {
  $_0 = _pfdc1_save_fp($fp, $img) | 0; //@line 25059
 } else {
  $_0 = _pfdc4_save_fp($fp, $img) | 0; //@line 25063
 }
 return $_0 | 0; //@line 25067
}
function _psi_probe_pfdc_fp($fp) {
 $fp = $fp | 0;
 var $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 25075
 STACKTOP = STACKTOP + 8 | 0; //@line 25075
 $1 = sp | 0; //@line 25077
 if ((_psi_read_ofs($fp, 0, $1, 4) | 0) != 0) {
  $_0 = 0; //@line 25082
  STACKTOP = sp; //@line 25084
  return $_0 | 0; //@line 25085
 }
 $_0 = (_psi_get_uint32_be($1, 0) | 0) == 1346782275 | 0; //@line 25091
 STACKTOP = sp; //@line 25093
 return $_0 | 0; //@line 25094
}
function _pfdc0_load_fp($fp, $img, $id, $sz) {
 $fp = $fp | 0;
 $img = $img | 0;
 $id = $id | 0;
 $sz = $sz | 0;
 var $buf_i = 0, $3 = 0, $7 = 0, $8 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $i_07 = 0, $26 = 0, $27 = 0, $29 = 0, $30 = 0, $37 = 0, $53 = 0, $60 = 0, $67 = 0, $84 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 25114
 STACKTOP = STACKTOP + 24 | 0; //@line 25114
 $buf_i = sp | 0; //@line 25115
 _fwrite(52976, 49, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 25118
 $3 = sp + 16 | 0; //@line 25119
 if ((_psi_read($fp, $3, 8) | 0) != 0) {
  $_0 = 1; //@line 25124
  STACKTOP = sp; //@line 25126
  return $_0 | 0; //@line 25127
 }
 $7 = _psi_get_uint32_be($3, 0) | 0; //@line 25129
 $8 = _psi_get_uint32_be($3, 4) | 0; //@line 25130
 if ($8 >>> 0 < 16) {
  $_0 = 1; //@line 25134
  STACKTOP = sp; //@line 25136
  return $_0 | 0; //@line 25137
 }
 if ((_psi_skip($fp, $8 - 16 | 0) | 0) != 0) {
  $_0 = 1; //@line 25144
  STACKTOP = sp; //@line 25146
  return $_0 | 0; //@line 25147
 }
 if (($7 | 0) == 0) {
  $_0 = 0; //@line 25152
  STACKTOP = sp; //@line 25154
  return $_0 | 0; //@line 25155
 }
 $15 = $buf_i | 0; //@line 25157
 $16 = $buf_i + 1 | 0; //@line 25158
 $17 = $buf_i + 5 | 0; //@line 25159
 $18 = $buf_i + 2 | 0; //@line 25160
 $19 = $buf_i + 3 | 0; //@line 25161
 $20 = $buf_i + 4 | 0; //@line 25162
 $21 = $buf_i + 12 | 0; //@line 25163
 $i_07 = 0; //@line 25165
 while (1) {
  if ((_psi_read($fp, $15, 12) | 0) != 0) {
   $_0 = 1; //@line 25172
   label = 12870; //@line 25173
   break;
  }
  $26 = HEAP8[$15] | 0; //@line 25176
  $27 = HEAP8[$16] | 0; //@line 25177
  $29 = HEAPU8[$17] | 0; //@line 25179
  $30 = _psi_get_uint16_be($15, 6) | 0; //@line 25180
  $37 = _psi_sct_new(HEAPU8[$18] | 0, HEAPU8[$19] | 0, HEAPU8[$20] | 0, $30) | 0; //@line 25187
  if (($37 | 0) == 0) {
   $_0 = 1; //@line 25191
   label = 12862; //@line 25192
   break;
  }
  if ((_psi_img_add_sector($img, $37, $26 & 255, $27 & 255) | 0) != 0) {
   label = 12848; //@line 25201
   break;
  }
  _psi_get_uint32_be($15, 8) | 0; //@line 25204
  _psi_sct_set_encoding($37, ($29 & 1 | 0) == 0 ? $29 & 2 : 1); //@line 25209
  if (($29 & 4 | 0) != 0) {
   $53 = $37 + 12 | 0; //@line 25214
   HEAP32[$53 >> 2] = HEAP32[$53 >> 2] | 1; //@line 25217
  }
  if (($29 & 8 | 0) != 0) {
   $60 = $37 + 12 | 0; //@line 25224
   HEAP32[$60 >> 2] = HEAP32[$60 >> 2] | 2; //@line 25227
  }
  if (($29 & 16 | 0) != 0) {
   $67 = $37 + 12 | 0; //@line 25234
   HEAP32[$67 >> 2] = HEAP32[$67 >> 2] | 4; //@line 25237
  }
  if (($29 & 128 | 0) == 0) {
   if ((_psi_read($fp, HEAP32[$37 + 24 >> 2] | 0, $30) | 0) != 0) {
    $_0 = 1; //@line 25250
    label = 12868; //@line 25251
    break;
   }
  } else {
   if ((_psi_read($fp, $21, 1) | 0) != 0) {
    $_0 = 1; //@line 25259
    label = 12864; //@line 25260
    break;
   }
   _psi_sct_fill($37, HEAPU8[$21] | 0); //@line 25265
  }
  $84 = $i_07 + 1 | 0; //@line 25268
  if ($84 >>> 0 < $7 >>> 0) {
   $i_07 = $84; //@line 25272
  } else {
   $_0 = 0; //@line 25274
   label = 12866; //@line 25275
   break;
  }
 }
 if ((label | 0) == 12868) {
  STACKTOP = sp; //@line 25281
  return $_0 | 0; //@line 25282
 } else if ((label | 0) == 12848) {
  _psi_sct_del($37); //@line 25285
  $_0 = 1; //@line 25287
  STACKTOP = sp; //@line 25289
  return $_0 | 0; //@line 25290
 } else if ((label | 0) == 12866) {
  STACKTOP = sp; //@line 25294
  return $_0 | 0; //@line 25295
 } else if ((label | 0) == 12864) {
  STACKTOP = sp; //@line 25299
  return $_0 | 0; //@line 25300
 } else if ((label | 0) == 12870) {
  STACKTOP = sp; //@line 25304
  return $_0 | 0; //@line 25305
 } else if ((label | 0) == 12862) {
  STACKTOP = sp; //@line 25309
  return $_0 | 0; //@line 25310
 }
 return 0;
}
function _pfdc0_save_fp($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i = 0, $1 = 0, $2 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $c_022 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $26 = 0, $27 = 0, $h_018 = 0, $30 = 0, $31 = 0, $34 = 0, $35 = 0, $s_017 = 0, $39 = 0, $42 = 0, $flg_0_load1924_i = 0, $dr_0_load20_i = 0, $49 = 0, $flg_0_load1923_i = 0, $flg_0_load1922_i = 0, $69 = 0, $70 = 0, $102 = 0, $103 = 0, $107 = 0, $108 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 25333
 STACKTOP = STACKTOP + 32 | 0; //@line 25333
 $buf_i = sp | 0; //@line 25334
 $1 = _psi_img_get_sector_count($img) | 0; //@line 25336
 $2 = sp + 16 | 0; //@line 25337
 _psi_set_uint32_be($2, 0, 1346782275); //@line 25338
 _psi_set_uint32_be($2, 4, 0); //@line 25339
 _psi_set_uint32_be($2, 8, $1); //@line 25340
 _psi_set_uint32_be($2, 12, 16); //@line 25341
 if ((_psi_write($fp, $2, 16) | 0) != 0) {
  $_0 = 1; //@line 25346
  STACKTOP = sp; //@line 25348
  return $_0 | 0; //@line 25349
 }
 $5 = $img | 0; //@line 25351
 $6 = HEAP16[$5 >> 1] | 0; //@line 25352
 L16238 : do {
  if ($6 << 16 >> 16 != 0) {
   $8 = $img + 4 | 0; //@line 25357
   $9 = $buf_i | 0; //@line 25358
   $10 = $buf_i + 1 | 0; //@line 25359
   $11 = $buf_i + 2 | 0; //@line 25360
   $12 = $buf_i + 3 | 0; //@line 25361
   $13 = $buf_i + 4 | 0; //@line 25362
   $14 = $buf_i + 5 | 0; //@line 25363
   $15 = $buf_i + 6 | 0; //@line 25364
   $16 = $buf_i + 7 | 0; //@line 25365
   $17 = $buf_i + 12 | 0; //@line 25366
   $c_022 = 0;
   $18 = $6;
   L16240 : while (1) {
    $21 = HEAP32[(HEAP32[$8 >> 2] | 0) + ($c_022 << 2) >> 2] | 0; //@line 25374
    $22 = $21 + 2 | 0; //@line 25375
    $23 = HEAP16[$22 >> 1] | 0; //@line 25376
    if ($23 << 16 >> 16 == 0) {
     $107 = $18; //@line 25380
    } else {
     $25 = $21 + 4 | 0; //@line 25382
     $26 = $c_022 & 255; //@line 25383
     $h_018 = 0;
     $27 = $23;
     while (1) {
      $30 = HEAP32[(HEAP32[$25 >> 2] | 0) + ($h_018 << 2) >> 2] | 0; //@line 25391
      $31 = $30 + 2 | 0; //@line 25392
      if ((HEAP16[$31 >> 1] | 0) == 0) {
       $102 = $27; //@line 25397
      } else {
       $34 = $30 + 4 | 0; //@line 25399
       $35 = $h_018 & 255; //@line 25400
       $s_017 = 0; //@line 25402
       do {
        $39 = HEAP32[(HEAP32[$34 >> 2] | 0) + ($s_017 << 2) >> 2] | 0; //@line 25407
        $42 = HEAPU16[$39 + 16 >> 1] | 0; //@line 25410
        if (($42 | 0) == 1) {
         $dr_0_load20_i = 125e3;
         $flg_0_load1924_i = 1;
        } else if (($42 | 0) == 32770) {
         $dr_0_load20_i = 5e5;
         $flg_0_load1924_i = 2;
        } else if (($42 | 0) == 32769) {
         $dr_0_load20_i = 25e4;
         $flg_0_load1924_i = 1;
        } else if (($42 | 0) == 2) {
         $dr_0_load20_i = 25e4;
         $flg_0_load1924_i = 2;
        } else if (($42 | 0) == 16386) {
         $dr_0_load20_i = 1e6;
         $flg_0_load1924_i = 2;
        } else {
         $dr_0_load20_i = 0;
         $flg_0_load1924_i = 0;
        }
        $49 = HEAP32[$39 + 12 >> 2] | 0; //@line 25432
        $flg_0_load1923_i = ($49 & 1 | 0) == 0 ? $flg_0_load1924_i : $flg_0_load1924_i | 4; //@line 25436
        $flg_0_load1922_i = ($49 & 2 | 0) == 0 ? $flg_0_load1923_i : $flg_0_load1923_i | 8; //@line 25440
        HEAP8[$9] = $26; //@line 25445
        HEAP8[$10] = $35; //@line 25446
        HEAP8[$11] = HEAP16[$39 + 4 >> 1] & 255; //@line 25450
        HEAP8[$12] = HEAP16[$39 + 6 >> 1] & 255; //@line 25454
        HEAP8[$13] = HEAP16[$39 + 8 >> 1] & 255; //@line 25458
        HEAP8[$14] = (($49 & 4 | 0) == 0 ? $flg_0_load1922_i : $flg_0_load1922_i | 16) & 255; //@line 25460
        $69 = $39 + 10 | 0; //@line 25461
        $70 = HEAP16[$69 >> 1] | 0; //@line 25462
        HEAP8[$15] = ($70 & 65535) >>> 8 & 255; //@line 25465
        HEAP8[$16] = $70 & 255; //@line 25467
        _psi_set_uint32_be($9, 8, $dr_0_load20_i); //@line 25468
        do {
         if ((_psi_sct_uniform($39) | 0) == 0) {
          label = 12887; //@line 25474
         } else {
          if ((HEAP16[$69 >> 1] | 0) == 0) {
           label = 12887; //@line 25480
           break;
          }
          HEAP8[$14] = HEAP8[$14] | -128; //@line 25485
          HEAP8[$17] = HEAP8[HEAP32[$39 + 24 >> 2] | 0] | 0; //@line 25489
          if ((_psi_write($fp, $9, 13) | 0) != 0) {
           $_0 = 1; //@line 25494
           label = 12898; //@line 25495
           break L16240;
          }
         }
        } while (0);
        if ((label | 0) == 12887) {
         label = 0; //@line 25501
         if ((_psi_write($fp, $9, 12) | 0) != 0) {
          $_0 = 1; //@line 25506
          label = 12896; //@line 25507
          break L16240;
         }
         if ((_psi_write($fp, HEAP32[$39 + 24 >> 2] | 0, HEAPU16[$69 >> 1] | 0) | 0) != 0) {
          $_0 = 1; //@line 25518
          label = 12900; //@line 25519
          break L16240;
         }
        }
        $s_017 = $s_017 + 1 | 0; //@line 25523
       } while ($s_017 >>> 0 < (HEAPU16[$31 >> 1] | 0) >>> 0);
       $102 = HEAP16[$22 >> 1] | 0; //@line 25536
      }
      $103 = $h_018 + 1 | 0; //@line 25539
      if ($103 >>> 0 < ($102 & 65535) >>> 0) {
       $h_018 = $103;
       $27 = $102;
      } else {
       break;
      }
     }
     $107 = HEAP16[$5 >> 1] | 0; //@line 25551
    }
    $108 = $c_022 + 1 | 0; //@line 25554
    if ($108 >>> 0 < ($107 & 65535) >>> 0) {
     $c_022 = $108;
     $18 = $107;
    } else {
     break L16238;
    }
   }
   if ((label | 0) == 12900) {
    STACKTOP = sp; //@line 25566
    return $_0 | 0; //@line 25567
   } else if ((label | 0) == 12898) {
    STACKTOP = sp; //@line 25571
    return $_0 | 0; //@line 25572
   } else if ((label | 0) == 12896) {
    STACKTOP = sp; //@line 25576
    return $_0 | 0; //@line 25577
   }
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 25581
 $_0 = 0; //@line 25583
 STACKTOP = sp; //@line 25585
 return $_0 | 0; //@line 25586
}
function _pfdc1_load_fp($fp, $img, $id, $sz) {
 $fp = $fp | 0;
 $img = $img | 0;
 $id = $id | 0;
 $sz = $sz | 0;
 var $buf_i = 0, $3 = 0, $7 = 0, $8 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $i_08 = 0, $24 = 0, $26 = 0, $31 = 0, $33 = 0, $34 = 0, $41 = 0, $44 = 0, $46 = 0, $50 = 0, $57 = 0, $64 = 0, $68 = 0, $_0_i_i = 0, $100 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 25607
 STACKTOP = STACKTOP + 40 | 0; //@line 25607
 $buf_i = sp | 0; //@line 25608
 _fwrite(52872, 49, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 25611
 $3 = sp + 32 | 0; //@line 25612
 if ((_psi_read($fp, $3, 8) | 0) != 0) {
  $_0 = 1; //@line 25617
  STACKTOP = sp; //@line 25619
  return $_0 | 0; //@line 25620
 }
 $7 = _psi_get_uint32_be($3, 0) | 0; //@line 25622
 $8 = _psi_get_uint32_be($3, 4) | 0; //@line 25623
 if ($8 >>> 0 < 16) {
  $_0 = 1; //@line 25627
  STACKTOP = sp; //@line 25629
  return $_0 | 0; //@line 25630
 }
 if ((_psi_skip($fp, $8 - 16 | 0) | 0) != 0) {
  $_0 = 1; //@line 25637
  STACKTOP = sp; //@line 25639
  return $_0 | 0; //@line 25640
 }
 if (($7 | 0) == 0) {
  $_0 = 0; //@line 25645
  STACKTOP = sp; //@line 25647
  return $_0 | 0; //@line 25648
 }
 $15 = $buf_i | 0; //@line 25650
 $16 = $buf_i + 1 | 0; //@line 25651
 $17 = $buf_i + 2 | 0; //@line 25652
 $18 = $buf_i + 3 | 0; //@line 25653
 $19 = $buf_i + 4 | 0; //@line 25654
 $20 = $buf_i + 5 | 0; //@line 25655
 $21 = $buf_i + 8 | 0; //@line 25656
 $22 = $buf_i + 16 | 0; //@line 25657
 $24 = 0;
 $i_08 = 0;
 while (1) {
  $26 = (_psi_read($fp, $15, 16) | 0) == 0; //@line 25664
  if (!($26 & (HEAP8[$15] | 0) == 83)) {
   $_0 = 1; //@line 25670
   label = 12935; //@line 25671
   break;
  }
  $31 = HEAPU8[$16] | 0; //@line 25675
  $33 = HEAPU8[$17] | 0; //@line 25677
  $34 = _psi_get_uint16_be($15, 6) | 0; //@line 25678
  $41 = _psi_sct_new(HEAPU8[$18] | 0, HEAPU8[$19] | 0, HEAPU8[$20] | 0, $34) | 0; //@line 25685
  if (($41 | 0) == 0) {
   $_0 = 1; //@line 25689
   label = 12938; //@line 25690
   break;
  }
  $44 = _psi_get_uint32_be($15, 12) | 0; //@line 25693
  $46 = (_psi_get_uint32_be($15, 8) | 0) & 16777215; //@line 25695
  if (($44 & 4 | 0) != 0) {
   $50 = $41 + 12 | 0; //@line 25700
   HEAP32[$50 >> 2] = HEAP32[$50 >> 2] | 1; //@line 25703
  }
  if (($44 & 8 | 0) != 0) {
   $57 = $41 + 12 | 0; //@line 25710
   HEAP32[$57 >> 2] = HEAP32[$57 >> 2] | 2; //@line 25713
  }
  if (($44 & 16 | 0) != 0) {
   $64 = $41 + 12 | 0; //@line 25720
   HEAP32[$64 >> 2] = HEAP32[$64 >> 2] | 4; //@line 25723
  }
  $68 = HEAPU8[$21] | 0; //@line 25727
  if (($68 | 0) == 1) {
   $_0_i_i = $46 >>> 0 < 375e3 ? 1 : 32769; //@line 25732
  } else if (($68 | 0) == 2) {
   $_0_i_i = $46 >>> 0 < 375e3 ? 2 : 32770; //@line 25737
  } else {
   $_0_i_i = 0; //@line 25739
  }
  _psi_sct_set_encoding($41, $_0_i_i); //@line 25742
  if (($44 & 1 | 0) == 0) {
   if ((_psi_img_add_sector($img, $41, $31, $33) | 0) != 0) {
    label = 12922; //@line 25751
    break;
   }
  } else {
   if (($24 | 0) == 0) {
    label = 12919; //@line 25758
    break;
   }
   _psi_sct_add_alternate($24, $41); //@line 25761
  }
  if (($44 & 128 | 0) == 0) {
   if ((_psi_read($fp, HEAP32[$41 + 24 >> 2] | 0, $34) | 0) != 0) {
    $_0 = 1; //@line 25774
    label = 12931; //@line 25775
    break;
   }
  } else {
   if ((_psi_read($fp, $22, 1) | 0) != 0) {
    $_0 = 1; //@line 25783
    label = 12930; //@line 25784
    break;
   }
   _psi_sct_fill($41, HEAPU8[$22] | 0); //@line 25789
  }
  $100 = $i_08 + 1 | 0; //@line 25792
  if ($100 >>> 0 < $7 >>> 0) {
   $24 = $41;
   $i_08 = $100;
  } else {
   $_0 = 0; //@line 25798
   label = 12932; //@line 25799
   break;
  }
 }
 if ((label | 0) == 12919) {
  _psi_sct_del($41); //@line 25804
  $_0 = 1; //@line 25806
  STACKTOP = sp; //@line 25808
  return $_0 | 0; //@line 25809
 } else if ((label | 0) == 12931) {
  STACKTOP = sp; //@line 25813
  return $_0 | 0; //@line 25814
 } else if ((label | 0) == 12932) {
  STACKTOP = sp; //@line 25818
  return $_0 | 0; //@line 25819
 } else if ((label | 0) == 12938) {
  STACKTOP = sp; //@line 25823
  return $_0 | 0; //@line 25824
 } else if ((label | 0) == 12930) {
  STACKTOP = sp; //@line 25828
  return $_0 | 0; //@line 25829
 } else if ((label | 0) == 12935) {
  STACKTOP = sp; //@line 25833
  return $_0 | 0; //@line 25834
 } else if ((label | 0) == 12922) {
  _psi_sct_del($41); //@line 25837
  $_0 = 1; //@line 25839
  STACKTOP = sp; //@line 25841
  return $_0 | 0; //@line 25842
 }
 return 0;
}
function _pfdc1_save_fp($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $1 = 0, $2 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $c_025 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $h_020 = 0, $20 = 0, $21 = 0, $24 = 0, $s_019 = 0, $28 = 0, $sct_pn_i = 0, $_012_i = 0, $41 = 0, $42 = 0, $46 = 0, $47 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 25858
 STACKTOP = STACKTOP + 16 | 0; //@line 25858
 $1 = _psi_img_get_sector_count($img) | 0; //@line 25860
 $2 = sp | 0; //@line 25861
 _psi_set_uint32_be($2, 0, 1346782275); //@line 25862
 _psi_set_uint16_be($2, 4, 1); //@line 25863
 _psi_set_uint16_be($2, 6, 0); //@line 25864
 _psi_set_uint32_be($2, 8, $1); //@line 25865
 _psi_set_uint32_be($2, 12, 16); //@line 25866
 if ((_psi_write($fp, $2, 16) | 0) != 0) {
  $_0 = 1; //@line 25871
  STACKTOP = sp; //@line 25873
  return $_0 | 0; //@line 25874
 }
 $5 = $img | 0; //@line 25876
 $6 = HEAP16[$5 >> 1] | 0; //@line 25877
 L16328 : do {
  if ($6 << 16 >> 16 != 0) {
   $8 = $img + 4 | 0; //@line 25882
   $c_025 = 0;
   $9 = $6;
   L16330 : while (1) {
    $12 = HEAP32[(HEAP32[$8 >> 2] | 0) + ($c_025 << 2) >> 2] | 0; //@line 25890
    $13 = $12 + 2 | 0; //@line 25891
    $14 = HEAP16[$13 >> 1] | 0; //@line 25892
    if ($14 << 16 >> 16 == 0) {
     $46 = $9; //@line 25896
    } else {
     $16 = $12 + 4 | 0; //@line 25898
     $h_020 = 0;
     $17 = $14;
     while (1) {
      $20 = HEAP32[(HEAP32[$16 >> 2] | 0) + ($h_020 << 2) >> 2] | 0; //@line 25906
      $21 = $20 + 2 | 0; //@line 25907
      if ((HEAP16[$21 >> 1] | 0) == 0) {
       $41 = $17; //@line 25912
      } else {
       $24 = $20 + 4 | 0; //@line 25914
       $s_019 = 0; //@line 25916
       do {
        $28 = HEAP32[(HEAP32[$24 >> 2] | 0) + ($s_019 << 2) >> 2] | 0; //@line 25921
        if ((_pfdc1_save_sector($fp, $28, $c_025, $h_020, 0) | 0) == 0) {
         $sct_pn_i = $28; //@line 25926
        } else {
         $_0 = 1; //@line 25928
         label = 12957; //@line 25929
         break L16330;
        }
        while (1) {
         $_012_i = HEAP32[$sct_pn_i >> 2] | 0; //@line 25935
         if (($_012_i | 0) == 0) {
          break;
         }
         if ((_pfdc1_save_sector($fp, $_012_i, $c_025, $h_020, 1) | 0) == 0) {
          $sct_pn_i = $_012_i; //@line 25945
         } else {
          $_0 = 1; //@line 25947
          label = 12958; //@line 25948
          break L16330;
         }
        }
        $s_019 = $s_019 + 1 | 0; //@line 25952
       } while ($s_019 >>> 0 < (HEAPU16[$21 >> 1] | 0) >>> 0);
       $41 = HEAP16[$13 >> 1] | 0; //@line 25965
      }
      $42 = $h_020 + 1 | 0; //@line 25968
      if ($42 >>> 0 < ($41 & 65535) >>> 0) {
       $h_020 = $42;
       $17 = $41;
      } else {
       break;
      }
     }
     $46 = HEAP16[$5 >> 1] | 0; //@line 25980
    }
    $47 = $c_025 + 1 | 0; //@line 25983
    if ($47 >>> 0 < ($46 & 65535) >>> 0) {
     $c_025 = $47;
     $9 = $46;
    } else {
     break L16328;
    }
   }
   if ((label | 0) == 12957) {
    STACKTOP = sp; //@line 25995
    return $_0 | 0; //@line 25996
   } else if ((label | 0) == 12958) {
    STACKTOP = sp; //@line 26000
    return $_0 | 0; //@line 26001
   }
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 26005
 $_0 = 0; //@line 26007
 STACKTOP = sp; //@line 26009
 return $_0 | 0; //@line 26010
}
function _pfdc1_save_sector($fp, $sct, $c, $h, $alt) {
 $fp = $fp | 0;
 $sct = $sct | 0;
 $c = $c | 0;
 $h = $h | 0;
 $alt = $alt | 0;
 var $buf = 0, $sct_idx_val = 0, $2 = 0, $f_1_i = 0, $f_1__i = 0, $flg_0 = 0, $flg_1 = 0, $18 = 0, $enc_0_load24_off0 = 0, $dr_0_load23 = 0, $24 = 0, $41 = 0, $42 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 26030
 STACKTOP = STACKTOP + 32 | 0; //@line 26030
 $buf = sp | 0; //@line 26031
 $sct_idx_val = HEAP32[$sct + 12 >> 2] | 0; //@line 26033
 $2 = $sct_idx_val << 2 & 4; //@line 26035
 $f_1_i = ($sct_idx_val & 2 | 0) == 0 ? $2 : $2 | 8; //@line 26039
 $f_1__i = ($sct_idx_val & 4 | 0) == 0 ? $f_1_i : $f_1_i | 16; //@line 26043
 if ((_psi_sct_uniform($sct) | 0) == 0) {
  $flg_0 = $f_1__i; //@line 26048
 } else {
  $flg_0 = (HEAP16[$sct + 10 >> 1] | 0) == 0 ? $f_1__i : $f_1__i | 128; //@line 26056
 }
 $flg_1 = $flg_0 | ($alt | 0) != 0; //@line 26061
 $18 = HEAPU16[$sct + 16 >> 1] | 0; //@line 26064
 if (($18 | 0) == 16386) {
  $dr_0_load23 = 1e6;
  $enc_0_load24_off0 = 2;
 } else if (($18 | 0) == 1) {
  $dr_0_load23 = 125e3;
  $enc_0_load24_off0 = 1;
 } else if (($18 | 0) == 32769) {
  $dr_0_load23 = 25e4;
  $enc_0_load24_off0 = 1;
 } else if (($18 | 0) == 32770) {
  $dr_0_load23 = 5e5;
  $enc_0_load24_off0 = 2;
 } else if (($18 | 0) == 2) {
  $dr_0_load23 = 25e4;
  $enc_0_load24_off0 = 2;
 } else {
  $dr_0_load23 = 0;
  $enc_0_load24_off0 = 0;
 }
 $24 = $buf | 0; //@line 26085
 _psi_set_uint32_be($24, 8, $dr_0_load23); //@line 26086
 HEAP8[$24] = 83; //@line 26087
 HEAP8[$buf + 1 | 0] = $c & 255; //@line 26090
 HEAP8[$buf + 2 | 0] = $h & 255; //@line 26093
 HEAP8[$buf + 3 | 0] = HEAP16[$sct + 4 >> 1] & 255; //@line 26098
 HEAP8[$buf + 4 | 0] = HEAP16[$sct + 6 >> 1] & 255; //@line 26103
 HEAP8[$buf + 5 | 0] = HEAP16[$sct + 8 >> 1] & 255; //@line 26108
 $41 = $sct + 10 | 0; //@line 26109
 $42 = HEAP16[$41 >> 1] | 0; //@line 26110
 HEAP8[$buf + 6 | 0] = ($42 & 65535) >>> 8 & 255; //@line 26114
 HEAP8[$buf + 7 | 0] = $42 & 255; //@line 26117
 HEAP8[$buf + 8 | 0] = $enc_0_load24_off0; //@line 26119
 _psi_set_uint32_be($24, 12, $flg_1); //@line 26120
 do {
  if (($flg_0 & 128 | 0) == 0) {
   if ((_psi_write($fp, $24, 16) | 0) != 0) {
    $_0 = 1; //@line 26130
    STACKTOP = sp; //@line 26132
    return $_0 | 0; //@line 26133
   }
   if ((_psi_write($fp, HEAP32[$sct + 24 >> 2] | 0, HEAPU16[$41 >> 1] | 0) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 26145
   }
   STACKTOP = sp; //@line 26148
   return $_0 | 0; //@line 26149
  } else {
   HEAP8[$buf + 16 | 0] = HEAP8[HEAP32[$sct + 24 >> 2] | 0] | 0; //@line 26155
   if ((_psi_write($fp, $24, 17) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 26162
   }
   STACKTOP = sp; //@line 26165
   return $_0 | 0; //@line 26166
  }
 } while (0);
 $_0 = 0; //@line 26170
 STACKTOP = sp; //@line 26172
 return $_0 | 0; //@line 26173
}
function _pfdc2_load_fp($fp, $img, $id, $sz) {
 $fp = $fp | 0;
 $img = $img | 0;
 $id = $id | 0;
 $sz = $sz | 0;
 var $buf_i34_i = 0, $buf_i_i = 0, $buf_i26 = 0, $buf_i = 0, $buf = 0, $3 = 0, $tmp_014_i = 0, $_013_i = 0, $_0912_i = 0, $7 = 0, $9 = 0, $_2_i = 0, $12 = 0, $_2_1_i = 0, $15 = 0, $_2_2_i = 0, $18 = 0, $_2_3_i = 0, $21 = 0, $_2_4_i = 0, $24 = 0, $_2_5_i = 0, $27 = 0, $_2_6_i = 0, $30 = 0, $_2_7_i = 0, $33 = 0, $35 = 0, $tmp_014_i_i9 = 0, $_013_i_i10 = 0, $_0912_i_i11 = 0, $43 = 0, $45 = 0, $_2_i_i12 = 0, $48 = 0, $_2_1_i_i13 = 0, $51 = 0, $_2_2_i_i14 = 0, $54 = 0, $_2_3_i_i15 = 0, $57 = 0, $_2_4_i_i16 = 0, $60 = 0, $_2_5_i_i17 = 0, $63 = 0, $_2_6_i_i18 = 0, $66 = 0, $_2_7_i_i19 = 0, $69 = 0, $72 = 0, $75 = 0, $76 = 0, $_079_i = 0, $79 = 0, $83 = 0, $tmp_014_i_i_i = 0, $_013_i_i_i = 0, $_0912_i_i_i = 0, $88 = 0, $90 = 0, $_2_i_i_i = 0, $93 = 0, $_2_1_i_i_i = 0, $96 = 0, $_2_2_i_i_i = 0, $99 = 0, $_2_3_i_i_i = 0, $102 = 0, $_2_4_i_i_i = 0, $105 = 0, $_2_5_i_i_i = 0, $108 = 0, $_2_6_i_i_i = 0, $111 = 0, $_2_7_i_i_i = 0, $114 = 0, $_09_lcssa_i_i_i = 0, $118 = 0, $119 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $_ph_i = 0, $129 = 0, $tmp_014_i_i_i28 = 0, $_013_i_i_i29 = 0, $_0912_i_i_i30 = 0, $135 = 0, $137 = 0, $_2_i_i_i31 = 0, $140 = 0, $_2_1_i_i_i32 = 0, $143 = 0, $_2_2_i_i_i33 = 0, $146 = 0, $_2_3_i_i_i34 = 0, $149 = 0, $_2_4_i_i_i35 = 0, $152 = 0, $_2_5_i_i_i36 = 0, $155 = 0, $_2_6_i_i_i37 = 0, $158 = 0, $_2_7_i_i_i38 = 0, $161 = 0, $164 = 0, $165 = 0, $tmp_014_i_i40 = 0, $_013_i_i41 = 0, $_0912_i_i42 = 0, $169 = 0, $171 = 0, $_2_i_i43 = 0, $174 = 0, $_2_1_i_i44 = 0, $177 = 0, $_2_2_i_i45 = 0, $180 = 0, $_2_3_i_i46 = 0, $183 = 0, $_2_4_i_i47 = 0, $186 = 0, $_2_5_i_i48 = 0, $189 = 0, $_2_6_i_i49 = 0, $192 = 0, $_2_7_i_i50 = 0, $195 = 0, $_01115_i_i_i = 0, $_01214_i_i_i = 0, $200 = 0, $204 = 0, $tmp_014_i_i_i_i = 0, $_013_i_i_i_i = 0, $_0912_i_i_i_i = 0, $209 = 0, $211 = 0, $_2_i_i_i_i = 0, $214 = 0, $_2_1_i_i_i_i = 0, $217 = 0, $_2_2_i_i_i_i = 0, $220 = 0, $_2_3_i_i_i_i = 0, $223 = 0, $_2_4_i_i_i_i = 0, $226 = 0, $_2_5_i_i_i_i = 0, $229 = 0, $_2_6_i_i_i_i = 0, $232 = 0, $_2_7_i_i_i_i = 0, $235 = 0, $tmp_014_i_i21_i = 0, $_013_i_i22_i = 0, $_0912_i_i23_i = 0, $240 = 0, $242 = 0, $_2_i_i24_i = 0, $245 = 0, $_2_1_i_i25_i = 0, $248 = 0, $_2_2_i_i26_i = 0, $251 = 0, $_2_3_i_i27_i = 0, $254 = 0, $_2_4_i_i28_i = 0, $257 = 0, $_2_5_i_i29_i = 0, $260 = 0, $_2_6_i_i30_i = 0, $263 = 0, $_2_7_i_i31_i = 0, $266 = 0, $_09_lcssa_i_i_i53 = 0, $_011_lcssa_i_i_i = 0, $tmp_014_i_i8_i_i = 0, $_013_i_i9_i_i = 0, $_0912_i_i10_i_i = 0, $277 = 0, $279 = 0, $_2_i_i11_i_i = 0, $282 = 0, $_2_1_i_i12_i_i = 0, $285 = 0, $_2_2_i_i13_i_i = 0, $288 = 0, $_2_3_i_i14_i_i = 0, $291 = 0, $_2_4_i_i15_i_i = 0, $294 = 0, $_2_5_i_i16_i_i = 0, $297 = 0, $_2_6_i_i17_i_i = 0, $300 = 0, $_2_7_i_i18_i_i = 0, $303 = 0, $tmp_014_i_i_i35_i = 0, $_013_i_i_i36_i = 0, $_0912_i_i_i37_i = 0, $316 = 0, $318 = 0, $_2_i_i_i38_i = 0, $321 = 0, $_2_1_i_i_i39_i = 0, $324 = 0, $_2_2_i_i_i40_i = 0, $327 = 0, $_2_3_i_i_i41_i = 0, $330 = 0, $_2_4_i_i_i42_i = 0, $333 = 0, $_2_5_i_i_i43_i = 0, $336 = 0, $_2_6_i_i_i44_i = 0, $339 = 0, $_2_7_i_i_i45_i = 0, $342 = 0, $346 = 0, $348 = 0, $350 = 0, $351 = 0, $358 = 0, $362 = 0, $366 = 0, $373 = 0, $380 = 0, $387 = 0, $391 = 0, $_0_i38_i_i = 0, $tmp_014_i_i47_i = 0, $_013_i_i48_i = 0, $_0912_i_i49_i = 0, $411 = 0, $413 = 0, $_2_i_i50_i = 0, $416 = 0, $_2_1_i_i51_i = 0, $419 = 0, $_2_2_i_i52_i = 0, $422 = 0, $_2_3_i_i53_i = 0, $425 = 0, $_2_4_i_i54_i = 0, $428 = 0, $_2_5_i_i55_i = 0, $431 = 0, $_2_6_i_i56_i = 0, $434 = 0, $_2_7_i_i57_i = 0, $437 = 0, $439 = 0, $449 = 0, $450 = 0, $451 = 0, $453 = 0, $_2_i_i59_i_i = 0, $456 = 0, $_2_1_i_i60_i_i = 0, $459 = 0, $_2_2_i_i61_i_i = 0, $462 = 0, $_2_3_i_i62_i_i = 0, $465 = 0, $_2_4_i_i63_i_i = 0, $468 = 0, $_2_5_i_i64_i_i = 0, $471 = 0, $_2_6_i_i65_i_i = 0, $474 = 0, $476 = 0, $478 = 0, $_2_i74_i_i = 0, $481 = 0, $_2_1_i75_i_i = 0, $484 = 0, $_2_2_i76_i_i = 0, $487 = 0, $_2_3_i77_i_i = 0, $490 = 0, $_2_4_i78_i_i = 0, $493 = 0, $_2_5_i79_i_i = 0, $496 = 0, $_2_6_i80_i_i = 0, $499 = 0, $503 = 0, $508 = 0, $509 = 0, $513 = 0, $tmp_014_i_i114_i_i = 0, $_013_i_i115_i_i = 0, $_0912_i_i116_i_i = 0, $518 = 0, $520 = 0, $_2_i_i117_i_i = 0, $523 = 0, $_2_1_i_i118_i_i = 0, $526 = 0, $_2_2_i_i119_i_i = 0, $529 = 0, $_2_3_i_i120_i_i = 0, $532 = 0, $_2_4_i_i121_i_i = 0, $535 = 0, $_2_5_i_i122_i_i = 0, $538 = 0, $_2_6_i_i123_i_i = 0, $541 = 0, $_2_7_i_i124_i_i = 0, $544 = 0, $tmp_014_i130_i_i = 0, $_013_i131_i_i = 0, $_0912_i132_i_i = 0, $550 = 0, $552 = 0, $_2_i133_i_i = 0, $555 = 0, $_2_1_i134_i_i = 0, $558 = 0, $_2_2_i135_i_i = 0, $561 = 0, $_2_3_i136_i_i = 0, $564 = 0, $_2_4_i137_i_i = 0, $567 = 0, $_2_5_i138_i_i = 0, $570 = 0, $_2_6_i139_i_i = 0, $573 = 0, $_2_7_i140_i_i = 0, $576 = 0, $_09_lcssa_i142_i_i = 0, $_036_i_i = 0, $_035_i_i = 0, $_01115_i_i60_i = 0, $_01214_i_i61_i = 0, $584 = 0, $588 = 0, $tmp_014_i_i99_i_i = 0, $_013_i_i100_i_i = 0, $_0912_i_i101_i_i = 0, $593 = 0, $595 = 0, $_2_i_i102_i_i = 0, $598 = 0, $_2_1_i_i103_i_i = 0, $601 = 0, $_2_2_i_i104_i_i = 0, $604 = 0, $_2_3_i_i105_i_i = 0, $607 = 0, $_2_4_i_i106_i_i = 0, $610 = 0, $_2_5_i_i107_i_i = 0, $613 = 0, $_2_6_i_i108_i_i = 0, $616 = 0, $_2_7_i_i109_i_i = 0, $619 = 0, $tmp_014_i85_i_i = 0, $_013_i86_i_i = 0, $_0912_i87_i_i = 0, $624 = 0, $626 = 0, $_2_i88_i_i = 0, $629 = 0, $_2_1_i89_i_i = 0, $632 = 0, $_2_2_i90_i_i = 0, $635 = 0, $_2_3_i91_i_i = 0, $638 = 0, $_2_4_i92_i_i = 0, $641 = 0, $_2_5_i93_i_i = 0, $644 = 0, $_2_6_i94_i_i = 0, $647 = 0, $_2_7_i95_i_i = 0, $650 = 0, $_09_lcssa_i_i63_i = 0, $_011_lcssa_i_i64_i = 0, $tmp_014_i_i41_i_i = 0, $_013_i_i42_i_i = 0, $_0912_i_i43_i_i = 0, $661 = 0, $663 = 0, $_2_i_i44_i_i = 0, $666 = 0, $_2_1_i_i45_i_i = 0, $669 = 0, $_2_2_i_i46_i_i = 0, $672 = 0, $_2_3_i_i47_i_i = 0, $675 = 0, $_2_4_i_i48_i_i = 0, $678 = 0, $_2_5_i_i49_i_i = 0, $681 = 0, $_2_6_i_i50_i_i = 0, $684 = 0, $_2_7_i_i51_i_i = 0, $687 = 0, $693 = 0, $697 = 0, $tmp_014_i_i_i69_i = 0, $_013_i_i_i70_i = 0, $_0912_i_i_i71_i = 0, $702 = 0, $704 = 0, $_2_i_i_i72_i = 0, $707 = 0, $_2_1_i_i_i73_i = 0, $710 = 0, $_2_2_i_i_i74_i = 0, $713 = 0, $_2_3_i_i_i75_i = 0, $716 = 0, $_2_4_i_i_i76_i = 0, $719 = 0, $_2_5_i_i_i77_i = 0, $722 = 0, $_2_6_i_i_i78_i = 0, $725 = 0, $_2_7_i_i_i79_i = 0, $728 = 0, $tmp_014_i_i81_i = 0, $_013_i_i82_i = 0, $_0912_i_i83_i = 0, $733 = 0, $735 = 0, $_2_i_i84_i = 0, $738 = 0, $_2_1_i_i85_i = 0, $741 = 0, $_2_2_i_i86_i = 0, $744 = 0, $_2_3_i_i87_i = 0, $747 = 0, $_2_4_i_i88_i = 0, $750 = 0, $_2_5_i_i89_i = 0, $753 = 0, $_2_6_i_i90_i = 0, $756 = 0, $_2_7_i_i91_i = 0, $759 = 0, $_09_lcssa_i_i93_i = 0, $_01115_i_i95_i = 0, $_01214_i_i96_i = 0, $765 = 0, $769 = 0, $tmp_014_i_i15_i_i = 0, $_013_i_i16_i_i = 0, $_0912_i_i17_i_i = 0, $774 = 0, $776 = 0, $_2_i_i18_i_i = 0, $779 = 0, $_2_1_i_i19_i_i = 0, $782 = 0, $_2_2_i_i20_i_i = 0, $785 = 0, $_2_3_i_i21_i_i = 0, $788 = 0, $_2_4_i_i22_i_i = 0, $791 = 0, $_2_5_i_i23_i_i = 0, $794 = 0, $_2_6_i_i24_i_i = 0, $797 = 0, $_2_7_i_i25_i_i = 0, $800 = 0, $tmp_014_i31_i_i = 0, $_013_i32_i_i = 0, $_0912_i33_i_i = 0, $805 = 0, $807 = 0, $_2_i34_i_i = 0, $810 = 0, $_2_1_i35_i_i = 0, $813 = 0, $_2_2_i36_i_i = 0, $816 = 0, $_2_3_i37_i_i = 0, $819 = 0, $_2_4_i38_i_i = 0, $822 = 0, $_2_5_i39_i_i = 0, $825 = 0, $_2_6_i40_i_i = 0, $828 = 0, $_2_7_i41_i_i = 0, $831 = 0, $_09_lcssa_i43_i_i = 0, $_011_lcssa_i_i97_i = 0, $tmp_014_i_i46_i_i = 0, $_013_i_i47_i_i = 0, $_0912_i_i48_i_i = 0, $842 = 0, $844 = 0, $_2_i_i49_i_i = 0, $847 = 0, $_2_1_i_i50_i_i = 0, $850 = 0, $_2_2_i_i51_i_i = 0, $853 = 0, $_2_3_i_i52_i_i = 0, $856 = 0, $_2_4_i_i53_i_i = 0, $859 = 0, $_2_5_i_i54_i_i = 0, $862 = 0, $_2_6_i_i55_i_i = 0, $865 = 0, $_2_7_i_i56_i_i = 0, $868 = 0, $tmp_014_i_i30_i_i = 0, $_013_i_i31_i_i = 0, $_0912_i_i32_i_i = 0, $880 = 0, $882 = 0, $_2_i_i33_i_i = 0, $885 = 0, $_2_1_i_i34_i_i = 0, $888 = 0, $_2_2_i_i35_i_i = 0, $891 = 0, $_2_3_i_i36_i_i = 0, $894 = 0, $_2_4_i_i37_i_i = 0, $897 = 0, $_2_5_i_i38_i_i = 0, $900 = 0, $_2_6_i_i39_i_i = 0, $903 = 0, $_2_7_i_i40_i_i = 0, $906 = 0, $911 = 0, $tmp_014_i_i_i104_i = 0, $_013_i_i_i105_i = 0, $_0912_i_i_i106_i = 0, $920 = 0, $922 = 0, $_2_i_i_i107_i = 0, $925 = 0, $_2_1_i_i_i108_i = 0, $928 = 0, $_2_2_i_i_i109_i = 0, $931 = 0, $_2_3_i_i_i110_i = 0, $934 = 0, $_2_4_i_i_i111_i = 0, $937 = 0, $_2_5_i_i_i112_i = 0, $940 = 0, $_2_6_i_i_i113_i = 0, $943 = 0, $_2_7_i_i_i114_i = 0, $946 = 0, $tmp_014_i_i116_i = 0, $_013_i_i117_i = 0, $_0912_i_i118_i = 0, $952 = 0, $954 = 0, $_2_i_i119_i = 0, $957 = 0, $_2_1_i_i120_i = 0, $960 = 0, $_2_2_i_i121_i = 0, $963 = 0, $_2_3_i_i122_i = 0, $966 = 0, $_2_4_i_i123_i = 0, $969 = 0, $_2_5_i_i124_i = 0, $972 = 0, $_2_6_i_i125_i = 0, $975 = 0, $_2_7_i_i126_i = 0, $978 = 0, $981 = 0, $_size_i_i = 0, $985 = 0, $n_1_i_i = 0, $991 = 0, $tmp_014_i_i85_i_i = 0, $_013_i_i86_i_i = 0, $_0912_i_i87_i_i = 0, $999 = 0, $1001 = 0, $_2_i_i88_i_i = 0, $1004 = 0, $_2_1_i_i89_i_i = 0, $1007 = 0, $_2_2_i_i90_i_i = 0, $1010 = 0, $_2_3_i_i91_i_i = 0, $1013 = 0, $_2_4_i_i92_i_i = 0, $1016 = 0, $_2_5_i_i93_i_i = 0, $1019 = 0, $_2_6_i_i94_i_i = 0, $1022 = 0, $_2_7_i_i95_i_i = 0, $1025 = 0, $_0_i52_i_i = 0, $_0_i129_i = 0, $_01115_i_i = 0, $_01214_i_i = 0, $1036 = 0, $1040 = 0, $tmp_014_i_i131_i = 0, $_013_i_i132_i = 0, $_0912_i_i133_i = 0, $1045 = 0, $1047 = 0, $_2_i_i134_i = 0, $1050 = 0, $_2_1_i_i135_i = 0, $1053 = 0, $_2_2_i_i136_i = 0, $1056 = 0, $_2_3_i_i137_i = 0, $1059 = 0, $_2_4_i_i138_i = 0, $1062 = 0, $_2_5_i_i139_i = 0, $1065 = 0, $_2_6_i_i140_i = 0, $1068 = 0, $_2_7_i_i141_i = 0, $1071 = 0, $tmp_014_i147_i = 0, $_013_i148_i = 0, $_0912_i149_i = 0, $1076 = 0, $1078 = 0, $_2_i150_i = 0, $1081 = 0, $_2_1_i151_i = 0, $1084 = 0, $_2_2_i152_i = 0, $1087 = 0, $_2_3_i153_i = 0, $1090 = 0, $_2_4_i154_i = 0, $1093 = 0, $_2_5_i155_i = 0, $1096 = 0, $_2_6_i156_i = 0, $1099 = 0, $_2_7_i157_i = 0, $1102 = 0, $_09_lcssa_i_i = 0, $_011_lcssa_i_i = 0, $tmp_014_i_i161_i = 0, $_013_i_i162_i = 0, $_0912_i_i163_i = 0, $1113 = 0, $1115 = 0, $_2_i_i164_i = 0, $1118 = 0, $_2_1_i_i165_i = 0, $1121 = 0, $_2_2_i_i166_i = 0, $1124 = 0, $_2_3_i_i167_i = 0, $1127 = 0, $_2_4_i_i168_i = 0, $1130 = 0, $_2_5_i_i169_i = 0, $1133 = 0, $_2_6_i_i170_i = 0, $1136 = 0, $_2_7_i_i171_i = 0, $1139 = 0, $1143 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_0912_i_i = 0, $1151 = 0, $1153 = 0, $_2_i_i = 0, $1156 = 0, $_2_1_i_i = 0, $1159 = 0, $_2_2_i_i = 0, $1162 = 0, $_2_3_i_i = 0, $1165 = 0, $_2_4_i_i = 0, $1168 = 0, $_2_5_i_i = 0, $1171 = 0, $_2_6_i_i = 0, $1174 = 0, $_2_7_i_i = 0, $1177 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 26370
 STACKTOP = STACKTOP + 568 | 0; //@line 26370
 $buf_i34_i = sp | 0; //@line 26371
 $buf_i_i = sp + 32 | 0; //@line 26372
 $buf_i26 = sp + 288 | 0; //@line 26373
 $buf_i = sp + 296 | 0; //@line 26374
 $buf = sp + 552 | 0; //@line 26375
 _fwrite(52800, 49, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 26377
 $3 = $buf | 0; //@line 26378
 _psi_set_uint32_be($3, 0, $id); //@line 26379
 _psi_set_uint32_be($3, 4, $sz); //@line 26380
 $_0912_i = -1;
 $_013_i = 8;
 $tmp_014_i = $3;
 while (1) {
  $7 = HEAPU8[$tmp_014_i] << 24 ^ $_0912_i; //@line 26389
  $9 = $7 << 1; //@line 26391
  $_2_i = ($7 | 0) < 0 ? $9 ^ 79764919 : $9; //@line 26393
  $12 = $_2_i << 1; //@line 26395
  $_2_1_i = ($_2_i | 0) < 0 ? $12 ^ 79764919 : $12; //@line 26397
  $15 = $_2_1_i << 1; //@line 26399
  $_2_2_i = ($_2_1_i | 0) < 0 ? $15 ^ 79764919 : $15; //@line 26401
  $18 = $_2_2_i << 1; //@line 26403
  $_2_3_i = ($_2_2_i | 0) < 0 ? $18 ^ 79764919 : $18; //@line 26405
  $21 = $_2_3_i << 1; //@line 26407
  $_2_4_i = ($_2_3_i | 0) < 0 ? $21 ^ 79764919 : $21; //@line 26409
  $24 = $_2_4_i << 1; //@line 26411
  $_2_5_i = ($_2_4_i | 0) < 0 ? $24 ^ 79764919 : $24; //@line 26413
  $27 = $_2_5_i << 1; //@line 26415
  $_2_6_i = ($_2_5_i | 0) < 0 ? $27 ^ 79764919 : $27; //@line 26417
  $30 = $_2_6_i << 1; //@line 26419
  $_2_7_i = ($_2_6_i | 0) < 0 ? $30 ^ 79764919 : $30; //@line 26421
  $33 = $_013_i - 1 | 0; //@line 26423
  if (($33 | 0) == 0) {
   break;
  } else {
   $_0912_i = $_2_7_i;
   $_013_i = $33;
   $tmp_014_i = $tmp_014_i + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i; //@line 26432
 $35 = $buf + 8 | 0; //@line 26433
 if ((_psi_read($fp, $35, 8) | 0) != 0) {
  $_0 = 1; //@line 26438
  STACKTOP = sp; //@line 26440
  return $_0 | 0; //@line 26441
 }
 $_0912_i_i11 = HEAP32[15666] | 0;
 $_013_i_i10 = 8;
 $tmp_014_i_i9 = $35;
 while (1) {
  $43 = HEAPU8[$tmp_014_i_i9] << 24 ^ $_0912_i_i11; //@line 26452
  $45 = $43 << 1; //@line 26454
  $_2_i_i12 = ($43 | 0) < 0 ? $45 ^ 79764919 : $45; //@line 26456
  $48 = $_2_i_i12 << 1; //@line 26458
  $_2_1_i_i13 = ($_2_i_i12 | 0) < 0 ? $48 ^ 79764919 : $48; //@line 26460
  $51 = $_2_1_i_i13 << 1; //@line 26462
  $_2_2_i_i14 = ($_2_1_i_i13 | 0) < 0 ? $51 ^ 79764919 : $51; //@line 26464
  $54 = $_2_2_i_i14 << 1; //@line 26466
  $_2_3_i_i15 = ($_2_2_i_i14 | 0) < 0 ? $54 ^ 79764919 : $54; //@line 26468
  $57 = $_2_3_i_i15 << 1; //@line 26470
  $_2_4_i_i16 = ($_2_3_i_i15 | 0) < 0 ? $57 ^ 79764919 : $57; //@line 26472
  $60 = $_2_4_i_i16 << 1; //@line 26474
  $_2_5_i_i17 = ($_2_4_i_i16 | 0) < 0 ? $60 ^ 79764919 : $60; //@line 26476
  $63 = $_2_5_i_i17 << 1; //@line 26478
  $_2_6_i_i18 = ($_2_5_i_i17 | 0) < 0 ? $63 ^ 79764919 : $63; //@line 26480
  $66 = $_2_6_i_i18 << 1; //@line 26482
  $_2_7_i_i19 = ($_2_6_i_i18 | 0) < 0 ? $66 ^ 79764919 : $66; //@line 26484
  $69 = $_013_i_i10 - 1 | 0; //@line 26486
  if (($69 | 0) == 0) {
   break;
  } else {
   $_0912_i_i11 = $_2_7_i_i19;
   $_013_i_i10 = $69;
   $tmp_014_i_i9 = $tmp_014_i_i9 + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i19; //@line 26495
 $72 = _psi_get_uint32_be($3, 12) | 0; //@line 26496
 if ($72 >>> 0 < 16) {
  $_0 = 1; //@line 26500
  STACKTOP = sp; //@line 26502
  return $_0 | 0; //@line 26503
 }
 $75 = $72 - 16 | 0; //@line 26505
 $76 = $buf_i | 0; //@line 26506
 L16387 : do {
  if (($75 | 0) != 0) {
   $_079_i = $75; //@line 26511
   while (1) {
    $79 = $_079_i >>> 0 < 256 ? $_079_i : 256; //@line 26515
    if ((_psi_read($fp, $76, $79) | 0) != 0) {
     $_0 = 1; //@line 26520
     break;
    }
    $83 = HEAP32[15666] | 0; //@line 26523
    if (($79 | 0) == 0) {
     $_09_lcssa_i_i_i = $83; //@line 26527
    } else {
     $_0912_i_i_i = $83;
     $_013_i_i_i = $79;
     $tmp_014_i_i_i = $76;
     while (1) {
      $88 = HEAPU8[$tmp_014_i_i_i] << 24 ^ $_0912_i_i_i; //@line 26537
      $90 = $88 << 1; //@line 26539
      $_2_i_i_i = ($88 | 0) < 0 ? $90 ^ 79764919 : $90; //@line 26541
      $93 = $_2_i_i_i << 1; //@line 26543
      $_2_1_i_i_i = ($_2_i_i_i | 0) < 0 ? $93 ^ 79764919 : $93; //@line 26545
      $96 = $_2_1_i_i_i << 1; //@line 26547
      $_2_2_i_i_i = ($_2_1_i_i_i | 0) < 0 ? $96 ^ 79764919 : $96; //@line 26549
      $99 = $_2_2_i_i_i << 1; //@line 26551
      $_2_3_i_i_i = ($_2_2_i_i_i | 0) < 0 ? $99 ^ 79764919 : $99; //@line 26553
      $102 = $_2_3_i_i_i << 1; //@line 26555
      $_2_4_i_i_i = ($_2_3_i_i_i | 0) < 0 ? $102 ^ 79764919 : $102; //@line 26557
      $105 = $_2_4_i_i_i << 1; //@line 26559
      $_2_5_i_i_i = ($_2_4_i_i_i | 0) < 0 ? $105 ^ 79764919 : $105; //@line 26561
      $108 = $_2_5_i_i_i << 1; //@line 26563
      $_2_6_i_i_i = ($_2_5_i_i_i | 0) < 0 ? $108 ^ 79764919 : $108; //@line 26565
      $111 = $_2_6_i_i_i << 1; //@line 26567
      $_2_7_i_i_i = ($_2_6_i_i_i | 0) < 0 ? $111 ^ 79764919 : $111; //@line 26569
      $114 = $_013_i_i_i - 1 | 0; //@line 26571
      if (($114 | 0) == 0) {
       $_09_lcssa_i_i_i = $_2_7_i_i_i; //@line 26575
       break;
      } else {
       $_0912_i_i_i = $_2_7_i_i_i;
       $_013_i_i_i = $114;
       $tmp_014_i_i_i = $tmp_014_i_i_i + 1 | 0;
      }
     }
    }
    HEAP32[15666] = $_09_lcssa_i_i_i; //@line 26583
    if (($_079_i | 0) == ($79 | 0)) {
     break L16387;
    } else {
     $_079_i = $_079_i - $79 | 0; //@line 26590
    }
   }
   STACKTOP = sp; //@line 26594
   return $_0 | 0; //@line 26595
  }
 } while (0);
 $118 = $buf_i26 | 0; //@line 26598
 $119 = $buf_i_i | 0; //@line 26599
 $120 = $buf_i34_i | 0; //@line 26600
 $121 = $buf_i34_i + 1 | 0; //@line 26601
 $122 = $buf_i34_i + 2 | 0; //@line 26602
 $123 = $buf_i34_i + 3 | 0; //@line 26603
 $124 = $buf_i34_i + 4 | 0; //@line 26604
 $125 = $buf_i34_i + 5 | 0; //@line 26605
 $126 = $buf_i34_i + 8 | 0; //@line 26606
 $_ph_i = 0; //@line 26608
 L16397 : while (1) {
  if ((_psi_read($fp, $118, 4) | 0) != 0) {
   $_0 = 1; //@line 26615
   label = 13122; //@line 26616
   break;
  }
  $129 = ($_ph_i | 0) == 0; //@line 26619
  while (1) {
   $_0912_i_i_i30 = HEAP32[15666] | 0;
   $_013_i_i_i29 = 4;
   $tmp_014_i_i_i28 = $118;
   while (1) {
    $135 = HEAPU8[$tmp_014_i_i_i28] << 24 ^ $_0912_i_i_i30; //@line 26631
    $137 = $135 << 1; //@line 26633
    $_2_i_i_i31 = ($135 | 0) < 0 ? $137 ^ 79764919 : $137; //@line 26635
    $140 = $_2_i_i_i31 << 1; //@line 26637
    $_2_1_i_i_i32 = ($_2_i_i_i31 | 0) < 0 ? $140 ^ 79764919 : $140; //@line 26639
    $143 = $_2_1_i_i_i32 << 1; //@line 26641
    $_2_2_i_i_i33 = ($_2_1_i_i_i32 | 0) < 0 ? $143 ^ 79764919 : $143; //@line 26643
    $146 = $_2_2_i_i_i33 << 1; //@line 26645
    $_2_3_i_i_i34 = ($_2_2_i_i_i33 | 0) < 0 ? $146 ^ 79764919 : $146; //@line 26647
    $149 = $_2_3_i_i_i34 << 1; //@line 26649
    $_2_4_i_i_i35 = ($_2_3_i_i_i34 | 0) < 0 ? $149 ^ 79764919 : $149; //@line 26651
    $152 = $_2_4_i_i_i35 << 1; //@line 26653
    $_2_5_i_i_i36 = ($_2_4_i_i_i35 | 0) < 0 ? $152 ^ 79764919 : $152; //@line 26655
    $155 = $_2_5_i_i_i36 << 1; //@line 26657
    $_2_6_i_i_i37 = ($_2_5_i_i_i36 | 0) < 0 ? $155 ^ 79764919 : $155; //@line 26659
    $158 = $_2_6_i_i_i37 << 1; //@line 26661
    $_2_7_i_i_i38 = ($_2_6_i_i_i37 | 0) < 0 ? $158 ^ 79764919 : $158; //@line 26663
    $161 = $_013_i_i_i29 - 1 | 0; //@line 26665
    if (($161 | 0) == 0) {
     break;
    } else {
     $_0912_i_i_i30 = $_2_7_i_i_i38;
     $_013_i_i_i29 = $161;
     $tmp_014_i_i_i28 = $tmp_014_i_i_i28 + 1 | 0;
    }
   }
   HEAP32[15666] = $_2_7_i_i_i38; //@line 26674
   $164 = _psi_get_uint16_be($118, 0) | 0; //@line 26675
   $165 = _psi_get_uint16_be($118, 2) | 0; //@line 26676
   $_0912_i_i42 = 0;
   $_013_i_i41 = 4;
   $tmp_014_i_i40 = $118;
   while (1) {
    $169 = HEAPU8[$tmp_014_i_i40] << 24 ^ $_0912_i_i42; //@line 26685
    $171 = $169 << 1; //@line 26687
    $_2_i_i43 = ($169 | 0) < 0 ? $171 ^ 79764919 : $171; //@line 26689
    $174 = $_2_i_i43 << 1; //@line 26691
    $_2_1_i_i44 = ($_2_i_i43 | 0) < 0 ? $174 ^ 79764919 : $174; //@line 26693
    $177 = $_2_1_i_i44 << 1; //@line 26695
    $_2_2_i_i45 = ($_2_1_i_i44 | 0) < 0 ? $177 ^ 79764919 : $177; //@line 26697
    $180 = $_2_2_i_i45 << 1; //@line 26699
    $_2_3_i_i46 = ($_2_2_i_i45 | 0) < 0 ? $180 ^ 79764919 : $180; //@line 26701
    $183 = $_2_3_i_i46 << 1; //@line 26703
    $_2_4_i_i47 = ($_2_3_i_i46 | 0) < 0 ? $183 ^ 79764919 : $183; //@line 26705
    $186 = $_2_4_i_i47 << 1; //@line 26707
    $_2_5_i_i48 = ($_2_4_i_i47 | 0) < 0 ? $186 ^ 79764919 : $186; //@line 26709
    $189 = $_2_5_i_i48 << 1; //@line 26711
    $_2_6_i_i49 = ($_2_5_i_i48 | 0) < 0 ? $189 ^ 79764919 : $189; //@line 26713
    $192 = $_2_6_i_i49 << 1; //@line 26715
    $_2_7_i_i50 = ($_2_6_i_i49 | 0) < 0 ? $192 ^ 79764919 : $192; //@line 26717
    $195 = $_013_i_i41 - 1 | 0; //@line 26719
    if (($195 | 0) == 0) {
     break;
    } else {
     $_0912_i_i42 = $_2_7_i_i50;
     $_013_i_i41 = $195;
     $tmp_014_i_i40 = $tmp_014_i_i40 + 1 | 0;
    }
   }
   if (($164 | 0) == 21315) {
    break;
   } else if (($164 | 0) == 17229) {
    if (($165 | 0) == 0) {
     if ((_psi_read($fp, $119, 4) | 0) != 0) {
      $_0 = 1; //@line 26738
      label = 13139; //@line 26739
      break L16397;
     }
     $_0912_i_i32_i_i = HEAP32[15666] | 0;
     $_013_i_i31_i_i = 4;
     $tmp_014_i_i30_i_i = $119;
     while (1) {
      $880 = HEAPU8[$tmp_014_i_i30_i_i] << 24 ^ $_0912_i_i32_i_i; //@line 26751
      $882 = $880 << 1; //@line 26753
      $_2_i_i33_i_i = ($880 | 0) < 0 ? $882 ^ 79764919 : $882; //@line 26755
      $885 = $_2_i_i33_i_i << 1; //@line 26757
      $_2_1_i_i34_i_i = ($_2_i_i33_i_i | 0) < 0 ? $885 ^ 79764919 : $885; //@line 26759
      $888 = $_2_1_i_i34_i_i << 1; //@line 26761
      $_2_2_i_i35_i_i = ($_2_1_i_i34_i_i | 0) < 0 ? $888 ^ 79764919 : $888; //@line 26763
      $891 = $_2_2_i_i35_i_i << 1; //@line 26765
      $_2_3_i_i36_i_i = ($_2_2_i_i35_i_i | 0) < 0 ? $891 ^ 79764919 : $891; //@line 26767
      $894 = $_2_3_i_i36_i_i << 1; //@line 26769
      $_2_4_i_i37_i_i = ($_2_3_i_i36_i_i | 0) < 0 ? $894 ^ 79764919 : $894; //@line 26771
      $897 = $_2_4_i_i37_i_i << 1; //@line 26773
      $_2_5_i_i38_i_i = ($_2_4_i_i37_i_i | 0) < 0 ? $897 ^ 79764919 : $897; //@line 26775
      $900 = $_2_5_i_i38_i_i << 1; //@line 26777
      $_2_6_i_i39_i_i = ($_2_5_i_i38_i_i | 0) < 0 ? $900 ^ 79764919 : $900; //@line 26779
      $903 = $_2_6_i_i39_i_i << 1; //@line 26781
      $_2_7_i_i40_i_i = ($_2_6_i_i39_i_i | 0) < 0 ? $903 ^ 79764919 : $903; //@line 26783
      $906 = $_013_i_i31_i_i - 1 | 0; //@line 26785
      if (($906 | 0) == 0) {
       break;
      } else {
       $_0912_i_i32_i_i = $_2_7_i_i40_i_i;
       $_013_i_i31_i_i = $906;
       $tmp_014_i_i30_i_i = $tmp_014_i_i30_i_i + 1 | 0;
      }
     }
     HEAP32[15666] = $_2_7_i_i40_i_i; //@line 26794
     $_0_i129_i = (_psi_get_uint32_be($119, 0) | 0) != ($_2_7_i_i50 | 0) | 0; //@line 26799
    } else {
     $911 = _malloc($165) | 0; //@line 26801
     if (($911 | 0) == 0) {
      $_0 = 1; //@line 26805
      label = 13116; //@line 26806
      break L16397;
     }
     if ((_psi_read($fp, $911, $165) | 0) != 0) {
      label = 13087; //@line 26813
      break L16397;
     }
     $_0912_i_i_i106_i = HEAP32[15666] | 0;
     $_013_i_i_i105_i = $165;
     $tmp_014_i_i_i104_i = $911;
     while (1) {
      $920 = HEAPU8[$tmp_014_i_i_i104_i] << 24 ^ $_0912_i_i_i106_i; //@line 26826
      $922 = $920 << 1; //@line 26828
      $_2_i_i_i107_i = ($920 | 0) < 0 ? $922 ^ 79764919 : $922; //@line 26830
      $925 = $_2_i_i_i107_i << 1; //@line 26832
      $_2_1_i_i_i108_i = ($_2_i_i_i107_i | 0) < 0 ? $925 ^ 79764919 : $925; //@line 26834
      $928 = $_2_1_i_i_i108_i << 1; //@line 26836
      $_2_2_i_i_i109_i = ($_2_1_i_i_i108_i | 0) < 0 ? $928 ^ 79764919 : $928; //@line 26838
      $931 = $_2_2_i_i_i109_i << 1; //@line 26840
      $_2_3_i_i_i110_i = ($_2_2_i_i_i109_i | 0) < 0 ? $931 ^ 79764919 : $931; //@line 26842
      $934 = $_2_3_i_i_i110_i << 1; //@line 26844
      $_2_4_i_i_i111_i = ($_2_3_i_i_i110_i | 0) < 0 ? $934 ^ 79764919 : $934; //@line 26846
      $937 = $_2_4_i_i_i111_i << 1; //@line 26848
      $_2_5_i_i_i112_i = ($_2_4_i_i_i111_i | 0) < 0 ? $937 ^ 79764919 : $937; //@line 26850
      $940 = $_2_5_i_i_i112_i << 1; //@line 26852
      $_2_6_i_i_i113_i = ($_2_5_i_i_i112_i | 0) < 0 ? $940 ^ 79764919 : $940; //@line 26854
      $943 = $_2_6_i_i_i113_i << 1; //@line 26856
      $_2_7_i_i_i114_i = ($_2_6_i_i_i113_i | 0) < 0 ? $943 ^ 79764919 : $943; //@line 26858
      $946 = $_013_i_i_i105_i - 1 | 0; //@line 26860
      if (($946 | 0) == 0) {
       break;
      } else {
       $_0912_i_i_i106_i = $_2_7_i_i_i114_i;
       $_013_i_i_i105_i = $946;
       $tmp_014_i_i_i104_i = $tmp_014_i_i_i104_i + 1 | 0;
      }
     }
     HEAP32[15666] = $_2_7_i_i_i114_i; //@line 26869
     $_0912_i_i118_i = $_2_7_i_i50;
     $_013_i_i117_i = $165;
     $tmp_014_i_i116_i = $911;
     while (1) {
      $952 = HEAPU8[$tmp_014_i_i116_i] << 24 ^ $_0912_i_i118_i; //@line 26879
      $954 = $952 << 1; //@line 26881
      $_2_i_i119_i = ($952 | 0) < 0 ? $954 ^ 79764919 : $954; //@line 26883
      $957 = $_2_i_i119_i << 1; //@line 26885
      $_2_1_i_i120_i = ($_2_i_i119_i | 0) < 0 ? $957 ^ 79764919 : $957; //@line 26887
      $960 = $_2_1_i_i120_i << 1; //@line 26889
      $_2_2_i_i121_i = ($_2_1_i_i120_i | 0) < 0 ? $960 ^ 79764919 : $960; //@line 26891
      $963 = $_2_2_i_i121_i << 1; //@line 26893
      $_2_3_i_i122_i = ($_2_2_i_i121_i | 0) < 0 ? $963 ^ 79764919 : $963; //@line 26895
      $966 = $_2_3_i_i122_i << 1; //@line 26897
      $_2_4_i_i123_i = ($_2_3_i_i122_i | 0) < 0 ? $966 ^ 79764919 : $966; //@line 26899
      $969 = $_2_4_i_i123_i << 1; //@line 26901
      $_2_5_i_i124_i = ($_2_4_i_i123_i | 0) < 0 ? $969 ^ 79764919 : $969; //@line 26903
      $972 = $_2_5_i_i124_i << 1; //@line 26905
      $_2_6_i_i125_i = ($_2_5_i_i124_i | 0) < 0 ? $972 ^ 79764919 : $972; //@line 26907
      $975 = $_2_6_i_i125_i << 1; //@line 26909
      $_2_7_i_i126_i = ($_2_6_i_i125_i | 0) < 0 ? $975 ^ 79764919 : $975; //@line 26911
      $978 = $_013_i_i117_i - 1 | 0; //@line 26913
      if (($978 | 0) == 0) {
       break;
      } else {
       $_0912_i_i118_i = $_2_7_i_i126_i;
       $_013_i_i117_i = $978;
       $tmp_014_i_i116_i = $tmp_014_i_i116_i + 1 | 0;
      }
     }
     $981 = (HEAP8[$911] | 0) == 10; //@line 26923
     $_size_i_i = ($981 << 31 >> 31) + $165 | 0; //@line 26926
     if (($_size_i_i | 0) == 0) {
      $n_1_i_i = 0; //@line 26930
     } else {
      $985 = $_size_i_i - 1 | 0; //@line 26932
      $n_1_i_i = (HEAP8[$911 + $985 | 0] | 0) == 10 ? $985 : $_size_i_i; //@line 26938
     }
     $991 = _psi_img_add_comment($img, $911 + ($981 & 1) | 0, $n_1_i_i) | 0; //@line 26942
     _free($911); //@line 26943
     if ((_psi_read($fp, $119, 4) | 0) == 0) {
      $_0912_i_i87_i_i = HEAP32[15666] | 0;
      $_013_i_i86_i_i = 4;
      $tmp_014_i_i85_i_i = $119;
      while (1) {
       $999 = HEAPU8[$tmp_014_i_i85_i_i] << 24 ^ $_0912_i_i87_i_i; //@line 26957
       $1001 = $999 << 1; //@line 26959
       $_2_i_i88_i_i = ($999 | 0) < 0 ? $1001 ^ 79764919 : $1001; //@line 26961
       $1004 = $_2_i_i88_i_i << 1; //@line 26963
       $_2_1_i_i89_i_i = ($_2_i_i88_i_i | 0) < 0 ? $1004 ^ 79764919 : $1004; //@line 26965
       $1007 = $_2_1_i_i89_i_i << 1; //@line 26967
       $_2_2_i_i90_i_i = ($_2_1_i_i89_i_i | 0) < 0 ? $1007 ^ 79764919 : $1007; //@line 26969
       $1010 = $_2_2_i_i90_i_i << 1; //@line 26971
       $_2_3_i_i91_i_i = ($_2_2_i_i90_i_i | 0) < 0 ? $1010 ^ 79764919 : $1010; //@line 26973
       $1013 = $_2_3_i_i91_i_i << 1; //@line 26975
       $_2_4_i_i92_i_i = ($_2_3_i_i91_i_i | 0) < 0 ? $1013 ^ 79764919 : $1013; //@line 26977
       $1016 = $_2_4_i_i92_i_i << 1; //@line 26979
       $_2_5_i_i93_i_i = ($_2_4_i_i92_i_i | 0) < 0 ? $1016 ^ 79764919 : $1016; //@line 26981
       $1019 = $_2_5_i_i93_i_i << 1; //@line 26983
       $_2_6_i_i94_i_i = ($_2_5_i_i93_i_i | 0) < 0 ? $1019 ^ 79764919 : $1019; //@line 26985
       $1022 = $_2_6_i_i94_i_i << 1; //@line 26987
       $_2_7_i_i95_i_i = ($_2_6_i_i94_i_i | 0) < 0 ? $1022 ^ 79764919 : $1022; //@line 26989
       $1025 = $_013_i_i86_i_i - 1 | 0; //@line 26991
       if (($1025 | 0) == 0) {
        break;
       } else {
        $_0912_i_i87_i_i = $_2_7_i_i95_i_i;
        $_013_i_i86_i_i = $1025;
        $tmp_014_i_i85_i_i = $tmp_014_i_i85_i_i + 1 | 0;
       }
      }
      HEAP32[15666] = $_2_7_i_i95_i_i; //@line 27000
      $_0_i52_i_i = (_psi_get_uint32_be($119, 0) | 0) != ($_2_7_i_i126_i | 0) | 0; //@line 27005
     } else {
      $_0_i52_i_i = 1; //@line 27007
     }
     $_0_i129_i = $_0_i52_i_i | $991; //@line 27012
    }
    if (($_0_i129_i | 0) != 0) {
     $_0 = 1; //@line 27018
     label = 13134; //@line 27019
     break L16397;
    }
   } else if (($164 | 0) == 17742) {
    label = 12998; //@line 27023
    break L16397;
   } else if (($164 | 0) == 21575) {
    if ($129) {
     $_0 = 1; //@line 27028
     label = 13144; //@line 27029
     break L16397;
    }
    $693 = $165 >>> 0 < 256 ? $165 : 256; //@line 27033
    if ((_psi_read($fp, $76, $693) | 0) != 0) {
     $_0 = 1; //@line 27038
     label = 13145; //@line 27039
     break L16397;
    }
    $697 = HEAP32[15666] | 0; //@line 27042
    if (($693 | 0) == 0) {
     HEAP32[15666] = $697; //@line 27046
     $_09_lcssa_i_i93_i = $_2_7_i_i50; //@line 27048
    } else {
     $_0912_i_i_i71_i = $697;
     $_013_i_i_i70_i = $693;
     $tmp_014_i_i_i69_i = $76;
     while (1) {
      $702 = HEAPU8[$tmp_014_i_i_i69_i] << 24 ^ $_0912_i_i_i71_i; //@line 27058
      $704 = $702 << 1; //@line 27060
      $_2_i_i_i72_i = ($702 | 0) < 0 ? $704 ^ 79764919 : $704; //@line 27062
      $707 = $_2_i_i_i72_i << 1; //@line 27064
      $_2_1_i_i_i73_i = ($_2_i_i_i72_i | 0) < 0 ? $707 ^ 79764919 : $707; //@line 27066
      $710 = $_2_1_i_i_i73_i << 1; //@line 27068
      $_2_2_i_i_i74_i = ($_2_1_i_i_i73_i | 0) < 0 ? $710 ^ 79764919 : $710; //@line 27070
      $713 = $_2_2_i_i_i74_i << 1; //@line 27072
      $_2_3_i_i_i75_i = ($_2_2_i_i_i74_i | 0) < 0 ? $713 ^ 79764919 : $713; //@line 27074
      $716 = $_2_3_i_i_i75_i << 1; //@line 27076
      $_2_4_i_i_i76_i = ($_2_3_i_i_i75_i | 0) < 0 ? $716 ^ 79764919 : $716; //@line 27078
      $719 = $_2_4_i_i_i76_i << 1; //@line 27080
      $_2_5_i_i_i77_i = ($_2_4_i_i_i76_i | 0) < 0 ? $719 ^ 79764919 : $719; //@line 27082
      $722 = $_2_5_i_i_i77_i << 1; //@line 27084
      $_2_6_i_i_i78_i = ($_2_5_i_i_i77_i | 0) < 0 ? $722 ^ 79764919 : $722; //@line 27086
      $725 = $_2_6_i_i_i78_i << 1; //@line 27088
      $_2_7_i_i_i79_i = ($_2_6_i_i_i78_i | 0) < 0 ? $725 ^ 79764919 : $725; //@line 27090
      $728 = $_013_i_i_i70_i - 1 | 0; //@line 27092
      if (($728 | 0) == 0) {
       break;
      } else {
       $_0912_i_i_i71_i = $_2_7_i_i_i79_i;
       $_013_i_i_i70_i = $728;
       $tmp_014_i_i_i69_i = $tmp_014_i_i_i69_i + 1 | 0;
      }
     }
     HEAP32[15666] = $_2_7_i_i_i79_i; //@line 27101
     $_0912_i_i83_i = $_2_7_i_i50;
     $_013_i_i82_i = $693;
     $tmp_014_i_i81_i = $76;
     while (1) {
      $733 = HEAPU8[$tmp_014_i_i81_i] << 24 ^ $_0912_i_i83_i; //@line 27111
      $735 = $733 << 1; //@line 27113
      $_2_i_i84_i = ($733 | 0) < 0 ? $735 ^ 79764919 : $735; //@line 27115
      $738 = $_2_i_i84_i << 1; //@line 27117
      $_2_1_i_i85_i = ($_2_i_i84_i | 0) < 0 ? $738 ^ 79764919 : $738; //@line 27119
      $741 = $_2_1_i_i85_i << 1; //@line 27121
      $_2_2_i_i86_i = ($_2_1_i_i85_i | 0) < 0 ? $741 ^ 79764919 : $741; //@line 27123
      $744 = $_2_2_i_i86_i << 1; //@line 27125
      $_2_3_i_i87_i = ($_2_2_i_i86_i | 0) < 0 ? $744 ^ 79764919 : $744; //@line 27127
      $747 = $_2_3_i_i87_i << 1; //@line 27129
      $_2_4_i_i88_i = ($_2_3_i_i87_i | 0) < 0 ? $747 ^ 79764919 : $747; //@line 27131
      $750 = $_2_4_i_i88_i << 1; //@line 27133
      $_2_5_i_i89_i = ($_2_4_i_i88_i | 0) < 0 ? $750 ^ 79764919 : $750; //@line 27135
      $753 = $_2_5_i_i89_i << 1; //@line 27137
      $_2_6_i_i90_i = ($_2_5_i_i89_i | 0) < 0 ? $753 ^ 79764919 : $753; //@line 27139
      $756 = $_2_6_i_i90_i << 1; //@line 27141
      $_2_7_i_i91_i = ($_2_6_i_i90_i | 0) < 0 ? $756 ^ 79764919 : $756; //@line 27143
      $759 = $_013_i_i82_i - 1 | 0; //@line 27145
      if (($759 | 0) == 0) {
       $_09_lcssa_i_i93_i = $_2_7_i_i91_i; //@line 27149
       break;
      } else {
       $_0912_i_i83_i = $_2_7_i_i91_i;
       $_013_i_i82_i = $759;
       $tmp_014_i_i81_i = $tmp_014_i_i81_i + 1 | 0;
      }
     }
    }
    _psi_sct_set_tags($_ph_i, $76, $693) | 0; //@line 27157
    if (($693 | 0) == ($165 | 0)) {
     $_011_lcssa_i_i97_i = $_09_lcssa_i_i93_i; //@line 27161
    } else {
     $_01214_i_i96_i = $165 - $693 | 0;
     $_01115_i_i95_i = $_09_lcssa_i_i93_i;
     while (1) {
      $765 = $_01214_i_i96_i >>> 0 < 256 ? $_01214_i_i96_i : 256; //@line 27170
      if ((_psi_read($fp, $119, $765) | 0) != 0) {
       $_0 = 1; //@line 27175
       label = 13118; //@line 27176
       break L16397;
      }
      $769 = HEAP32[15666] | 0; //@line 27179
      if (($765 | 0) == 0) {
       HEAP32[15666] = $769; //@line 27183
       $_09_lcssa_i43_i_i = $_01115_i_i95_i; //@line 27185
      } else {
       $_0912_i_i17_i_i = $769;
       $_013_i_i16_i_i = $765;
       $tmp_014_i_i15_i_i = $119;
       while (1) {
        $774 = HEAPU8[$tmp_014_i_i15_i_i] << 24 ^ $_0912_i_i17_i_i; //@line 27195
        $776 = $774 << 1; //@line 27197
        $_2_i_i18_i_i = ($774 | 0) < 0 ? $776 ^ 79764919 : $776; //@line 27199
        $779 = $_2_i_i18_i_i << 1; //@line 27201
        $_2_1_i_i19_i_i = ($_2_i_i18_i_i | 0) < 0 ? $779 ^ 79764919 : $779; //@line 27203
        $782 = $_2_1_i_i19_i_i << 1; //@line 27205
        $_2_2_i_i20_i_i = ($_2_1_i_i19_i_i | 0) < 0 ? $782 ^ 79764919 : $782; //@line 27207
        $785 = $_2_2_i_i20_i_i << 1; //@line 27209
        $_2_3_i_i21_i_i = ($_2_2_i_i20_i_i | 0) < 0 ? $785 ^ 79764919 : $785; //@line 27211
        $788 = $_2_3_i_i21_i_i << 1; //@line 27213
        $_2_4_i_i22_i_i = ($_2_3_i_i21_i_i | 0) < 0 ? $788 ^ 79764919 : $788; //@line 27215
        $791 = $_2_4_i_i22_i_i << 1; //@line 27217
        $_2_5_i_i23_i_i = ($_2_4_i_i22_i_i | 0) < 0 ? $791 ^ 79764919 : $791; //@line 27219
        $794 = $_2_5_i_i23_i_i << 1; //@line 27221
        $_2_6_i_i24_i_i = ($_2_5_i_i23_i_i | 0) < 0 ? $794 ^ 79764919 : $794; //@line 27223
        $797 = $_2_6_i_i24_i_i << 1; //@line 27225
        $_2_7_i_i25_i_i = ($_2_6_i_i24_i_i | 0) < 0 ? $797 ^ 79764919 : $797; //@line 27227
        $800 = $_013_i_i16_i_i - 1 | 0; //@line 27229
        if (($800 | 0) == 0) {
         break;
        } else {
         $_0912_i_i17_i_i = $_2_7_i_i25_i_i;
         $_013_i_i16_i_i = $800;
         $tmp_014_i_i15_i_i = $tmp_014_i_i15_i_i + 1 | 0;
        }
       }
       HEAP32[15666] = $_2_7_i_i25_i_i; //@line 27238
       $_0912_i33_i_i = $_01115_i_i95_i;
       $_013_i32_i_i = $765;
       $tmp_014_i31_i_i = $119;
       while (1) {
        $805 = HEAPU8[$tmp_014_i31_i_i] << 24 ^ $_0912_i33_i_i; //@line 27248
        $807 = $805 << 1; //@line 27250
        $_2_i34_i_i = ($805 | 0) < 0 ? $807 ^ 79764919 : $807; //@line 27252
        $810 = $_2_i34_i_i << 1; //@line 27254
        $_2_1_i35_i_i = ($_2_i34_i_i | 0) < 0 ? $810 ^ 79764919 : $810; //@line 27256
        $813 = $_2_1_i35_i_i << 1; //@line 27258
        $_2_2_i36_i_i = ($_2_1_i35_i_i | 0) < 0 ? $813 ^ 79764919 : $813; //@line 27260
        $816 = $_2_2_i36_i_i << 1; //@line 27262
        $_2_3_i37_i_i = ($_2_2_i36_i_i | 0) < 0 ? $816 ^ 79764919 : $816; //@line 27264
        $819 = $_2_3_i37_i_i << 1; //@line 27266
        $_2_4_i38_i_i = ($_2_3_i37_i_i | 0) < 0 ? $819 ^ 79764919 : $819; //@line 27268
        $822 = $_2_4_i38_i_i << 1; //@line 27270
        $_2_5_i39_i_i = ($_2_4_i38_i_i | 0) < 0 ? $822 ^ 79764919 : $822; //@line 27272
        $825 = $_2_5_i39_i_i << 1; //@line 27274
        $_2_6_i40_i_i = ($_2_5_i39_i_i | 0) < 0 ? $825 ^ 79764919 : $825; //@line 27276
        $828 = $_2_6_i40_i_i << 1; //@line 27278
        $_2_7_i41_i_i = ($_2_6_i40_i_i | 0) < 0 ? $828 ^ 79764919 : $828; //@line 27280
        $831 = $_013_i32_i_i - 1 | 0; //@line 27282
        if (($831 | 0) == 0) {
         $_09_lcssa_i43_i_i = $_2_7_i41_i_i; //@line 27286
         break;
        } else {
         $_0912_i33_i_i = $_2_7_i41_i_i;
         $_013_i32_i_i = $831;
         $tmp_014_i31_i_i = $tmp_014_i31_i_i + 1 | 0;
        }
       }
      }
      if (($_01214_i_i96_i | 0) == ($765 | 0)) {
       $_011_lcssa_i_i97_i = $_09_lcssa_i43_i_i; //@line 27298
       break;
      } else {
       $_01214_i_i96_i = $_01214_i_i96_i - $765 | 0;
       $_01115_i_i95_i = $_09_lcssa_i43_i_i;
      }
     }
    }
    if ((_psi_read($fp, $119, 4) | 0) != 0) {
     $_0 = 1; //@line 27310
     label = 13119; //@line 27311
     break L16397;
    }
    $_0912_i_i48_i_i = HEAP32[15666] | 0;
    $_013_i_i47_i_i = 4;
    $tmp_014_i_i46_i_i = $119;
    while (1) {
     $842 = HEAPU8[$tmp_014_i_i46_i_i] << 24 ^ $_0912_i_i48_i_i; //@line 27323
     $844 = $842 << 1; //@line 27325
     $_2_i_i49_i_i = ($842 | 0) < 0 ? $844 ^ 79764919 : $844; //@line 27327
     $847 = $_2_i_i49_i_i << 1; //@line 27329
     $_2_1_i_i50_i_i = ($_2_i_i49_i_i | 0) < 0 ? $847 ^ 79764919 : $847; //@line 27331
     $850 = $_2_1_i_i50_i_i << 1; //@line 27333
     $_2_2_i_i51_i_i = ($_2_1_i_i50_i_i | 0) < 0 ? $850 ^ 79764919 : $850; //@line 27335
     $853 = $_2_2_i_i51_i_i << 1; //@line 27337
     $_2_3_i_i52_i_i = ($_2_2_i_i51_i_i | 0) < 0 ? $853 ^ 79764919 : $853; //@line 27339
     $856 = $_2_3_i_i52_i_i << 1; //@line 27341
     $_2_4_i_i53_i_i = ($_2_3_i_i52_i_i | 0) < 0 ? $856 ^ 79764919 : $856; //@line 27343
     $859 = $_2_4_i_i53_i_i << 1; //@line 27345
     $_2_5_i_i54_i_i = ($_2_4_i_i53_i_i | 0) < 0 ? $859 ^ 79764919 : $859; //@line 27347
     $862 = $_2_5_i_i54_i_i << 1; //@line 27349
     $_2_6_i_i55_i_i = ($_2_5_i_i54_i_i | 0) < 0 ? $862 ^ 79764919 : $862; //@line 27351
     $865 = $_2_6_i_i55_i_i << 1; //@line 27353
     $_2_7_i_i56_i_i = ($_2_6_i_i55_i_i | 0) < 0 ? $865 ^ 79764919 : $865; //@line 27355
     $868 = $_013_i_i47_i_i - 1 | 0; //@line 27357
     if (($868 | 0) == 0) {
      break;
     } else {
      $_0912_i_i48_i_i = $_2_7_i_i56_i_i;
      $_013_i_i47_i_i = $868;
      $tmp_014_i_i46_i_i = $tmp_014_i_i46_i_i + 1 | 0;
     }
    }
    HEAP32[15666] = $_2_7_i_i56_i_i; //@line 27366
    if ((_psi_get_uint32_be($119, 0) | 0) != ($_011_lcssa_i_i97_i | 0)) {
     $_0 = 1; //@line 27371
     label = 13137; //@line 27372
     break L16397;
    }
   } else {
    if (($165 | 0) == 0) {
     $_011_lcssa_i_i = $_2_7_i_i50; //@line 27379
    } else {
     $_01214_i_i = $165;
     $_01115_i_i = $_2_7_i_i50;
     while (1) {
      $1036 = $_01214_i_i >>> 0 < 256 ? $_01214_i_i : 256; //@line 27386
      if ((_psi_read($fp, $119, $1036) | 0) != 0) {
       $_0 = 1; //@line 27391
       label = 13141; //@line 27392
       break L16397;
      }
      $1040 = HEAP32[15666] | 0; //@line 27395
      if (($1036 | 0) == 0) {
       HEAP32[15666] = $1040; //@line 27399
       $_09_lcssa_i_i = $_01115_i_i; //@line 27401
      } else {
       $_0912_i_i133_i = $1040;
       $_013_i_i132_i = $1036;
       $tmp_014_i_i131_i = $119;
       while (1) {
        $1045 = HEAPU8[$tmp_014_i_i131_i] << 24 ^ $_0912_i_i133_i; //@line 27411
        $1047 = $1045 << 1; //@line 27413
        $_2_i_i134_i = ($1045 | 0) < 0 ? $1047 ^ 79764919 : $1047; //@line 27415
        $1050 = $_2_i_i134_i << 1; //@line 27417
        $_2_1_i_i135_i = ($_2_i_i134_i | 0) < 0 ? $1050 ^ 79764919 : $1050; //@line 27419
        $1053 = $_2_1_i_i135_i << 1; //@line 27421
        $_2_2_i_i136_i = ($_2_1_i_i135_i | 0) < 0 ? $1053 ^ 79764919 : $1053; //@line 27423
        $1056 = $_2_2_i_i136_i << 1; //@line 27425
        $_2_3_i_i137_i = ($_2_2_i_i136_i | 0) < 0 ? $1056 ^ 79764919 : $1056; //@line 27427
        $1059 = $_2_3_i_i137_i << 1; //@line 27429
        $_2_4_i_i138_i = ($_2_3_i_i137_i | 0) < 0 ? $1059 ^ 79764919 : $1059; //@line 27431
        $1062 = $_2_4_i_i138_i << 1; //@line 27433
        $_2_5_i_i139_i = ($_2_4_i_i138_i | 0) < 0 ? $1062 ^ 79764919 : $1062; //@line 27435
        $1065 = $_2_5_i_i139_i << 1; //@line 27437
        $_2_6_i_i140_i = ($_2_5_i_i139_i | 0) < 0 ? $1065 ^ 79764919 : $1065; //@line 27439
        $1068 = $_2_6_i_i140_i << 1; //@line 27441
        $_2_7_i_i141_i = ($_2_6_i_i140_i | 0) < 0 ? $1068 ^ 79764919 : $1068; //@line 27443
        $1071 = $_013_i_i132_i - 1 | 0; //@line 27445
        if (($1071 | 0) == 0) {
         break;
        } else {
         $_0912_i_i133_i = $_2_7_i_i141_i;
         $_013_i_i132_i = $1071;
         $tmp_014_i_i131_i = $tmp_014_i_i131_i + 1 | 0;
        }
       }
       HEAP32[15666] = $_2_7_i_i141_i; //@line 27454
       $_0912_i149_i = $_01115_i_i;
       $_013_i148_i = $1036;
       $tmp_014_i147_i = $119;
       while (1) {
        $1076 = HEAPU8[$tmp_014_i147_i] << 24 ^ $_0912_i149_i; //@line 27464
        $1078 = $1076 << 1; //@line 27466
        $_2_i150_i = ($1076 | 0) < 0 ? $1078 ^ 79764919 : $1078; //@line 27468
        $1081 = $_2_i150_i << 1; //@line 27470
        $_2_1_i151_i = ($_2_i150_i | 0) < 0 ? $1081 ^ 79764919 : $1081; //@line 27472
        $1084 = $_2_1_i151_i << 1; //@line 27474
        $_2_2_i152_i = ($_2_1_i151_i | 0) < 0 ? $1084 ^ 79764919 : $1084; //@line 27476
        $1087 = $_2_2_i152_i << 1; //@line 27478
        $_2_3_i153_i = ($_2_2_i152_i | 0) < 0 ? $1087 ^ 79764919 : $1087; //@line 27480
        $1090 = $_2_3_i153_i << 1; //@line 27482
        $_2_4_i154_i = ($_2_3_i153_i | 0) < 0 ? $1090 ^ 79764919 : $1090; //@line 27484
        $1093 = $_2_4_i154_i << 1; //@line 27486
        $_2_5_i155_i = ($_2_4_i154_i | 0) < 0 ? $1093 ^ 79764919 : $1093; //@line 27488
        $1096 = $_2_5_i155_i << 1; //@line 27490
        $_2_6_i156_i = ($_2_5_i155_i | 0) < 0 ? $1096 ^ 79764919 : $1096; //@line 27492
        $1099 = $_2_6_i156_i << 1; //@line 27494
        $_2_7_i157_i = ($_2_6_i156_i | 0) < 0 ? $1099 ^ 79764919 : $1099; //@line 27496
        $1102 = $_013_i148_i - 1 | 0; //@line 27498
        if (($1102 | 0) == 0) {
         $_09_lcssa_i_i = $_2_7_i157_i; //@line 27502
         break;
        } else {
         $_0912_i149_i = $_2_7_i157_i;
         $_013_i148_i = $1102;
         $tmp_014_i147_i = $tmp_014_i147_i + 1 | 0;
        }
       }
      }
      if (($_01214_i_i | 0) == ($1036 | 0)) {
       $_011_lcssa_i_i = $_09_lcssa_i_i; //@line 27514
       break;
      } else {
       $_01214_i_i = $_01214_i_i - $1036 | 0;
       $_01115_i_i = $_09_lcssa_i_i;
      }
     }
    }
    if ((_psi_read($fp, $119, 4) | 0) != 0) {
     $_0 = 1; //@line 27526
     label = 13117; //@line 27527
     break L16397;
    }
    $_0912_i_i163_i = HEAP32[15666] | 0;
    $_013_i_i162_i = 4;
    $tmp_014_i_i161_i = $119;
    while (1) {
     $1113 = HEAPU8[$tmp_014_i_i161_i] << 24 ^ $_0912_i_i163_i; //@line 27539
     $1115 = $1113 << 1; //@line 27541
     $_2_i_i164_i = ($1113 | 0) < 0 ? $1115 ^ 79764919 : $1115; //@line 27543
     $1118 = $_2_i_i164_i << 1; //@line 27545
     $_2_1_i_i165_i = ($_2_i_i164_i | 0) < 0 ? $1118 ^ 79764919 : $1118; //@line 27547
     $1121 = $_2_1_i_i165_i << 1; //@line 27549
     $_2_2_i_i166_i = ($_2_1_i_i165_i | 0) < 0 ? $1121 ^ 79764919 : $1121; //@line 27551
     $1124 = $_2_2_i_i166_i << 1; //@line 27553
     $_2_3_i_i167_i = ($_2_2_i_i166_i | 0) < 0 ? $1124 ^ 79764919 : $1124; //@line 27555
     $1127 = $_2_3_i_i167_i << 1; //@line 27557
     $_2_4_i_i168_i = ($_2_3_i_i167_i | 0) < 0 ? $1127 ^ 79764919 : $1127; //@line 27559
     $1130 = $_2_4_i_i168_i << 1; //@line 27561
     $_2_5_i_i169_i = ($_2_4_i_i168_i | 0) < 0 ? $1130 ^ 79764919 : $1130; //@line 27563
     $1133 = $_2_5_i_i169_i << 1; //@line 27565
     $_2_6_i_i170_i = ($_2_5_i_i169_i | 0) < 0 ? $1133 ^ 79764919 : $1133; //@line 27567
     $1136 = $_2_6_i_i170_i << 1; //@line 27569
     $_2_7_i_i171_i = ($_2_6_i_i170_i | 0) < 0 ? $1136 ^ 79764919 : $1136; //@line 27571
     $1139 = $_013_i_i162_i - 1 | 0; //@line 27573
     if (($1139 | 0) == 0) {
      break;
     } else {
      $_0912_i_i163_i = $_2_7_i_i171_i;
      $_013_i_i162_i = $1139;
      $tmp_014_i_i161_i = $tmp_014_i_i161_i + 1 | 0;
     }
    }
    HEAP32[15666] = $_2_7_i_i171_i; //@line 27582
    if ((_psi_get_uint32_be($119, 0) | 0) != ($_011_lcssa_i_i | 0)) {
     $_0 = 1; //@line 27587
     label = 13127; //@line 27588
     break L16397;
    }
   }
   if ((_psi_read($fp, $118, 4) | 0) != 0) {
    $_0 = 1; //@line 27596
    label = 13140; //@line 27597
    break L16397;
   }
  }
  if ($165 >>> 0 < 12) {
   $_0 = 1; //@line 27604
   label = 13129; //@line 27605
   break;
  }
  if ((_psi_read($fp, $120, 12) | 0) != 0) {
   $_0 = 1; //@line 27612
   label = 13130; //@line 27613
   break;
  }
  $_0912_i_i_i37_i = HEAP32[15666] | 0;
  $_013_i_i_i36_i = 12;
  $tmp_014_i_i_i35_i = $120;
  while (1) {
   $316 = HEAPU8[$tmp_014_i_i_i35_i] << 24 ^ $_0912_i_i_i37_i; //@line 27625
   $318 = $316 << 1; //@line 27627
   $_2_i_i_i38_i = ($316 | 0) < 0 ? $318 ^ 79764919 : $318; //@line 27629
   $321 = $_2_i_i_i38_i << 1; //@line 27631
   $_2_1_i_i_i39_i = ($_2_i_i_i38_i | 0) < 0 ? $321 ^ 79764919 : $321; //@line 27633
   $324 = $_2_1_i_i_i39_i << 1; //@line 27635
   $_2_2_i_i_i40_i = ($_2_1_i_i_i39_i | 0) < 0 ? $324 ^ 79764919 : $324; //@line 27637
   $327 = $_2_2_i_i_i40_i << 1; //@line 27639
   $_2_3_i_i_i41_i = ($_2_2_i_i_i40_i | 0) < 0 ? $327 ^ 79764919 : $327; //@line 27641
   $330 = $_2_3_i_i_i41_i << 1; //@line 27643
   $_2_4_i_i_i42_i = ($_2_3_i_i_i41_i | 0) < 0 ? $330 ^ 79764919 : $330; //@line 27645
   $333 = $_2_4_i_i_i42_i << 1; //@line 27647
   $_2_5_i_i_i43_i = ($_2_4_i_i_i42_i | 0) < 0 ? $333 ^ 79764919 : $333; //@line 27649
   $336 = $_2_5_i_i_i43_i << 1; //@line 27651
   $_2_6_i_i_i44_i = ($_2_5_i_i_i43_i | 0) < 0 ? $336 ^ 79764919 : $336; //@line 27653
   $339 = $_2_6_i_i_i44_i << 1; //@line 27655
   $_2_7_i_i_i45_i = ($_2_6_i_i_i44_i | 0) < 0 ? $339 ^ 79764919 : $339; //@line 27657
   $342 = $_013_i_i_i36_i - 1 | 0; //@line 27659
   if (($342 | 0) == 0) {
    break;
   } else {
    $_0912_i_i_i37_i = $_2_7_i_i_i45_i;
    $_013_i_i_i36_i = $342;
    $tmp_014_i_i_i35_i = $tmp_014_i_i_i35_i + 1 | 0;
   }
  }
  HEAP32[15666] = $_2_7_i_i_i45_i; //@line 27668
  $346 = HEAPU8[$120] | 0; //@line 27670
  $348 = HEAPU8[$121] | 0; //@line 27672
  $350 = HEAPU8[$122] | 0; //@line 27674
  $351 = _psi_get_uint16_be($120, 6) | 0; //@line 27675
  $358 = _psi_sct_new(HEAPU8[$123] | 0, HEAPU8[$124] | 0, HEAPU8[$125] | 0, $351) | 0; //@line 27682
  if (($358 | 0) == 0) {
   $_0 = 1; //@line 27686
   label = 13138; //@line 27687
   break;
  }
  $362 = (_psi_get_uint32_be($120, 8) | 0) & 16777215; //@line 27691
  if (($346 & 1 | 0) != 0) {
   $366 = $358 + 12 | 0; //@line 27696
   HEAP32[$366 >> 2] = HEAP32[$366 >> 2] | 1; //@line 27699
  }
  if (($346 & 2 | 0) != 0) {
   $373 = $358 + 12 | 0; //@line 27706
   HEAP32[$373 >> 2] = HEAP32[$373 >> 2] | 2; //@line 27709
  }
  if (($346 & 4 | 0) != 0) {
   $380 = $358 + 12 | 0; //@line 27716
   HEAP32[$380 >> 2] = HEAP32[$380 >> 2] | 4; //@line 27719
  }
  if (($346 & 8 | 0) != 0) {
   $387 = $358 + 12 | 0; //@line 27726
   HEAP32[$387 >> 2] = HEAP32[$387 >> 2] | 8; //@line 27729
  }
  $391 = HEAPU8[$126] | 0; //@line 27733
  if (($391 | 0) == 1) {
   $_0_i38_i_i = $362 >>> 0 < 375e3 ? 1 : 32769; //@line 27738
  } else if (($391 | 0) == 2) {
   $_0_i38_i_i = $362 >>> 0 < 375e3 ? 2 : 32770; //@line 27743
  } else if (($391 | 0) == 3) {
   $_0_i38_i_i = 3; //@line 27745
  } else {
   $_0_i38_i_i = 0; //@line 27748
  }
  _psi_sct_set_encoding($358, $_0_i38_i_i); //@line 27751
  if (($346 & 64 | 0) == 0) {
   if ((_psi_img_add_sector($img, $358, $348, $350) | 0) == 0) {
    $_0912_i_i49_i = $_2_7_i_i50;
    $_013_i_i48_i = 12;
    $tmp_014_i_i47_i = $120;
   } else {
    label = 13032; //@line 27762
    break;
   }
  } else {
   if ($129) {
    label = 13029; //@line 27768
    break;
   }
   _psi_sct_add_alternate($_ph_i, $358); //@line 27771
   $_0912_i_i49_i = $_2_7_i_i50;
   $_013_i_i48_i = 12;
   $tmp_014_i_i47_i = $120;
  }
  while (1) {
   $411 = HEAPU8[$tmp_014_i_i47_i] << 24 ^ $_0912_i_i49_i; //@line 27782
   $413 = $411 << 1; //@line 27784
   $_2_i_i50_i = ($411 | 0) < 0 ? $413 ^ 79764919 : $413; //@line 27786
   $416 = $_2_i_i50_i << 1; //@line 27788
   $_2_1_i_i51_i = ($_2_i_i50_i | 0) < 0 ? $416 ^ 79764919 : $416; //@line 27790
   $419 = $_2_1_i_i51_i << 1; //@line 27792
   $_2_2_i_i52_i = ($_2_1_i_i51_i | 0) < 0 ? $419 ^ 79764919 : $419; //@line 27794
   $422 = $_2_2_i_i52_i << 1; //@line 27796
   $_2_3_i_i53_i = ($_2_2_i_i52_i | 0) < 0 ? $422 ^ 79764919 : $422; //@line 27798
   $425 = $_2_3_i_i53_i << 1; //@line 27800
   $_2_4_i_i54_i = ($_2_3_i_i53_i | 0) < 0 ? $425 ^ 79764919 : $425; //@line 27802
   $428 = $_2_4_i_i54_i << 1; //@line 27804
   $_2_5_i_i55_i = ($_2_4_i_i54_i | 0) < 0 ? $428 ^ 79764919 : $428; //@line 27806
   $431 = $_2_5_i_i55_i << 1; //@line 27808
   $_2_6_i_i56_i = ($_2_5_i_i55_i | 0) < 0 ? $431 ^ 79764919 : $431; //@line 27810
   $434 = $_2_6_i_i56_i << 1; //@line 27812
   $_2_7_i_i57_i = ($_2_6_i_i56_i | 0) < 0 ? $434 ^ 79764919 : $434; //@line 27814
   $437 = $_013_i_i48_i - 1 | 0; //@line 27816
   if (($437 | 0) == 0) {
    break;
   } else {
    $_0912_i_i49_i = $_2_7_i_i57_i;
    $_013_i_i48_i = $437;
    $tmp_014_i_i47_i = $tmp_014_i_i47_i + 1 | 0;
   }
  }
  $439 = $165 - 12 | 0; //@line 27825
  if (($346 & 128 | 0) == 0) {
   $503 = $358 + 10 | 0; //@line 27830
   if ($439 >>> 0 < (HEAPU16[$503 >> 1] | 0) >>> 0) {
    $_0 = 1; //@line 27836
    label = 13123; //@line 27837
    break;
   }
   $508 = $358 + 24 | 0; //@line 27840
   $509 = HEAP32[$508 >> 2] | 0; //@line 27841
   if ((_psi_read($fp, $509, $351) | 0) != 0) {
    $_0 = 1; //@line 27846
    label = 13124; //@line 27847
    break;
   }
   $513 = HEAP32[15666] | 0; //@line 27850
   if (($351 | 0) == 0) {
    HEAP32[15666] = $513; //@line 27854
    $_09_lcssa_i142_i_i = $_2_7_i_i57_i; //@line 27856
   } else {
    $_0912_i_i116_i_i = $513;
    $_013_i_i115_i_i = $351;
    $tmp_014_i_i114_i_i = $509;
    while (1) {
     $518 = HEAPU8[$tmp_014_i_i114_i_i] << 24 ^ $_0912_i_i116_i_i; //@line 27866
     $520 = $518 << 1; //@line 27868
     $_2_i_i117_i_i = ($518 | 0) < 0 ? $520 ^ 79764919 : $520; //@line 27870
     $523 = $_2_i_i117_i_i << 1; //@line 27872
     $_2_1_i_i118_i_i = ($_2_i_i117_i_i | 0) < 0 ? $523 ^ 79764919 : $523; //@line 27874
     $526 = $_2_1_i_i118_i_i << 1; //@line 27876
     $_2_2_i_i119_i_i = ($_2_1_i_i118_i_i | 0) < 0 ? $526 ^ 79764919 : $526; //@line 27878
     $529 = $_2_2_i_i119_i_i << 1; //@line 27880
     $_2_3_i_i120_i_i = ($_2_2_i_i119_i_i | 0) < 0 ? $529 ^ 79764919 : $529; //@line 27882
     $532 = $_2_3_i_i120_i_i << 1; //@line 27884
     $_2_4_i_i121_i_i = ($_2_3_i_i120_i_i | 0) < 0 ? $532 ^ 79764919 : $532; //@line 27886
     $535 = $_2_4_i_i121_i_i << 1; //@line 27888
     $_2_5_i_i122_i_i = ($_2_4_i_i121_i_i | 0) < 0 ? $535 ^ 79764919 : $535; //@line 27890
     $538 = $_2_5_i_i122_i_i << 1; //@line 27892
     $_2_6_i_i123_i_i = ($_2_5_i_i122_i_i | 0) < 0 ? $538 ^ 79764919 : $538; //@line 27894
     $541 = $_2_6_i_i123_i_i << 1; //@line 27896
     $_2_7_i_i124_i_i = ($_2_6_i_i123_i_i | 0) < 0 ? $541 ^ 79764919 : $541; //@line 27898
     $544 = $_013_i_i115_i_i - 1 | 0; //@line 27900
     if (($544 | 0) == 0) {
      break;
     } else {
      $_0912_i_i116_i_i = $_2_7_i_i124_i_i;
      $_013_i_i115_i_i = $544;
      $tmp_014_i_i114_i_i = $tmp_014_i_i114_i_i + 1 | 0;
     }
    }
    HEAP32[15666] = $_2_7_i_i124_i_i; //@line 27909
    $_0912_i132_i_i = $_2_7_i_i57_i;
    $_013_i131_i_i = $351;
    $tmp_014_i130_i_i = HEAP32[$508 >> 2] | 0;
    while (1) {
     $550 = HEAPU8[$tmp_014_i130_i_i] << 24 ^ $_0912_i132_i_i; //@line 27920
     $552 = $550 << 1; //@line 27922
     $_2_i133_i_i = ($550 | 0) < 0 ? $552 ^ 79764919 : $552; //@line 27924
     $555 = $_2_i133_i_i << 1; //@line 27926
     $_2_1_i134_i_i = ($_2_i133_i_i | 0) < 0 ? $555 ^ 79764919 : $555; //@line 27928
     $558 = $_2_1_i134_i_i << 1; //@line 27930
     $_2_2_i135_i_i = ($_2_1_i134_i_i | 0) < 0 ? $558 ^ 79764919 : $558; //@line 27932
     $561 = $_2_2_i135_i_i << 1; //@line 27934
     $_2_3_i136_i_i = ($_2_2_i135_i_i | 0) < 0 ? $561 ^ 79764919 : $561; //@line 27936
     $564 = $_2_3_i136_i_i << 1; //@line 27938
     $_2_4_i137_i_i = ($_2_3_i136_i_i | 0) < 0 ? $564 ^ 79764919 : $564; //@line 27940
     $567 = $_2_4_i137_i_i << 1; //@line 27942
     $_2_5_i138_i_i = ($_2_4_i137_i_i | 0) < 0 ? $567 ^ 79764919 : $567; //@line 27944
     $570 = $_2_5_i138_i_i << 1; //@line 27946
     $_2_6_i139_i_i = ($_2_5_i138_i_i | 0) < 0 ? $570 ^ 79764919 : $570; //@line 27948
     $573 = $_2_6_i139_i_i << 1; //@line 27950
     $_2_7_i140_i_i = ($_2_6_i139_i_i | 0) < 0 ? $573 ^ 79764919 : $573; //@line 27952
     $576 = $_013_i131_i_i - 1 | 0; //@line 27954
     if (($576 | 0) == 0) {
      $_09_lcssa_i142_i_i = $_2_7_i140_i_i; //@line 27958
      break;
     } else {
      $_0912_i132_i_i = $_2_7_i140_i_i;
      $_013_i131_i_i = $576;
      $tmp_014_i130_i_i = $tmp_014_i130_i_i + 1 | 0;
     }
    }
   }
   $_035_i_i = $439 - (HEAPU16[$503 >> 1] | 0) | 0;
   $_036_i_i = $_09_lcssa_i142_i_i;
  } else {
   if (($439 | 0) == 0) {
    $_0 = 1; //@line 27974
    label = 13126; //@line 27975
    break;
   }
   if ((_psi_read($fp, $120, 1) | 0) != 0) {
    $_0 = 1; //@line 27982
    label = 13136; //@line 27983
    break;
   }
   $449 = HEAPU8[$120] | 0; //@line 27988
   $450 = $449 << 24; //@line 27989
   $451 = $450 ^ HEAP32[15666]; //@line 27990
   $453 = $451 << 1; //@line 27992
   $_2_i_i59_i_i = ($451 | 0) < 0 ? $453 ^ 79764919 : $453; //@line 27994
   $456 = $_2_i_i59_i_i << 1; //@line 27996
   $_2_1_i_i60_i_i = ($_2_i_i59_i_i | 0) < 0 ? $456 ^ 79764919 : $456; //@line 27998
   $459 = $_2_1_i_i60_i_i << 1; //@line 28000
   $_2_2_i_i61_i_i = ($_2_1_i_i60_i_i | 0) < 0 ? $459 ^ 79764919 : $459; //@line 28002
   $462 = $_2_2_i_i61_i_i << 1; //@line 28004
   $_2_3_i_i62_i_i = ($_2_2_i_i61_i_i | 0) < 0 ? $462 ^ 79764919 : $462; //@line 28006
   $465 = $_2_3_i_i62_i_i << 1; //@line 28008
   $_2_4_i_i63_i_i = ($_2_3_i_i62_i_i | 0) < 0 ? $465 ^ 79764919 : $465; //@line 28010
   $468 = $_2_4_i_i63_i_i << 1; //@line 28012
   $_2_5_i_i64_i_i = ($_2_4_i_i63_i_i | 0) < 0 ? $468 ^ 79764919 : $468; //@line 28014
   $471 = $_2_5_i_i64_i_i << 1; //@line 28016
   $_2_6_i_i65_i_i = ($_2_5_i_i64_i_i | 0) < 0 ? $471 ^ 79764919 : $471; //@line 28018
   $474 = $_2_6_i_i65_i_i << 1; //@line 28020
   HEAP32[15666] = ($_2_6_i_i65_i_i | 0) < 0 ? $474 ^ 79764919 : $474; //@line 28023
   $476 = $450 ^ $_2_7_i_i57_i; //@line 28024
   $478 = $476 << 1; //@line 28026
   $_2_i74_i_i = ($476 | 0) < 0 ? $478 ^ 79764919 : $478; //@line 28028
   $481 = $_2_i74_i_i << 1; //@line 28030
   $_2_1_i75_i_i = ($_2_i74_i_i | 0) < 0 ? $481 ^ 79764919 : $481; //@line 28032
   $484 = $_2_1_i75_i_i << 1; //@line 28034
   $_2_2_i76_i_i = ($_2_1_i75_i_i | 0) < 0 ? $484 ^ 79764919 : $484; //@line 28036
   $487 = $_2_2_i76_i_i << 1; //@line 28038
   $_2_3_i77_i_i = ($_2_2_i76_i_i | 0) < 0 ? $487 ^ 79764919 : $487; //@line 28040
   $490 = $_2_3_i77_i_i << 1; //@line 28042
   $_2_4_i78_i_i = ($_2_3_i77_i_i | 0) < 0 ? $490 ^ 79764919 : $490; //@line 28044
   $493 = $_2_4_i78_i_i << 1; //@line 28046
   $_2_5_i79_i_i = ($_2_4_i78_i_i | 0) < 0 ? $493 ^ 79764919 : $493; //@line 28048
   $496 = $_2_5_i79_i_i << 1; //@line 28050
   $_2_6_i80_i_i = ($_2_5_i79_i_i | 0) < 0 ? $496 ^ 79764919 : $496; //@line 28052
   $499 = $_2_6_i80_i_i << 1; //@line 28054
   _psi_sct_fill($358, $449); //@line 28057
   $_035_i_i = $165 - 13 | 0;
   $_036_i_i = ($_2_6_i80_i_i | 0) < 0 ? $499 ^ 79764919 : $499;
  }
  if (($_035_i_i | 0) == 0) {
   $_011_lcssa_i_i64_i = $_036_i_i; //@line 28067
  } else {
   $_01214_i_i61_i = $_035_i_i;
   $_01115_i_i60_i = $_036_i_i;
   while (1) {
    $584 = $_01214_i_i61_i >>> 0 < 256 ? $_01214_i_i61_i : 256; //@line 28074
    if ((_psi_read($fp, $119, $584) | 0) != 0) {
     $_0 = 1; //@line 28079
     label = 13142; //@line 28080
     break L16397;
    }
    $588 = HEAP32[15666] | 0; //@line 28083
    if (($584 | 0) == 0) {
     HEAP32[15666] = $588; //@line 28087
     $_09_lcssa_i_i63_i = $_01115_i_i60_i; //@line 28089
    } else {
     $_0912_i_i101_i_i = $588;
     $_013_i_i100_i_i = $584;
     $tmp_014_i_i99_i_i = $119;
     while (1) {
      $593 = HEAPU8[$tmp_014_i_i99_i_i] << 24 ^ $_0912_i_i101_i_i; //@line 28099
      $595 = $593 << 1; //@line 28101
      $_2_i_i102_i_i = ($593 | 0) < 0 ? $595 ^ 79764919 : $595; //@line 28103
      $598 = $_2_i_i102_i_i << 1; //@line 28105
      $_2_1_i_i103_i_i = ($_2_i_i102_i_i | 0) < 0 ? $598 ^ 79764919 : $598; //@line 28107
      $601 = $_2_1_i_i103_i_i << 1; //@line 28109
      $_2_2_i_i104_i_i = ($_2_1_i_i103_i_i | 0) < 0 ? $601 ^ 79764919 : $601; //@line 28111
      $604 = $_2_2_i_i104_i_i << 1; //@line 28113
      $_2_3_i_i105_i_i = ($_2_2_i_i104_i_i | 0) < 0 ? $604 ^ 79764919 : $604; //@line 28115
      $607 = $_2_3_i_i105_i_i << 1; //@line 28117
      $_2_4_i_i106_i_i = ($_2_3_i_i105_i_i | 0) < 0 ? $607 ^ 79764919 : $607; //@line 28119
      $610 = $_2_4_i_i106_i_i << 1; //@line 28121
      $_2_5_i_i107_i_i = ($_2_4_i_i106_i_i | 0) < 0 ? $610 ^ 79764919 : $610; //@line 28123
      $613 = $_2_5_i_i107_i_i << 1; //@line 28125
      $_2_6_i_i108_i_i = ($_2_5_i_i107_i_i | 0) < 0 ? $613 ^ 79764919 : $613; //@line 28127
      $616 = $_2_6_i_i108_i_i << 1; //@line 28129
      $_2_7_i_i109_i_i = ($_2_6_i_i108_i_i | 0) < 0 ? $616 ^ 79764919 : $616; //@line 28131
      $619 = $_013_i_i100_i_i - 1 | 0; //@line 28133
      if (($619 | 0) == 0) {
       break;
      } else {
       $_0912_i_i101_i_i = $_2_7_i_i109_i_i;
       $_013_i_i100_i_i = $619;
       $tmp_014_i_i99_i_i = $tmp_014_i_i99_i_i + 1 | 0;
      }
     }
     HEAP32[15666] = $_2_7_i_i109_i_i; //@line 28142
     $_0912_i87_i_i = $_01115_i_i60_i;
     $_013_i86_i_i = $584;
     $tmp_014_i85_i_i = $119;
     while (1) {
      $624 = HEAPU8[$tmp_014_i85_i_i] << 24 ^ $_0912_i87_i_i; //@line 28152
      $626 = $624 << 1; //@line 28154
      $_2_i88_i_i = ($624 | 0) < 0 ? $626 ^ 79764919 : $626; //@line 28156
      $629 = $_2_i88_i_i << 1; //@line 28158
      $_2_1_i89_i_i = ($_2_i88_i_i | 0) < 0 ? $629 ^ 79764919 : $629; //@line 28160
      $632 = $_2_1_i89_i_i << 1; //@line 28162
      $_2_2_i90_i_i = ($_2_1_i89_i_i | 0) < 0 ? $632 ^ 79764919 : $632; //@line 28164
      $635 = $_2_2_i90_i_i << 1; //@line 28166
      $_2_3_i91_i_i = ($_2_2_i90_i_i | 0) < 0 ? $635 ^ 79764919 : $635; //@line 28168
      $638 = $_2_3_i91_i_i << 1; //@line 28170
      $_2_4_i92_i_i = ($_2_3_i91_i_i | 0) < 0 ? $638 ^ 79764919 : $638; //@line 28172
      $641 = $_2_4_i92_i_i << 1; //@line 28174
      $_2_5_i93_i_i = ($_2_4_i92_i_i | 0) < 0 ? $641 ^ 79764919 : $641; //@line 28176
      $644 = $_2_5_i93_i_i << 1; //@line 28178
      $_2_6_i94_i_i = ($_2_5_i93_i_i | 0) < 0 ? $644 ^ 79764919 : $644; //@line 28180
      $647 = $_2_6_i94_i_i << 1; //@line 28182
      $_2_7_i95_i_i = ($_2_6_i94_i_i | 0) < 0 ? $647 ^ 79764919 : $647; //@line 28184
      $650 = $_013_i86_i_i - 1 | 0; //@line 28186
      if (($650 | 0) == 0) {
       $_09_lcssa_i_i63_i = $_2_7_i95_i_i; //@line 28190
       break;
      } else {
       $_0912_i87_i_i = $_2_7_i95_i_i;
       $_013_i86_i_i = $650;
       $tmp_014_i85_i_i = $tmp_014_i85_i_i + 1 | 0;
      }
     }
    }
    if (($_01214_i_i61_i | 0) == ($584 | 0)) {
     $_011_lcssa_i_i64_i = $_09_lcssa_i_i63_i; //@line 28202
     break;
    } else {
     $_01214_i_i61_i = $_01214_i_i61_i - $584 | 0;
     $_01115_i_i60_i = $_09_lcssa_i_i63_i;
    }
   }
  }
  if ((_psi_read($fp, $119, 4) | 0) != 0) {
   $_0 = 1; //@line 28214
   label = 13132; //@line 28215
   break;
  }
  $_0912_i_i43_i_i = HEAP32[15666] | 0;
  $_013_i_i42_i_i = 4;
  $tmp_014_i_i41_i_i = $119;
  while (1) {
   $661 = HEAPU8[$tmp_014_i_i41_i_i] << 24 ^ $_0912_i_i43_i_i; //@line 28227
   $663 = $661 << 1; //@line 28229
   $_2_i_i44_i_i = ($661 | 0) < 0 ? $663 ^ 79764919 : $663; //@line 28231
   $666 = $_2_i_i44_i_i << 1; //@line 28233
   $_2_1_i_i45_i_i = ($_2_i_i44_i_i | 0) < 0 ? $666 ^ 79764919 : $666; //@line 28235
   $669 = $_2_1_i_i45_i_i << 1; //@line 28237
   $_2_2_i_i46_i_i = ($_2_1_i_i45_i_i | 0) < 0 ? $669 ^ 79764919 : $669; //@line 28239
   $672 = $_2_2_i_i46_i_i << 1; //@line 28241
   $_2_3_i_i47_i_i = ($_2_2_i_i46_i_i | 0) < 0 ? $672 ^ 79764919 : $672; //@line 28243
   $675 = $_2_3_i_i47_i_i << 1; //@line 28245
   $_2_4_i_i48_i_i = ($_2_3_i_i47_i_i | 0) < 0 ? $675 ^ 79764919 : $675; //@line 28247
   $678 = $_2_4_i_i48_i_i << 1; //@line 28249
   $_2_5_i_i49_i_i = ($_2_4_i_i48_i_i | 0) < 0 ? $678 ^ 79764919 : $678; //@line 28251
   $681 = $_2_5_i_i49_i_i << 1; //@line 28253
   $_2_6_i_i50_i_i = ($_2_5_i_i49_i_i | 0) < 0 ? $681 ^ 79764919 : $681; //@line 28255
   $684 = $_2_6_i_i50_i_i << 1; //@line 28257
   $_2_7_i_i51_i_i = ($_2_6_i_i50_i_i | 0) < 0 ? $684 ^ 79764919 : $684; //@line 28259
   $687 = $_013_i_i42_i_i - 1 | 0; //@line 28261
   if (($687 | 0) == 0) {
    break;
   } else {
    $_0912_i_i43_i_i = $_2_7_i_i51_i_i;
    $_013_i_i42_i_i = $687;
    $tmp_014_i_i41_i_i = $tmp_014_i_i41_i_i + 1 | 0;
   }
  }
  HEAP32[15666] = $_2_7_i_i51_i_i; //@line 28270
  if ((_psi_get_uint32_be($119, 0) | 0) == ($_011_lcssa_i_i64_i | 0)) {
   $_ph_i = $358; //@line 28275
  } else {
   $_0 = 1; //@line 28277
   label = 13143; //@line 28278
   break;
  }
 }
 if ((label | 0) == 13029) {
  _psi_sct_del($358); //@line 28283
  $_0 = 1; //@line 28285
  STACKTOP = sp; //@line 28287
  return $_0 | 0; //@line 28288
 } else if ((label | 0) == 13032) {
  _psi_sct_del($358); //@line 28291
  $_0 = 1; //@line 28293
  STACKTOP = sp; //@line 28295
  return $_0 | 0; //@line 28296
 } else if ((label | 0) == 13087) {
  _free($911); //@line 28299
  $_0 = 1; //@line 28301
  STACKTOP = sp; //@line 28303
  return $_0 | 0; //@line 28304
 } else if ((label | 0) == 12998) {
  L16555 : do {
   if (($165 | 0) == 0) {
    $_011_lcssa_i_i_i = $_2_7_i_i50; //@line 28311
   } else {
    $_01214_i_i_i = $165;
    $_01115_i_i_i = $_2_7_i_i50;
    while (1) {
     $200 = $_01214_i_i_i >>> 0 < 256 ? $_01214_i_i_i : 256; //@line 28318
     if ((_psi_read($fp, $119, $200) | 0) != 0) {
      $_0 = 1; //@line 28323
      break;
     }
     $204 = HEAP32[15666] | 0; //@line 28326
     if (($200 | 0) == 0) {
      HEAP32[15666] = $204; //@line 28330
      $_09_lcssa_i_i_i53 = $_01115_i_i_i; //@line 28332
     } else {
      $_0912_i_i_i_i = $204;
      $_013_i_i_i_i = $200;
      $tmp_014_i_i_i_i = $119;
      while (1) {
       $209 = HEAPU8[$tmp_014_i_i_i_i] << 24 ^ $_0912_i_i_i_i; //@line 28342
       $211 = $209 << 1; //@line 28344
       $_2_i_i_i_i = ($209 | 0) < 0 ? $211 ^ 79764919 : $211; //@line 28346
       $214 = $_2_i_i_i_i << 1; //@line 28348
       $_2_1_i_i_i_i = ($_2_i_i_i_i | 0) < 0 ? $214 ^ 79764919 : $214; //@line 28350
       $217 = $_2_1_i_i_i_i << 1; //@line 28352
       $_2_2_i_i_i_i = ($_2_1_i_i_i_i | 0) < 0 ? $217 ^ 79764919 : $217; //@line 28354
       $220 = $_2_2_i_i_i_i << 1; //@line 28356
       $_2_3_i_i_i_i = ($_2_2_i_i_i_i | 0) < 0 ? $220 ^ 79764919 : $220; //@line 28358
       $223 = $_2_3_i_i_i_i << 1; //@line 28360
       $_2_4_i_i_i_i = ($_2_3_i_i_i_i | 0) < 0 ? $223 ^ 79764919 : $223; //@line 28362
       $226 = $_2_4_i_i_i_i << 1; //@line 28364
       $_2_5_i_i_i_i = ($_2_4_i_i_i_i | 0) < 0 ? $226 ^ 79764919 : $226; //@line 28366
       $229 = $_2_5_i_i_i_i << 1; //@line 28368
       $_2_6_i_i_i_i = ($_2_5_i_i_i_i | 0) < 0 ? $229 ^ 79764919 : $229; //@line 28370
       $232 = $_2_6_i_i_i_i << 1; //@line 28372
       $_2_7_i_i_i_i = ($_2_6_i_i_i_i | 0) < 0 ? $232 ^ 79764919 : $232; //@line 28374
       $235 = $_013_i_i_i_i - 1 | 0; //@line 28376
       if (($235 | 0) == 0) {
        break;
       } else {
        $_0912_i_i_i_i = $_2_7_i_i_i_i;
        $_013_i_i_i_i = $235;
        $tmp_014_i_i_i_i = $tmp_014_i_i_i_i + 1 | 0;
       }
      }
      HEAP32[15666] = $_2_7_i_i_i_i; //@line 28385
      $_0912_i_i23_i = $_01115_i_i_i;
      $_013_i_i22_i = $200;
      $tmp_014_i_i21_i = $119;
      while (1) {
       $240 = HEAPU8[$tmp_014_i_i21_i] << 24 ^ $_0912_i_i23_i; //@line 28395
       $242 = $240 << 1; //@line 28397
       $_2_i_i24_i = ($240 | 0) < 0 ? $242 ^ 79764919 : $242; //@line 28399
       $245 = $_2_i_i24_i << 1; //@line 28401
       $_2_1_i_i25_i = ($_2_i_i24_i | 0) < 0 ? $245 ^ 79764919 : $245; //@line 28403
       $248 = $_2_1_i_i25_i << 1; //@line 28405
       $_2_2_i_i26_i = ($_2_1_i_i25_i | 0) < 0 ? $248 ^ 79764919 : $248; //@line 28407
       $251 = $_2_2_i_i26_i << 1; //@line 28409
       $_2_3_i_i27_i = ($_2_2_i_i26_i | 0) < 0 ? $251 ^ 79764919 : $251; //@line 28411
       $254 = $_2_3_i_i27_i << 1; //@line 28413
       $_2_4_i_i28_i = ($_2_3_i_i27_i | 0) < 0 ? $254 ^ 79764919 : $254; //@line 28415
       $257 = $_2_4_i_i28_i << 1; //@line 28417
       $_2_5_i_i29_i = ($_2_4_i_i28_i | 0) < 0 ? $257 ^ 79764919 : $257; //@line 28419
       $260 = $_2_5_i_i29_i << 1; //@line 28421
       $_2_6_i_i30_i = ($_2_5_i_i29_i | 0) < 0 ? $260 ^ 79764919 : $260; //@line 28423
       $263 = $_2_6_i_i30_i << 1; //@line 28425
       $_2_7_i_i31_i = ($_2_6_i_i30_i | 0) < 0 ? $263 ^ 79764919 : $263; //@line 28427
       $266 = $_013_i_i22_i - 1 | 0; //@line 28429
       if (($266 | 0) == 0) {
        $_09_lcssa_i_i_i53 = $_2_7_i_i31_i; //@line 28433
        break;
       } else {
        $_0912_i_i23_i = $_2_7_i_i31_i;
        $_013_i_i22_i = $266;
        $tmp_014_i_i21_i = $tmp_014_i_i21_i + 1 | 0;
       }
      }
     }
     if (($_01214_i_i_i | 0) == ($200 | 0)) {
      $_011_lcssa_i_i_i = $_09_lcssa_i_i_i53; //@line 28445
      break L16555;
     } else {
      $_01214_i_i_i = $_01214_i_i_i - $200 | 0;
      $_01115_i_i_i = $_09_lcssa_i_i_i53;
     }
    }
    STACKTOP = sp; //@line 28452
    return $_0 | 0; //@line 28453
   }
  } while (0);
  if ((_psi_read($fp, $119, 4) | 0) != 0) {
   $_0 = 1; //@line 28461
   STACKTOP = sp; //@line 28463
   return $_0 | 0; //@line 28464
  }
  $_0912_i_i10_i_i = HEAP32[15666] | 0;
  $_013_i_i9_i_i = 4;
  $tmp_014_i_i8_i_i = $119;
  while (1) {
   $277 = HEAPU8[$tmp_014_i_i8_i_i] << 24 ^ $_0912_i_i10_i_i; //@line 28475
   $279 = $277 << 1; //@line 28477
   $_2_i_i11_i_i = ($277 | 0) < 0 ? $279 ^ 79764919 : $279; //@line 28479
   $282 = $_2_i_i11_i_i << 1; //@line 28481
   $_2_1_i_i12_i_i = ($_2_i_i11_i_i | 0) < 0 ? $282 ^ 79764919 : $282; //@line 28483
   $285 = $_2_1_i_i12_i_i << 1; //@line 28485
   $_2_2_i_i13_i_i = ($_2_1_i_i12_i_i | 0) < 0 ? $285 ^ 79764919 : $285; //@line 28487
   $288 = $_2_2_i_i13_i_i << 1; //@line 28489
   $_2_3_i_i14_i_i = ($_2_2_i_i13_i_i | 0) < 0 ? $288 ^ 79764919 : $288; //@line 28491
   $291 = $_2_3_i_i14_i_i << 1; //@line 28493
   $_2_4_i_i15_i_i = ($_2_3_i_i14_i_i | 0) < 0 ? $291 ^ 79764919 : $291; //@line 28495
   $294 = $_2_4_i_i15_i_i << 1; //@line 28497
   $_2_5_i_i16_i_i = ($_2_4_i_i15_i_i | 0) < 0 ? $294 ^ 79764919 : $294; //@line 28499
   $297 = $_2_5_i_i16_i_i << 1; //@line 28501
   $_2_6_i_i17_i_i = ($_2_5_i_i16_i_i | 0) < 0 ? $297 ^ 79764919 : $297; //@line 28503
   $300 = $_2_6_i_i17_i_i << 1; //@line 28505
   $_2_7_i_i18_i_i = ($_2_6_i_i17_i_i | 0) < 0 ? $300 ^ 79764919 : $300; //@line 28507
   $303 = $_013_i_i9_i_i - 1 | 0; //@line 28509
   if (($303 | 0) == 0) {
    break;
   } else {
    $_0912_i_i10_i_i = $_2_7_i_i18_i_i;
    $_013_i_i9_i_i = $303;
    $tmp_014_i_i8_i_i = $tmp_014_i_i8_i_i + 1 | 0;
   }
  }
  HEAP32[15666] = $_2_7_i_i18_i_i; //@line 28518
  if ((_psi_get_uint32_be($119, 0) | 0) != ($_011_lcssa_i_i_i | 0)) {
   $_0 = 1; //@line 28523
   STACKTOP = sp; //@line 28525
   return $_0 | 0; //@line 28526
  }
  _psi_img_clean_comment($img); //@line 28528
  $1143 = HEAP32[15666] | 0; //@line 28529
  if ((_psi_read($fp, $3, 4) | 0) != 0) {
   $_0 = 1; //@line 28534
   STACKTOP = sp; //@line 28536
   return $_0 | 0; //@line 28537
  }
  $_0912_i_i = HEAP32[15666] | 0;
  $_013_i_i = 4;
  $tmp_014_i_i = $3;
  while (1) {
   $1151 = HEAPU8[$tmp_014_i_i] << 24 ^ $_0912_i_i; //@line 28548
   $1153 = $1151 << 1; //@line 28550
   $_2_i_i = ($1151 | 0) < 0 ? $1153 ^ 79764919 : $1153; //@line 28552
   $1156 = $_2_i_i << 1; //@line 28554
   $_2_1_i_i = ($_2_i_i | 0) < 0 ? $1156 ^ 79764919 : $1156; //@line 28556
   $1159 = $_2_1_i_i << 1; //@line 28558
   $_2_2_i_i = ($_2_1_i_i | 0) < 0 ? $1159 ^ 79764919 : $1159; //@line 28560
   $1162 = $_2_2_i_i << 1; //@line 28562
   $_2_3_i_i = ($_2_2_i_i | 0) < 0 ? $1162 ^ 79764919 : $1162; //@line 28564
   $1165 = $_2_3_i_i << 1; //@line 28566
   $_2_4_i_i = ($_2_3_i_i | 0) < 0 ? $1165 ^ 79764919 : $1165; //@line 28568
   $1168 = $_2_4_i_i << 1; //@line 28570
   $_2_5_i_i = ($_2_4_i_i | 0) < 0 ? $1168 ^ 79764919 : $1168; //@line 28572
   $1171 = $_2_5_i_i << 1; //@line 28574
   $_2_6_i_i = ($_2_5_i_i | 0) < 0 ? $1171 ^ 79764919 : $1171; //@line 28576
   $1174 = $_2_6_i_i << 1; //@line 28578
   $_2_7_i_i = ($_2_6_i_i | 0) < 0 ? $1174 ^ 79764919 : $1174; //@line 28580
   $1177 = $_013_i_i - 1 | 0; //@line 28582
   if (($1177 | 0) == 0) {
    break;
   } else {
    $_0912_i_i = $_2_7_i_i;
    $_013_i_i = $1177;
    $tmp_014_i_i = $tmp_014_i_i + 1 | 0;
   }
  }
  HEAP32[15666] = $_2_7_i_i; //@line 28591
  $_0 = (_psi_get_uint32_be($3, 0) | 0) != ($1143 | 0) | 0; //@line 28596
  STACKTOP = sp; //@line 28598
  return $_0 | 0; //@line 28599
 } else if ((label | 0) == 13116) {
  STACKTOP = sp; //@line 28603
  return $_0 | 0; //@line 28604
 } else if ((label | 0) == 13117) {
  STACKTOP = sp; //@line 28608
  return $_0 | 0; //@line 28609
 } else if ((label | 0) == 13118) {
  STACKTOP = sp; //@line 28613
  return $_0 | 0; //@line 28614
 } else if ((label | 0) == 13119) {
  STACKTOP = sp; //@line 28618
  return $_0 | 0; //@line 28619
 } else if ((label | 0) == 13122) {
  STACKTOP = sp; //@line 28623
  return $_0 | 0; //@line 28624
 } else if ((label | 0) == 13123) {
  STACKTOP = sp; //@line 28628
  return $_0 | 0; //@line 28629
 } else if ((label | 0) == 13124) {
  STACKTOP = sp; //@line 28633
  return $_0 | 0; //@line 28634
 } else if ((label | 0) == 13126) {
  STACKTOP = sp; //@line 28638
  return $_0 | 0; //@line 28639
 } else if ((label | 0) == 13127) {
  STACKTOP = sp; //@line 28643
  return $_0 | 0; //@line 28644
 } else if ((label | 0) == 13129) {
  STACKTOP = sp; //@line 28648
  return $_0 | 0; //@line 28649
 } else if ((label | 0) == 13130) {
  STACKTOP = sp; //@line 28653
  return $_0 | 0; //@line 28654
 } else if ((label | 0) == 13132) {
  STACKTOP = sp; //@line 28658
  return $_0 | 0; //@line 28659
 } else if ((label | 0) == 13134) {
  STACKTOP = sp; //@line 28663
  return $_0 | 0; //@line 28664
 } else if ((label | 0) == 13136) {
  STACKTOP = sp; //@line 28668
  return $_0 | 0; //@line 28669
 } else if ((label | 0) == 13137) {
  STACKTOP = sp; //@line 28673
  return $_0 | 0; //@line 28674
 } else if ((label | 0) == 13138) {
  STACKTOP = sp; //@line 28678
  return $_0 | 0; //@line 28679
 } else if ((label | 0) == 13139) {
  STACKTOP = sp; //@line 28683
  return $_0 | 0; //@line 28684
 } else if ((label | 0) == 13140) {
  STACKTOP = sp; //@line 28688
  return $_0 | 0; //@line 28689
 } else if ((label | 0) == 13141) {
  STACKTOP = sp; //@line 28693
  return $_0 | 0; //@line 28694
 } else if ((label | 0) == 13142) {
  STACKTOP = sp; //@line 28698
  return $_0 | 0; //@line 28699
 } else if ((label | 0) == 13143) {
  STACKTOP = sp; //@line 28703
  return $_0 | 0; //@line 28704
 } else if ((label | 0) == 13144) {
  STACKTOP = sp; //@line 28708
  return $_0 | 0; //@line 28709
 } else if ((label | 0) == 13145) {
  STACKTOP = sp; //@line 28713
  return $_0 | 0; //@line 28714
 }
 return 0;
}
function _pfdc2_save_fp($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i = 0, $1 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_0912_i_i = 0, $9 = 0, $11 = 0, $_2_i_i = 0, $14 = 0, $_2_1_i_i = 0, $17 = 0, $_2_2_i_i = 0, $20 = 0, $_2_3_i_i = 0, $23 = 0, $_2_4_i_i = 0, $26 = 0, $_2_5_i_i = 0, $29 = 0, $_2_6_i_i = 0, $32 = 0, $_2_7_i_i = 0, $35 = 0, $38 = 0, $39 = 0, $45 = 0, $tmp_014_i_i20 = 0, $_013_i_i21 = 0, $_0912_i_i22 = 0, $49 = 0, $51 = 0, $_2_i_i23 = 0, $54 = 0, $_2_1_i_i24 = 0, $57 = 0, $_2_2_i_i25 = 0, $60 = 0, $_2_3_i_i26 = 0, $63 = 0, $_2_4_i_i27 = 0, $66 = 0, $_2_5_i_i28 = 0, $69 = 0, $_2_6_i_i29 = 0, $72 = 0, $_2_7_i_i30 = 0, $75 = 0, $77 = 0, $78 = 0, $tmp_014_i16_i = 0, $_013_i17_i = 0, $_0912_i18_i = 0, $84 = 0, $86 = 0, $_2_i19_i = 0, $89 = 0, $_2_1_i20_i = 0, $92 = 0, $_2_2_i21_i = 0, $95 = 0, $_2_3_i22_i = 0, $98 = 0, $_2_4_i23_i = 0, $101 = 0, $_2_5_i24_i = 0, $104 = 0, $_2_6_i25_i = 0, $107 = 0, $_2_7_i26_i = 0, $110 = 0, $_0912_i46_ph_i = 0, $_2_i47_i = 0, $117 = 0, $_2_1_i48_i = 0, $120 = 0, $_2_2_i49_i = 0, $123 = 0, $_2_3_i50_i = 0, $126 = 0, $_2_4_i51_i = 0, $129 = 0, $_2_5_i52_i = 0, $132 = 0, $_2_6_i53_i = 0, $135 = 0, $_2_7_i54_i = 0, $tmp_014_i_i73_i = 0, $_013_i_i74_i = 0, $_0912_i_i75_i = 0, $144 = 0, $146 = 0, $_2_i_i76_i = 0, $149 = 0, $_2_1_i_i77_i = 0, $152 = 0, $_2_2_i_i78_i = 0, $155 = 0, $_2_3_i_i79_i = 0, $158 = 0, $_2_4_i_i80_i = 0, $161 = 0, $_2_5_i_i81_i = 0, $164 = 0, $_2_6_i_i82_i = 0, $167 = 0, $_2_7_i_i83_i = 0, $170 = 0, $_0_i87_i = 0, $172 = 0, $173 = 0, $177 = 0, $tmp_014_i_i58_i = 0, $_013_i_i59_i = 0, $_0912_i_i60_i = 0, $182 = 0, $184 = 0, $_2_i_i61_i = 0, $187 = 0, $_2_1_i_i62_i = 0, $190 = 0, $_2_2_i_i63_i = 0, $193 = 0, $_2_3_i_i64_i = 0, $196 = 0, $_2_4_i_i65_i = 0, $199 = 0, $_2_5_i_i66_i = 0, $202 = 0, $_2_6_i_i67_i = 0, $205 = 0, $_2_7_i_i68_i = 0, $208 = 0, $_09_lcssa_i_i_i = 0, $_0_i71_i = 0, $217 = 0, $219 = 0, $_2_i_i32_i = 0, $222 = 0, $_2_1_i_i33_i = 0, $225 = 0, $_2_2_i_i34_i = 0, $228 = 0, $_2_3_i_i35_i = 0, $231 = 0, $_2_4_i_i36_i = 0, $234 = 0, $_2_5_i_i37_i = 0, $237 = 0, $_2_6_i_i38_i = 0, $240 = 0, $_0_i42_i = 0, $242 = 0, $tmp_014_i_i_i = 0, $_013_i_i_i = 0, $_0912_i_i_i = 0, $250 = 0, $252 = 0, $_2_i_i_i = 0, $255 = 0, $_2_1_i_i_i = 0, $258 = 0, $_2_2_i_i_i = 0, $261 = 0, $_2_3_i_i_i = 0, $264 = 0, $_2_4_i_i_i = 0, $267 = 0, $_2_5_i_i_i = 0, $270 = 0, $_2_6_i_i_i = 0, $273 = 0, $_2_7_i_i_i = 0, $276 = 0, $_0_i_i = 0, $280 = 0, $281 = 0, $283 = 0, $284 = 0, $c_060 = 0, $287 = 0, $288 = 0, $289 = 0, $291 = 0, $292 = 0, $h_055 = 0, $295 = 0, $296 = 0, $299 = 0, $s_054 = 0, $303 = 0, $sct_pn_i = 0, $_012_i = 0, $316 = 0, $317 = 0, $320 = 0, $321 = 0, $tmp_014_i_i35 = 0, $_013_i_i36 = 0, $_0912_i_i37 = 0, $335 = 0, $337 = 0, $_2_i_i38 = 0, $340 = 0, $_2_1_i_i39 = 0, $343 = 0, $_2_2_i_i40 = 0, $346 = 0, $_2_3_i_i41 = 0, $349 = 0, $_2_4_i_i42 = 0, $352 = 0, $_2_5_i_i43 = 0, $355 = 0, $_2_6_i_i44 = 0, $358 = 0, $_2_7_i_i45 = 0, $361 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 28781
 STACKTOP = STACKTOP + 32 | 0; //@line 28781
 $buf_i = sp | 0; //@line 28782
 HEAP32[15666] = -1; //@line 28784
 $1 = sp + 16 | 0; //@line 28785
 _psi_set_uint32_be($1, 0, 1346782275); //@line 28786
 _psi_set_uint16_be($1, 4, 2); //@line 28787
 _psi_set_uint16_be($1, 6, 0); //@line 28788
 _psi_set_uint32_be($1, 8, 0); //@line 28789
 _psi_set_uint32_be($1, 12, 16); //@line 28790
 if ((_psi_write($fp, $1, 16) | 0) != 0) {
  $_0 = 1; //@line 28795
  STACKTOP = sp; //@line 28797
  return $_0 | 0; //@line 28798
 }
 $_0912_i_i = HEAP32[15666] | 0;
 $_013_i_i = 16;
 $tmp_014_i_i = $1;
 while (1) {
  $9 = HEAPU8[$tmp_014_i_i] << 24 ^ $_0912_i_i; //@line 28809
  $11 = $9 << 1; //@line 28811
  $_2_i_i = ($9 | 0) < 0 ? $11 ^ 79764919 : $11; //@line 28813
  $14 = $_2_i_i << 1; //@line 28815
  $_2_1_i_i = ($_2_i_i | 0) < 0 ? $14 ^ 79764919 : $14; //@line 28817
  $17 = $_2_1_i_i << 1; //@line 28819
  $_2_2_i_i = ($_2_1_i_i | 0) < 0 ? $17 ^ 79764919 : $17; //@line 28821
  $20 = $_2_2_i_i << 1; //@line 28823
  $_2_3_i_i = ($_2_2_i_i | 0) < 0 ? $20 ^ 79764919 : $20; //@line 28825
  $23 = $_2_3_i_i << 1; //@line 28827
  $_2_4_i_i = ($_2_3_i_i | 0) < 0 ? $23 ^ 79764919 : $23; //@line 28829
  $26 = $_2_4_i_i << 1; //@line 28831
  $_2_5_i_i = ($_2_4_i_i | 0) < 0 ? $26 ^ 79764919 : $26; //@line 28833
  $29 = $_2_5_i_i << 1; //@line 28835
  $_2_6_i_i = ($_2_5_i_i | 0) < 0 ? $29 ^ 79764919 : $29; //@line 28837
  $32 = $_2_6_i_i << 1; //@line 28839
  $_2_7_i_i = ($_2_6_i_i | 0) < 0 ? $32 ^ 79764919 : $32; //@line 28841
  $35 = $_013_i_i - 1 | 0; //@line 28843
  if (($35 | 0) == 0) {
   break;
  } else {
   $_0912_i_i = $_2_7_i_i;
   $_013_i_i = $35;
   $tmp_014_i_i = $tmp_014_i_i + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i; //@line 28852
 $38 = $buf_i | 0; //@line 28853
 $39 = $img + 8 | 0; //@line 28854
 do {
  if ((HEAP32[$39 >> 2] | 0) != 0) {
   _psi_set_uint16_be($38, 0, 17229); //@line 28860
   _psi_set_uint16_be($38, 2, (HEAP32[$39 >> 2] | 0) + 2 | 0); //@line 28863
   $45 = $buf_i + 4 | 0; //@line 28864
   HEAP8[$45] = 10; //@line 28865
   $_0912_i_i22 = 0;
   $_013_i_i21 = 5;
   $tmp_014_i_i20 = $38;
   while (1) {
    $49 = HEAPU8[$tmp_014_i_i20] << 24 ^ $_0912_i_i22; //@line 28874
    $51 = $49 << 1; //@line 28876
    $_2_i_i23 = ($49 | 0) < 0 ? $51 ^ 79764919 : $51; //@line 28878
    $54 = $_2_i_i23 << 1; //@line 28880
    $_2_1_i_i24 = ($_2_i_i23 | 0) < 0 ? $54 ^ 79764919 : $54; //@line 28882
    $57 = $_2_1_i_i24 << 1; //@line 28884
    $_2_2_i_i25 = ($_2_1_i_i24 | 0) < 0 ? $57 ^ 79764919 : $57; //@line 28886
    $60 = $_2_2_i_i25 << 1; //@line 28888
    $_2_3_i_i26 = ($_2_2_i_i25 | 0) < 0 ? $60 ^ 79764919 : $60; //@line 28890
    $63 = $_2_3_i_i26 << 1; //@line 28892
    $_2_4_i_i27 = ($_2_3_i_i26 | 0) < 0 ? $63 ^ 79764919 : $63; //@line 28894
    $66 = $_2_4_i_i27 << 1; //@line 28896
    $_2_5_i_i28 = ($_2_4_i_i27 | 0) < 0 ? $66 ^ 79764919 : $66; //@line 28898
    $69 = $_2_5_i_i28 << 1; //@line 28900
    $_2_6_i_i29 = ($_2_5_i_i28 | 0) < 0 ? $69 ^ 79764919 : $69; //@line 28902
    $72 = $_2_6_i_i29 << 1; //@line 28904
    $_2_7_i_i30 = ($_2_6_i_i29 | 0) < 0 ? $72 ^ 79764919 : $72; //@line 28906
    $75 = $_013_i_i21 - 1 | 0; //@line 28908
    if (($75 | 0) == 0) {
     break;
    } else {
     $_0912_i_i22 = $_2_7_i_i30;
     $_013_i_i21 = $75;
     $tmp_014_i_i20 = $tmp_014_i_i20 + 1 | 0;
    }
   }
   $77 = $img + 12 | 0; //@line 28917
   $78 = HEAP32[$39 >> 2] | 0; //@line 28918
   if (($78 | 0) == 0) {
    $_0912_i46_ph_i = $_2_7_i_i30; //@line 28922
   } else {
    $_0912_i18_i = $_2_7_i_i30;
    $_013_i17_i = $78;
    $tmp_014_i16_i = HEAP32[$77 >> 2] | 0;
    while (1) {
     $84 = HEAPU8[$tmp_014_i16_i] << 24 ^ $_0912_i18_i; //@line 28934
     $86 = $84 << 1; //@line 28936
     $_2_i19_i = ($84 | 0) < 0 ? $86 ^ 79764919 : $86; //@line 28938
     $89 = $_2_i19_i << 1; //@line 28940
     $_2_1_i20_i = ($_2_i19_i | 0) < 0 ? $89 ^ 79764919 : $89; //@line 28942
     $92 = $_2_1_i20_i << 1; //@line 28944
     $_2_2_i21_i = ($_2_1_i20_i | 0) < 0 ? $92 ^ 79764919 : $92; //@line 28946
     $95 = $_2_2_i21_i << 1; //@line 28948
     $_2_3_i22_i = ($_2_2_i21_i | 0) < 0 ? $95 ^ 79764919 : $95; //@line 28950
     $98 = $_2_3_i22_i << 1; //@line 28952
     $_2_4_i23_i = ($_2_3_i22_i | 0) < 0 ? $98 ^ 79764919 : $98; //@line 28954
     $101 = $_2_4_i23_i << 1; //@line 28956
     $_2_5_i24_i = ($_2_4_i23_i | 0) < 0 ? $101 ^ 79764919 : $101; //@line 28958
     $104 = $_2_5_i24_i << 1; //@line 28960
     $_2_6_i25_i = ($_2_5_i24_i | 0) < 0 ? $104 ^ 79764919 : $104; //@line 28962
     $107 = $_2_6_i25_i << 1; //@line 28964
     $_2_7_i26_i = ($_2_6_i25_i | 0) < 0 ? $107 ^ 79764919 : $107; //@line 28966
     $110 = $_013_i17_i - 1 | 0; //@line 28968
     if (($110 | 0) == 0) {
      $_0912_i46_ph_i = $_2_7_i26_i; //@line 28972
      break;
     } else {
      $_0912_i18_i = $_2_7_i26_i;
      $_013_i17_i = $110;
      $tmp_014_i16_i = $tmp_014_i16_i + 1 | 0;
     }
    }
   }
   $_2_i47_i = ($_0912_i46_ph_i >> 31) + 335544320 & -54452809 ^ $_0912_i46_ph_i << 1; //@line 28984
   $117 = $_2_i47_i << 1; //@line 28986
   $_2_1_i48_i = ($_2_i47_i | 0) < 0 ? $117 ^ 79764919 : $117; //@line 28988
   $120 = $_2_1_i48_i << 1; //@line 28990
   $_2_2_i49_i = ($_2_1_i48_i | 0) < 0 ? $120 ^ 79764919 : $120; //@line 28992
   $123 = $_2_2_i49_i << 1; //@line 28994
   $_2_3_i50_i = ($_2_2_i49_i | 0) < 0 ? $123 ^ 79764919 : $123; //@line 28996
   $126 = $_2_3_i50_i << 1; //@line 28998
   $_2_4_i51_i = ($_2_3_i50_i | 0) < 0 ? $126 ^ 79764919 : $126; //@line 29000
   $129 = $_2_4_i51_i << 1; //@line 29002
   $_2_5_i52_i = ($_2_4_i51_i | 0) < 0 ? $129 ^ 79764919 : $129; //@line 29004
   $132 = $_2_5_i52_i << 1; //@line 29006
   $_2_6_i53_i = ($_2_5_i52_i | 0) < 0 ? $132 ^ 79764919 : $132; //@line 29008
   $135 = $_2_6_i53_i << 1; //@line 29010
   $_2_7_i54_i = ($_2_6_i53_i | 0) < 0 ? $135 ^ 79764919 : $135; //@line 29012
   if ((_psi_write($fp, $38, 5) | 0) == 0) {
    $_0912_i_i75_i = HEAP32[15666] | 0;
    $_013_i_i74_i = 5;
    $tmp_014_i_i73_i = $38;
    while (1) {
     $144 = HEAPU8[$tmp_014_i_i73_i] << 24 ^ $_0912_i_i75_i; //@line 29026
     $146 = $144 << 1; //@line 29028
     $_2_i_i76_i = ($144 | 0) < 0 ? $146 ^ 79764919 : $146; //@line 29030
     $149 = $_2_i_i76_i << 1; //@line 29032
     $_2_1_i_i77_i = ($_2_i_i76_i | 0) < 0 ? $149 ^ 79764919 : $149; //@line 29034
     $152 = $_2_1_i_i77_i << 1; //@line 29036
     $_2_2_i_i78_i = ($_2_1_i_i77_i | 0) < 0 ? $152 ^ 79764919 : $152; //@line 29038
     $155 = $_2_2_i_i78_i << 1; //@line 29040
     $_2_3_i_i79_i = ($_2_2_i_i78_i | 0) < 0 ? $155 ^ 79764919 : $155; //@line 29042
     $158 = $_2_3_i_i79_i << 1; //@line 29044
     $_2_4_i_i80_i = ($_2_3_i_i79_i | 0) < 0 ? $158 ^ 79764919 : $158; //@line 29046
     $161 = $_2_4_i_i80_i << 1; //@line 29048
     $_2_5_i_i81_i = ($_2_4_i_i80_i | 0) < 0 ? $161 ^ 79764919 : $161; //@line 29050
     $164 = $_2_5_i_i81_i << 1; //@line 29052
     $_2_6_i_i82_i = ($_2_5_i_i81_i | 0) < 0 ? $164 ^ 79764919 : $164; //@line 29054
     $167 = $_2_6_i_i82_i << 1; //@line 29056
     $_2_7_i_i83_i = ($_2_6_i_i82_i | 0) < 0 ? $167 ^ 79764919 : $167; //@line 29058
     $170 = $_013_i_i74_i - 1 | 0; //@line 29060
     if (($170 | 0) == 0) {
      break;
     } else {
      $_0912_i_i75_i = $_2_7_i_i83_i;
      $_013_i_i74_i = $170;
      $tmp_014_i_i73_i = $tmp_014_i_i73_i + 1 | 0;
     }
    }
    HEAP32[15666] = $_2_7_i_i83_i; //@line 29069
    $_0_i87_i = 0; //@line 29071
   } else {
    $_0_i87_i = 1; //@line 29073
   }
   $172 = HEAP32[$77 >> 2] | 0; //@line 29076
   $173 = HEAP32[$39 >> 2] | 0; //@line 29077
   if ((_psi_write($fp, $172, $173) | 0) == 0) {
    $177 = HEAP32[15666] | 0; //@line 29082
    if (($173 | 0) == 0) {
     $_09_lcssa_i_i_i = $177; //@line 29086
    } else {
     $_0912_i_i60_i = $177;
     $_013_i_i59_i = $173;
     $tmp_014_i_i58_i = $172;
     while (1) {
      $182 = HEAPU8[$tmp_014_i_i58_i] << 24 ^ $_0912_i_i60_i; //@line 29096
      $184 = $182 << 1; //@line 29098
      $_2_i_i61_i = ($182 | 0) < 0 ? $184 ^ 79764919 : $184; //@line 29100
      $187 = $_2_i_i61_i << 1; //@line 29102
      $_2_1_i_i62_i = ($_2_i_i61_i | 0) < 0 ? $187 ^ 79764919 : $187; //@line 29104
      $190 = $_2_1_i_i62_i << 1; //@line 29106
      $_2_2_i_i63_i = ($_2_1_i_i62_i | 0) < 0 ? $190 ^ 79764919 : $190; //@line 29108
      $193 = $_2_2_i_i63_i << 1; //@line 29110
      $_2_3_i_i64_i = ($_2_2_i_i63_i | 0) < 0 ? $193 ^ 79764919 : $193; //@line 29112
      $196 = $_2_3_i_i64_i << 1; //@line 29114
      $_2_4_i_i65_i = ($_2_3_i_i64_i | 0) < 0 ? $196 ^ 79764919 : $196; //@line 29116
      $199 = $_2_4_i_i65_i << 1; //@line 29118
      $_2_5_i_i66_i = ($_2_4_i_i65_i | 0) < 0 ? $199 ^ 79764919 : $199; //@line 29120
      $202 = $_2_5_i_i66_i << 1; //@line 29122
      $_2_6_i_i67_i = ($_2_5_i_i66_i | 0) < 0 ? $202 ^ 79764919 : $202; //@line 29124
      $205 = $_2_6_i_i67_i << 1; //@line 29126
      $_2_7_i_i68_i = ($_2_6_i_i67_i | 0) < 0 ? $205 ^ 79764919 : $205; //@line 29128
      $208 = $_013_i_i59_i - 1 | 0; //@line 29130
      if (($208 | 0) == 0) {
       $_09_lcssa_i_i_i = $_2_7_i_i68_i; //@line 29134
       break;
      } else {
       $_0912_i_i60_i = $_2_7_i_i68_i;
       $_013_i_i59_i = $208;
       $tmp_014_i_i58_i = $tmp_014_i_i58_i + 1 | 0;
      }
     }
    }
    HEAP32[15666] = $_09_lcssa_i_i_i; //@line 29142
    $_0_i71_i = 0; //@line 29144
   } else {
    $_0_i71_i = 1; //@line 29146
   }
   if ((_psi_write($fp, $45, 1) | 0) == 0) {
    $217 = HEAPU8[$45] << 24 ^ HEAP32[15666]; //@line 29158
    $219 = $217 << 1; //@line 29160
    $_2_i_i32_i = ($217 | 0) < 0 ? $219 ^ 79764919 : $219; //@line 29162
    $222 = $_2_i_i32_i << 1; //@line 29164
    $_2_1_i_i33_i = ($_2_i_i32_i | 0) < 0 ? $222 ^ 79764919 : $222; //@line 29166
    $225 = $_2_1_i_i33_i << 1; //@line 29168
    $_2_2_i_i34_i = ($_2_1_i_i33_i | 0) < 0 ? $225 ^ 79764919 : $225; //@line 29170
    $228 = $_2_2_i_i34_i << 1; //@line 29172
    $_2_3_i_i35_i = ($_2_2_i_i34_i | 0) < 0 ? $228 ^ 79764919 : $228; //@line 29174
    $231 = $_2_3_i_i35_i << 1; //@line 29176
    $_2_4_i_i36_i = ($_2_3_i_i35_i | 0) < 0 ? $231 ^ 79764919 : $231; //@line 29178
    $234 = $_2_4_i_i36_i << 1; //@line 29180
    $_2_5_i_i37_i = ($_2_4_i_i36_i | 0) < 0 ? $234 ^ 79764919 : $234; //@line 29182
    $237 = $_2_5_i_i37_i << 1; //@line 29184
    $_2_6_i_i38_i = ($_2_5_i_i37_i | 0) < 0 ? $237 ^ 79764919 : $237; //@line 29186
    $240 = $_2_6_i_i38_i << 1; //@line 29188
    HEAP32[15666] = ($_2_6_i_i38_i | 0) < 0 ? $240 ^ 79764919 : $240; //@line 29191
    $_0_i42_i = 0; //@line 29193
   } else {
    $_0_i42_i = 1; //@line 29195
   }
   $242 = $_0_i71_i | $_0_i87_i | $_0_i42_i; //@line 29198
   _psi_set_uint32_be($38, 0, $_2_7_i54_i); //@line 29199
   if ((_psi_write($fp, $38, 4) | 0) == 0) {
    $_0912_i_i_i = HEAP32[15666] | 0;
    $_013_i_i_i = 4;
    $tmp_014_i_i_i = $38;
    while (1) {
     $250 = HEAPU8[$tmp_014_i_i_i] << 24 ^ $_0912_i_i_i; //@line 29213
     $252 = $250 << 1; //@line 29215
     $_2_i_i_i = ($250 | 0) < 0 ? $252 ^ 79764919 : $252; //@line 29217
     $255 = $_2_i_i_i << 1; //@line 29219
     $_2_1_i_i_i = ($_2_i_i_i | 0) < 0 ? $255 ^ 79764919 : $255; //@line 29221
     $258 = $_2_1_i_i_i << 1; //@line 29223
     $_2_2_i_i_i = ($_2_1_i_i_i | 0) < 0 ? $258 ^ 79764919 : $258; //@line 29225
     $261 = $_2_2_i_i_i << 1; //@line 29227
     $_2_3_i_i_i = ($_2_2_i_i_i | 0) < 0 ? $261 ^ 79764919 : $261; //@line 29229
     $264 = $_2_3_i_i_i << 1; //@line 29231
     $_2_4_i_i_i = ($_2_3_i_i_i | 0) < 0 ? $264 ^ 79764919 : $264; //@line 29233
     $267 = $_2_4_i_i_i << 1; //@line 29235
     $_2_5_i_i_i = ($_2_4_i_i_i | 0) < 0 ? $267 ^ 79764919 : $267; //@line 29237
     $270 = $_2_5_i_i_i << 1; //@line 29239
     $_2_6_i_i_i = ($_2_5_i_i_i | 0) < 0 ? $270 ^ 79764919 : $270; //@line 29241
     $273 = $_2_6_i_i_i << 1; //@line 29243
     $_2_7_i_i_i = ($_2_6_i_i_i | 0) < 0 ? $273 ^ 79764919 : $273; //@line 29245
     $276 = $_013_i_i_i - 1 | 0; //@line 29247
     if (($276 | 0) == 0) {
      break;
     } else {
      $_0912_i_i_i = $_2_7_i_i_i;
      $_013_i_i_i = $276;
      $tmp_014_i_i_i = $tmp_014_i_i_i + 1 | 0;
     }
    }
    HEAP32[15666] = $_2_7_i_i_i; //@line 29256
    $_0_i_i = 0; //@line 29258
   } else {
    $_0_i_i = 1; //@line 29260
   }
   if (($242 | $_0_i_i | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 29269
   }
   STACKTOP = sp; //@line 29272
   return $_0 | 0; //@line 29273
  }
 } while (0);
 $280 = $img | 0; //@line 29276
 $281 = HEAP16[$280 >> 1] | 0; //@line 29277
 L16649 : do {
  if ($281 << 16 >> 16 != 0) {
   $283 = $img + 4 | 0; //@line 29282
   $c_060 = 0;
   $284 = $281;
   L16651 : while (1) {
    $287 = HEAP32[(HEAP32[$283 >> 2] | 0) + ($c_060 << 2) >> 2] | 0; //@line 29290
    $288 = $287 + 2 | 0; //@line 29291
    $289 = HEAP16[$288 >> 1] | 0; //@line 29292
    if ($289 << 16 >> 16 == 0) {
     $320 = $284; //@line 29296
    } else {
     $291 = $287 + 4 | 0; //@line 29298
     $h_055 = 0;
     $292 = $289;
     while (1) {
      $295 = HEAP32[(HEAP32[$291 >> 2] | 0) + ($h_055 << 2) >> 2] | 0; //@line 29306
      $296 = $295 + 2 | 0; //@line 29307
      if ((HEAP16[$296 >> 1] | 0) == 0) {
       $316 = $292; //@line 29312
      } else {
       $299 = $295 + 4 | 0; //@line 29314
       $s_054 = 0; //@line 29316
       do {
        $303 = HEAP32[(HEAP32[$299 >> 2] | 0) + ($s_054 << 2) >> 2] | 0; //@line 29321
        if ((_pfdc2_save_sector($fp, $303, $c_060, $h_055, 0) | 0) == 0) {
         $sct_pn_i = $303; //@line 29326
        } else {
         $_0 = 1; //@line 29328
         label = 13196; //@line 29329
         break L16651;
        }
        while (1) {
         $_012_i = HEAP32[$sct_pn_i >> 2] | 0; //@line 29335
         if (($_012_i | 0) == 0) {
          break;
         }
         if ((_pfdc2_save_sector($fp, $_012_i, $c_060, $h_055, 1) | 0) == 0) {
          $sct_pn_i = $_012_i; //@line 29345
         } else {
          $_0 = 1; //@line 29347
          label = 13194; //@line 29348
          break L16651;
         }
        }
        $s_054 = $s_054 + 1 | 0; //@line 29352
       } while ($s_054 >>> 0 < (HEAPU16[$296 >> 1] | 0) >>> 0);
       $316 = HEAP16[$288 >> 1] | 0; //@line 29365
      }
      $317 = $h_055 + 1 | 0; //@line 29368
      if ($317 >>> 0 < ($316 & 65535) >>> 0) {
       $h_055 = $317;
       $292 = $316;
      } else {
       break;
      }
     }
     $320 = HEAP16[$280 >> 1] | 0; //@line 29380
    }
    $321 = $c_060 + 1 | 0; //@line 29383
    if ($321 >>> 0 < ($320 & 65535) >>> 0) {
     $c_060 = $321;
     $284 = $320;
    } else {
     break L16649;
    }
   }
   if ((label | 0) == 13196) {
    STACKTOP = sp; //@line 29395
    return $_0 | 0; //@line 29396
   } else if ((label | 0) == 13194) {
    STACKTOP = sp; //@line 29400
    return $_0 | 0; //@line 29401
   }
  }
 } while (0);
 if ((_pfdc2_save_chunk($fp, 17742, 0, 0) | 0) != 0) {
  $_0 = 1; //@line 29409
  STACKTOP = sp; //@line 29411
  return $_0 | 0; //@line 29412
 }
 _psi_set_uint32_be($1, 0, HEAP32[15666] | 0); //@line 29415
 if ((_psi_write($fp, $1, 4) | 0) != 0) {
  $_0 = 1; //@line 29420
  STACKTOP = sp; //@line 29422
  return $_0 | 0; //@line 29423
 }
 $_0912_i_i37 = HEAP32[15666] | 0;
 $_013_i_i36 = 4;
 $tmp_014_i_i35 = $1;
 while (1) {
  $335 = HEAPU8[$tmp_014_i_i35] << 24 ^ $_0912_i_i37; //@line 29434
  $337 = $335 << 1; //@line 29436
  $_2_i_i38 = ($335 | 0) < 0 ? $337 ^ 79764919 : $337; //@line 29438
  $340 = $_2_i_i38 << 1; //@line 29440
  $_2_1_i_i39 = ($_2_i_i38 | 0) < 0 ? $340 ^ 79764919 : $340; //@line 29442
  $343 = $_2_1_i_i39 << 1; //@line 29444
  $_2_2_i_i40 = ($_2_1_i_i39 | 0) < 0 ? $343 ^ 79764919 : $343; //@line 29446
  $346 = $_2_2_i_i40 << 1; //@line 29448
  $_2_3_i_i41 = ($_2_2_i_i40 | 0) < 0 ? $346 ^ 79764919 : $346; //@line 29450
  $349 = $_2_3_i_i41 << 1; //@line 29452
  $_2_4_i_i42 = ($_2_3_i_i41 | 0) < 0 ? $349 ^ 79764919 : $349; //@line 29454
  $352 = $_2_4_i_i42 << 1; //@line 29456
  $_2_5_i_i43 = ($_2_4_i_i42 | 0) < 0 ? $352 ^ 79764919 : $352; //@line 29458
  $355 = $_2_5_i_i43 << 1; //@line 29460
  $_2_6_i_i44 = ($_2_5_i_i43 | 0) < 0 ? $355 ^ 79764919 : $355; //@line 29462
  $358 = $_2_6_i_i44 << 1; //@line 29464
  $_2_7_i_i45 = ($_2_6_i_i44 | 0) < 0 ? $358 ^ 79764919 : $358; //@line 29466
  $361 = $_013_i_i36 - 1 | 0; //@line 29468
  if (($361 | 0) == 0) {
   break;
  } else {
   $_0912_i_i37 = $_2_7_i_i45;
   $_013_i_i36 = $361;
   $tmp_014_i_i35 = $tmp_014_i_i35 + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i45; //@line 29477
 _fflush($fp | 0) | 0; //@line 29478
 $_0 = 0; //@line 29480
 STACKTOP = sp; //@line 29482
 return $_0 | 0; //@line 29483
}
function _pfdc2_save_chunk($fp, $ckid, $size, $data) {
 $fp = $fp | 0;
 $ckid = $ckid | 0;
 $size = $size | 0;
 $data = $data | 0;
 var $1 = 0, $tmp_014_i = 0, $_013_i = 0, $_0912_i = 0, $5 = 0, $7 = 0, $_2_i = 0, $10 = 0, $_2_1_i = 0, $13 = 0, $_2_2_i = 0, $16 = 0, $_2_3_i = 0, $19 = 0, $_2_4_i = 0, $22 = 0, $_2_5_i = 0, $25 = 0, $_2_6_i = 0, $28 = 0, $_2_7_i = 0, $31 = 0, $tmp_014_i_i12 = 0, $_013_i_i13 = 0, $_0912_i_i14 = 0, $40 = 0, $42 = 0, $_2_i_i15 = 0, $45 = 0, $_2_1_i_i16 = 0, $48 = 0, $_2_2_i_i17 = 0, $51 = 0, $_2_3_i_i18 = 0, $54 = 0, $_2_4_i_i19 = 0, $57 = 0, $_2_5_i_i20 = 0, $60 = 0, $_2_6_i_i21 = 0, $63 = 0, $_2_7_i_i22 = 0, $66 = 0, $tmp_014_i27 = 0, $_013_i28 = 0, $_0912_i29 = 0, $73 = 0, $75 = 0, $_2_i30 = 0, $78 = 0, $_2_1_i31 = 0, $81 = 0, $_2_2_i32 = 0, $84 = 0, $_2_3_i33 = 0, $87 = 0, $_2_4_i34 = 0, $90 = 0, $_2_5_i35 = 0, $93 = 0, $_2_6_i36 = 0, $96 = 0, $_2_7_i37 = 0, $99 = 0, $tmp_014_i_i40 = 0, $_013_i_i41 = 0, $_0912_i_i42 = 0, $107 = 0, $109 = 0, $_2_i_i43 = 0, $112 = 0, $_2_1_i_i44 = 0, $115 = 0, $_2_2_i_i45 = 0, $118 = 0, $_2_3_i_i46 = 0, $121 = 0, $_2_4_i_i47 = 0, $124 = 0, $_2_5_i_i48 = 0, $127 = 0, $_2_6_i_i49 = 0, $130 = 0, $_2_7_i_i50 = 0, $133 = 0, $crc_0 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_0912_i_i = 0, $143 = 0, $145 = 0, $_2_i_i = 0, $148 = 0, $_2_1_i_i = 0, $151 = 0, $_2_2_i_i = 0, $154 = 0, $_2_3_i_i = 0, $157 = 0, $_2_4_i_i = 0, $160 = 0, $_2_5_i_i = 0, $163 = 0, $_2_6_i_i = 0, $166 = 0, $_2_7_i_i = 0, $169 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 29521
 STACKTOP = STACKTOP + 8 | 0; //@line 29521
 $1 = sp | 0; //@line 29523
 _psi_set_uint16_be($1, 0, $ckid); //@line 29524
 _psi_set_uint16_be($1, 2, $size); //@line 29525
 $_0912_i = 0;
 $_013_i = 4;
 $tmp_014_i = $1;
 while (1) {
  $5 = (HEAPU8[$tmp_014_i] | 0) << 24 ^ $_0912_i; //@line 29534
  $7 = $5 << 1; //@line 29536
  $_2_i = ($5 | 0) < 0 ? $7 ^ 79764919 : $7; //@line 29538
  $10 = $_2_i << 1; //@line 29540
  $_2_1_i = ($_2_i | 0) < 0 ? $10 ^ 79764919 : $10; //@line 29542
  $13 = $_2_1_i << 1; //@line 29544
  $_2_2_i = ($_2_1_i | 0) < 0 ? $13 ^ 79764919 : $13; //@line 29546
  $16 = $_2_2_i << 1; //@line 29548
  $_2_3_i = ($_2_2_i | 0) < 0 ? $16 ^ 79764919 : $16; //@line 29550
  $19 = $_2_3_i << 1; //@line 29552
  $_2_4_i = ($_2_3_i | 0) < 0 ? $19 ^ 79764919 : $19; //@line 29554
  $22 = $_2_4_i << 1; //@line 29556
  $_2_5_i = ($_2_4_i | 0) < 0 ? $22 ^ 79764919 : $22; //@line 29558
  $25 = $_2_5_i << 1; //@line 29560
  $_2_6_i = ($_2_5_i | 0) < 0 ? $25 ^ 79764919 : $25; //@line 29562
  $28 = $_2_6_i << 1; //@line 29564
  $_2_7_i = ($_2_6_i | 0) < 0 ? $28 ^ 79764919 : $28; //@line 29566
  $31 = $_013_i - 1 | 0; //@line 29568
  if (($31 | 0) == 0) {
   break;
  } else {
   $_0912_i = $_2_7_i;
   $_013_i = $31;
   $tmp_014_i = $tmp_014_i + 1 | 0;
  }
 }
 if ((_psi_write($fp, $1, 4) | 0) != 0) {
  $_0 = 1; //@line 29581
  STACKTOP = sp; //@line 29583
  return $_0 | 0; //@line 29584
 }
 $_0912_i_i14 = HEAP32[15666] | 0;
 $_013_i_i13 = 4;
 $tmp_014_i_i12 = $1;
 while (1) {
  $40 = (HEAPU8[$tmp_014_i_i12] | 0) << 24 ^ $_0912_i_i14; //@line 29595
  $42 = $40 << 1; //@line 29597
  $_2_i_i15 = ($40 | 0) < 0 ? $42 ^ 79764919 : $42; //@line 29599
  $45 = $_2_i_i15 << 1; //@line 29601
  $_2_1_i_i16 = ($_2_i_i15 | 0) < 0 ? $45 ^ 79764919 : $45; //@line 29603
  $48 = $_2_1_i_i16 << 1; //@line 29605
  $_2_2_i_i17 = ($_2_1_i_i16 | 0) < 0 ? $48 ^ 79764919 : $48; //@line 29607
  $51 = $_2_2_i_i17 << 1; //@line 29609
  $_2_3_i_i18 = ($_2_2_i_i17 | 0) < 0 ? $51 ^ 79764919 : $51; //@line 29611
  $54 = $_2_3_i_i18 << 1; //@line 29613
  $_2_4_i_i19 = ($_2_3_i_i18 | 0) < 0 ? $54 ^ 79764919 : $54; //@line 29615
  $57 = $_2_4_i_i19 << 1; //@line 29617
  $_2_5_i_i20 = ($_2_4_i_i19 | 0) < 0 ? $57 ^ 79764919 : $57; //@line 29619
  $60 = $_2_5_i_i20 << 1; //@line 29621
  $_2_6_i_i21 = ($_2_5_i_i20 | 0) < 0 ? $60 ^ 79764919 : $60; //@line 29623
  $63 = $_2_6_i_i21 << 1; //@line 29625
  $_2_7_i_i22 = ($_2_6_i_i21 | 0) < 0 ? $63 ^ 79764919 : $63; //@line 29627
  $66 = $_013_i_i13 - 1 | 0; //@line 29629
  if (($66 | 0) == 0) {
   break;
  } else {
   $_0912_i_i14 = $_2_7_i_i22;
   $_013_i_i13 = $66;
   $tmp_014_i_i12 = $tmp_014_i_i12 + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i22; //@line 29638
 if (($size | 0) == 0) {
  $crc_0 = $_2_7_i; //@line 29642
 } else {
  $_0912_i29 = $_2_7_i;
  $_013_i28 = $size;
  $tmp_014_i27 = $data;
  while (1) {
   $73 = (HEAPU8[$tmp_014_i27] | 0) << 24 ^ $_0912_i29; //@line 29652
   $75 = $73 << 1; //@line 29654
   $_2_i30 = ($73 | 0) < 0 ? $75 ^ 79764919 : $75; //@line 29656
   $78 = $_2_i30 << 1; //@line 29658
   $_2_1_i31 = ($_2_i30 | 0) < 0 ? $78 ^ 79764919 : $78; //@line 29660
   $81 = $_2_1_i31 << 1; //@line 29662
   $_2_2_i32 = ($_2_1_i31 | 0) < 0 ? $81 ^ 79764919 : $81; //@line 29664
   $84 = $_2_2_i32 << 1; //@line 29666
   $_2_3_i33 = ($_2_2_i32 | 0) < 0 ? $84 ^ 79764919 : $84; //@line 29668
   $87 = $_2_3_i33 << 1; //@line 29670
   $_2_4_i34 = ($_2_3_i33 | 0) < 0 ? $87 ^ 79764919 : $87; //@line 29672
   $90 = $_2_4_i34 << 1; //@line 29674
   $_2_5_i35 = ($_2_4_i34 | 0) < 0 ? $90 ^ 79764919 : $90; //@line 29676
   $93 = $_2_5_i35 << 1; //@line 29678
   $_2_6_i36 = ($_2_5_i35 | 0) < 0 ? $93 ^ 79764919 : $93; //@line 29680
   $96 = $_2_6_i36 << 1; //@line 29682
   $_2_7_i37 = ($_2_6_i36 | 0) < 0 ? $96 ^ 79764919 : $96; //@line 29684
   $99 = $_013_i28 - 1 | 0; //@line 29686
   if (($99 | 0) == 0) {
    break;
   } else {
    $_0912_i29 = $_2_7_i37;
    $_013_i28 = $99;
    $tmp_014_i27 = $tmp_014_i27 + 1 | 0;
   }
  }
  if ((_psi_write($fp, $data, $size) | 0) != 0) {
   $_0 = 1; //@line 29699
   STACKTOP = sp; //@line 29701
   return $_0 | 0; //@line 29702
  }
  $_0912_i_i42 = HEAP32[15666] | 0;
  $_013_i_i41 = $size;
  $tmp_014_i_i40 = $data;
  while (1) {
   $107 = (HEAPU8[$tmp_014_i_i40] | 0) << 24 ^ $_0912_i_i42; //@line 29714
   $109 = $107 << 1; //@line 29716
   $_2_i_i43 = ($107 | 0) < 0 ? $109 ^ 79764919 : $109; //@line 29718
   $112 = $_2_i_i43 << 1; //@line 29720
   $_2_1_i_i44 = ($_2_i_i43 | 0) < 0 ? $112 ^ 79764919 : $112; //@line 29722
   $115 = $_2_1_i_i44 << 1; //@line 29724
   $_2_2_i_i45 = ($_2_1_i_i44 | 0) < 0 ? $115 ^ 79764919 : $115; //@line 29726
   $118 = $_2_2_i_i45 << 1; //@line 29728
   $_2_3_i_i46 = ($_2_2_i_i45 | 0) < 0 ? $118 ^ 79764919 : $118; //@line 29730
   $121 = $_2_3_i_i46 << 1; //@line 29732
   $_2_4_i_i47 = ($_2_3_i_i46 | 0) < 0 ? $121 ^ 79764919 : $121; //@line 29734
   $124 = $_2_4_i_i47 << 1; //@line 29736
   $_2_5_i_i48 = ($_2_4_i_i47 | 0) < 0 ? $124 ^ 79764919 : $124; //@line 29738
   $127 = $_2_5_i_i48 << 1; //@line 29740
   $_2_6_i_i49 = ($_2_5_i_i48 | 0) < 0 ? $127 ^ 79764919 : $127; //@line 29742
   $130 = $_2_6_i_i49 << 1; //@line 29744
   $_2_7_i_i50 = ($_2_6_i_i49 | 0) < 0 ? $130 ^ 79764919 : $130; //@line 29746
   $133 = $_013_i_i41 - 1 | 0; //@line 29748
   if (($133 | 0) == 0) {
    break;
   } else {
    $_0912_i_i42 = $_2_7_i_i50;
    $_013_i_i41 = $133;
    $tmp_014_i_i40 = $tmp_014_i_i40 + 1 | 0;
   }
  }
  HEAP32[15666] = $_2_7_i_i50; //@line 29757
  $crc_0 = $_2_7_i37; //@line 29759
 }
 _psi_set_uint32_be($1, 0, $crc_0); //@line 29762
 if ((_psi_write($fp, $1, 4) | 0) != 0) {
  $_0 = 1; //@line 29767
  STACKTOP = sp; //@line 29769
  return $_0 | 0; //@line 29770
 }
 $_0912_i_i = HEAP32[15666] | 0;
 $_013_i_i = 4;
 $tmp_014_i_i = $1;
 while (1) {
  $143 = (HEAPU8[$tmp_014_i_i] | 0) << 24 ^ $_0912_i_i; //@line 29781
  $145 = $143 << 1; //@line 29783
  $_2_i_i = ($143 | 0) < 0 ? $145 ^ 79764919 : $145; //@line 29785
  $148 = $_2_i_i << 1; //@line 29787
  $_2_1_i_i = ($_2_i_i | 0) < 0 ? $148 ^ 79764919 : $148; //@line 29789
  $151 = $_2_1_i_i << 1; //@line 29791
  $_2_2_i_i = ($_2_1_i_i | 0) < 0 ? $151 ^ 79764919 : $151; //@line 29793
  $154 = $_2_2_i_i << 1; //@line 29795
  $_2_3_i_i = ($_2_2_i_i | 0) < 0 ? $154 ^ 79764919 : $154; //@line 29797
  $157 = $_2_3_i_i << 1; //@line 29799
  $_2_4_i_i = ($_2_3_i_i | 0) < 0 ? $157 ^ 79764919 : $157; //@line 29801
  $160 = $_2_4_i_i << 1; //@line 29803
  $_2_5_i_i = ($_2_4_i_i | 0) < 0 ? $160 ^ 79764919 : $160; //@line 29805
  $163 = $_2_5_i_i << 1; //@line 29807
  $_2_6_i_i = ($_2_5_i_i | 0) < 0 ? $163 ^ 79764919 : $163; //@line 29809
  $166 = $_2_6_i_i << 1; //@line 29811
  $_2_7_i_i = ($_2_6_i_i | 0) < 0 ? $166 ^ 79764919 : $166; //@line 29813
  $169 = $_013_i_i - 1 | 0; //@line 29815
  if (($169 | 0) == 0) {
   break;
  } else {
   $_0912_i_i = $_2_7_i_i;
   $_013_i_i = $169;
   $tmp_014_i_i = $tmp_014_i_i + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i; //@line 29824
 $_0 = 0; //@line 29826
 STACKTOP = sp; //@line 29828
 return $_0 | 0; //@line 29829
}
function _pfdc2_save_sector($fp, $sct, $c, $h, $alt) {
 $fp = $fp | 0;
 $sct = $sct | 0;
 $c = $c | 0;
 $h = $h | 0;
 $alt = $alt | 0;
 var $buf = 0, $sct_idx_val = 0, $1 = 0, $f_1_i = 0, $f_1__i = 0, $f_3_i = 0, $11 = 0, $13 = 0, $_pre = 0, $cnt_0 = 0, $flg_0 = 0, $flg_1 = 0, $22 = 0, $sct_idx34_val = 0, $23 = 0, $enc_0_load109_off0 = 0, $dr_0_load108 = 0, $47 = 0, $48 = 0, $tmp_014_i = 0, $_013_i = 0, $_0912_i = 0, $58 = 0, $60 = 0, $_2_i = 0, $63 = 0, $_2_1_i = 0, $66 = 0, $_2_2_i = 0, $69 = 0, $_2_3_i = 0, $72 = 0, $_2_4_i = 0, $75 = 0, $_2_5_i = 0, $78 = 0, $_2_6_i = 0, $81 = 0, $_2_7_i = 0, $84 = 0, $tmp_014_i_i50 = 0, $_013_i_i51 = 0, $_0912_i_i52 = 0, $93 = 0, $95 = 0, $_2_i_i53 = 0, $98 = 0, $_2_1_i_i54 = 0, $101 = 0, $_2_2_i_i55 = 0, $104 = 0, $_2_3_i_i56 = 0, $107 = 0, $_2_4_i_i57 = 0, $110 = 0, $_2_5_i_i58 = 0, $113 = 0, $_2_6_i_i59 = 0, $116 = 0, $_2_7_i_i60 = 0, $119 = 0, $124 = 0, $125 = 0, $128 = 0, $130 = 0, $_2_i69 = 0, $133 = 0, $_2_1_i70 = 0, $136 = 0, $_2_2_i71 = 0, $139 = 0, $_2_3_i72 = 0, $142 = 0, $_2_4_i73 = 0, $145 = 0, $_2_5_i74 = 0, $148 = 0, $_2_6_i75 = 0, $150 = 0, $159 = 0, $161 = 0, $_2_i_i95 = 0, $164 = 0, $_2_1_i_i96 = 0, $167 = 0, $_2_2_i_i97 = 0, $170 = 0, $_2_3_i_i98 = 0, $173 = 0, $_2_4_i_i99 = 0, $176 = 0, $_2_5_i_i100 = 0, $179 = 0, $_2_6_i_i101 = 0, $182 = 0, $185 = 0, $186 = 0, $187 = 0, $tmp_014_i79 = 0, $_013_i80 = 0, $_0912_i81 = 0, $191 = 0, $193 = 0, $_2_i82 = 0, $196 = 0, $_2_1_i83 = 0, $199 = 0, $_2_2_i84 = 0, $202 = 0, $_2_3_i85 = 0, $205 = 0, $_2_4_i86 = 0, $208 = 0, $_2_5_i87 = 0, $211 = 0, $_2_6_i88 = 0, $214 = 0, $_2_7_i89 = 0, $217 = 0, $_pre_phi = 0, $_09_lcssa_i = 0, $222 = 0, $tmp_014_i_i35 = 0, $_013_i_i36 = 0, $_0912_i_i37 = 0, $226 = 0, $228 = 0, $_2_i_i38 = 0, $231 = 0, $_2_1_i_i39 = 0, $234 = 0, $_2_2_i_i40 = 0, $237 = 0, $_2_3_i_i41 = 0, $240 = 0, $_2_4_i_i42 = 0, $243 = 0, $_2_5_i_i43 = 0, $246 = 0, $_2_6_i_i44 = 0, $249 = 0, $_2_7_i_i45 = 0, $252 = 0, $storemerge = 0, $crc_0 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_0912_i_i = 0, $261 = 0, $263 = 0, $_2_i_i = 0, $266 = 0, $_2_1_i_i = 0, $269 = 0, $_2_2_i_i = 0, $272 = 0, $_2_3_i_i = 0, $275 = 0, $_2_4_i_i = 0, $278 = 0, $_2_5_i_i = 0, $281 = 0, $_2_6_i_i = 0, $284 = 0, $_2_7_i_i = 0, $287 = 0, $290 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 29887
 STACKTOP = STACKTOP + 256 | 0; //@line 29887
 $buf = sp | 0; //@line 29888
 $sct_idx_val = HEAP32[$sct + 12 >> 2] | 0; //@line 29890
 $1 = $sct_idx_val & 1; //@line 29891
 $f_1_i = ($sct_idx_val & 2 | 0) == 0 ? $1 : $1 | 2; //@line 29895
 $f_1__i = ($sct_idx_val & 4 | 0) == 0 ? $f_1_i : $f_1_i | 4; //@line 29899
 $f_3_i = ($sct_idx_val & 8 | 0) == 0 ? $f_1__i : $f_1__i | 8; //@line 29903
 $11 = $f_3_i & 255; //@line 29904
 $13 = (_psi_sct_uniform($sct) | 0) == 0; //@line 29906
 $_pre = HEAP16[$sct + 10 >> 1] | 0; //@line 29908
 do {
  if ($13) {
   $flg_0 = $11;
   $cnt_0 = ($_pre & 65535) + 12 | 0;
  } else {
   if ($_pre << 16 >> 16 == 0) {
    $flg_0 = $11;
    $cnt_0 = 12;
    break;
   }
   $flg_0 = ($f_3_i | 128) & 255;
   $cnt_0 = 13;
  }
 } while (0);
 $flg_1 = ($alt | 0) == 0 ? $flg_0 : $flg_0 | 64; //@line 29933
 $22 = $buf | 0; //@line 29934
 _psi_set_uint16_be($22, 0, 21315); //@line 29935
 _psi_set_uint16_be($22, 2, $cnt_0); //@line 29936
 $sct_idx34_val = HEAP16[$sct + 16 >> 1] | 0; //@line 29938
 $23 = $sct_idx34_val & 65535; //@line 29939
 if (($23 | 0) == 16386) {
  $dr_0_load108 = 1e6;
  $enc_0_load109_off0 = 2;
 } else if (($23 | 0) == 32769) {
  $dr_0_load108 = 25e4;
  $enc_0_load109_off0 = 1;
 } else if (($23 | 0) == 3) {
  $dr_0_load108 = 5e5;
  $enc_0_load109_off0 = $sct_idx34_val & 255;
 } else if (($23 | 0) == 32770) {
  $dr_0_load108 = 5e5;
  $enc_0_load109_off0 = 2;
 } else if (($23 | 0) == 2) {
  $dr_0_load108 = 25e4;
  $enc_0_load109_off0 = $sct_idx34_val & 255;
 } else if (($23 | 0) == 1) {
  $dr_0_load108 = 125e3;
  $enc_0_load109_off0 = 1;
 } else {
  $dr_0_load108 = 0;
  $enc_0_load109_off0 = 0;
 }
 _psi_set_uint32_be($22, 12, $dr_0_load108); //@line 29965
 HEAP8[$buf + 4 | 0] = $flg_1; //@line 29967
 HEAP8[$buf + 5 | 0] = $c & 255; //@line 29970
 HEAP8[$buf + 6 | 0] = $h & 255; //@line 29973
 HEAP8[$buf + 7 | 0] = HEAP16[$sct + 4 >> 1] & 255; //@line 29978
 HEAP8[$buf + 8 | 0] = HEAP16[$sct + 6 >> 1] & 255; //@line 29983
 HEAP8[$buf + 9 | 0] = HEAP16[$sct + 8 >> 1] & 255; //@line 29988
 $47 = $sct + 10 | 0; //@line 29989
 $48 = HEAP16[$47 >> 1] | 0; //@line 29990
 HEAP8[$buf + 10 | 0] = ($48 & 65535) >>> 8 & 255; //@line 29994
 HEAP8[$buf + 11 | 0] = $48 & 255; //@line 29997
 HEAP8[$buf + 12 | 0] = $enc_0_load109_off0; //@line 29999
 $_0912_i = 0;
 $_013_i = 16;
 $tmp_014_i = $22;
 while (1) {
  $58 = (HEAPU8[$tmp_014_i] | 0) << 24 ^ $_0912_i; //@line 30008
  $60 = $58 << 1; //@line 30010
  $_2_i = ($58 | 0) < 0 ? $60 ^ 79764919 : $60; //@line 30012
  $63 = $_2_i << 1; //@line 30014
  $_2_1_i = ($_2_i | 0) < 0 ? $63 ^ 79764919 : $63; //@line 30016
  $66 = $_2_1_i << 1; //@line 30018
  $_2_2_i = ($_2_1_i | 0) < 0 ? $66 ^ 79764919 : $66; //@line 30020
  $69 = $_2_2_i << 1; //@line 30022
  $_2_3_i = ($_2_2_i | 0) < 0 ? $69 ^ 79764919 : $69; //@line 30024
  $72 = $_2_3_i << 1; //@line 30026
  $_2_4_i = ($_2_3_i | 0) < 0 ? $72 ^ 79764919 : $72; //@line 30028
  $75 = $_2_4_i << 1; //@line 30030
  $_2_5_i = ($_2_4_i | 0) < 0 ? $75 ^ 79764919 : $75; //@line 30032
  $78 = $_2_5_i << 1; //@line 30034
  $_2_6_i = ($_2_5_i | 0) < 0 ? $78 ^ 79764919 : $78; //@line 30036
  $81 = $_2_6_i << 1; //@line 30038
  $_2_7_i = ($_2_6_i | 0) < 0 ? $81 ^ 79764919 : $81; //@line 30040
  $84 = $_013_i - 1 | 0; //@line 30042
  if (($84 | 0) == 0) {
   break;
  } else {
   $_0912_i = $_2_7_i;
   $_013_i = $84;
   $tmp_014_i = $tmp_014_i + 1 | 0;
  }
 }
 if ((_psi_write($fp, $22, 16) | 0) != 0) {
  $_0 = 1; //@line 30055
  STACKTOP = sp; //@line 30057
  return $_0 | 0; //@line 30058
 }
 $_0912_i_i52 = HEAP32[15666] | 0;
 $_013_i_i51 = 16;
 $tmp_014_i_i50 = $22;
 while (1) {
  $93 = (HEAPU8[$tmp_014_i_i50] | 0) << 24 ^ $_0912_i_i52; //@line 30069
  $95 = $93 << 1; //@line 30071
  $_2_i_i53 = ($93 | 0) < 0 ? $95 ^ 79764919 : $95; //@line 30073
  $98 = $_2_i_i53 << 1; //@line 30075
  $_2_1_i_i54 = ($_2_i_i53 | 0) < 0 ? $98 ^ 79764919 : $98; //@line 30077
  $101 = $_2_1_i_i54 << 1; //@line 30079
  $_2_2_i_i55 = ($_2_1_i_i54 | 0) < 0 ? $101 ^ 79764919 : $101; //@line 30081
  $104 = $_2_2_i_i55 << 1; //@line 30083
  $_2_3_i_i56 = ($_2_2_i_i55 | 0) < 0 ? $104 ^ 79764919 : $104; //@line 30085
  $107 = $_2_3_i_i56 << 1; //@line 30087
  $_2_4_i_i57 = ($_2_3_i_i56 | 0) < 0 ? $107 ^ 79764919 : $107; //@line 30089
  $110 = $_2_4_i_i57 << 1; //@line 30091
  $_2_5_i_i58 = ($_2_4_i_i57 | 0) < 0 ? $110 ^ 79764919 : $110; //@line 30093
  $113 = $_2_5_i_i58 << 1; //@line 30095
  $_2_6_i_i59 = ($_2_5_i_i58 | 0) < 0 ? $113 ^ 79764919 : $113; //@line 30097
  $116 = $_2_6_i_i59 << 1; //@line 30099
  $_2_7_i_i60 = ($_2_6_i_i59 | 0) < 0 ? $116 ^ 79764919 : $116; //@line 30101
  $119 = $_013_i_i51 - 1 | 0; //@line 30103
  if (($119 | 0) == 0) {
   break;
  } else {
   $_0912_i_i52 = $_2_7_i_i60;
   $_013_i_i51 = $119;
   $tmp_014_i_i50 = $tmp_014_i_i50 + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i60; //@line 30112
 $124 = HEAP32[$sct + 24 >> 2] | 0; //@line 30115
 do {
  if ($flg_1 << 24 >> 24 < 0) {
   $125 = HEAP8[$124] | 0; //@line 30119
   HEAP8[$22] = $125; //@line 30120
   $128 = ($125 & 255) << 24 ^ $_2_7_i; //@line 30123
   $130 = $128 << 1; //@line 30125
   $_2_i69 = ($128 | 0) < 0 ? $130 ^ 79764919 : $130; //@line 30127
   $133 = $_2_i69 << 1; //@line 30129
   $_2_1_i70 = ($_2_i69 | 0) < 0 ? $133 ^ 79764919 : $133; //@line 30131
   $136 = $_2_1_i70 << 1; //@line 30133
   $_2_2_i71 = ($_2_1_i70 | 0) < 0 ? $136 ^ 79764919 : $136; //@line 30135
   $139 = $_2_2_i71 << 1; //@line 30137
   $_2_3_i72 = ($_2_2_i71 | 0) < 0 ? $139 ^ 79764919 : $139; //@line 30139
   $142 = $_2_3_i72 << 1; //@line 30141
   $_2_4_i73 = ($_2_3_i72 | 0) < 0 ? $142 ^ 79764919 : $142; //@line 30143
   $145 = $_2_4_i73 << 1; //@line 30145
   $_2_5_i74 = ($_2_4_i73 | 0) < 0 ? $145 ^ 79764919 : $145; //@line 30147
   $148 = $_2_5_i74 << 1; //@line 30149
   $_2_6_i75 = ($_2_5_i74 | 0) < 0 ? $148 ^ 79764919 : $148; //@line 30151
   $150 = $_2_6_i75 << 1; //@line 30152
   if ((_psi_write($fp, $22, 1) | 0) == 0) {
    $159 = (HEAPU8[$22] | 0) << 24 ^ HEAP32[15666]; //@line 30164
    $161 = $159 << 1; //@line 30166
    $_2_i_i95 = ($159 | 0) < 0 ? $161 ^ 79764919 : $161; //@line 30168
    $164 = $_2_i_i95 << 1; //@line 30170
    $_2_1_i_i96 = ($_2_i_i95 | 0) < 0 ? $164 ^ 79764919 : $164; //@line 30172
    $167 = $_2_1_i_i96 << 1; //@line 30174
    $_2_2_i_i97 = ($_2_1_i_i96 | 0) < 0 ? $167 ^ 79764919 : $167; //@line 30176
    $170 = $_2_2_i_i97 << 1; //@line 30178
    $_2_3_i_i98 = ($_2_2_i_i97 | 0) < 0 ? $170 ^ 79764919 : $170; //@line 30180
    $173 = $_2_3_i_i98 << 1; //@line 30182
    $_2_4_i_i99 = ($_2_3_i_i98 | 0) < 0 ? $173 ^ 79764919 : $173; //@line 30184
    $176 = $_2_4_i_i99 << 1; //@line 30186
    $_2_5_i_i100 = ($_2_4_i_i99 | 0) < 0 ? $176 ^ 79764919 : $176; //@line 30188
    $179 = $_2_5_i_i100 << 1; //@line 30190
    $_2_6_i_i101 = ($_2_5_i_i100 | 0) < 0 ? $179 ^ 79764919 : $179; //@line 30192
    $182 = $_2_6_i_i101 << 1; //@line 30194
    $crc_0 = ($_2_6_i75 | 0) < 0 ? $150 ^ 79764919 : $150;
    $storemerge = ($_2_6_i_i101 | 0) < 0 ? $182 ^ 79764919 : $182;
    break;
   } else {
    $_0 = 1; //@line 30200
    STACKTOP = sp; //@line 30202
    return $_0 | 0; //@line 30203
   }
  } else {
   $185 = HEAP16[$47 >> 1] | 0; //@line 30206
   $186 = $185 << 16 >> 16 == 0; //@line 30207
   if ($186) {
    $_09_lcssa_i = $_2_7_i;
    $_pre_phi = 0;
   } else {
    $187 = $185 & 65535; //@line 30212
    $_0912_i81 = $_2_7_i;
    $_013_i80 = $187;
    $tmp_014_i79 = $124;
    while (1) {
     $191 = (HEAPU8[$tmp_014_i79] | 0) << 24 ^ $_0912_i81; //@line 30222
     $193 = $191 << 1; //@line 30224
     $_2_i82 = ($191 | 0) < 0 ? $193 ^ 79764919 : $193; //@line 30226
     $196 = $_2_i82 << 1; //@line 30228
     $_2_1_i83 = ($_2_i82 | 0) < 0 ? $196 ^ 79764919 : $196; //@line 30230
     $199 = $_2_1_i83 << 1; //@line 30232
     $_2_2_i84 = ($_2_1_i83 | 0) < 0 ? $199 ^ 79764919 : $199; //@line 30234
     $202 = $_2_2_i84 << 1; //@line 30236
     $_2_3_i85 = ($_2_2_i84 | 0) < 0 ? $202 ^ 79764919 : $202; //@line 30238
     $205 = $_2_3_i85 << 1; //@line 30240
     $_2_4_i86 = ($_2_3_i85 | 0) < 0 ? $205 ^ 79764919 : $205; //@line 30242
     $208 = $_2_4_i86 << 1; //@line 30244
     $_2_5_i87 = ($_2_4_i86 | 0) < 0 ? $208 ^ 79764919 : $208; //@line 30246
     $211 = $_2_5_i87 << 1; //@line 30248
     $_2_6_i88 = ($_2_5_i87 | 0) < 0 ? $211 ^ 79764919 : $211; //@line 30250
     $214 = $_2_6_i88 << 1; //@line 30252
     $_2_7_i89 = ($_2_6_i88 | 0) < 0 ? $214 ^ 79764919 : $214; //@line 30254
     $217 = $_013_i80 - 1 | 0; //@line 30256
     if (($217 | 0) == 0) {
      $_09_lcssa_i = $_2_7_i89;
      $_pre_phi = $187;
      break;
     } else {
      $_0912_i81 = $_2_7_i89;
      $_013_i80 = $217;
      $tmp_014_i79 = $tmp_014_i79 + 1 | 0;
     }
    }
   }
   if ((_psi_write($fp, $124, $_pre_phi) | 0) != 0) {
    $_0 = 1; //@line 30273
    STACKTOP = sp; //@line 30275
    return $_0 | 0; //@line 30276
   }
   $222 = HEAP32[15666] | 0; //@line 30278
   if ($186) {
    $crc_0 = $_09_lcssa_i;
    $storemerge = $222;
    break;
   } else {
    $_0912_i_i37 = $222;
    $_013_i_i36 = $_pre_phi;
    $tmp_014_i_i35 = $124;
   }
   while (1) {
    $226 = (HEAPU8[$tmp_014_i_i35] | 0) << 24 ^ $_0912_i_i37; //@line 30293
    $228 = $226 << 1; //@line 30295
    $_2_i_i38 = ($226 | 0) < 0 ? $228 ^ 79764919 : $228; //@line 30297
    $231 = $_2_i_i38 << 1; //@line 30299
    $_2_1_i_i39 = ($_2_i_i38 | 0) < 0 ? $231 ^ 79764919 : $231; //@line 30301
    $234 = $_2_1_i_i39 << 1; //@line 30303
    $_2_2_i_i40 = ($_2_1_i_i39 | 0) < 0 ? $234 ^ 79764919 : $234; //@line 30305
    $237 = $_2_2_i_i40 << 1; //@line 30307
    $_2_3_i_i41 = ($_2_2_i_i40 | 0) < 0 ? $237 ^ 79764919 : $237; //@line 30309
    $240 = $_2_3_i_i41 << 1; //@line 30311
    $_2_4_i_i42 = ($_2_3_i_i41 | 0) < 0 ? $240 ^ 79764919 : $240; //@line 30313
    $243 = $_2_4_i_i42 << 1; //@line 30315
    $_2_5_i_i43 = ($_2_4_i_i42 | 0) < 0 ? $243 ^ 79764919 : $243; //@line 30317
    $246 = $_2_5_i_i43 << 1; //@line 30319
    $_2_6_i_i44 = ($_2_5_i_i43 | 0) < 0 ? $246 ^ 79764919 : $246; //@line 30321
    $249 = $_2_6_i_i44 << 1; //@line 30323
    $_2_7_i_i45 = ($_2_6_i_i44 | 0) < 0 ? $249 ^ 79764919 : $249; //@line 30325
    $252 = $_013_i_i36 - 1 | 0; //@line 30327
    if (($252 | 0) == 0) {
     $crc_0 = $_09_lcssa_i;
     $storemerge = $_2_7_i_i45;
     break;
    } else {
     $_0912_i_i37 = $_2_7_i_i45;
     $_013_i_i36 = $252;
     $tmp_014_i_i35 = $tmp_014_i_i35 + 1 | 0;
    }
   }
  }
 } while (0);
 HEAP32[15666] = $storemerge; //@line 30341
 _psi_set_uint32_be($22, 0, $crc_0); //@line 30342
 if ((_psi_write($fp, $22, 4) | 0) != 0) {
  $_0 = 1; //@line 30347
  STACKTOP = sp; //@line 30349
  return $_0 | 0; //@line 30350
 }
 $_0912_i_i = HEAP32[15666] | 0;
 $_013_i_i = 4;
 $tmp_014_i_i = $22;
 while (1) {
  $261 = (HEAPU8[$tmp_014_i_i] | 0) << 24 ^ $_0912_i_i; //@line 30361
  $263 = $261 << 1; //@line 30363
  $_2_i_i = ($261 | 0) < 0 ? $263 ^ 79764919 : $263; //@line 30365
  $266 = $_2_i_i << 1; //@line 30367
  $_2_1_i_i = ($_2_i_i | 0) < 0 ? $266 ^ 79764919 : $266; //@line 30369
  $269 = $_2_1_i_i << 1; //@line 30371
  $_2_2_i_i = ($_2_1_i_i | 0) < 0 ? $269 ^ 79764919 : $269; //@line 30373
  $272 = $_2_2_i_i << 1; //@line 30375
  $_2_3_i_i = ($_2_2_i_i | 0) < 0 ? $272 ^ 79764919 : $272; //@line 30377
  $275 = $_2_3_i_i << 1; //@line 30379
  $_2_4_i_i = ($_2_3_i_i | 0) < 0 ? $275 ^ 79764919 : $275; //@line 30381
  $278 = $_2_4_i_i << 1; //@line 30383
  $_2_5_i_i = ($_2_4_i_i | 0) < 0 ? $278 ^ 79764919 : $278; //@line 30385
  $281 = $_2_5_i_i << 1; //@line 30387
  $_2_6_i_i = ($_2_5_i_i | 0) < 0 ? $281 ^ 79764919 : $281; //@line 30389
  $284 = $_2_6_i_i << 1; //@line 30391
  $_2_7_i_i = ($_2_6_i_i | 0) < 0 ? $284 ^ 79764919 : $284; //@line 30393
  $287 = $_013_i_i - 1 | 0; //@line 30395
  if (($287 | 0) == 0) {
   break;
  } else {
   $_0912_i_i = $_2_7_i_i;
   $_013_i_i = $287;
   $tmp_014_i_i = $tmp_014_i_i + 1 | 0;
  }
 }
 HEAP32[15666] = $_2_7_i_i; //@line 30404
 $290 = _psi_sct_get_tags($sct, $22, 256) | 0; //@line 30405
 do {
  if (($290 | 0) != 0) {
   if ((_pfdc2_save_chunk($fp, 21575, $290, $22) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 30416
   }
   STACKTOP = sp; //@line 30419
   return $_0 | 0; //@line 30420
  }
 } while (0);
 $_0 = 0; //@line 30424
 STACKTOP = sp; //@line 30426
 return $_0 | 0; //@line 30427
}
function _pfdc4_load_fp($fp, $img, $id, $sz) {
 $fp = $fp | 0;
 $img = $img | 0;
 $id = $id | 0;
 $sz = $sz | 0;
 var $buf_i99 = 0, $buf_i59 = 0, $buf_i21 = 0, $buf_i = 0, $buf = 0, $1 = 0, $i_017_i = 0, $3 = 0, $reg_1_i = 0, $6 = 0, $reg_1_1_i = 0, $9 = 0, $reg_1_2_i = 0, $12 = 0, $reg_1_3_i = 0, $15 = 0, $reg_1_4_i = 0, $18 = 0, $reg_1_5_i = 0, $21 = 0, $reg_1_6_i = 0, $24 = 0, $30 = 0, $34 = 0, $36 = 0, $43 = 0, $45 = 0, $52 = 0, $54 = 0, $61 = 0, $63 = 0, $70 = 0, $72 = 0, $79 = 0, $81 = 0, $88 = 0, $96 = 0, $97 = 0, $i_017_i_i = 0, $104 = 0, $reg_1_i_i = 0, $107 = 0, $reg_1_1_i_i = 0, $110 = 0, $reg_1_2_i_i = 0, $113 = 0, $reg_1_3_i_i = 0, $116 = 0, $reg_1_4_i_i = 0, $119 = 0, $reg_1_5_i_i = 0, $122 = 0, $reg_1_6_i_i = 0, $125 = 0, $139 = 0, $148 = 0, $157 = 0, $165 = 0, $166 = 0, $169 = 0, $172 = 0, $173 = 0, $_08_i42_i = 0, $crc333541_i = 0, $176 = 0, $i_017_i10_i = 0, $181 = 0, $reg_1_i12_i = 0, $184 = 0, $reg_1_1_i13_i = 0, $187 = 0, $reg_1_2_i14_i = 0, $190 = 0, $reg_1_3_i15_i = 0, $193 = 0, $reg_1_4_i16_i = 0, $196 = 0, $reg_1_5_i17_i = 0, $199 = 0, $reg_1_6_i18_i = 0, $202 = 0, $src_013_i22_i = 0, $_012_i23_i = 0, $_01011_i24_i = 0, $217 = 0, $218 = 0, $crc3334_ph_i = 0, $crc3335_lcssa_i = 0, $227 = 0, $228 = 0, $229 = 0, $230 = 0, $232 = 0, $i_017_i26 = 0, $236 = 0, $reg_1_i28 = 0, $239 = 0, $reg_1_1_i29 = 0, $242 = 0, $reg_1_2_i30 = 0, $245 = 0, $reg_1_3_i31 = 0, $248 = 0, $reg_1_4_i32 = 0, $251 = 0, $reg_1_5_i33 = 0, $254 = 0, $reg_1_6_i34 = 0, $257 = 0, $266 = 0, $274 = 0, $282 = 0, $290 = 0, $298 = 0, $306 = 0, $314 = 0, $322 = 0, $323 = 0, $324 = 0, $_08_i17_i = 0, $crc1116_i = 0, $328 = 0, $i_017_i_i46 = 0, $333 = 0, $reg_1_i_i48 = 0, $336 = 0, $reg_1_1_i_i49 = 0, $339 = 0, $reg_1_2_i_i50 = 0, $342 = 0, $reg_1_3_i_i51 = 0, $345 = 0, $reg_1_4_i_i52 = 0, $348 = 0, $reg_1_5_i_i53 = 0, $351 = 0, $reg_1_6_i_i54 = 0, $354 = 0, $src_013_i_i = 0, $_012_i_i = 0, $_01011_i_i = 0, $369 = 0, $370 = 0, $crc10_ph_i = 0, $crc11_lcssa_i = 0, $380 = 0, $i_017_i_i61 = 0, $390 = 0, $reg_1_i_i63 = 0, $393 = 0, $reg_1_1_i_i64 = 0, $396 = 0, $reg_1_2_i_i65 = 0, $399 = 0, $reg_1_3_i_i66 = 0, $402 = 0, $reg_1_4_i_i67 = 0, $405 = 0, $reg_1_5_i_i68 = 0, $408 = 0, $reg_1_6_i_i69 = 0, $411 = 0, $src_013_i_i72 = 0, $_012_i_i73 = 0, $_01011_i_i74 = 0, $425 = 0, $426 = 0, $429 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $444 = 0, $451 = 0, $458 = 0, $465 = 0, $468 = 0, $484 = 0, $_08_i60_i = 0, $crc515359_i = 0, $493 = 0, $i_017_i28_i = 0, $498 = 0, $reg_1_i30_i = 0, $501 = 0, $reg_1_1_i31_i = 0, $504 = 0, $reg_1_2_i32_i = 0, $507 = 0, $reg_1_3_i33_i = 0, $510 = 0, $reg_1_4_i34_i = 0, $513 = 0, $reg_1_5_i35_i = 0, $516 = 0, $reg_1_6_i36_i = 0, $519 = 0, $src_013_i40_i = 0, $_012_i41_i = 0, $_01011_i42_i = 0, $534 = 0, $535 = 0, $crc5152_ph_i = 0, $crc5153_lcssa_i = 0, $_ph = 0, $546 = 0, $547 = 0, $548 = 0, $550 = 0, $555 = 0, $_size_i = 0, $559 = 0, $i_017_i_i80 = 0, $564 = 0, $reg_1_i_i82 = 0, $567 = 0, $reg_1_1_i_i83 = 0, $570 = 0, $reg_1_2_i_i84 = 0, $573 = 0, $reg_1_3_i_i85 = 0, $576 = 0, $reg_1_4_i_i86 = 0, $579 = 0, $reg_1_5_i_i87 = 0, $582 = 0, $reg_1_6_i_i88 = 0, $585 = 0, $src_013_i_i91 = 0, $_012_i_i92 = 0, $_01011_i_i93 = 0, $599 = 0, $600 = 0, $crc30_i = 0, $_08_i38_i = 0, $crc303237_i = 0, $606 = 0, $i_017_i5_i = 0, $611 = 0, $reg_1_i7_i = 0, $614 = 0, $reg_1_1_i8_i = 0, $617 = 0, $reg_1_2_i9_i = 0, $620 = 0, $reg_1_3_i10_i = 0, $623 = 0, $reg_1_4_i11_i = 0, $626 = 0, $reg_1_5_i12_i = 0, $629 = 0, $reg_1_6_i13_i = 0, $632 = 0, $src_013_i17_i = 0, $_012_i18_i = 0, $_01011_i19_i = 0, $647 = 0, $648 = 0, $crc3031_ph_i = 0, $crc3032_lcssa_i = 0, $663 = 0, $i_017_i_i101 = 0, $668 = 0, $reg_1_i_i103 = 0, $671 = 0, $reg_1_1_i_i104 = 0, $674 = 0, $reg_1_2_i_i105 = 0, $677 = 0, $reg_1_3_i_i106 = 0, $680 = 0, $reg_1_4_i_i107 = 0, $683 = 0, $reg_1_5_i_i108 = 0, $686 = 0, $reg_1_6_i_i109 = 0, $689 = 0, $src_013_i_i113 = 0, $_012_i_i114 = 0, $_01011_i_i115 = 0, $704 = 0, $705 = 0, $crc38_ph_i = 0, $_08_i47_i = 0, $crc384046_i = 0, $712 = 0, $i_017_i14_i = 0, $717 = 0, $reg_1_i16_i = 0, $720 = 0, $reg_1_1_i17_i = 0, $723 = 0, $reg_1_2_i18_i = 0, $726 = 0, $reg_1_3_i19_i = 0, $729 = 0, $reg_1_4_i20_i = 0, $732 = 0, $reg_1_5_i21_i = 0, $735 = 0, $reg_1_6_i22_i = 0, $738 = 0, $src_013_i26_i = 0, $_012_i27_i = 0, $_01011_i28_i = 0, $753 = 0, $754 = 0, $crc3839_ph_i = 0, $crc3840_lcssa_i = 0, $778 = 0, $i_017_i_i121 = 0, $785 = 0, $reg_1_i_i123 = 0, $788 = 0, $reg_1_1_i_i124 = 0, $791 = 0, $reg_1_2_i_i125 = 0, $794 = 0, $reg_1_3_i_i126 = 0, $797 = 0, $reg_1_4_i_i127 = 0, $800 = 0, $reg_1_5_i_i128 = 0, $803 = 0, $reg_1_6_i_i129 = 0, $806 = 0, $src_013_i_i132 = 0, $_012_i_i133 = 0, $_01011_i_i134 = 0, $820 = 0, $821 = 0, $825 = 0, $_size_i136 = 0, $829 = 0, $n_1_i = 0, $835 = 0, $842 = 0, $_0_i24_i = 0, $_08_i197 = 0, $850 = 0, $852 = 0, $i_017_i142 = 0, $857 = 0, $reg_1_i144 = 0, $860 = 0, $reg_1_1_i145 = 0, $863 = 0, $reg_1_2_i146 = 0, $866 = 0, $reg_1_3_i147 = 0, $869 = 0, $reg_1_4_i148 = 0, $872 = 0, $reg_1_5_i149 = 0, $875 = 0, $reg_1_6_i150 = 0, $878 = 0, $src_013_i154 = 0, $_012_i155 = 0, $_01011_i156 = 0, $893 = 0, $894 = 0, $_ph178 = 0, $_lcssa195 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 30567
 STACKTOP = STACKTOP + 560 | 0; //@line 30567
 $buf_i99 = sp | 0; //@line 30568
 $buf_i59 = sp + 256 | 0; //@line 30569
 $buf_i21 = sp + 288 | 0; //@line 30570
 $buf_i = sp + 296 | 0; //@line 30571
 $buf = sp + 552 | 0; //@line 30572
 $1 = $buf | 0; //@line 30573
 _psi_set_uint32_be($1, 0, $id); //@line 30574
 _psi_set_uint32_be($1, 4, $sz); //@line 30575
 if (!(HEAP8[6664] | 0)) {
  $i_017_i = 0; //@line 30579
  do {
   $3 = $i_017_i << 25; //@line 30584
   $reg_1_i = ($i_017_i & 128 | 0) != 0 ? $3 ^ 517762881 : $3; //@line 30586
   $6 = $reg_1_i << 1; //@line 30588
   $reg_1_1_i = ($reg_1_i | 0) < 0 ? $6 ^ 517762881 : $6; //@line 30590
   $9 = $reg_1_1_i << 1; //@line 30592
   $reg_1_2_i = ($reg_1_1_i | 0) < 0 ? $9 ^ 517762881 : $9; //@line 30594
   $12 = $reg_1_2_i << 1; //@line 30596
   $reg_1_3_i = ($reg_1_2_i | 0) < 0 ? $12 ^ 517762881 : $12; //@line 30598
   $15 = $reg_1_3_i << 1; //@line 30600
   $reg_1_4_i = ($reg_1_3_i | 0) < 0 ? $15 ^ 517762881 : $15; //@line 30602
   $18 = $reg_1_4_i << 1; //@line 30604
   $reg_1_5_i = ($reg_1_4_i | 0) < 0 ? $18 ^ 517762881 : $18; //@line 30606
   $21 = $reg_1_5_i << 1; //@line 30608
   $reg_1_6_i = ($reg_1_5_i | 0) < 0 ? $21 ^ 517762881 : $21; //@line 30610
   $24 = $reg_1_6_i << 1; //@line 30612
   HEAP32[60264 + ($i_017_i << 2) >> 2] = ($reg_1_6_i | 0) < 0 ? $24 ^ 517762881 : $24; //@line 30616
   $i_017_i = $i_017_i + 1 | 0; //@line 30617
  } while ($i_017_i >>> 0 < 256);
  HEAP8[6664] = 1; //@line 30626
 }
 $30 = $buf + 1 | 0; //@line 30629
 $34 = HEAP32[60264 + (HEAPU8[$1] << 2) >> 2] | 0; //@line 30633
 $36 = $buf + 2 | 0; //@line 30635
 $43 = HEAP32[60264 + ((HEAPU8[$30] ^ $34 >>> 24) << 2) >> 2] ^ $34 << 8; //@line 30642
 $45 = $buf + 3 | 0; //@line 30644
 $52 = HEAP32[60264 + ((HEAPU8[$36] ^ $43 >>> 24) << 2) >> 2] ^ $43 << 8; //@line 30651
 $54 = $buf + 4 | 0; //@line 30653
 $61 = HEAP32[60264 + ((HEAPU8[$45] ^ $52 >>> 24) << 2) >> 2] ^ $52 << 8; //@line 30660
 $63 = $buf + 5 | 0; //@line 30662
 $70 = HEAP32[60264 + ((HEAPU8[$54] ^ $61 >>> 24) << 2) >> 2] ^ $61 << 8; //@line 30669
 $72 = $buf + 6 | 0; //@line 30671
 $79 = HEAP32[60264 + ((HEAPU8[$63] ^ $70 >>> 24) << 2) >> 2] ^ $70 << 8; //@line 30678
 $81 = $buf + 7 | 0; //@line 30680
 $88 = HEAP32[60264 + ((HEAPU8[$72] ^ $79 >>> 24) << 2) >> 2] ^ $79 << 8; //@line 30687
 $96 = HEAP32[60264 + ((HEAPU8[$81] ^ $88 >>> 24) << 2) >> 2] ^ $88 << 8; //@line 30695
 $97 = $buf_i21 | 0; //@line 30696
 if ($sz >>> 0 < 4) {
  $_0 = 1; //@line 30700
  STACKTOP = sp; //@line 30702
  return $_0 | 0; //@line 30703
 }
 if ((_fread($97 | 0, 1, 4, $fp | 0) | 0) != 4) {
  $_0 = 1; //@line 30709
  STACKTOP = sp; //@line 30711
  return $_0 | 0; //@line 30712
 }
 if (!(HEAP8[6664] | 0)) {
  $i_017_i_i = 0; //@line 30717
  do {
   $104 = $i_017_i_i << 25; //@line 30722
   $reg_1_i_i = ($i_017_i_i & 128 | 0) != 0 ? $104 ^ 517762881 : $104; //@line 30724
   $107 = $reg_1_i_i << 1; //@line 30726
   $reg_1_1_i_i = ($reg_1_i_i | 0) < 0 ? $107 ^ 517762881 : $107; //@line 30728
   $110 = $reg_1_1_i_i << 1; //@line 30730
   $reg_1_2_i_i = ($reg_1_1_i_i | 0) < 0 ? $110 ^ 517762881 : $110; //@line 30732
   $113 = $reg_1_2_i_i << 1; //@line 30734
   $reg_1_3_i_i = ($reg_1_2_i_i | 0) < 0 ? $113 ^ 517762881 : $113; //@line 30736
   $116 = $reg_1_3_i_i << 1; //@line 30738
   $reg_1_4_i_i = ($reg_1_3_i_i | 0) < 0 ? $116 ^ 517762881 : $116; //@line 30740
   $119 = $reg_1_4_i_i << 1; //@line 30742
   $reg_1_5_i_i = ($reg_1_4_i_i | 0) < 0 ? $119 ^ 517762881 : $119; //@line 30744
   $122 = $reg_1_5_i_i << 1; //@line 30746
   $reg_1_6_i_i = ($reg_1_5_i_i | 0) < 0 ? $122 ^ 517762881 : $122; //@line 30748
   $125 = $reg_1_6_i_i << 1; //@line 30750
   HEAP32[60264 + ($i_017_i_i << 2) >> 2] = ($reg_1_6_i_i | 0) < 0 ? $125 ^ 517762881 : $125; //@line 30754
   $i_017_i_i = $i_017_i_i + 1 | 0; //@line 30755
  } while ($i_017_i_i >>> 0 < 256);
  HEAP8[6664] = 1; //@line 30764
 }
 $139 = HEAP32[60264 + ((HEAPU8[$97] ^ $96 >>> 24) << 2) >> 2] ^ $96 << 8; //@line 30775
 $148 = HEAP32[60264 + ((HEAPU8[$buf_i21 + 1 | 0] ^ $139 >>> 24) << 2) >> 2] ^ $139 << 8; //@line 30784
 $157 = HEAP32[60264 + ((HEAPU8[$buf_i21 + 2 | 0] ^ $148 >>> 24) << 2) >> 2] ^ $148 << 8; //@line 30793
 $165 = HEAP32[60264 + ((HEAPU8[$buf_i21 + 3 | 0] ^ $157 >>> 24) << 2) >> 2] ^ $157 << 8; //@line 30801
 $166 = _psi_get_uint32_be($97, 0) | 0; //@line 30802
 if (($166 | 0) != 262144) {
  $169 = HEAP32[_stderr >> 2] | 0; //@line 30806
  _fprintf($169 | 0, 49992, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $166, tempInt) | 0) | 0; //@line 30807
  $_0 = 1; //@line 30809
  STACKTOP = sp; //@line 30811
  return $_0 | 0; //@line 30812
 }
 $172 = $sz - 4 | 0; //@line 30814
 $173 = $buf_i | 0; //@line 30815
 L16783 : do {
  if (($172 | 0) == 0) {
   $crc3335_lcssa_i = $165; //@line 30820
  } else {
   $crc333541_i = $165;
   $_08_i42_i = $172;
   while (1) {
    $176 = $_08_i42_i >>> 0 < 256 ? $_08_i42_i : 256; //@line 30827
    if ((_fread($173 | 0, 1, $176 | 0, $fp | 0) | 0) != ($176 | 0)) {
     $_0 = 1; //@line 30832
     break;
    }
    if (!(HEAP8[6664] | 0)) {
     $i_017_i10_i = 0; //@line 30838
     do {
      $181 = $i_017_i10_i << 25; //@line 30843
      $reg_1_i12_i = ($i_017_i10_i & 128 | 0) != 0 ? $181 ^ 517762881 : $181; //@line 30845
      $184 = $reg_1_i12_i << 1; //@line 30847
      $reg_1_1_i13_i = ($reg_1_i12_i | 0) < 0 ? $184 ^ 517762881 : $184; //@line 30849
      $187 = $reg_1_1_i13_i << 1; //@line 30851
      $reg_1_2_i14_i = ($reg_1_1_i13_i | 0) < 0 ? $187 ^ 517762881 : $187; //@line 30853
      $190 = $reg_1_2_i14_i << 1; //@line 30855
      $reg_1_3_i15_i = ($reg_1_2_i14_i | 0) < 0 ? $190 ^ 517762881 : $190; //@line 30857
      $193 = $reg_1_3_i15_i << 1; //@line 30859
      $reg_1_4_i16_i = ($reg_1_3_i15_i | 0) < 0 ? $193 ^ 517762881 : $193; //@line 30861
      $196 = $reg_1_4_i16_i << 1; //@line 30863
      $reg_1_5_i17_i = ($reg_1_4_i16_i | 0) < 0 ? $196 ^ 517762881 : $196; //@line 30865
      $199 = $reg_1_5_i17_i << 1; //@line 30867
      $reg_1_6_i18_i = ($reg_1_5_i17_i | 0) < 0 ? $199 ^ 517762881 : $199; //@line 30869
      $202 = $reg_1_6_i18_i << 1; //@line 30871
      HEAP32[60264 + ($i_017_i10_i << 2) >> 2] = ($reg_1_6_i18_i | 0) < 0 ? $202 ^ 517762881 : $202; //@line 30875
      $i_017_i10_i = $i_017_i10_i + 1 | 0; //@line 30876
     } while ($i_017_i10_i >>> 0 < 256);
     HEAP8[6664] = 1; //@line 30885
    }
    if (($176 | 0) == 0) {
     $crc3334_ph_i = $crc333541_i; //@line 30891
    } else {
     $_01011_i24_i = $176;
     $_012_i23_i = $crc333541_i;
     $src_013_i22_i = $173;
     while (1) {
      $217 = HEAP32[60264 + ((HEAPU8[$src_013_i22_i] ^ $_012_i23_i >>> 24) << 2) >> 2] ^ $_012_i23_i << 8; //@line 30906
      $218 = $_01011_i24_i - 1 | 0; //@line 30907
      if (($218 | 0) == 0) {
       $crc3334_ph_i = $217; //@line 30911
       break;
      } else {
       $_01011_i24_i = $218;
       $_012_i23_i = $217;
       $src_013_i22_i = $src_013_i22_i + 1 | 0;
      }
     }
    }
    if (($_08_i42_i | 0) == ($176 | 0)) {
     $crc3335_lcssa_i = $crc3334_ph_i; //@line 30923
     break L16783;
    } else {
     $crc333541_i = $crc3334_ph_i;
     $_08_i42_i = $_08_i42_i - $176 | 0;
    }
   }
   STACKTOP = sp; //@line 30930
   return $_0 | 0; //@line 30931
  }
 } while (0);
 if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
  $_0 = 1; //@line 30939
  STACKTOP = sp; //@line 30941
  return $_0 | 0; //@line 30942
 }
 if ((_psi_get_uint32_be($173, 0) | 0) != ($crc3335_lcssa_i | 0)) {
  $232 = HEAP32[_stderr >> 2] | 0; //@line 30948
  _fwrite(52760, 16, 1, $232 | 0) | 0; //@line 30949
  $_0 = 1; //@line 30951
  STACKTOP = sp; //@line 30953
  return $_0 | 0; //@line 30954
 }
 $227 = $buf_i99 | 0; //@line 30956
 $228 = $buf_i59 | 0; //@line 30957
 $229 = $buf_i59 + 12 | 0; //@line 30958
 $230 = $buf_i59 + 13 | 0; //@line 30959
 $_ph = 0; //@line 30961
 L16805 : while (1) {
  if ((_fread($1 | 0, 1, 8, $fp | 0) | 0) != 8) {
   $_0 = 1; //@line 30968
   label = 13415; //@line 30969
   break;
  }
  $546 = ($_ph | 0) == 0; //@line 30972
  $547 = $_ph + 10 | 0; //@line 30973
  $548 = $_ph + 24 | 0; //@line 30974
  L16808 : while (1) {
   if (!(HEAP8[6664] | 0)) {
    $i_017_i26 = 0; //@line 30980
    do {
     $236 = $i_017_i26 << 25; //@line 30985
     $reg_1_i28 = ($i_017_i26 & 128 | 0) != 0 ? $236 ^ 517762881 : $236; //@line 30987
     $239 = $reg_1_i28 << 1; //@line 30989
     $reg_1_1_i29 = ($reg_1_i28 | 0) < 0 ? $239 ^ 517762881 : $239; //@line 30991
     $242 = $reg_1_1_i29 << 1; //@line 30993
     $reg_1_2_i30 = ($reg_1_1_i29 | 0) < 0 ? $242 ^ 517762881 : $242; //@line 30995
     $245 = $reg_1_2_i30 << 1; //@line 30997
     $reg_1_3_i31 = ($reg_1_2_i30 | 0) < 0 ? $245 ^ 517762881 : $245; //@line 30999
     $248 = $reg_1_3_i31 << 1; //@line 31001
     $reg_1_4_i32 = ($reg_1_3_i31 | 0) < 0 ? $248 ^ 517762881 : $248; //@line 31003
     $251 = $reg_1_4_i32 << 1; //@line 31005
     $reg_1_5_i33 = ($reg_1_4_i32 | 0) < 0 ? $251 ^ 517762881 : $251; //@line 31007
     $254 = $reg_1_5_i33 << 1; //@line 31009
     $reg_1_6_i34 = ($reg_1_5_i33 | 0) < 0 ? $254 ^ 517762881 : $254; //@line 31011
     $257 = $reg_1_6_i34 << 1; //@line 31013
     HEAP32[60264 + ($i_017_i26 << 2) >> 2] = ($reg_1_6_i34 | 0) < 0 ? $257 ^ 517762881 : $257; //@line 31017
     $i_017_i26 = $i_017_i26 + 1 | 0; //@line 31018
    } while ($i_017_i26 >>> 0 < 256);
    HEAP8[6664] = 1; //@line 31027
   }
   $266 = HEAP32[60264 + (HEAPU8[$1] << 2) >> 2] | 0; //@line 31033
   $274 = HEAP32[60264 + ((HEAPU8[$30] ^ $266 >>> 24) << 2) >> 2] ^ $266 << 8; //@line 31041
   $282 = HEAP32[60264 + ((HEAPU8[$36] ^ $274 >>> 24) << 2) >> 2] ^ $274 << 8; //@line 31049
   $290 = HEAP32[60264 + ((HEAPU8[$45] ^ $282 >>> 24) << 2) >> 2] ^ $282 << 8; //@line 31057
   $298 = HEAP32[60264 + ((HEAPU8[$54] ^ $290 >>> 24) << 2) >> 2] ^ $290 << 8; //@line 31065
   $306 = HEAP32[60264 + ((HEAPU8[$63] ^ $298 >>> 24) << 2) >> 2] ^ $298 << 8; //@line 31073
   $314 = HEAP32[60264 + ((HEAPU8[$72] ^ $306 >>> 24) << 2) >> 2] ^ $306 << 8; //@line 31081
   $322 = HEAP32[60264 + ((HEAPU8[$81] ^ $314 >>> 24) << 2) >> 2] ^ $314 << 8; //@line 31089
   $323 = _psi_get_uint32_be($1, 0) | 0; //@line 31090
   $324 = _psi_get_uint32_be($1, 4) | 0; //@line 31091
   do {
    if (($323 | 0) == 1397048148) {
     break L16808;
    } else if (($323 | 0) == 1162757152) {
     label = 13285; //@line 31096
     break L16805;
    } else if (($323 | 0) == 1413830740) {
     if (($324 | 0) == 0) {
      if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
       $_0 = 1; //@line 31106
       label = 13426; //@line 31107
       break L16805;
      }
      if ((_psi_get_uint32_be($173, 0) | 0) == ($322 | 0)) {
       break;
      } else {
       label = 13377; //@line 31116
       break L16805;
      }
     }
     $778 = _malloc($324) | 0; //@line 31120
     if (($778 | 0) == 0) {
      $_0 = 1; //@line 31124
      label = 13436; //@line 31125
      break L16805;
     }
     if ((_fread($778 | 0, 1, $324 | 0, $fp | 0) | 0) != ($324 | 0)) {
      label = 13384; //@line 31132
      break L16805;
     }
     if (HEAP8[6664] | 0) {
      $_01011_i_i134 = $324;
      $_012_i_i133 = $322;
      $src_013_i_i132 = $778;
     } else {
      $i_017_i_i121 = 0; //@line 31140
      do {
       $785 = $i_017_i_i121 << 25; //@line 31145
       $reg_1_i_i123 = ($i_017_i_i121 & 128 | 0) != 0 ? $785 ^ 517762881 : $785; //@line 31147
       $788 = $reg_1_i_i123 << 1; //@line 31149
       $reg_1_1_i_i124 = ($reg_1_i_i123 | 0) < 0 ? $788 ^ 517762881 : $788; //@line 31151
       $791 = $reg_1_1_i_i124 << 1; //@line 31153
       $reg_1_2_i_i125 = ($reg_1_1_i_i124 | 0) < 0 ? $791 ^ 517762881 : $791; //@line 31155
       $794 = $reg_1_2_i_i125 << 1; //@line 31157
       $reg_1_3_i_i126 = ($reg_1_2_i_i125 | 0) < 0 ? $794 ^ 517762881 : $794; //@line 31159
       $797 = $reg_1_3_i_i126 << 1; //@line 31161
       $reg_1_4_i_i127 = ($reg_1_3_i_i126 | 0) < 0 ? $797 ^ 517762881 : $797; //@line 31163
       $800 = $reg_1_4_i_i127 << 1; //@line 31165
       $reg_1_5_i_i128 = ($reg_1_4_i_i127 | 0) < 0 ? $800 ^ 517762881 : $800; //@line 31167
       $803 = $reg_1_5_i_i128 << 1; //@line 31169
       $reg_1_6_i_i129 = ($reg_1_5_i_i128 | 0) < 0 ? $803 ^ 517762881 : $803; //@line 31171
       $806 = $reg_1_6_i_i129 << 1; //@line 31173
       HEAP32[60264 + ($i_017_i_i121 << 2) >> 2] = ($reg_1_6_i_i129 | 0) < 0 ? $806 ^ 517762881 : $806; //@line 31177
       $i_017_i_i121 = $i_017_i_i121 + 1 | 0; //@line 31178
      } while ($i_017_i_i121 >>> 0 < 256);
      HEAP8[6664] = 1; //@line 31187
      $_01011_i_i134 = $324;
      $_012_i_i133 = $322;
      $src_013_i_i132 = $778;
     }
     while (1) {
      $820 = HEAP32[60264 + ((HEAPU8[$src_013_i_i132] ^ $_012_i_i133 >>> 24) << 2) >> 2] ^ $_012_i_i133 << 8; //@line 31203
      $821 = $_01011_i_i134 - 1 | 0; //@line 31204
      if (($821 | 0) == 0) {
       break;
      } else {
       $_01011_i_i134 = $821;
       $_012_i_i133 = $820;
       $src_013_i_i132 = $src_013_i_i132 + 1 | 0;
      }
     }
     $825 = (HEAP8[$778] | 0) == 10; //@line 31214
     $_size_i136 = ($825 << 31 >> 31) + $324 | 0; //@line 31217
     if (($_size_i136 | 0) == 0) {
      $n_1_i = 0; //@line 31221
     } else {
      $829 = $_size_i136 - 1 | 0; //@line 31223
      $n_1_i = (HEAP8[$778 + $829 | 0] | 0) == 10 ? $829 : $_size_i136; //@line 31229
     }
     $835 = _psi_img_add_comment($img, $778 + ($825 & 1) | 0, $n_1_i) | 0; //@line 31233
     _free($778); //@line 31234
     do {
      if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) == 4) {
       if ((_psi_get_uint32_be($173, 0) | 0) == ($820 | 0)) {
        $_0_i24_i = 0; //@line 31244
        break;
       }
       $842 = HEAP32[_stderr >> 2] | 0; //@line 31247
       _fwrite(52760, 16, 1, $842 | 0) | 0; //@line 31248
       $_0_i24_i = 1; //@line 31250
      } else {
       $_0_i24_i = 1; //@line 31252
      }
     } while (0);
     if (($_0_i24_i | $835 | 0) != 0) {
      $_0 = 1; //@line 31260
      label = 13413; //@line 31261
      break L16805;
     }
    } else if (($323 | 0) == 1145132097) {
     if ($546) {
      $_0 = 1; //@line 31267
      label = 13429; //@line 31268
      break L16805;
     }
     $555 = HEAPU16[$547 >> 1] | 0; //@line 31272
     $_size_i = $555 >>> 0 < $324 >>> 0 ? $555 : $324; //@line 31274
     if (($_size_i | 0) == 0) {
      $crc30_i = $322; //@line 31278
     } else {
      $559 = HEAP32[$548 >> 2] | 0; //@line 31280
      if ((_fread($559 | 0, 1, $_size_i | 0, $fp | 0) | 0) != ($_size_i | 0)) {
       $_0 = 1; //@line 31285
       label = 13430; //@line 31286
       break L16805;
      }
      if (HEAP8[6664] | 0) {
       $_01011_i_i93 = $_size_i;
       $_012_i_i92 = $322;
       $src_013_i_i91 = $559;
      } else {
       $i_017_i_i80 = 0; //@line 31294
       do {
        $564 = $i_017_i_i80 << 25; //@line 31299
        $reg_1_i_i82 = ($i_017_i_i80 & 128 | 0) != 0 ? $564 ^ 517762881 : $564; //@line 31301
        $567 = $reg_1_i_i82 << 1; //@line 31303
        $reg_1_1_i_i83 = ($reg_1_i_i82 | 0) < 0 ? $567 ^ 517762881 : $567; //@line 31305
        $570 = $reg_1_1_i_i83 << 1; //@line 31307
        $reg_1_2_i_i84 = ($reg_1_1_i_i83 | 0) < 0 ? $570 ^ 517762881 : $570; //@line 31309
        $573 = $reg_1_2_i_i84 << 1; //@line 31311
        $reg_1_3_i_i85 = ($reg_1_2_i_i84 | 0) < 0 ? $573 ^ 517762881 : $573; //@line 31313
        $576 = $reg_1_3_i_i85 << 1; //@line 31315
        $reg_1_4_i_i86 = ($reg_1_3_i_i85 | 0) < 0 ? $576 ^ 517762881 : $576; //@line 31317
        $579 = $reg_1_4_i_i86 << 1; //@line 31319
        $reg_1_5_i_i87 = ($reg_1_4_i_i86 | 0) < 0 ? $579 ^ 517762881 : $579; //@line 31321
        $582 = $reg_1_5_i_i87 << 1; //@line 31323
        $reg_1_6_i_i88 = ($reg_1_5_i_i87 | 0) < 0 ? $582 ^ 517762881 : $582; //@line 31325
        $585 = $reg_1_6_i_i88 << 1; //@line 31327
        HEAP32[60264 + ($i_017_i_i80 << 2) >> 2] = ($reg_1_6_i_i88 | 0) < 0 ? $585 ^ 517762881 : $585; //@line 31331
        $i_017_i_i80 = $i_017_i_i80 + 1 | 0; //@line 31332
       } while ($i_017_i_i80 >>> 0 < 256);
       HEAP8[6664] = 1; //@line 31341
       $_01011_i_i93 = $_size_i;
       $_012_i_i92 = $322;
       $src_013_i_i91 = $559;
      }
      while (1) {
       $599 = HEAP32[60264 + ((HEAPU8[$src_013_i_i91] ^ $_012_i_i92 >>> 24) << 2) >> 2] ^ $_012_i_i92 << 8; //@line 31357
       $600 = $_01011_i_i93 - 1 | 0; //@line 31358
       if (($600 | 0) == 0) {
        $crc30_i = $599; //@line 31362
        break;
       } else {
        $_01011_i_i93 = $600;
        $_012_i_i92 = $599;
        $src_013_i_i91 = $src_013_i_i91 + 1 | 0;
       }
      }
     }
     if (($_size_i | 0) == ($324 | 0)) {
      $crc3032_lcssa_i = $crc30_i; //@line 31373
     } else {
      $crc303237_i = $crc30_i;
      $_08_i38_i = $324 - $_size_i | 0;
      while (1) {
       $606 = $_08_i38_i >>> 0 < 256 ? $_08_i38_i : 256; //@line 31382
       if ((_fread($173 | 0, 1, $606 | 0, $fp | 0) | 0) != ($606 | 0)) {
        $_0 = 1; //@line 31387
        label = 13407; //@line 31388
        break L16805;
       }
       if (!(HEAP8[6664] | 0)) {
        $i_017_i5_i = 0; //@line 31394
        do {
         $611 = $i_017_i5_i << 25; //@line 31399
         $reg_1_i7_i = ($i_017_i5_i & 128 | 0) != 0 ? $611 ^ 517762881 : $611; //@line 31401
         $614 = $reg_1_i7_i << 1; //@line 31403
         $reg_1_1_i8_i = ($reg_1_i7_i | 0) < 0 ? $614 ^ 517762881 : $614; //@line 31405
         $617 = $reg_1_1_i8_i << 1; //@line 31407
         $reg_1_2_i9_i = ($reg_1_1_i8_i | 0) < 0 ? $617 ^ 517762881 : $617; //@line 31409
         $620 = $reg_1_2_i9_i << 1; //@line 31411
         $reg_1_3_i10_i = ($reg_1_2_i9_i | 0) < 0 ? $620 ^ 517762881 : $620; //@line 31413
         $623 = $reg_1_3_i10_i << 1; //@line 31415
         $reg_1_4_i11_i = ($reg_1_3_i10_i | 0) < 0 ? $623 ^ 517762881 : $623; //@line 31417
         $626 = $reg_1_4_i11_i << 1; //@line 31419
         $reg_1_5_i12_i = ($reg_1_4_i11_i | 0) < 0 ? $626 ^ 517762881 : $626; //@line 31421
         $629 = $reg_1_5_i12_i << 1; //@line 31423
         $reg_1_6_i13_i = ($reg_1_5_i12_i | 0) < 0 ? $629 ^ 517762881 : $629; //@line 31425
         $632 = $reg_1_6_i13_i << 1; //@line 31427
         HEAP32[60264 + ($i_017_i5_i << 2) >> 2] = ($reg_1_6_i13_i | 0) < 0 ? $632 ^ 517762881 : $632; //@line 31431
         $i_017_i5_i = $i_017_i5_i + 1 | 0; //@line 31432
        } while ($i_017_i5_i >>> 0 < 256);
        HEAP8[6664] = 1; //@line 31441
       }
       if (($606 | 0) == 0) {
        $crc3031_ph_i = $crc303237_i; //@line 31447
       } else {
        $_01011_i19_i = $606;
        $_012_i18_i = $crc303237_i;
        $src_013_i17_i = $173;
        while (1) {
         $647 = HEAP32[60264 + ((HEAPU8[$src_013_i17_i] ^ $_012_i18_i >>> 24) << 2) >> 2] ^ $_012_i18_i << 8; //@line 31462
         $648 = $_01011_i19_i - 1 | 0; //@line 31463
         if (($648 | 0) == 0) {
          $crc3031_ph_i = $647; //@line 31467
          break;
         } else {
          $_01011_i19_i = $648;
          $_012_i18_i = $647;
          $src_013_i17_i = $src_013_i17_i + 1 | 0;
         }
        }
       }
       if (($_08_i38_i | 0) == ($606 | 0)) {
        $crc3032_lcssa_i = $crc3031_ph_i; //@line 31479
        break;
       } else {
        $crc303237_i = $crc3031_ph_i;
        $_08_i38_i = $_08_i38_i - $606 | 0;
       }
      }
     }
     if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
      $_0 = 1; //@line 31491
      label = 13416; //@line 31492
      break L16805;
     }
     if ((_psi_get_uint32_be($173, 0) | 0) != ($crc3032_lcssa_i | 0)) {
      label = 13354; //@line 31499
      break L16805;
     }
    } else if (($323 | 0) == 1413564243) {
     if ($546) {
      $_0 = 1; //@line 31505
      label = 13431; //@line 31506
      break L16805;
     }
     $663 = $324 >>> 0 < 256 ? $324 : 256; //@line 31510
     if ((_fread($227 | 0, 1, $663 | 0, $fp | 0) | 0) != ($663 | 0)) {
      $_0 = 1; //@line 31515
      label = 13419; //@line 31516
      break L16805;
     }
     if (!(HEAP8[6664] | 0)) {
      $i_017_i_i101 = 0; //@line 31522
      do {
       $668 = $i_017_i_i101 << 25; //@line 31527
       $reg_1_i_i103 = ($i_017_i_i101 & 128 | 0) != 0 ? $668 ^ 517762881 : $668; //@line 31529
       $671 = $reg_1_i_i103 << 1; //@line 31531
       $reg_1_1_i_i104 = ($reg_1_i_i103 | 0) < 0 ? $671 ^ 517762881 : $671; //@line 31533
       $674 = $reg_1_1_i_i104 << 1; //@line 31535
       $reg_1_2_i_i105 = ($reg_1_1_i_i104 | 0) < 0 ? $674 ^ 517762881 : $674; //@line 31537
       $677 = $reg_1_2_i_i105 << 1; //@line 31539
       $reg_1_3_i_i106 = ($reg_1_2_i_i105 | 0) < 0 ? $677 ^ 517762881 : $677; //@line 31541
       $680 = $reg_1_3_i_i106 << 1; //@line 31543
       $reg_1_4_i_i107 = ($reg_1_3_i_i106 | 0) < 0 ? $680 ^ 517762881 : $680; //@line 31545
       $683 = $reg_1_4_i_i107 << 1; //@line 31547
       $reg_1_5_i_i108 = ($reg_1_4_i_i107 | 0) < 0 ? $683 ^ 517762881 : $683; //@line 31549
       $686 = $reg_1_5_i_i108 << 1; //@line 31551
       $reg_1_6_i_i109 = ($reg_1_5_i_i108 | 0) < 0 ? $686 ^ 517762881 : $686; //@line 31553
       $689 = $reg_1_6_i_i109 << 1; //@line 31555
       HEAP32[60264 + ($i_017_i_i101 << 2) >> 2] = ($reg_1_6_i_i109 | 0) < 0 ? $689 ^ 517762881 : $689; //@line 31559
       $i_017_i_i101 = $i_017_i_i101 + 1 | 0; //@line 31560
      } while ($i_017_i_i101 >>> 0 < 256);
      HEAP8[6664] = 1; //@line 31569
     }
     if (($663 | 0) == 0) {
      $crc38_ph_i = $322; //@line 31575
     } else {
      $_01011_i_i115 = $663;
      $_012_i_i114 = $322;
      $src_013_i_i113 = $227;
      while (1) {
       $704 = HEAP32[60264 + ((HEAPU8[$src_013_i_i113] ^ $_012_i_i114 >>> 24) << 2) >> 2] ^ $_012_i_i114 << 8; //@line 31590
       $705 = $_01011_i_i115 - 1 | 0; //@line 31591
       if (($705 | 0) == 0) {
        $crc38_ph_i = $704; //@line 31595
        break;
       } else {
        $_01011_i_i115 = $705;
        $_012_i_i114 = $704;
        $src_013_i_i113 = $src_013_i_i113 + 1 | 0;
       }
      }
     }
     _psi_sct_set_tags($_ph, $227, $663) | 0; //@line 31603
     if (($663 | 0) == ($324 | 0)) {
      $crc3840_lcssa_i = $crc38_ph_i; //@line 31607
     } else {
      $crc384046_i = $crc38_ph_i;
      $_08_i47_i = $324 - $663 | 0;
      while (1) {
       $712 = $_08_i47_i >>> 0 < 256 ? $_08_i47_i : 256; //@line 31616
       if ((_fread($173 | 0, 1, $712 | 0, $fp | 0) | 0) != ($712 | 0)) {
        $_0 = 1; //@line 31621
        label = 13439; //@line 31622
        break L16805;
       }
       if (!(HEAP8[6664] | 0)) {
        $i_017_i14_i = 0; //@line 31628
        do {
         $717 = $i_017_i14_i << 25; //@line 31633
         $reg_1_i16_i = ($i_017_i14_i & 128 | 0) != 0 ? $717 ^ 517762881 : $717; //@line 31635
         $720 = $reg_1_i16_i << 1; //@line 31637
         $reg_1_1_i17_i = ($reg_1_i16_i | 0) < 0 ? $720 ^ 517762881 : $720; //@line 31639
         $723 = $reg_1_1_i17_i << 1; //@line 31641
         $reg_1_2_i18_i = ($reg_1_1_i17_i | 0) < 0 ? $723 ^ 517762881 : $723; //@line 31643
         $726 = $reg_1_2_i18_i << 1; //@line 31645
         $reg_1_3_i19_i = ($reg_1_2_i18_i | 0) < 0 ? $726 ^ 517762881 : $726; //@line 31647
         $729 = $reg_1_3_i19_i << 1; //@line 31649
         $reg_1_4_i20_i = ($reg_1_3_i19_i | 0) < 0 ? $729 ^ 517762881 : $729; //@line 31651
         $732 = $reg_1_4_i20_i << 1; //@line 31653
         $reg_1_5_i21_i = ($reg_1_4_i20_i | 0) < 0 ? $732 ^ 517762881 : $732; //@line 31655
         $735 = $reg_1_5_i21_i << 1; //@line 31657
         $reg_1_6_i22_i = ($reg_1_5_i21_i | 0) < 0 ? $735 ^ 517762881 : $735; //@line 31659
         $738 = $reg_1_6_i22_i << 1; //@line 31661
         HEAP32[60264 + ($i_017_i14_i << 2) >> 2] = ($reg_1_6_i22_i | 0) < 0 ? $738 ^ 517762881 : $738; //@line 31665
         $i_017_i14_i = $i_017_i14_i + 1 | 0; //@line 31666
        } while ($i_017_i14_i >>> 0 < 256);
        HEAP8[6664] = 1; //@line 31675
       }
       if (($712 | 0) == 0) {
        $crc3839_ph_i = $crc384046_i; //@line 31681
       } else {
        $_01011_i28_i = $712;
        $_012_i27_i = $crc384046_i;
        $src_013_i26_i = $173;
        while (1) {
         $753 = HEAP32[60264 + ((HEAPU8[$src_013_i26_i] ^ $_012_i27_i >>> 24) << 2) >> 2] ^ $_012_i27_i << 8; //@line 31696
         $754 = $_01011_i28_i - 1 | 0; //@line 31697
         if (($754 | 0) == 0) {
          $crc3839_ph_i = $753; //@line 31701
          break;
         } else {
          $_01011_i28_i = $754;
          $_012_i27_i = $753;
          $src_013_i26_i = $src_013_i26_i + 1 | 0;
         }
        }
       }
       if (($_08_i47_i | 0) == ($712 | 0)) {
        $crc3840_lcssa_i = $crc3839_ph_i; //@line 31713
        break;
       } else {
        $crc384046_i = $crc3839_ph_i;
        $_08_i47_i = $_08_i47_i - $712 | 0;
       }
      }
     }
     if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
      $_0 = 1; //@line 31725
      label = 13410; //@line 31726
      break L16805;
     }
     if ((_psi_get_uint32_be($173, 0) | 0) != ($crc3840_lcssa_i | 0)) {
      label = 13373; //@line 31733
      break L16805;
     }
    } else {
     if (($324 | 0) == 0) {
      $_lcssa195 = $322; //@line 31740
     } else {
      $850 = $322;
      $_08_i197 = $324;
      while (1) {
       $852 = $_08_i197 >>> 0 < 256 ? $_08_i197 : 256; //@line 31747
       if ((_fread($173 | 0, 1, $852 | 0, $fp | 0) | 0) != ($852 | 0)) {
        $_0 = 1; //@line 31752
        label = 13433; //@line 31753
        break L16805;
       }
       if (!(HEAP8[6664] | 0)) {
        $i_017_i142 = 0; //@line 31759
        do {
         $857 = $i_017_i142 << 25; //@line 31764
         $reg_1_i144 = ($i_017_i142 & 128 | 0) != 0 ? $857 ^ 517762881 : $857; //@line 31766
         $860 = $reg_1_i144 << 1; //@line 31768
         $reg_1_1_i145 = ($reg_1_i144 | 0) < 0 ? $860 ^ 517762881 : $860; //@line 31770
         $863 = $reg_1_1_i145 << 1; //@line 31772
         $reg_1_2_i146 = ($reg_1_1_i145 | 0) < 0 ? $863 ^ 517762881 : $863; //@line 31774
         $866 = $reg_1_2_i146 << 1; //@line 31776
         $reg_1_3_i147 = ($reg_1_2_i146 | 0) < 0 ? $866 ^ 517762881 : $866; //@line 31778
         $869 = $reg_1_3_i147 << 1; //@line 31780
         $reg_1_4_i148 = ($reg_1_3_i147 | 0) < 0 ? $869 ^ 517762881 : $869; //@line 31782
         $872 = $reg_1_4_i148 << 1; //@line 31784
         $reg_1_5_i149 = ($reg_1_4_i148 | 0) < 0 ? $872 ^ 517762881 : $872; //@line 31786
         $875 = $reg_1_5_i149 << 1; //@line 31788
         $reg_1_6_i150 = ($reg_1_5_i149 | 0) < 0 ? $875 ^ 517762881 : $875; //@line 31790
         $878 = $reg_1_6_i150 << 1; //@line 31792
         HEAP32[60264 + ($i_017_i142 << 2) >> 2] = ($reg_1_6_i150 | 0) < 0 ? $878 ^ 517762881 : $878; //@line 31796
         $i_017_i142 = $i_017_i142 + 1 | 0; //@line 31797
        } while ($i_017_i142 >>> 0 < 256);
        HEAP8[6664] = 1; //@line 31806
       }
       if (($852 | 0) == 0) {
        $_ph178 = $850; //@line 31812
       } else {
        $_01011_i156 = $852;
        $_012_i155 = $850;
        $src_013_i154 = $173;
        while (1) {
         $893 = HEAP32[60264 + ((HEAPU8[$src_013_i154] ^ $_012_i155 >>> 24) << 2) >> 2] ^ $_012_i155 << 8; //@line 31827
         $894 = $_01011_i156 - 1 | 0; //@line 31828
         if (($894 | 0) == 0) {
          $_ph178 = $893; //@line 31832
          break;
         } else {
          $_01011_i156 = $894;
          $_012_i155 = $893;
          $src_013_i154 = $src_013_i154 + 1 | 0;
         }
        }
       }
       if (($_08_i197 | 0) == ($852 | 0)) {
        $_lcssa195 = $_ph178; //@line 31844
        break;
       } else {
        $850 = $_ph178;
        $_08_i197 = $_08_i197 - $852 | 0;
       }
      }
     }
     if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
      $_0 = 1; //@line 31856
      label = 13404; //@line 31857
      break L16805;
     }
     if ((_psi_get_uint32_be($173, 0) | 0) != ($_lcssa195 | 0)) {
      label = 13402; //@line 31864
      break L16805;
     }
    }
   } while (0);
   if ((_fread($1 | 0, 1, 8, $fp | 0) | 0) != 8) {
    $_0 = 1; //@line 31873
    label = 13432; //@line 31874
    break L16805;
   }
  }
  if ($324 >>> 0 < 18) {
   $_0 = 1; //@line 31881
   label = 13409; //@line 31882
   break;
  }
  if ((_fread($228 | 0, 1, 18, $fp | 0) | 0) != 18) {
   $_0 = 1; //@line 31889
   label = 13418; //@line 31890
   break;
  }
  if (HEAP8[6664] | 0) {
   $_01011_i_i74 = 18;
   $_012_i_i73 = $322;
   $src_013_i_i72 = $228;
  } else {
   $i_017_i_i61 = 0; //@line 31898
   do {
    $390 = $i_017_i_i61 << 25; //@line 31903
    $reg_1_i_i63 = ($i_017_i_i61 & 128 | 0) != 0 ? $390 ^ 517762881 : $390; //@line 31905
    $393 = $reg_1_i_i63 << 1; //@line 31907
    $reg_1_1_i_i64 = ($reg_1_i_i63 | 0) < 0 ? $393 ^ 517762881 : $393; //@line 31909
    $396 = $reg_1_1_i_i64 << 1; //@line 31911
    $reg_1_2_i_i65 = ($reg_1_1_i_i64 | 0) < 0 ? $396 ^ 517762881 : $396; //@line 31913
    $399 = $reg_1_2_i_i65 << 1; //@line 31915
    $reg_1_3_i_i66 = ($reg_1_2_i_i65 | 0) < 0 ? $399 ^ 517762881 : $399; //@line 31917
    $402 = $reg_1_3_i_i66 << 1; //@line 31919
    $reg_1_4_i_i67 = ($reg_1_3_i_i66 | 0) < 0 ? $402 ^ 517762881 : $402; //@line 31921
    $405 = $reg_1_4_i_i67 << 1; //@line 31923
    $reg_1_5_i_i68 = ($reg_1_4_i_i67 | 0) < 0 ? $405 ^ 517762881 : $405; //@line 31925
    $408 = $reg_1_5_i_i68 << 1; //@line 31927
    $reg_1_6_i_i69 = ($reg_1_5_i_i68 | 0) < 0 ? $408 ^ 517762881 : $408; //@line 31929
    $411 = $reg_1_6_i_i69 << 1; //@line 31931
    HEAP32[60264 + ($i_017_i_i61 << 2) >> 2] = ($reg_1_6_i_i69 | 0) < 0 ? $411 ^ 517762881 : $411; //@line 31935
    $i_017_i_i61 = $i_017_i_i61 + 1 | 0; //@line 31936
   } while ($i_017_i_i61 >>> 0 < 256);
   HEAP8[6664] = 1; //@line 31945
   $_01011_i_i74 = 18;
   $_012_i_i73 = $322;
   $src_013_i_i72 = $228;
  }
  while (1) {
   $425 = HEAP32[60264 + ((HEAPU8[$src_013_i_i72] ^ $_012_i_i73 >>> 24) << 2) >> 2] ^ $_012_i_i73 << 8; //@line 31961
   $426 = $_01011_i_i74 - 1 | 0; //@line 31962
   if (($426 | 0) == 0) {
    break;
   } else {
    $_01011_i_i74 = $426;
    $_012_i_i73 = $425;
    $src_013_i_i72 = $src_013_i_i72 + 1 | 0;
   }
  }
  $429 = _psi_get_uint16_be($228, 0) | 0; //@line 31971
  $430 = _psi_get_uint16_be($228, 2) | 0; //@line 31972
  $431 = _psi_get_uint16_be($228, 4) | 0; //@line 31973
  $432 = _psi_get_uint16_be($228, 6) | 0; //@line 31974
  $433 = _psi_get_uint16_be($228, 8) | 0; //@line 31975
  $434 = _psi_get_uint16_be($228, 10) | 0; //@line 31976
  $435 = HEAP8[$229] | 0; //@line 31977
  $436 = _psi_get_uint16_be($228, 14) | 0; //@line 31978
  $437 = _psi_get_uint16_be($228, 16) | 0; //@line 31979
  $438 = _psi_sct_new($431, $432, $433, $434) | 0; //@line 31980
  if (($438 | 0) == 0) {
   $_0 = 1; //@line 31984
   label = 13411; //@line 31985
   break;
  }
  if (($436 & 1 | 0) != 0) {
   $444 = $438 + 12 | 0; //@line 31992
   HEAP32[$444 >> 2] = HEAP32[$444 >> 2] | 1; //@line 31995
  }
  if (($436 & 2 | 0) != 0) {
   $451 = $438 + 12 | 0; //@line 32002
   HEAP32[$451 >> 2] = HEAP32[$451 >> 2] | 2; //@line 32005
  }
  if (($436 & 4 | 0) != 0) {
   $458 = $438 + 12 | 0; //@line 32012
   HEAP32[$458 >> 2] = HEAP32[$458 >> 2] | 4; //@line 32015
  }
  if (($436 & 8 | 0) != 0) {
   $465 = $438 + 12 | 0; //@line 32022
   HEAP32[$465 >> 2] = HEAP32[$465 >> 2] | 8; //@line 32025
  }
  _psi_sct_set_encoding($438, $437); //@line 32028
  $468 = $437 & 4095; //@line 32029
  if (($468 | 0) == 1 | ($468 | 0) == 2) {
   _psi_sct_set_mfm_size($438, $435); //@line 32031
  } else if (($468 | 0) == 3) {
   _psi_sct_set_gcr_format($438, $435); //@line 32034
  }
  if (($436 & 16384 | 0) == 0) {
   if ((_psi_img_add_sector($img, $438, $429, $430) | 0) != 0) {
    label = 13320; //@line 32045
    break;
   }
  } else {
   if ($546) {
    label = 13317; //@line 32051
    break;
   }
   _psi_sct_add_alternate($_ph, $438); //@line 32054
  }
  $484 = $324 - 18 | 0; //@line 32057
  if (($436 & 32768 | 0) != 0) {
   _psi_sct_fill($438, HEAPU8[$230] | 0); //@line 32064
  }
  if (($484 | 0) == 0) {
   $crc5153_lcssa_i = $425; //@line 32070
  } else {
   $crc515359_i = $425;
   $_08_i60_i = $484;
   while (1) {
    $493 = $_08_i60_i >>> 0 < 256 ? $_08_i60_i : 256; //@line 32077
    if ((_fread($173 | 0, 1, $493 | 0, $fp | 0) | 0) != ($493 | 0)) {
     $_0 = 1; //@line 32082
     label = 13421; //@line 32083
     break L16805;
    }
    if (!(HEAP8[6664] | 0)) {
     $i_017_i28_i = 0; //@line 32089
     do {
      $498 = $i_017_i28_i << 25; //@line 32094
      $reg_1_i30_i = ($i_017_i28_i & 128 | 0) != 0 ? $498 ^ 517762881 : $498; //@line 32096
      $501 = $reg_1_i30_i << 1; //@line 32098
      $reg_1_1_i31_i = ($reg_1_i30_i | 0) < 0 ? $501 ^ 517762881 : $501; //@line 32100
      $504 = $reg_1_1_i31_i << 1; //@line 32102
      $reg_1_2_i32_i = ($reg_1_1_i31_i | 0) < 0 ? $504 ^ 517762881 : $504; //@line 32104
      $507 = $reg_1_2_i32_i << 1; //@line 32106
      $reg_1_3_i33_i = ($reg_1_2_i32_i | 0) < 0 ? $507 ^ 517762881 : $507; //@line 32108
      $510 = $reg_1_3_i33_i << 1; //@line 32110
      $reg_1_4_i34_i = ($reg_1_3_i33_i | 0) < 0 ? $510 ^ 517762881 : $510; //@line 32112
      $513 = $reg_1_4_i34_i << 1; //@line 32114
      $reg_1_5_i35_i = ($reg_1_4_i34_i | 0) < 0 ? $513 ^ 517762881 : $513; //@line 32116
      $516 = $reg_1_5_i35_i << 1; //@line 32118
      $reg_1_6_i36_i = ($reg_1_5_i35_i | 0) < 0 ? $516 ^ 517762881 : $516; //@line 32120
      $519 = $reg_1_6_i36_i << 1; //@line 32122
      HEAP32[60264 + ($i_017_i28_i << 2) >> 2] = ($reg_1_6_i36_i | 0) < 0 ? $519 ^ 517762881 : $519; //@line 32126
      $i_017_i28_i = $i_017_i28_i + 1 | 0; //@line 32127
     } while ($i_017_i28_i >>> 0 < 256);
     HEAP8[6664] = 1; //@line 32136
    }
    if (($493 | 0) == 0) {
     $crc5152_ph_i = $crc515359_i; //@line 32142
    } else {
     $_01011_i42_i = $493;
     $_012_i41_i = $crc515359_i;
     $src_013_i40_i = $173;
     while (1) {
      $534 = HEAP32[60264 + ((HEAPU8[$src_013_i40_i] ^ $_012_i41_i >>> 24) << 2) >> 2] ^ $_012_i41_i << 8; //@line 32157
      $535 = $_01011_i42_i - 1 | 0; //@line 32158
      if (($535 | 0) == 0) {
       $crc5152_ph_i = $534; //@line 32162
       break;
      } else {
       $_01011_i42_i = $535;
       $_012_i41_i = $534;
       $src_013_i40_i = $src_013_i40_i + 1 | 0;
      }
     }
    }
    if (($_08_i60_i | 0) == ($493 | 0)) {
     $crc5153_lcssa_i = $crc5152_ph_i; //@line 32174
     break;
    } else {
     $crc515359_i = $crc5152_ph_i;
     $_08_i60_i = $_08_i60_i - $493 | 0;
    }
   }
  }
  if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
   $_0 = 1; //@line 32186
   label = 13417; //@line 32187
   break;
  }
  if ((_psi_get_uint32_be($173, 0) | 0) == ($crc5153_lcssa_i | 0)) {
   $_ph = $438; //@line 32194
  } else {
   label = 13335; //@line 32196
   break;
  }
 }
 if ((label | 0) == 13335) {
  $550 = HEAP32[_stderr >> 2] | 0; //@line 32201
  _fwrite(52760, 16, 1, $550 | 0) | 0; //@line 32202
  $_0 = 1; //@line 32204
  STACKTOP = sp; //@line 32206
  return $_0 | 0; //@line 32207
 } else if ((label | 0) == 13384) {
  _free($778); //@line 32210
  $_0 = 1; //@line 32212
  STACKTOP = sp; //@line 32214
  return $_0 | 0; //@line 32215
 } else if ((label | 0) == 13285) {
  L16966 : do {
   if (($324 | 0) == 0) {
    $crc11_lcssa_i = $322; //@line 32222
   } else {
    $crc1116_i = $322;
    $_08_i17_i = $324;
    while (1) {
     $328 = $_08_i17_i >>> 0 < 256 ? $_08_i17_i : 256; //@line 32229
     if ((_fread($173 | 0, 1, $328 | 0, $fp | 0) | 0) != ($328 | 0)) {
      $_0 = 1; //@line 32234
      break;
     }
     if (!(HEAP8[6664] | 0)) {
      $i_017_i_i46 = 0; //@line 32240
      do {
       $333 = $i_017_i_i46 << 25; //@line 32245
       $reg_1_i_i48 = ($i_017_i_i46 & 128 | 0) != 0 ? $333 ^ 517762881 : $333; //@line 32247
       $336 = $reg_1_i_i48 << 1; //@line 32249
       $reg_1_1_i_i49 = ($reg_1_i_i48 | 0) < 0 ? $336 ^ 517762881 : $336; //@line 32251
       $339 = $reg_1_1_i_i49 << 1; //@line 32253
       $reg_1_2_i_i50 = ($reg_1_1_i_i49 | 0) < 0 ? $339 ^ 517762881 : $339; //@line 32255
       $342 = $reg_1_2_i_i50 << 1; //@line 32257
       $reg_1_3_i_i51 = ($reg_1_2_i_i50 | 0) < 0 ? $342 ^ 517762881 : $342; //@line 32259
       $345 = $reg_1_3_i_i51 << 1; //@line 32261
       $reg_1_4_i_i52 = ($reg_1_3_i_i51 | 0) < 0 ? $345 ^ 517762881 : $345; //@line 32263
       $348 = $reg_1_4_i_i52 << 1; //@line 32265
       $reg_1_5_i_i53 = ($reg_1_4_i_i52 | 0) < 0 ? $348 ^ 517762881 : $348; //@line 32267
       $351 = $reg_1_5_i_i53 << 1; //@line 32269
       $reg_1_6_i_i54 = ($reg_1_5_i_i53 | 0) < 0 ? $351 ^ 517762881 : $351; //@line 32271
       $354 = $reg_1_6_i_i54 << 1; //@line 32273
       HEAP32[60264 + ($i_017_i_i46 << 2) >> 2] = ($reg_1_6_i_i54 | 0) < 0 ? $354 ^ 517762881 : $354; //@line 32277
       $i_017_i_i46 = $i_017_i_i46 + 1 | 0; //@line 32278
      } while ($i_017_i_i46 >>> 0 < 256);
      HEAP8[6664] = 1; //@line 32287
     }
     if (($328 | 0) == 0) {
      $crc10_ph_i = $crc1116_i; //@line 32293
     } else {
      $_01011_i_i = $328;
      $_012_i_i = $crc1116_i;
      $src_013_i_i = $173;
      while (1) {
       $369 = HEAP32[60264 + ((HEAPU8[$src_013_i_i] ^ $_012_i_i >>> 24) << 2) >> 2] ^ $_012_i_i << 8; //@line 32308
       $370 = $_01011_i_i - 1 | 0; //@line 32309
       if (($370 | 0) == 0) {
        $crc10_ph_i = $369; //@line 32313
        break;
       } else {
        $_01011_i_i = $370;
        $_012_i_i = $369;
        $src_013_i_i = $src_013_i_i + 1 | 0;
       }
      }
     }
     if (($_08_i17_i | 0) == ($328 | 0)) {
      $crc11_lcssa_i = $crc10_ph_i; //@line 32325
      break L16966;
     } else {
      $crc1116_i = $crc10_ph_i;
      $_08_i17_i = $_08_i17_i - $328 | 0;
     }
    }
    STACKTOP = sp; //@line 32332
    return $_0 | 0; //@line 32333
   }
  } while (0);
  if ((_fread($173 | 0, 1, 4, $fp | 0) | 0) != 4) {
   $_0 = 1; //@line 32341
   STACKTOP = sp; //@line 32343
   return $_0 | 0; //@line 32344
  }
  if ((_psi_get_uint32_be($173, 0) | 0) == ($crc11_lcssa_i | 0)) {
   _psi_img_clean_comment($img); //@line 32350
   $_0 = 0; //@line 32352
   STACKTOP = sp; //@line 32354
   return $_0 | 0; //@line 32355
  } else {
   $380 = HEAP32[_stderr >> 2] | 0; //@line 32357
   _fwrite(52760, 16, 1, $380 | 0) | 0; //@line 32358
   $_0 = 1; //@line 32360
   STACKTOP = sp; //@line 32362
   return $_0 | 0; //@line 32363
  }
 } else if ((label | 0) == 13317) {
  _fwrite(56480, 32, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 32368
  _psi_sct_del($438); //@line 32369
  $_0 = 1; //@line 32371
  STACKTOP = sp; //@line 32373
  return $_0 | 0; //@line 32374
 } else if ((label | 0) == 13377) {
  _fwrite(52760, 16, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 32378
  $_0 = 1; //@line 32380
  STACKTOP = sp; //@line 32382
  return $_0 | 0; //@line 32383
 } else if ((label | 0) == 13320) {
  _psi_sct_del($438); //@line 32386
  $_0 = 1; //@line 32388
  STACKTOP = sp; //@line 32390
  return $_0 | 0; //@line 32391
 } else if ((label | 0) == 13373) {
  _fwrite(52760, 16, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 32395
  $_0 = 1; //@line 32397
  STACKTOP = sp; //@line 32399
  return $_0 | 0; //@line 32400
 } else if ((label | 0) == 13354) {
  _fwrite(52760, 16, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 32404
  $_0 = 1; //@line 32406
  STACKTOP = sp; //@line 32408
  return $_0 | 0; //@line 32409
 } else if ((label | 0) == 13402) {
  _fwrite(52760, 16, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 32413
  $_0 = 1; //@line 32415
  STACKTOP = sp; //@line 32417
  return $_0 | 0; //@line 32418
 } else if ((label | 0) == 13404) {
  STACKTOP = sp; //@line 32422
  return $_0 | 0; //@line 32423
 } else if ((label | 0) == 13407) {
  STACKTOP = sp; //@line 32427
  return $_0 | 0; //@line 32428
 } else if ((label | 0) == 13409) {
  STACKTOP = sp; //@line 32432
  return $_0 | 0; //@line 32433
 } else if ((label | 0) == 13410) {
  STACKTOP = sp; //@line 32437
  return $_0 | 0; //@line 32438
 } else if ((label | 0) == 13411) {
  STACKTOP = sp; //@line 32442
  return $_0 | 0; //@line 32443
 } else if ((label | 0) == 13413) {
  STACKTOP = sp; //@line 32447
  return $_0 | 0; //@line 32448
 } else if ((label | 0) == 13415) {
  STACKTOP = sp; //@line 32452
  return $_0 | 0; //@line 32453
 } else if ((label | 0) == 13416) {
  STACKTOP = sp; //@line 32457
  return $_0 | 0; //@line 32458
 } else if ((label | 0) == 13417) {
  STACKTOP = sp; //@line 32462
  return $_0 | 0; //@line 32463
 } else if ((label | 0) == 13418) {
  STACKTOP = sp; //@line 32467
  return $_0 | 0; //@line 32468
 } else if ((label | 0) == 13419) {
  STACKTOP = sp; //@line 32472
  return $_0 | 0; //@line 32473
 } else if ((label | 0) == 13421) {
  STACKTOP = sp; //@line 32477
  return $_0 | 0; //@line 32478
 } else if ((label | 0) == 13426) {
  STACKTOP = sp; //@line 32482
  return $_0 | 0; //@line 32483
 } else if ((label | 0) == 13429) {
  STACKTOP = sp; //@line 32487
  return $_0 | 0; //@line 32488
 } else if ((label | 0) == 13430) {
  STACKTOP = sp; //@line 32492
  return $_0 | 0; //@line 32493
 } else if ((label | 0) == 13431) {
  STACKTOP = sp; //@line 32497
  return $_0 | 0; //@line 32498
 } else if ((label | 0) == 13432) {
  STACKTOP = sp; //@line 32502
  return $_0 | 0; //@line 32503
 } else if ((label | 0) == 13433) {
  STACKTOP = sp; //@line 32507
  return $_0 | 0; //@line 32508
 } else if ((label | 0) == 13436) {
  STACKTOP = sp; //@line 32512
  return $_0 | 0; //@line 32513
 } else if ((label | 0) == 13439) {
  STACKTOP = sp; //@line 32517
  return $_0 | 0; //@line 32518
 }
 return 0;
}
function _pfdc4_save_fp($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $crc_i21 = 0, $buf_i22 = 0, $crc_i = 0, $buf_i19 = 0, $1 = 0, $5 = 0, $6 = 0, $11 = 0, $12 = 0, $17 = 0, $19 = 0, $24 = 0, $25 = 0, $27 = 0, $28 = 0, $c_034 = 0, $31 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $h_029 = 0, $39 = 0, $40 = 0, $43 = 0, $s_028 = 0, $47 = 0, $sct_pn_i = 0, $_012_i = 0, $60 = 0, $61 = 0, $64 = 0, $65 = 0, $69 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 32538
 STACKTOP = STACKTOP + 48 | 0; //@line 32538
 $crc_i21 = sp | 0; //@line 32539
 $buf_i22 = sp + 8 | 0; //@line 32540
 $crc_i = sp + 16 | 0; //@line 32541
 $buf_i19 = sp + 24 | 0; //@line 32542
 $1 = sp + 40 | 0; //@line 32544
 _psi_set_uint16_be($1, 0, 4); //@line 32545
 _psi_set_uint16_be($1, 2, 0); //@line 32546
 if ((_pfdc4_save_chunk($fp, 1346782275, 4, $1) | 0) != 0) {
  $_0 = 1; //@line 32551
  STACKTOP = sp; //@line 32553
  return $_0 | 0; //@line 32554
 }
 $5 = $buf_i19 | 0; //@line 32557
 $6 = $img + 8 | 0; //@line 32558
 do {
  if ((HEAP32[$6 >> 2] | 0) != 0) {
   _psi_set_uint32_be($5, 0, 1413830740); //@line 32564
   _psi_set_uint32_be($5, 4, (HEAP32[$6 >> 2] | 0) + 2 | 0); //@line 32567
   $11 = $buf_i19 + 8 | 0; //@line 32568
   HEAP8[$11] = 10; //@line 32569
   HEAP32[$crc_i >> 2] = 0; //@line 32570
   $12 = _pfdc4_write($fp, $5, 9, $crc_i) | 0; //@line 32571
   $17 = _pfdc4_write($fp, HEAP32[$img + 12 >> 2] | 0, HEAP32[$6 >> 2] | 0, $crc_i) | 0 | $12; //@line 32576
   $19 = $17 | (_pfdc4_write($fp, $11, 1, $crc_i) | 0); //@line 32578
   _psi_set_uint32_be($5, 0, HEAP32[$crc_i >> 2] | 0); //@line 32580
   if (($19 | (_fwrite($5 | 0, 1, 4, $fp | 0) | 0) != 4 | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 32590
   }
   STACKTOP = sp; //@line 32593
   return $_0 | 0; //@line 32594
  }
 } while (0);
 $24 = $img | 0; //@line 32597
 $25 = HEAP16[$24 >> 1] | 0; //@line 32598
 L17029 : do {
  if ($25 << 16 >> 16 != 0) {
   $27 = $img + 4 | 0; //@line 32603
   $c_034 = 0;
   $28 = $25;
   L17031 : while (1) {
    $31 = HEAP32[(HEAP32[$27 >> 2] | 0) + ($c_034 << 2) >> 2] | 0; //@line 32611
    $32 = $31 + 2 | 0; //@line 32612
    $33 = HEAP16[$32 >> 1] | 0; //@line 32613
    if ($33 << 16 >> 16 == 0) {
     $64 = $28; //@line 32617
    } else {
     $35 = $31 + 4 | 0; //@line 32619
     $h_029 = 0;
     $36 = $33;
     while (1) {
      $39 = HEAP32[(HEAP32[$35 >> 2] | 0) + ($h_029 << 2) >> 2] | 0; //@line 32627
      $40 = $39 + 2 | 0; //@line 32628
      if ((HEAP16[$40 >> 1] | 0) == 0) {
       $60 = $36; //@line 32633
      } else {
       $43 = $39 + 4 | 0; //@line 32635
       $s_028 = 0; //@line 32637
       do {
        $47 = HEAP32[(HEAP32[$43 >> 2] | 0) + ($s_028 << 2) >> 2] | 0; //@line 32642
        if ((_pfdc4_save_sector($fp, $47, $c_034, $h_029, 0) | 0) == 0) {
         $sct_pn_i = $47; //@line 32647
        } else {
         $_0 = 1; //@line 32649
         label = 13468; //@line 32650
         break L17031;
        }
        while (1) {
         $_012_i = HEAP32[$sct_pn_i >> 2] | 0; //@line 32656
         if (($_012_i | 0) == 0) {
          break;
         }
         if ((_pfdc4_save_sector($fp, $_012_i, $c_034, $h_029, 1) | 0) == 0) {
          $sct_pn_i = $_012_i; //@line 32666
         } else {
          $_0 = 1; //@line 32668
          label = 13465; //@line 32669
          break L17031;
         }
        }
        $s_028 = $s_028 + 1 | 0; //@line 32673
       } while ($s_028 >>> 0 < (HEAPU16[$40 >> 1] | 0) >>> 0);
       $60 = HEAP16[$32 >> 1] | 0; //@line 32686
      }
      $61 = $h_029 + 1 | 0; //@line 32689
      if ($61 >>> 0 < ($60 & 65535) >>> 0) {
       $h_029 = $61;
       $36 = $60;
      } else {
       break;
      }
     }
     $64 = HEAP16[$24 >> 1] | 0; //@line 32701
    }
    $65 = $c_034 + 1 | 0; //@line 32704
    if ($65 >>> 0 < ($64 & 65535) >>> 0) {
     $c_034 = $65;
     $28 = $64;
    } else {
     break L17029;
    }
   }
   if ((label | 0) == 13468) {
    STACKTOP = sp; //@line 32716
    return $_0 | 0; //@line 32717
   } else if ((label | 0) == 13465) {
    STACKTOP = sp; //@line 32721
    return $_0 | 0; //@line 32722
   }
  }
 } while (0);
 $69 = $buf_i22 | 0; //@line 32727
 _psi_set_uint32_be($69, 0, 1162757152); //@line 32728
 _psi_set_uint32_be($69, 4, 0); //@line 32729
 HEAP32[$crc_i21 >> 2] = 0; //@line 32730
 if ((_pfdc4_write($fp, $69, 8, $crc_i21) | 0) != 0) {
  $_0 = 1; //@line 32735
  STACKTOP = sp; //@line 32737
  return $_0 | 0; //@line 32738
 }
 _psi_set_uint32_be($69, 0, HEAP32[$crc_i21 >> 2] | 0); //@line 32741
 if ((_fwrite($69 | 0, 1, 4, $fp | 0) | 0) != 4) {
  $_0 = 1; //@line 32746
  STACKTOP = sp; //@line 32748
  return $_0 | 0; //@line 32749
 }
 _fflush($fp | 0) | 0; //@line 32751
 $_0 = 0; //@line 32753
 STACKTOP = sp; //@line 32755
 return $_0 | 0; //@line 32756
}
function _pfdc4_save_chunk($fp, $ckid, $size, $data) {
 $fp = $fp | 0;
 $ckid = $ckid | 0;
 $size = $size | 0;
 $data = $data | 0;
 var $crc = 0, $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 32768
 STACKTOP = STACKTOP + 16 | 0; //@line 32768
 $crc = sp | 0; //@line 32769
 $1 = sp + 8 | 0; //@line 32771
 _psi_set_uint32_be($1, 0, $ckid); //@line 32772
 _psi_set_uint32_be($1, 4, $size); //@line 32773
 HEAP32[$crc >> 2] = 0; //@line 32774
 if ((_pfdc4_write($fp, $1, 8, $crc) | 0) != 0) {
  $_0 = 1; //@line 32779
  STACKTOP = sp; //@line 32781
  return $_0 | 0; //@line 32782
 }
 do {
  if (($size | 0) != 0) {
   if ((_pfdc4_write($fp, $data, $size, $crc) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 32794
   }
   STACKTOP = sp; //@line 32797
   return $_0 | 0; //@line 32798
  }
 } while (0);
 _psi_set_uint32_be($1, 0, HEAP32[$crc >> 2] | 0); //@line 32802
 $_0 = (_fwrite($1 | 0, 1, 4, $fp | 0) | 0) != 4 | 0; //@line 32807
 STACKTOP = sp; //@line 32809
 return $_0 | 0; //@line 32810
}
function _pfdc4_write($fp, $buf, $cnt, $crc) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $crc = $crc | 0;
 var $3 = 0, $i_017_i = 0, $5 = 0, $reg_1_i = 0, $8 = 0, $reg_1_1_i = 0, $11 = 0, $reg_1_2_i = 0, $14 = 0, $reg_1_3_i = 0, $17 = 0, $reg_1_4_i = 0, $20 = 0, $reg_1_5_i = 0, $23 = 0, $reg_1_6_i = 0, $26 = 0, $src_013_i = 0, $_012_i = 0, $_01011_i = 0, $41 = 0, $42 = 0, $_0_lcssa_i = 0, $45 = 0, $not_ = 0, $_ = 0;
 if (($crc | 0) == 0) {
  $45 = _fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0; //@line 32832
  $not_ = ($45 | 0) != ($cnt | 0); //@line 32833
  $_ = $not_ & 1; //@line 32834
  return $_ | 0; //@line 32836
 }
 $3 = HEAP32[$crc >> 2] | 0; //@line 32838
 if (!(HEAP8[6664] | 0)) {
  $i_017_i = 0; //@line 32842
  do {
   $5 = $i_017_i << 25; //@line 32847
   $reg_1_i = ($i_017_i & 128 | 0) != 0 ? $5 ^ 517762881 : $5; //@line 32849
   $8 = $reg_1_i << 1; //@line 32851
   $reg_1_1_i = ($reg_1_i | 0) < 0 ? $8 ^ 517762881 : $8; //@line 32853
   $11 = $reg_1_1_i << 1; //@line 32855
   $reg_1_2_i = ($reg_1_1_i | 0) < 0 ? $11 ^ 517762881 : $11; //@line 32857
   $14 = $reg_1_2_i << 1; //@line 32859
   $reg_1_3_i = ($reg_1_2_i | 0) < 0 ? $14 ^ 517762881 : $14; //@line 32861
   $17 = $reg_1_3_i << 1; //@line 32863
   $reg_1_4_i = ($reg_1_3_i | 0) < 0 ? $17 ^ 517762881 : $17; //@line 32865
   $20 = $reg_1_4_i << 1; //@line 32867
   $reg_1_5_i = ($reg_1_4_i | 0) < 0 ? $20 ^ 517762881 : $20; //@line 32869
   $23 = $reg_1_5_i << 1; //@line 32871
   $reg_1_6_i = ($reg_1_5_i | 0) < 0 ? $23 ^ 517762881 : $23; //@line 32873
   $26 = $reg_1_6_i << 1; //@line 32875
   HEAP32[60264 + ($i_017_i << 2) >> 2] = ($reg_1_6_i | 0) < 0 ? $26 ^ 517762881 : $26; //@line 32879
   $i_017_i = $i_017_i + 1 | 0; //@line 32880
  } while ($i_017_i >>> 0 < 256);
  HEAP8[6664] = 1; //@line 32889
 }
 if (($cnt | 0) == 0) {
  $_0_lcssa_i = $3; //@line 32895
 } else {
  $_01011_i = $cnt;
  $_012_i = $3;
  $src_013_i = $buf;
  while (1) {
   $41 = HEAP32[60264 + (((HEAPU8[$src_013_i] | 0) ^ $_012_i >>> 24) << 2) >> 2] ^ $_012_i << 8; //@line 32910
   $42 = $_01011_i - 1 | 0; //@line 32911
   if (($42 | 0) == 0) {
    $_0_lcssa_i = $41; //@line 32915
    break;
   } else {
    $_01011_i = $42;
    $_012_i = $41;
    $src_013_i = $src_013_i + 1 | 0;
   }
  }
 }
 HEAP32[$crc >> 2] = $_0_lcssa_i; //@line 32923
 $45 = _fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0; //@line 32925
 $not_ = ($45 | 0) != ($cnt | 0); //@line 32926
 $_ = $not_ & 1; //@line 32927
 return $_ | 0; //@line 32929
}
function _pfdc4_save_sector($fp, $sct, $c, $h, $alt) {
 $fp = $fp | 0;
 $sct = $sct | 0;
 $c = $c | 0;
 $h = $h | 0;
 $alt = $alt | 0;
 var $buf = 0, $sct_idx_val = 0, $1 = 0, $f_1_i = 0, $f_1__i = 0, $f_3_i = 0, $_pre = 0, $flg_0 = 0, $flg_1 = 0, $19 = 0, $31 = 0, $44 = 0, $57 = 0, $i_0 = 0, $71 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 32950
 STACKTOP = STACKTOP + 256 | 0; //@line 32950
 $buf = sp | 0; //@line 32951
 $sct_idx_val = HEAP32[$sct + 12 >> 2] | 0; //@line 32953
 $1 = $sct_idx_val & 1; //@line 32954
 $f_1_i = ($sct_idx_val & 2 | 0) == 0 ? $1 : $1 | 2; //@line 32958
 $f_1__i = ($sct_idx_val & 4 | 0) == 0 ? $f_1_i : $f_1_i | 4; //@line 32962
 $f_3_i = ($sct_idx_val & 8 | 0) == 0 ? $f_1__i : $f_1__i | 8; //@line 32966
 $_pre = $sct + 10 | 0; //@line 32969
 if ((_psi_sct_uniform($sct) | 0) == 0) {
  $flg_0 = $f_3_i; //@line 32972
 } else {
  $flg_0 = (HEAP16[$_pre >> 1] | 0) == 0 ? $f_3_i : $f_3_i | 32768; //@line 32979
 }
 $flg_1 = ($alt | 0) == 0 ? $flg_0 : $flg_0 | 16384; //@line 32984
 $19 = $buf | 0; //@line 32985
 _psi_set_uint16_be($19, 0, $c); //@line 32986
 _psi_set_uint16_be($19, 2, $h); //@line 32987
 _psi_set_uint16_be($19, 4, HEAPU16[$sct + 4 >> 1] | 0); //@line 32991
 _psi_set_uint16_be($19, 6, HEAPU16[$sct + 6 >> 1] | 0); //@line 32995
 _psi_set_uint16_be($19, 8, HEAPU16[$sct + 8 >> 1] | 0); //@line 32999
 _psi_set_uint16_be($19, 10, HEAPU16[$_pre >> 1] | 0); //@line 33002
 _psi_set_uint16_be($19, 12, 0); //@line 33003
 _psi_set_uint16_be($19, 14, $flg_1); //@line 33004
 $31 = $sct + 16 | 0; //@line 33005
 _psi_set_uint16_be($19, 16, HEAPU16[$31 >> 1] | 0); //@line 33008
 if (($flg_1 & 32768 | 0) != 0) {
  HEAP8[$buf + 13 | 0] = HEAP8[HEAP32[$sct + 24 >> 2] | 0] | 0; //@line 33017
 }
 $44 = HEAP16[$31 >> 1] & 4095; //@line 33022
 if (($44 | 0) == 1 | ($44 | 0) == 2) {
  HEAP8[$buf + 12 | 0] = (_psi_sct_get_mfm_size($sct) | 0) & 255; //@line 33027
 } else if (($44 | 0) == 3) {
  HEAP8[$buf + 12 | 0] = (_psi_sct_get_gcr_format($sct) | 0) & 255; //@line 33033
 }
 if ((_pfdc4_save_chunk($fp, 1397048148, 18, $19) | 0) != 0) {
  $_0 = 1; //@line 33040
  STACKTOP = sp; //@line 33042
  return $_0 | 0; //@line 33043
 }
 $57 = _psi_sct_get_tags($sct, $19, 256) | 0; //@line 33045
 L17097 : do {
  if (($57 | 0) != 0) {
   $i_0 = 0; //@line 33050
   while (1) {
    if ($i_0 >>> 0 >= $57 >>> 0) {
     break L17097;
    }
    if ((HEAP8[$buf + $i_0 | 0] | 0) == 0) {
     $i_0 = $i_0 + 1 | 0; //@line 33064
    } else {
     break;
    }
   }
   if ((_pfdc4_save_chunk($fp, 1413564243, $57, $19) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 33075
   }
   STACKTOP = sp; //@line 33078
   return $_0 | 0; //@line 33079
  }
 } while (0);
 do {
  if (($flg_1 & 32776 | 0) == 0) {
   $71 = HEAP16[$_pre >> 1] | 0; //@line 33087
   if ($71 << 16 >> 16 == 0) {
    break;
   }
   if ((_pfdc4_save_chunk($fp, 1145132097, $71 & 65535, HEAP32[$sct + 24 >> 2] | 0) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 33102
   }
   STACKTOP = sp; //@line 33105
   return $_0 | 0; //@line 33106
  }
 } while (0);
 $_0 = 0; //@line 33110
 STACKTOP = sp; //@line 33112
 return $_0 | 0; //@line 33113
}
function _psi_load_psi($fp) {
 $fp = $fp | 0;
 var $buf_i195_i = 0, $buf_i151_i = 0, $buf_i_i_i = 0, $buf_i_i = 0, $buf_i = 0, $1 = 0, $4 = 0, $i_017_i_i = 0, $9 = 0, $reg_1_i_i = 0, $12 = 0, $reg_1_1_i_i = 0, $15 = 0, $reg_1_2_i_i = 0, $18 = 0, $reg_1_3_i_i = 0, $21 = 0, $reg_1_4_i_i = 0, $24 = 0, $reg_1_5_i_i = 0, $27 = 0, $reg_1_6_i_i = 0, $30 = 0, $36 = 0, $40 = 0, $42 = 0, $49 = 0, $51 = 0, $58 = 0, $60 = 0, $67 = 0, $69 = 0, $76 = 0, $78 = 0, $85 = 0, $87 = 0, $94 = 0, $102 = 0, $103 = 0, $104 = 0, $107 = 0, $i_017_i_i_i = 0, $114 = 0, $reg_1_i_i_i = 0, $117 = 0, $reg_1_1_i_i_i = 0, $120 = 0, $reg_1_2_i_i_i = 0, $123 = 0, $reg_1_3_i_i_i = 0, $126 = 0, $reg_1_4_i_i_i = 0, $129 = 0, $reg_1_5_i_i_i = 0, $132 = 0, $reg_1_6_i_i_i = 0, $135 = 0, $142 = 0, $149 = 0, $151 = 0, $158 = 0, $160 = 0, $167 = 0, $175 = 0, $176 = 0, $179 = 0, $182 = 0, $enc_0_load359_i = 0, $190 = 0, $191 = 0, $_08_i49_i_i = 0, $crc404248_i_i = 0, $194 = 0, $i_017_i17_i_i = 0, $199 = 0, $reg_1_i19_i_i = 0, $202 = 0, $reg_1_1_i20_i_i = 0, $205 = 0, $reg_1_2_i21_i_i = 0, $208 = 0, $reg_1_3_i22_i_i = 0, $211 = 0, $reg_1_4_i23_i_i = 0, $214 = 0, $reg_1_5_i24_i_i = 0, $217 = 0, $reg_1_6_i25_i_i = 0, $220 = 0, $src_013_i29_i_i = 0, $_012_i30_i_i = 0, $_01011_i31_i_i = 0, $235 = 0, $236 = 0, $crc4041_ph_i_i = 0, $crc4042_lcssa_i_i = 0, $247 = 0, $248 = 0, $249 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $260 = 0, $262 = 0, $265 = 0, $i_017_i39_i = 0, $267 = 0, $reg_1_i41_i = 0, $270 = 0, $reg_1_1_i42_i = 0, $273 = 0, $reg_1_2_i43_i = 0, $276 = 0, $reg_1_3_i44_i = 0, $279 = 0, $reg_1_4_i45_i = 0, $282 = 0, $reg_1_5_i46_i = 0, $285 = 0, $reg_1_6_i47_i = 0, $288 = 0, $297 = 0, $305 = 0, $313 = 0, $321 = 0, $329 = 0, $337 = 0, $345 = 0, $353 = 0, $354 = 0, $355 = 0, $_08_i17_i_i = 0, $crc1116_i_i = 0, $359 = 0, $i_017_i_i60_i = 0, $364 = 0, $reg_1_i_i62_i = 0, $367 = 0, $reg_1_1_i_i63_i = 0, $370 = 0, $reg_1_2_i_i64_i = 0, $373 = 0, $reg_1_3_i_i65_i = 0, $376 = 0, $reg_1_4_i_i66_i = 0, $379 = 0, $reg_1_5_i_i67_i = 0, $382 = 0, $reg_1_6_i_i68_i = 0, $385 = 0, $src_013_i_i_i = 0, $_012_i_i_i = 0, $_01011_i_i_i = 0, $400 = 0, $401 = 0, $crc10_ph_i_i = 0, $crc11_lcssa_i_i = 0, $411 = 0, $i_017_i_i76_i = 0, $420 = 0, $reg_1_i_i78_i = 0, $423 = 0, $reg_1_1_i_i79_i = 0, $426 = 0, $reg_1_2_i_i80_i = 0, $429 = 0, $reg_1_3_i_i81_i = 0, $432 = 0, $reg_1_4_i_i82_i = 0, $435 = 0, $reg_1_5_i_i83_i = 0, $438 = 0, $reg_1_6_i_i84_i = 0, $441 = 0, $454 = 0, $462 = 0, $470 = 0, $478 = 0, $486 = 0, $494 = 0, $502 = 0, $510 = 0, $511 = 0, $513 = 0, $515 = 0, $516 = 0, $518 = 0, $519 = 0, $538 = 0, $542 = 0, $_08_i58_i_i = 0, $crc495157_i_i = 0, $551 = 0, $i_017_i26_i_i = 0, $556 = 0, $reg_1_i28_i_i = 0, $559 = 0, $reg_1_1_i29_i_i = 0, $562 = 0, $reg_1_2_i30_i_i = 0, $565 = 0, $reg_1_3_i31_i_i = 0, $568 = 0, $reg_1_4_i32_i_i = 0, $571 = 0, $reg_1_5_i33_i_i = 0, $574 = 0, $reg_1_6_i34_i_i = 0, $577 = 0, $src_013_i38_i_i = 0, $_012_i39_i_i = 0, $_01011_i40_i_i = 0, $592 = 0, $593 = 0, $crc4950_ph_i_i = 0, $crc4951_lcssa_i_i = 0, $i_017_i_i94_i = 0, $613 = 0, $reg_1_i_i96_i = 0, $616 = 0, $reg_1_1_i_i97_i = 0, $619 = 0, $reg_1_2_i_i98_i = 0, $622 = 0, $reg_1_3_i_i99_i = 0, $625 = 0, $reg_1_4_i_i100_i = 0, $628 = 0, $reg_1_5_i_i101_i = 0, $631 = 0, $reg_1_6_i_i102_i = 0, $634 = 0, $641 = 0, $647 = 0, $649 = 0, $655 = 0, $657 = 0, $663 = 0, $665 = 0, $671 = 0, $673 = 0, $679 = 0, $681 = 0, $687 = 0, $697 = 0, $704 = 0, $711 = 0, $718 = 0, $725 = 0, $_08_i37_i_i = 0, $crc283036_i_i = 0, $728 = 0, $i_017_i5_i_i = 0, $733 = 0, $reg_1_i7_i_i = 0, $736 = 0, $reg_1_1_i8_i_i = 0, $739 = 0, $reg_1_2_i9_i_i = 0, $742 = 0, $reg_1_3_i10_i_i = 0, $745 = 0, $reg_1_4_i11_i_i = 0, $748 = 0, $reg_1_5_i12_i_i = 0, $751 = 0, $reg_1_6_i13_i_i = 0, $754 = 0, $src_013_i17_i_i = 0, $_012_i18_i_i = 0, $_01011_i19_i_i = 0, $769 = 0, $770 = 0, $crc2829_ph_i_i = 0, $crc2830_lcssa_i_i = 0, $i_017_i_i113_i = 0, $790 = 0, $reg_1_i_i115_i = 0, $793 = 0, $reg_1_1_i_i116_i = 0, $796 = 0, $reg_1_2_i_i117_i = 0, $799 = 0, $reg_1_3_i_i118_i = 0, $802 = 0, $reg_1_4_i_i119_i = 0, $805 = 0, $reg_1_5_i_i120_i = 0, $808 = 0, $reg_1_6_i_i121_i = 0, $811 = 0, $818 = 0, $824 = 0, $826 = 0, $832 = 0, $834 = 0, $840 = 0, $842 = 0, $848 = 0, $850 = 0, $856 = 0, $859 = 0, $864 = 0, $874 = 0, $881 = 0, $888 = 0, $895 = 0, $903 = 0, $_08_i37_i125_i = 0, $crc283036_i126_i = 0, $906 = 0, $i_017_i5_i129_i = 0, $911 = 0, $reg_1_i7_i131_i = 0, $914 = 0, $reg_1_1_i8_i132_i = 0, $917 = 0, $reg_1_2_i9_i133_i = 0, $920 = 0, $reg_1_3_i10_i134_i = 0, $923 = 0, $reg_1_4_i11_i135_i = 0, $926 = 0, $reg_1_5_i12_i136_i = 0, $929 = 0, $reg_1_6_i13_i137_i = 0, $932 = 0, $src_013_i17_i141_i = 0, $_012_i18_i142_i = 0, $_01011_i19_i143_i = 0, $947 = 0, $948 = 0, $crc2829_ph_i145_i = 0, $crc2830_lcssa_i147_i = 0, $i_017_i_i154_i = 0, $968 = 0, $reg_1_i_i156_i = 0, $971 = 0, $reg_1_1_i_i157_i = 0, $974 = 0, $reg_1_2_i_i158_i = 0, $977 = 0, $reg_1_3_i_i159_i = 0, $980 = 0, $reg_1_4_i_i160_i = 0, $983 = 0, $reg_1_5_i_i161_i = 0, $986 = 0, $reg_1_6_i_i162_i = 0, $989 = 0, $src_013_i_i165_i = 0, $_012_i_i166_i = 0, $_01011_i_i167_i = 0, $1003 = 0, $1004 = 0, $1017 = 0, $1021 = 0, $1028 = 0, $1035 = 0, $1040 = 0, $_08_i37_i169_i = 0, $crc283036_i170_i = 0, $1043 = 0, $i_017_i5_i173_i = 0, $1048 = 0, $reg_1_i7_i175_i = 0, $1051 = 0, $reg_1_1_i8_i176_i = 0, $1054 = 0, $reg_1_2_i9_i177_i = 0, $1057 = 0, $reg_1_3_i10_i178_i = 0, $1060 = 0, $reg_1_4_i11_i179_i = 0, $1063 = 0, $reg_1_5_i12_i180_i = 0, $1066 = 0, $reg_1_6_i13_i181_i = 0, $1069 = 0, $src_013_i17_i185_i = 0, $_012_i18_i186_i = 0, $_01011_i19_i187_i = 0, $1084 = 0, $1085 = 0, $crc2829_ph_i189_i = 0, $crc2830_lcssa_i191_i = 0, $i_017_i_i198_i = 0, $1105 = 0, $reg_1_i_i200_i = 0, $1108 = 0, $reg_1_1_i_i201_i = 0, $1111 = 0, $reg_1_2_i_i202_i = 0, $1114 = 0, $reg_1_3_i_i203_i = 0, $1117 = 0, $reg_1_4_i_i204_i = 0, $1120 = 0, $reg_1_5_i_i205_i = 0, $1123 = 0, $reg_1_6_i_i206_i = 0, $1126 = 0, $1139 = 0, $1147 = 0, $1155 = 0, $1163 = 0, $1165 = 0, $_08_i37_i210_i = 0, $crc283036_i211_i = 0, $1168 = 0, $i_017_i5_i214_i = 0, $1173 = 0, $reg_1_i7_i216_i = 0, $1176 = 0, $reg_1_1_i8_i217_i = 0, $1179 = 0, $reg_1_2_i9_i218_i = 0, $1182 = 0, $reg_1_3_i10_i219_i = 0, $1185 = 0, $reg_1_4_i11_i220_i = 0, $1188 = 0, $reg_1_5_i12_i221_i = 0, $1191 = 0, $reg_1_6_i13_i222_i = 0, $1194 = 0, $src_013_i17_i226_i = 0, $_012_i18_i227_i = 0, $_01011_i19_i228_i = 0, $1209 = 0, $1210 = 0, $crc2829_ph_i230_i = 0, $crc2830_lcssa_i232_i = 0, $i_017_i_i239_i = 0, $1230 = 0, $reg_1_i_i241_i = 0, $1233 = 0, $reg_1_1_i_i242_i = 0, $1236 = 0, $reg_1_2_i_i243_i = 0, $1239 = 0, $reg_1_3_i_i244_i = 0, $1242 = 0, $reg_1_4_i_i245_i = 0, $1245 = 0, $reg_1_5_i_i246_i = 0, $1248 = 0, $reg_1_6_i_i247_i = 0, $1251 = 0, $1264 = 0, $1272 = 0, $1280 = 0, $1288 = 0, $1290 = 0, $_08_i37_i251_i = 0, $crc283036_i252_i = 0, $1293 = 0, $i_017_i5_i255_i = 0, $1298 = 0, $reg_1_i7_i257_i = 0, $1301 = 0, $reg_1_1_i8_i258_i = 0, $1304 = 0, $reg_1_2_i9_i259_i = 0, $1307 = 0, $reg_1_3_i10_i260_i = 0, $1310 = 0, $reg_1_4_i11_i261_i = 0, $1313 = 0, $reg_1_5_i12_i262_i = 0, $1316 = 0, $reg_1_6_i13_i263_i = 0, $1319 = 0, $src_013_i17_i267_i = 0, $_012_i18_i268_i = 0, $_01011_i19_i269_i = 0, $1334 = 0, $1335 = 0, $crc2829_ph_i271_i = 0, $crc2830_lcssa_i273_i = 0, $1356 = 0, $i_017_i_i278_i = 0, $1361 = 0, $reg_1_i_i280_i = 0, $1364 = 0, $reg_1_1_i_i281_i = 0, $1367 = 0, $reg_1_2_i_i282_i = 0, $1370 = 0, $reg_1_3_i_i283_i = 0, $1373 = 0, $reg_1_4_i_i284_i = 0, $1376 = 0, $reg_1_5_i_i285_i = 0, $1379 = 0, $reg_1_6_i_i286_i = 0, $1382 = 0, $src_013_i_i289_i = 0, $_012_i_i290_i = 0, $_01011_i_i291_i = 0, $1396 = 0, $1397 = 0, $crc30_i_i = 0, $1416 = 0, $1419 = 0, $i_017_i_i296_i = 0, $1426 = 0, $reg_1_i_i298_i = 0, $1429 = 0, $reg_1_1_i_i299_i = 0, $1432 = 0, $reg_1_2_i_i300_i = 0, $1435 = 0, $reg_1_3_i_i301_i = 0, $1438 = 0, $reg_1_4_i_i302_i = 0, $1441 = 0, $reg_1_5_i_i303_i = 0, $1444 = 0, $reg_1_6_i_i304_i = 0, $1447 = 0, $src_013_i_i307_i = 0, $_012_i_i308_i = 0, $_01011_i_i309_i = 0, $1461 = 0, $1462 = 0, $1466 = 0, $_size_i_i = 0, $1470 = 0, $n_1_i_i = 0, $1476 = 0, $1483 = 0, $_0_i23_i_i = 0, $_be_i = 0, $_08_i396_i = 0, $1491 = 0, $1493 = 0, $i_017_i318_i = 0, $1498 = 0, $reg_1_i320_i = 0, $1501 = 0, $reg_1_1_i321_i = 0, $1504 = 0, $reg_1_2_i322_i = 0, $1507 = 0, $reg_1_3_i323_i = 0, $1510 = 0, $reg_1_4_i324_i = 0, $1513 = 0, $reg_1_5_i325_i = 0, $1516 = 0, $reg_1_6_i326_i = 0, $1519 = 0, $src_013_i330_i = 0, $_012_i331_i = 0, $_01011_i332_i = 0, $1534 = 0, $1535 = 0, $_ph372_i = 0, $_lcssa394_i = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 33335
 STACKTOP = STACKTOP + 304 | 0; //@line 33335
 $buf_i195_i = sp | 0; //@line 33336
 $buf_i151_i = sp + 8 | 0; //@line 33337
 $buf_i_i_i = sp + 32 | 0; //@line 33338
 $buf_i_i = sp + 288 | 0; //@line 33339
 $buf_i = sp + 296 | 0; //@line 33340
 $1 = _psi_img_new() | 0; //@line 33341
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 33345
  STACKTOP = sp; //@line 33347
  return $_0 | 0; //@line 33348
 }
 $4 = $buf_i | 0; //@line 33350
 L17114 : do {
  if ((_fread($4 | 0, 1, 8, $fp | 0) | 0) == 8) {
   if (!(HEAP8[6648] | 0)) {
    $i_017_i_i = 0; //@line 33359
    do {
     $9 = $i_017_i_i << 25; //@line 33364
     $reg_1_i_i = ($i_017_i_i & 128 | 0) != 0 ? $9 ^ 517762881 : $9; //@line 33366
     $12 = $reg_1_i_i << 1; //@line 33368
     $reg_1_1_i_i = ($reg_1_i_i | 0) < 0 ? $12 ^ 517762881 : $12; //@line 33370
     $15 = $reg_1_1_i_i << 1; //@line 33372
     $reg_1_2_i_i = ($reg_1_1_i_i | 0) < 0 ? $15 ^ 517762881 : $15; //@line 33374
     $18 = $reg_1_2_i_i << 1; //@line 33376
     $reg_1_3_i_i = ($reg_1_2_i_i | 0) < 0 ? $18 ^ 517762881 : $18; //@line 33378
     $21 = $reg_1_3_i_i << 1; //@line 33380
     $reg_1_4_i_i = ($reg_1_3_i_i | 0) < 0 ? $21 ^ 517762881 : $21; //@line 33382
     $24 = $reg_1_4_i_i << 1; //@line 33384
     $reg_1_5_i_i = ($reg_1_4_i_i | 0) < 0 ? $24 ^ 517762881 : $24; //@line 33386
     $27 = $reg_1_5_i_i << 1; //@line 33388
     $reg_1_6_i_i = ($reg_1_5_i_i | 0) < 0 ? $27 ^ 517762881 : $27; //@line 33390
     $30 = $reg_1_6_i_i << 1; //@line 33392
     HEAP32[58216 + ($i_017_i_i << 2) >> 2] = ($reg_1_6_i_i | 0) < 0 ? $30 ^ 517762881 : $30; //@line 33396
     $i_017_i_i = $i_017_i_i + 1 | 0; //@line 33397
    } while ($i_017_i_i >>> 0 < 256);
    HEAP8[6648] = 1; //@line 33406
   }
   $36 = $buf_i + 1 | 0; //@line 33409
   $40 = HEAP32[58216 + (HEAPU8[$4] << 2) >> 2] | 0; //@line 33413
   $42 = $buf_i + 2 | 0; //@line 33415
   $49 = HEAP32[58216 + ((HEAPU8[$36] ^ $40 >>> 24) << 2) >> 2] ^ $40 << 8; //@line 33422
   $51 = $buf_i + 3 | 0; //@line 33424
   $58 = HEAP32[58216 + ((HEAPU8[$42] ^ $49 >>> 24) << 2) >> 2] ^ $49 << 8; //@line 33431
   $60 = $buf_i + 4 | 0; //@line 33433
   $67 = HEAP32[58216 + ((HEAPU8[$51] ^ $58 >>> 24) << 2) >> 2] ^ $58 << 8; //@line 33440
   $69 = $buf_i + 5 | 0; //@line 33442
   $76 = HEAP32[58216 + ((HEAPU8[$60] ^ $67 >>> 24) << 2) >> 2] ^ $67 << 8; //@line 33449
   $78 = $buf_i + 6 | 0; //@line 33451
   $85 = HEAP32[58216 + ((HEAPU8[$69] ^ $76 >>> 24) << 2) >> 2] ^ $76 << 8; //@line 33458
   $87 = $buf_i + 7 | 0; //@line 33460
   $94 = HEAP32[58216 + ((HEAPU8[$78] ^ $85 >>> 24) << 2) >> 2] ^ $85 << 8; //@line 33467
   $102 = HEAP32[58216 + ((HEAPU8[$87] ^ $94 >>> 24) << 2) >> 2] ^ $94 << 8; //@line 33475
   $103 = _psi_get_uint32_be($4, 0) | 0; //@line 33476
   $104 = _psi_get_uint32_be($4, 4) | 0; //@line 33477
   if (($103 | 0) != 1347635488) {
    break;
   }
   $107 = $buf_i_i | 0; //@line 33483
   if ($104 >>> 0 < 4) {
    break;
   }
   if ((_fread($107 | 0, 1, 4, $fp | 0) | 0) != 4) {
    break;
   }
   if (!(HEAP8[6648] | 0)) {
    $i_017_i_i_i = 0; //@line 33498
    do {
     $114 = $i_017_i_i_i << 25; //@line 33503
     $reg_1_i_i_i = ($i_017_i_i_i & 128 | 0) != 0 ? $114 ^ 517762881 : $114; //@line 33505
     $117 = $reg_1_i_i_i << 1; //@line 33507
     $reg_1_1_i_i_i = ($reg_1_i_i_i | 0) < 0 ? $117 ^ 517762881 : $117; //@line 33509
     $120 = $reg_1_1_i_i_i << 1; //@line 33511
     $reg_1_2_i_i_i = ($reg_1_1_i_i_i | 0) < 0 ? $120 ^ 517762881 : $120; //@line 33513
     $123 = $reg_1_2_i_i_i << 1; //@line 33515
     $reg_1_3_i_i_i = ($reg_1_2_i_i_i | 0) < 0 ? $123 ^ 517762881 : $123; //@line 33517
     $126 = $reg_1_3_i_i_i << 1; //@line 33519
     $reg_1_4_i_i_i = ($reg_1_3_i_i_i | 0) < 0 ? $126 ^ 517762881 : $126; //@line 33521
     $129 = $reg_1_4_i_i_i << 1; //@line 33523
     $reg_1_5_i_i_i = ($reg_1_4_i_i_i | 0) < 0 ? $129 ^ 517762881 : $129; //@line 33525
     $132 = $reg_1_5_i_i_i << 1; //@line 33527
     $reg_1_6_i_i_i = ($reg_1_5_i_i_i | 0) < 0 ? $132 ^ 517762881 : $132; //@line 33529
     $135 = $reg_1_6_i_i_i << 1; //@line 33531
     HEAP32[58216 + ($i_017_i_i_i << 2) >> 2] = ($reg_1_6_i_i_i | 0) < 0 ? $135 ^ 517762881 : $135; //@line 33535
     $i_017_i_i_i = $i_017_i_i_i + 1 | 0; //@line 33536
    } while ($i_017_i_i_i >>> 0 < 256);
    HEAP8[6648] = 1; //@line 33545
   }
   $142 = $buf_i_i + 1 | 0; //@line 33549
   $149 = HEAP32[58216 + ((HEAPU8[$107] ^ $102 >>> 24) << 2) >> 2] ^ $102 << 8; //@line 33556
   $151 = $buf_i_i + 2 | 0; //@line 33558
   $158 = HEAP32[58216 + ((HEAPU8[$142] ^ $149 >>> 24) << 2) >> 2] ^ $149 << 8; //@line 33565
   $160 = $buf_i_i + 3 | 0; //@line 33567
   $167 = HEAP32[58216 + ((HEAPU8[$151] ^ $158 >>> 24) << 2) >> 2] ^ $158 << 8; //@line 33574
   $175 = HEAP32[58216 + ((HEAPU8[$160] ^ $167 >>> 24) << 2) >> 2] ^ $167 << 8; //@line 33582
   $176 = _psi_get_uint16_be($107, 0) | 0; //@line 33583
   if (($176 | 0) != 0) {
    $179 = HEAP32[_stderr >> 2] | 0; //@line 33587
    _fprintf($179 | 0, 46136, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $176, tempInt) | 0) | 0; //@line 33588
    break;
   }
   $182 = _psi_get_uint16_be($107, 2) | 0; //@line 33592
   if (($182 | 0) == 512) {
    $enc_0_load359_i = 2; //@line 33595
   } else if (($182 | 0) == 257) {
    $enc_0_load359_i = 32769; //@line 33598
   } else if (($182 | 0) == 256) {
    $enc_0_load359_i = 1; //@line 33600
   } else if (($182 | 0) == 513) {
    $enc_0_load359_i = 32770; //@line 33603
   } else if (($182 | 0) == 514) {
    $enc_0_load359_i = 16386; //@line 33606
   } else if (($182 | 0) == 768) {
    $enc_0_load359_i = 3; //@line 33609
   } else {
    $enc_0_load359_i = 0; //@line 33612
   }
   $190 = $104 - 4 | 0; //@line 33615
   $191 = $buf_i_i_i | 0; //@line 33616
   if (($190 | 0) == 0) {
    $crc4042_lcssa_i_i = $175; //@line 33620
   } else {
    $crc404248_i_i = $175;
    $_08_i49_i_i = $190;
    while (1) {
     $194 = $_08_i49_i_i >>> 0 < 256 ? $_08_i49_i_i : 256; //@line 33627
     if ((_fread($191 | 0, 1, $194 | 0, $fp | 0) | 0) != ($194 | 0)) {
      break L17114;
     }
     if (!(HEAP8[6648] | 0)) {
      $i_017_i17_i_i = 0; //@line 33637
      do {
       $199 = $i_017_i17_i_i << 25; //@line 33642
       $reg_1_i19_i_i = ($i_017_i17_i_i & 128 | 0) != 0 ? $199 ^ 517762881 : $199; //@line 33644
       $202 = $reg_1_i19_i_i << 1; //@line 33646
       $reg_1_1_i20_i_i = ($reg_1_i19_i_i | 0) < 0 ? $202 ^ 517762881 : $202; //@line 33648
       $205 = $reg_1_1_i20_i_i << 1; //@line 33650
       $reg_1_2_i21_i_i = ($reg_1_1_i20_i_i | 0) < 0 ? $205 ^ 517762881 : $205; //@line 33652
       $208 = $reg_1_2_i21_i_i << 1; //@line 33654
       $reg_1_3_i22_i_i = ($reg_1_2_i21_i_i | 0) < 0 ? $208 ^ 517762881 : $208; //@line 33656
       $211 = $reg_1_3_i22_i_i << 1; //@line 33658
       $reg_1_4_i23_i_i = ($reg_1_3_i22_i_i | 0) < 0 ? $211 ^ 517762881 : $211; //@line 33660
       $214 = $reg_1_4_i23_i_i << 1; //@line 33662
       $reg_1_5_i24_i_i = ($reg_1_4_i23_i_i | 0) < 0 ? $214 ^ 517762881 : $214; //@line 33664
       $217 = $reg_1_5_i24_i_i << 1; //@line 33666
       $reg_1_6_i25_i_i = ($reg_1_5_i24_i_i | 0) < 0 ? $217 ^ 517762881 : $217; //@line 33668
       $220 = $reg_1_6_i25_i_i << 1; //@line 33670
       HEAP32[58216 + ($i_017_i17_i_i << 2) >> 2] = ($reg_1_6_i25_i_i | 0) < 0 ? $220 ^ 517762881 : $220; //@line 33674
       $i_017_i17_i_i = $i_017_i17_i_i + 1 | 0; //@line 33675
      } while ($i_017_i17_i_i >>> 0 < 256);
      HEAP8[6648] = 1; //@line 33684
     }
     if (($194 | 0) == 0) {
      $crc4041_ph_i_i = $crc404248_i_i; //@line 33690
     } else {
      $_01011_i31_i_i = $194;
      $_012_i30_i_i = $crc404248_i_i;
      $src_013_i29_i_i = $191;
      while (1) {
       $235 = HEAP32[58216 + ((HEAPU8[$src_013_i29_i_i] ^ $_012_i30_i_i >>> 24) << 2) >> 2] ^ $_012_i30_i_i << 8; //@line 33705
       $236 = $_01011_i31_i_i - 1 | 0; //@line 33706
       if (($236 | 0) == 0) {
        $crc4041_ph_i_i = $235; //@line 33710
        break;
       } else {
        $_01011_i31_i_i = $236;
        $_012_i30_i_i = $235;
        $src_013_i29_i_i = $src_013_i29_i_i + 1 | 0;
       }
      }
     }
     if (($_08_i49_i_i | 0) == ($194 | 0)) {
      $crc4042_lcssa_i_i = $crc4041_ph_i_i; //@line 33722
      break;
     } else {
      $crc404248_i_i = $crc4041_ph_i_i;
      $_08_i49_i_i = $_08_i49_i_i - $194 | 0;
     }
    }
   }
   if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
    break;
   }
   if ((_psi_get_uint32_be($191, 0) | 0) != ($crc4042_lcssa_i_i | 0)) {
    $262 = HEAP32[_stderr >> 2] | 0; //@line 33740
    _fwrite(56464, 15, 1, $262 | 0) | 0; //@line 33741
    break;
   }
   if ((_fread($4 | 0, 1, 8, $fp | 0) | 0) != 8) {
    break;
   }
   $247 = $buf_i_i + 4 | 0; //@line 33751
   $248 = $buf_i_i + 5 | 0; //@line 33752
   $249 = $buf_i_i + 6 | 0; //@line 33753
   $250 = $buf_i_i + 7 | 0; //@line 33754
   $251 = $buf_i151_i | 0; //@line 33755
   $252 = $buf_i151_i + 2 | 0; //@line 33756
   $253 = $buf_i151_i + 3 | 0; //@line 33757
   $254 = $buf_i151_i + 4 | 0; //@line 33758
   $255 = $buf_i151_i + 5 | 0; //@line 33759
   $256 = $buf_i151_i + 6 | 0; //@line 33760
   $257 = $buf_i195_i | 0; //@line 33761
   $258 = $buf_i195_i + 1 | 0; //@line 33762
   $259 = $buf_i195_i + 2 | 0; //@line 33763
   $260 = $buf_i195_i + 3 | 0; //@line 33764
   $265 = 0; //@line 33766
   L17159 : while (1) {
    if (!(HEAP8[6648] | 0)) {
     $i_017_i39_i = 0; //@line 33772
     do {
      $267 = $i_017_i39_i << 25; //@line 33777
      $reg_1_i41_i = ($i_017_i39_i & 128 | 0) != 0 ? $267 ^ 517762881 : $267; //@line 33779
      $270 = $reg_1_i41_i << 1; //@line 33781
      $reg_1_1_i42_i = ($reg_1_i41_i | 0) < 0 ? $270 ^ 517762881 : $270; //@line 33783
      $273 = $reg_1_1_i42_i << 1; //@line 33785
      $reg_1_2_i43_i = ($reg_1_1_i42_i | 0) < 0 ? $273 ^ 517762881 : $273; //@line 33787
      $276 = $reg_1_2_i43_i << 1; //@line 33789
      $reg_1_3_i44_i = ($reg_1_2_i43_i | 0) < 0 ? $276 ^ 517762881 : $276; //@line 33791
      $279 = $reg_1_3_i44_i << 1; //@line 33793
      $reg_1_4_i45_i = ($reg_1_3_i44_i | 0) < 0 ? $279 ^ 517762881 : $279; //@line 33795
      $282 = $reg_1_4_i45_i << 1; //@line 33797
      $reg_1_5_i46_i = ($reg_1_4_i45_i | 0) < 0 ? $282 ^ 517762881 : $282; //@line 33799
      $285 = $reg_1_5_i46_i << 1; //@line 33801
      $reg_1_6_i47_i = ($reg_1_5_i46_i | 0) < 0 ? $285 ^ 517762881 : $285; //@line 33803
      $288 = $reg_1_6_i47_i << 1; //@line 33805
      HEAP32[58216 + ($i_017_i39_i << 2) >> 2] = ($reg_1_6_i47_i | 0) < 0 ? $288 ^ 517762881 : $288; //@line 33809
      $i_017_i39_i = $i_017_i39_i + 1 | 0; //@line 33810
     } while ($i_017_i39_i >>> 0 < 256);
     HEAP8[6648] = 1; //@line 33819
    }
    $297 = HEAP32[58216 + (HEAPU8[$4] << 2) >> 2] | 0; //@line 33825
    $305 = HEAP32[58216 + ((HEAPU8[$36] ^ $297 >>> 24) << 2) >> 2] ^ $297 << 8; //@line 33833
    $313 = HEAP32[58216 + ((HEAPU8[$42] ^ $305 >>> 24) << 2) >> 2] ^ $305 << 8; //@line 33841
    $321 = HEAP32[58216 + ((HEAPU8[$51] ^ $313 >>> 24) << 2) >> 2] ^ $313 << 8; //@line 33849
    $329 = HEAP32[58216 + ((HEAPU8[$60] ^ $321 >>> 24) << 2) >> 2] ^ $321 << 8; //@line 33857
    $337 = HEAP32[58216 + ((HEAPU8[$69] ^ $329 >>> 24) << 2) >> 2] ^ $329 << 8; //@line 33865
    $345 = HEAP32[58216 + ((HEAPU8[$78] ^ $337 >>> 24) << 2) >> 2] ^ $337 << 8; //@line 33873
    $353 = HEAP32[58216 + ((HEAPU8[$87] ^ $345 >>> 24) << 2) >> 2] ^ $345 << 8; //@line 33881
    $354 = _psi_get_uint32_be($4, 0) | 0; //@line 33882
    $355 = _psi_get_uint32_be($4, 4) | 0; //@line 33883
    do {
     if (($354 | 0) == 1414090053) {
      if (($265 | 0) == 0 | $355 >>> 0 < 4) {
       break L17114;
      }
      if ((_fread($257 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if (!(HEAP8[6648] | 0)) {
       $i_017_i_i239_i = 0; //@line 33902
       do {
        $1230 = $i_017_i_i239_i << 25; //@line 33907
        $reg_1_i_i241_i = ($i_017_i_i239_i & 128 | 0) != 0 ? $1230 ^ 517762881 : $1230; //@line 33909
        $1233 = $reg_1_i_i241_i << 1; //@line 33911
        $reg_1_1_i_i242_i = ($reg_1_i_i241_i | 0) < 0 ? $1233 ^ 517762881 : $1233; //@line 33913
        $1236 = $reg_1_1_i_i242_i << 1; //@line 33915
        $reg_1_2_i_i243_i = ($reg_1_1_i_i242_i | 0) < 0 ? $1236 ^ 517762881 : $1236; //@line 33917
        $1239 = $reg_1_2_i_i243_i << 1; //@line 33919
        $reg_1_3_i_i244_i = ($reg_1_2_i_i243_i | 0) < 0 ? $1239 ^ 517762881 : $1239; //@line 33921
        $1242 = $reg_1_3_i_i244_i << 1; //@line 33923
        $reg_1_4_i_i245_i = ($reg_1_3_i_i244_i | 0) < 0 ? $1242 ^ 517762881 : $1242; //@line 33925
        $1245 = $reg_1_4_i_i245_i << 1; //@line 33927
        $reg_1_5_i_i246_i = ($reg_1_4_i_i245_i | 0) < 0 ? $1245 ^ 517762881 : $1245; //@line 33929
        $1248 = $reg_1_5_i_i246_i << 1; //@line 33931
        $reg_1_6_i_i247_i = ($reg_1_5_i_i246_i | 0) < 0 ? $1248 ^ 517762881 : $1248; //@line 33933
        $1251 = $reg_1_6_i_i247_i << 1; //@line 33935
        HEAP32[58216 + ($i_017_i_i239_i << 2) >> 2] = ($reg_1_6_i_i247_i | 0) < 0 ? $1251 ^ 517762881 : $1251; //@line 33939
        $i_017_i_i239_i = $i_017_i_i239_i + 1 | 0; //@line 33940
       } while ($i_017_i_i239_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 33949
      }
      $1264 = HEAP32[58216 + ((HEAPU8[$257] ^ $353 >>> 24) << 2) >> 2] ^ $353 << 8; //@line 33959
      $1272 = HEAP32[58216 + ((HEAPU8[$258] ^ $1264 >>> 24) << 2) >> 2] ^ $1264 << 8; //@line 33967
      $1280 = HEAP32[58216 + ((HEAPU8[$259] ^ $1272 >>> 24) << 2) >> 2] ^ $1272 << 8; //@line 33975
      $1288 = HEAP32[58216 + ((HEAPU8[$260] ^ $1280 >>> 24) << 2) >> 2] ^ $1280 << 8; //@line 33983
      _psi_sct_set_read_time($265, _psi_get_uint32_be($257, 0) | 0); //@line 33985
      $1290 = $355 - 4 | 0; //@line 33986
      if (($1290 | 0) == 0) {
       $crc2830_lcssa_i273_i = $1288; //@line 33990
      } else {
       $crc283036_i252_i = $1288;
       $_08_i37_i251_i = $1290;
       while (1) {
        $1293 = $_08_i37_i251_i >>> 0 < 256 ? $_08_i37_i251_i : 256; //@line 33997
        if ((_fread($191 | 0, 1, $1293 | 0, $fp | 0) | 0) != ($1293 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i5_i255_i = 0; //@line 34007
         do {
          $1298 = $i_017_i5_i255_i << 25; //@line 34012
          $reg_1_i7_i257_i = ($i_017_i5_i255_i & 128 | 0) != 0 ? $1298 ^ 517762881 : $1298; //@line 34014
          $1301 = $reg_1_i7_i257_i << 1; //@line 34016
          $reg_1_1_i8_i258_i = ($reg_1_i7_i257_i | 0) < 0 ? $1301 ^ 517762881 : $1301; //@line 34018
          $1304 = $reg_1_1_i8_i258_i << 1; //@line 34020
          $reg_1_2_i9_i259_i = ($reg_1_1_i8_i258_i | 0) < 0 ? $1304 ^ 517762881 : $1304; //@line 34022
          $1307 = $reg_1_2_i9_i259_i << 1; //@line 34024
          $reg_1_3_i10_i260_i = ($reg_1_2_i9_i259_i | 0) < 0 ? $1307 ^ 517762881 : $1307; //@line 34026
          $1310 = $reg_1_3_i10_i260_i << 1; //@line 34028
          $reg_1_4_i11_i261_i = ($reg_1_3_i10_i260_i | 0) < 0 ? $1310 ^ 517762881 : $1310; //@line 34030
          $1313 = $reg_1_4_i11_i261_i << 1; //@line 34032
          $reg_1_5_i12_i262_i = ($reg_1_4_i11_i261_i | 0) < 0 ? $1313 ^ 517762881 : $1313; //@line 34034
          $1316 = $reg_1_5_i12_i262_i << 1; //@line 34036
          $reg_1_6_i13_i263_i = ($reg_1_5_i12_i262_i | 0) < 0 ? $1316 ^ 517762881 : $1316; //@line 34038
          $1319 = $reg_1_6_i13_i263_i << 1; //@line 34040
          HEAP32[58216 + ($i_017_i5_i255_i << 2) >> 2] = ($reg_1_6_i13_i263_i | 0) < 0 ? $1319 ^ 517762881 : $1319; //@line 34044
          $i_017_i5_i255_i = $i_017_i5_i255_i + 1 | 0; //@line 34045
         } while ($i_017_i5_i255_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 34054
        }
        if (($1293 | 0) == 0) {
         $crc2829_ph_i271_i = $crc283036_i252_i; //@line 34060
        } else {
         $_01011_i19_i269_i = $1293;
         $_012_i18_i268_i = $crc283036_i252_i;
         $src_013_i17_i267_i = $191;
         while (1) {
          $1334 = HEAP32[58216 + ((HEAPU8[$src_013_i17_i267_i] ^ $_012_i18_i268_i >>> 24) << 2) >> 2] ^ $_012_i18_i268_i << 8; //@line 34075
          $1335 = $_01011_i19_i269_i - 1 | 0; //@line 34076
          if (($1335 | 0) == 0) {
           $crc2829_ph_i271_i = $1334; //@line 34080
           break;
          } else {
           $_01011_i19_i269_i = $1335;
           $_012_i18_i268_i = $1334;
           $src_013_i17_i267_i = $src_013_i17_i267_i + 1 | 0;
          }
         }
        }
        if (($_08_i37_i251_i | 0) == ($1293 | 0)) {
         $crc2830_lcssa_i273_i = $crc2829_ph_i271_i; //@line 34092
         break;
        } else {
         $crc283036_i252_i = $crc2829_ph_i271_i;
         $_08_i37_i251_i = $_08_i37_i251_i - $1293 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc2830_lcssa_i273_i | 0)) {
       $_be_i = $265; //@line 34110
      } else {
       label = 13693; //@line 34112
       break L17159;
      }
     } else if (($354 | 0) == 1330005587) {
      if (($265 | 0) == 0 | $355 >>> 0 < 4) {
       break L17114;
      }
      if ((_fread($257 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if (!(HEAP8[6648] | 0)) {
       $i_017_i_i198_i = 0; //@line 34132
       do {
        $1105 = $i_017_i_i198_i << 25; //@line 34137
        $reg_1_i_i200_i = ($i_017_i_i198_i & 128 | 0) != 0 ? $1105 ^ 517762881 : $1105; //@line 34139
        $1108 = $reg_1_i_i200_i << 1; //@line 34141
        $reg_1_1_i_i201_i = ($reg_1_i_i200_i | 0) < 0 ? $1108 ^ 517762881 : $1108; //@line 34143
        $1111 = $reg_1_1_i_i201_i << 1; //@line 34145
        $reg_1_2_i_i202_i = ($reg_1_1_i_i201_i | 0) < 0 ? $1111 ^ 517762881 : $1111; //@line 34147
        $1114 = $reg_1_2_i_i202_i << 1; //@line 34149
        $reg_1_3_i_i203_i = ($reg_1_2_i_i202_i | 0) < 0 ? $1114 ^ 517762881 : $1114; //@line 34151
        $1117 = $reg_1_3_i_i203_i << 1; //@line 34153
        $reg_1_4_i_i204_i = ($reg_1_3_i_i203_i | 0) < 0 ? $1117 ^ 517762881 : $1117; //@line 34155
        $1120 = $reg_1_4_i_i204_i << 1; //@line 34157
        $reg_1_5_i_i205_i = ($reg_1_4_i_i204_i | 0) < 0 ? $1120 ^ 517762881 : $1120; //@line 34159
        $1123 = $reg_1_5_i_i205_i << 1; //@line 34161
        $reg_1_6_i_i206_i = ($reg_1_5_i_i205_i | 0) < 0 ? $1123 ^ 517762881 : $1123; //@line 34163
        $1126 = $reg_1_6_i_i206_i << 1; //@line 34165
        HEAP32[58216 + ($i_017_i_i198_i << 2) >> 2] = ($reg_1_6_i_i206_i | 0) < 0 ? $1126 ^ 517762881 : $1126; //@line 34169
        $i_017_i_i198_i = $i_017_i_i198_i + 1 | 0; //@line 34170
       } while ($i_017_i_i198_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 34179
      }
      $1139 = HEAP32[58216 + ((HEAPU8[$257] ^ $353 >>> 24) << 2) >> 2] ^ $353 << 8; //@line 34189
      $1147 = HEAP32[58216 + ((HEAPU8[$258] ^ $1139 >>> 24) << 2) >> 2] ^ $1139 << 8; //@line 34197
      $1155 = HEAP32[58216 + ((HEAPU8[$259] ^ $1147 >>> 24) << 2) >> 2] ^ $1147 << 8; //@line 34205
      $1163 = HEAP32[58216 + ((HEAPU8[$260] ^ $1155 >>> 24) << 2) >> 2] ^ $1155 << 8; //@line 34213
      _psi_sct_set_position($265, _psi_get_uint32_be($257, 0) | 0); //@line 34215
      $1165 = $355 - 4 | 0; //@line 34216
      if (($1165 | 0) == 0) {
       $crc2830_lcssa_i232_i = $1163; //@line 34220
      } else {
       $crc283036_i211_i = $1163;
       $_08_i37_i210_i = $1165;
       while (1) {
        $1168 = $_08_i37_i210_i >>> 0 < 256 ? $_08_i37_i210_i : 256; //@line 34227
        if ((_fread($191 | 0, 1, $1168 | 0, $fp | 0) | 0) != ($1168 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i5_i214_i = 0; //@line 34237
         do {
          $1173 = $i_017_i5_i214_i << 25; //@line 34242
          $reg_1_i7_i216_i = ($i_017_i5_i214_i & 128 | 0) != 0 ? $1173 ^ 517762881 : $1173; //@line 34244
          $1176 = $reg_1_i7_i216_i << 1; //@line 34246
          $reg_1_1_i8_i217_i = ($reg_1_i7_i216_i | 0) < 0 ? $1176 ^ 517762881 : $1176; //@line 34248
          $1179 = $reg_1_1_i8_i217_i << 1; //@line 34250
          $reg_1_2_i9_i218_i = ($reg_1_1_i8_i217_i | 0) < 0 ? $1179 ^ 517762881 : $1179; //@line 34252
          $1182 = $reg_1_2_i9_i218_i << 1; //@line 34254
          $reg_1_3_i10_i219_i = ($reg_1_2_i9_i218_i | 0) < 0 ? $1182 ^ 517762881 : $1182; //@line 34256
          $1185 = $reg_1_3_i10_i219_i << 1; //@line 34258
          $reg_1_4_i11_i220_i = ($reg_1_3_i10_i219_i | 0) < 0 ? $1185 ^ 517762881 : $1185; //@line 34260
          $1188 = $reg_1_4_i11_i220_i << 1; //@line 34262
          $reg_1_5_i12_i221_i = ($reg_1_4_i11_i220_i | 0) < 0 ? $1188 ^ 517762881 : $1188; //@line 34264
          $1191 = $reg_1_5_i12_i221_i << 1; //@line 34266
          $reg_1_6_i13_i222_i = ($reg_1_5_i12_i221_i | 0) < 0 ? $1191 ^ 517762881 : $1191; //@line 34268
          $1194 = $reg_1_6_i13_i222_i << 1; //@line 34270
          HEAP32[58216 + ($i_017_i5_i214_i << 2) >> 2] = ($reg_1_6_i13_i222_i | 0) < 0 ? $1194 ^ 517762881 : $1194; //@line 34274
          $i_017_i5_i214_i = $i_017_i5_i214_i + 1 | 0; //@line 34275
         } while ($i_017_i5_i214_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 34284
        }
        if (($1168 | 0) == 0) {
         $crc2829_ph_i230_i = $crc283036_i211_i; //@line 34290
        } else {
         $_01011_i19_i228_i = $1168;
         $_012_i18_i227_i = $crc283036_i211_i;
         $src_013_i17_i226_i = $191;
         while (1) {
          $1209 = HEAP32[58216 + ((HEAPU8[$src_013_i17_i226_i] ^ $_012_i18_i227_i >>> 24) << 2) >> 2] ^ $_012_i18_i227_i << 8; //@line 34305
          $1210 = $_01011_i19_i228_i - 1 | 0; //@line 34306
          if (($1210 | 0) == 0) {
           $crc2829_ph_i230_i = $1209; //@line 34310
           break;
          } else {
           $_01011_i19_i228_i = $1210;
           $_012_i18_i227_i = $1209;
           $src_013_i17_i226_i = $src_013_i17_i226_i + 1 | 0;
          }
         }
        }
        if (($_08_i37_i210_i | 0) == ($1168 | 0)) {
         $crc2830_lcssa_i232_i = $crc2829_ph_i230_i; //@line 34322
         break;
        } else {
         $crc283036_i211_i = $crc2829_ph_i230_i;
         $_08_i37_i210_i = $_08_i37_i210_i - $1168 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc2830_lcssa_i232_i | 0)) {
       $_be_i = $265; //@line 34340
      } else {
       label = 13677; //@line 34342
       break L17159;
      }
     } else if (($354 | 0) == 1296122695) {
      if (($265 | 0) == 0 | $355 >>> 0 < 18) {
       break L17114;
      }
      if ((_fread($251 | 0, 1, 18, $fp | 0) | 0) != 18) {
       break L17114;
      }
      if (HEAP8[6648] | 0) {
       $_01011_i_i167_i = 18;
       $_012_i_i166_i = $353;
       $src_013_i_i165_i = $251;
      } else {
       $i_017_i_i154_i = 0; //@line 34364
       do {
        $968 = $i_017_i_i154_i << 25; //@line 34369
        $reg_1_i_i156_i = ($i_017_i_i154_i & 128 | 0) != 0 ? $968 ^ 517762881 : $968; //@line 34371
        $971 = $reg_1_i_i156_i << 1; //@line 34373
        $reg_1_1_i_i157_i = ($reg_1_i_i156_i | 0) < 0 ? $971 ^ 517762881 : $971; //@line 34375
        $974 = $reg_1_1_i_i157_i << 1; //@line 34377
        $reg_1_2_i_i158_i = ($reg_1_1_i_i157_i | 0) < 0 ? $974 ^ 517762881 : $974; //@line 34379
        $977 = $reg_1_2_i_i158_i << 1; //@line 34381
        $reg_1_3_i_i159_i = ($reg_1_2_i_i158_i | 0) < 0 ? $977 ^ 517762881 : $977; //@line 34383
        $980 = $reg_1_3_i_i159_i << 1; //@line 34385
        $reg_1_4_i_i160_i = ($reg_1_3_i_i159_i | 0) < 0 ? $980 ^ 517762881 : $980; //@line 34387
        $983 = $reg_1_4_i_i160_i << 1; //@line 34389
        $reg_1_5_i_i161_i = ($reg_1_4_i_i160_i | 0) < 0 ? $983 ^ 517762881 : $983; //@line 34391
        $986 = $reg_1_5_i_i161_i << 1; //@line 34393
        $reg_1_6_i_i162_i = ($reg_1_5_i_i161_i | 0) < 0 ? $986 ^ 517762881 : $986; //@line 34395
        $989 = $reg_1_6_i_i162_i << 1; //@line 34397
        HEAP32[58216 + ($i_017_i_i154_i << 2) >> 2] = ($reg_1_6_i_i162_i | 0) < 0 ? $989 ^ 517762881 : $989; //@line 34401
        $i_017_i_i154_i = $i_017_i_i154_i + 1 | 0; //@line 34402
       } while ($i_017_i_i154_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 34411
       $_01011_i_i167_i = 18;
       $_012_i_i166_i = $353;
       $src_013_i_i165_i = $251;
      }
      while (1) {
       $1003 = HEAP32[58216 + ((HEAPU8[$src_013_i_i165_i] ^ $_012_i_i166_i >>> 24) << 2) >> 2] ^ $_012_i_i166_i << 8; //@line 34427
       $1004 = $_01011_i_i167_i - 1 | 0; //@line 34428
       if (($1004 | 0) == 0) {
        break;
       } else {
        $_01011_i_i167_i = $1004;
        $_012_i_i166_i = $1003;
        $src_013_i_i165_i = $src_013_i_i165_i + 1 | 0;
       }
      }
      HEAP16[$265 + 4 >> 1] = (_psi_get_uint16_be($251, 0) | 0) & 65535; //@line 34440
      HEAP16[$265 + 6 >> 1] = HEAPU8[$252] | 0; //@line 34444
      HEAP16[$265 + 8 >> 1] = HEAPU8[$253] | 0; //@line 34448
      _psi_sct_set_gcr_format($265, HEAP8[$254] | 0); //@line 34450
      $1017 = HEAP8[$255] | 0; //@line 34451
      if (($1017 & 1) != 0) {
       $1021 = $265 + 12 | 0; //@line 34456
       HEAP32[$1021 >> 2] = HEAP32[$1021 >> 2] | 1; //@line 34459
      }
      if (($1017 & 2) != 0) {
       $1028 = $265 + 12 | 0; //@line 34466
       HEAP32[$1028 >> 2] = HEAP32[$1028 >> 2] | 2; //@line 34469
      }
      if (($1017 & 4) != 0) {
       $1035 = $265 + 12 | 0; //@line 34476
       HEAP32[$1035 >> 2] = HEAP32[$1035 >> 2] | 8; //@line 34479
      }
      _psi_sct_set_encoding($265, 3); //@line 34482
      _psi_sct_set_tags($265, $256, 12) | 0; //@line 34483
      $1040 = $355 - 18 | 0; //@line 34484
      if (($1040 | 0) == 0) {
       $crc2830_lcssa_i191_i = $1003; //@line 34488
      } else {
       $crc283036_i170_i = $1003;
       $_08_i37_i169_i = $1040;
       while (1) {
        $1043 = $_08_i37_i169_i >>> 0 < 256 ? $_08_i37_i169_i : 256; //@line 34495
        if ((_fread($191 | 0, 1, $1043 | 0, $fp | 0) | 0) != ($1043 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i5_i173_i = 0; //@line 34505
         do {
          $1048 = $i_017_i5_i173_i << 25; //@line 34510
          $reg_1_i7_i175_i = ($i_017_i5_i173_i & 128 | 0) != 0 ? $1048 ^ 517762881 : $1048; //@line 34512
          $1051 = $reg_1_i7_i175_i << 1; //@line 34514
          $reg_1_1_i8_i176_i = ($reg_1_i7_i175_i | 0) < 0 ? $1051 ^ 517762881 : $1051; //@line 34516
          $1054 = $reg_1_1_i8_i176_i << 1; //@line 34518
          $reg_1_2_i9_i177_i = ($reg_1_1_i8_i176_i | 0) < 0 ? $1054 ^ 517762881 : $1054; //@line 34520
          $1057 = $reg_1_2_i9_i177_i << 1; //@line 34522
          $reg_1_3_i10_i178_i = ($reg_1_2_i9_i177_i | 0) < 0 ? $1057 ^ 517762881 : $1057; //@line 34524
          $1060 = $reg_1_3_i10_i178_i << 1; //@line 34526
          $reg_1_4_i11_i179_i = ($reg_1_3_i10_i178_i | 0) < 0 ? $1060 ^ 517762881 : $1060; //@line 34528
          $1063 = $reg_1_4_i11_i179_i << 1; //@line 34530
          $reg_1_5_i12_i180_i = ($reg_1_4_i11_i179_i | 0) < 0 ? $1063 ^ 517762881 : $1063; //@line 34532
          $1066 = $reg_1_5_i12_i180_i << 1; //@line 34534
          $reg_1_6_i13_i181_i = ($reg_1_5_i12_i180_i | 0) < 0 ? $1066 ^ 517762881 : $1066; //@line 34536
          $1069 = $reg_1_6_i13_i181_i << 1; //@line 34538
          HEAP32[58216 + ($i_017_i5_i173_i << 2) >> 2] = ($reg_1_6_i13_i181_i | 0) < 0 ? $1069 ^ 517762881 : $1069; //@line 34542
          $i_017_i5_i173_i = $i_017_i5_i173_i + 1 | 0; //@line 34543
         } while ($i_017_i5_i173_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 34552
        }
        if (($1043 | 0) == 0) {
         $crc2829_ph_i189_i = $crc283036_i170_i; //@line 34558
        } else {
         $_01011_i19_i187_i = $1043;
         $_012_i18_i186_i = $crc283036_i170_i;
         $src_013_i17_i185_i = $191;
         while (1) {
          $1084 = HEAP32[58216 + ((HEAPU8[$src_013_i17_i185_i] ^ $_012_i18_i186_i >>> 24) << 2) >> 2] ^ $_012_i18_i186_i << 8; //@line 34573
          $1085 = $_01011_i19_i187_i - 1 | 0; //@line 34574
          if (($1085 | 0) == 0) {
           $crc2829_ph_i189_i = $1084; //@line 34578
           break;
          } else {
           $_01011_i19_i187_i = $1085;
           $_012_i18_i186_i = $1084;
           $src_013_i17_i185_i = $src_013_i17_i185_i + 1 | 0;
          }
         }
        }
        if (($_08_i37_i169_i | 0) == ($1043 | 0)) {
         $crc2830_lcssa_i191_i = $crc2829_ph_i189_i; //@line 34590
         break;
        } else {
         $crc283036_i170_i = $crc2829_ph_i189_i;
         $_08_i37_i169_i = $_08_i37_i169_i - $1043 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc2830_lcssa_i191_i | 0)) {
       $_be_i = $265; //@line 34608
      } else {
       label = 13661; //@line 34610
       break L17159;
      }
     } else if (($354 | 0) == 1162757152) {
      label = 13546; //@line 34614
      break L17159;
     } else if (($354 | 0) == 1229081926) {
      if (($265 | 0) == 0 | $355 >>> 0 < 6) {
       break L17114;
      }
      if ((_fread($107 | 0, 1, 6, $fp | 0) | 0) != 6) {
       break L17114;
      }
      if (!(HEAP8[6648] | 0)) {
       $i_017_i_i94_i = 0; //@line 34633
       do {
        $613 = $i_017_i_i94_i << 25; //@line 34638
        $reg_1_i_i96_i = ($i_017_i_i94_i & 128 | 0) != 0 ? $613 ^ 517762881 : $613; //@line 34640
        $616 = $reg_1_i_i96_i << 1; //@line 34642
        $reg_1_1_i_i97_i = ($reg_1_i_i96_i | 0) < 0 ? $616 ^ 517762881 : $616; //@line 34644
        $619 = $reg_1_1_i_i97_i << 1; //@line 34646
        $reg_1_2_i_i98_i = ($reg_1_1_i_i97_i | 0) < 0 ? $619 ^ 517762881 : $619; //@line 34648
        $622 = $reg_1_2_i_i98_i << 1; //@line 34650
        $reg_1_3_i_i99_i = ($reg_1_2_i_i98_i | 0) < 0 ? $622 ^ 517762881 : $622; //@line 34652
        $625 = $reg_1_3_i_i99_i << 1; //@line 34654
        $reg_1_4_i_i100_i = ($reg_1_3_i_i99_i | 0) < 0 ? $625 ^ 517762881 : $625; //@line 34656
        $628 = $reg_1_4_i_i100_i << 1; //@line 34658
        $reg_1_5_i_i101_i = ($reg_1_4_i_i100_i | 0) < 0 ? $628 ^ 517762881 : $628; //@line 34660
        $631 = $reg_1_5_i_i101_i << 1; //@line 34662
        $reg_1_6_i_i102_i = ($reg_1_5_i_i101_i | 0) < 0 ? $631 ^ 517762881 : $631; //@line 34664
        $634 = $reg_1_6_i_i102_i << 1; //@line 34666
        HEAP32[58216 + ($i_017_i_i94_i << 2) >> 2] = ($reg_1_6_i_i102_i | 0) < 0 ? $634 ^ 517762881 : $634; //@line 34670
        $i_017_i_i94_i = $i_017_i_i94_i + 1 | 0; //@line 34671
       } while ($i_017_i_i94_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 34680
      }
      $641 = HEAP8[$107] | 0; //@line 34684
      $647 = HEAP32[58216 + (($641 & 255 ^ $353 >>> 24) << 2) >> 2] ^ $353 << 8; //@line 34690
      $649 = HEAP8[$142] | 0; //@line 34692
      $655 = HEAP32[58216 + (($649 & 255 ^ $647 >>> 24) << 2) >> 2] ^ $647 << 8; //@line 34698
      $657 = HEAP8[$151] | 0; //@line 34700
      $663 = HEAP32[58216 + (($657 & 255 ^ $655 >>> 24) << 2) >> 2] ^ $655 << 8; //@line 34706
      $665 = HEAP8[$160] | 0; //@line 34708
      $671 = HEAP32[58216 + (($665 & 255 ^ $663 >>> 24) << 2) >> 2] ^ $663 << 8; //@line 34714
      $673 = HEAP8[$247] | 0; //@line 34716
      $679 = HEAP32[58216 + (($673 & 255 ^ $671 >>> 24) << 2) >> 2] ^ $671 << 8; //@line 34722
      $681 = HEAP8[$248] | 0; //@line 34724
      $687 = HEAP32[58216 + (($681 & 255 ^ $679 >>> 24) << 2) >> 2] ^ $679 << 8; //@line 34730
      HEAP16[$265 + 4 >> 1] = $641 & 255; //@line 34733
      HEAP16[$265 + 6 >> 1] = $649 & 255; //@line 34736
      HEAP16[$265 + 8 >> 1] = $657 & 255; //@line 34739
      _psi_sct_set_mfm_size($265, $665); //@line 34740
      if (($673 & 1) != 0) {
       $697 = $265 + 12 | 0; //@line 34745
       HEAP32[$697 >> 2] = HEAP32[$697 >> 2] | 1; //@line 34748
      }
      if (($673 & 2) != 0) {
       $704 = $265 + 12 | 0; //@line 34755
       HEAP32[$704 >> 2] = HEAP32[$704 >> 2] | 2; //@line 34758
      }
      if (($673 & 4) != 0) {
       $711 = $265 + 12 | 0; //@line 34765
       HEAP32[$711 >> 2] = HEAP32[$711 >> 2] | 4; //@line 34768
      }
      if (($673 & 8) != 0) {
       $718 = $265 + 12 | 0; //@line 34775
       HEAP32[$718 >> 2] = HEAP32[$718 >> 2] | 8; //@line 34778
      }
      if ($681 << 24 >> 24 == 1) {
       _psi_sct_set_encoding($265, 32769); //@line 34784
      } else {
       _psi_sct_set_encoding($265, 1); //@line 34787
      }
      $725 = $355 - 6 | 0; //@line 34790
      if (($725 | 0) == 0) {
       $crc2830_lcssa_i_i = $687; //@line 34794
      } else {
       $crc283036_i_i = $687;
       $_08_i37_i_i = $725;
       while (1) {
        $728 = $_08_i37_i_i >>> 0 < 256 ? $_08_i37_i_i : 256; //@line 34801
        if ((_fread($191 | 0, 1, $728 | 0, $fp | 0) | 0) != ($728 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i5_i_i = 0; //@line 34811
         do {
          $733 = $i_017_i5_i_i << 25; //@line 34816
          $reg_1_i7_i_i = ($i_017_i5_i_i & 128 | 0) != 0 ? $733 ^ 517762881 : $733; //@line 34818
          $736 = $reg_1_i7_i_i << 1; //@line 34820
          $reg_1_1_i8_i_i = ($reg_1_i7_i_i | 0) < 0 ? $736 ^ 517762881 : $736; //@line 34822
          $739 = $reg_1_1_i8_i_i << 1; //@line 34824
          $reg_1_2_i9_i_i = ($reg_1_1_i8_i_i | 0) < 0 ? $739 ^ 517762881 : $739; //@line 34826
          $742 = $reg_1_2_i9_i_i << 1; //@line 34828
          $reg_1_3_i10_i_i = ($reg_1_2_i9_i_i | 0) < 0 ? $742 ^ 517762881 : $742; //@line 34830
          $745 = $reg_1_3_i10_i_i << 1; //@line 34832
          $reg_1_4_i11_i_i = ($reg_1_3_i10_i_i | 0) < 0 ? $745 ^ 517762881 : $745; //@line 34834
          $748 = $reg_1_4_i11_i_i << 1; //@line 34836
          $reg_1_5_i12_i_i = ($reg_1_4_i11_i_i | 0) < 0 ? $748 ^ 517762881 : $748; //@line 34838
          $751 = $reg_1_5_i12_i_i << 1; //@line 34840
          $reg_1_6_i13_i_i = ($reg_1_5_i12_i_i | 0) < 0 ? $751 ^ 517762881 : $751; //@line 34842
          $754 = $reg_1_6_i13_i_i << 1; //@line 34844
          HEAP32[58216 + ($i_017_i5_i_i << 2) >> 2] = ($reg_1_6_i13_i_i | 0) < 0 ? $754 ^ 517762881 : $754; //@line 34848
          $i_017_i5_i_i = $i_017_i5_i_i + 1 | 0; //@line 34849
         } while ($i_017_i5_i_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 34858
        }
        if (($728 | 0) == 0) {
         $crc2829_ph_i_i = $crc283036_i_i; //@line 34864
        } else {
         $_01011_i19_i_i = $728;
         $_012_i18_i_i = $crc283036_i_i;
         $src_013_i17_i_i = $191;
         while (1) {
          $769 = HEAP32[58216 + ((HEAPU8[$src_013_i17_i_i] ^ $_012_i18_i_i >>> 24) << 2) >> 2] ^ $_012_i18_i_i << 8; //@line 34879
          $770 = $_01011_i19_i_i - 1 | 0; //@line 34880
          if (($770 | 0) == 0) {
           $crc2829_ph_i_i = $769; //@line 34884
           break;
          } else {
           $_01011_i19_i_i = $770;
           $_012_i18_i_i = $769;
           $src_013_i17_i_i = $src_013_i17_i_i + 1 | 0;
          }
         }
        }
        if (($_08_i37_i_i | 0) == ($728 | 0)) {
         $crc2830_lcssa_i_i = $crc2829_ph_i_i; //@line 34896
         break;
        } else {
         $crc283036_i_i = $crc2829_ph_i_i;
         $_08_i37_i_i = $_08_i37_i_i - $728 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc2830_lcssa_i_i | 0)) {
       $_be_i = $265; //@line 34914
      } else {
       label = 13610; //@line 34916
       break L17159;
      }
     } else if (($354 | 0) == 1145132097) {
      if (($265 | 0) == 0) {
       break L17114;
      }
      if ((_psi_sct_set_size($265, $355, 0) | 0) != 0) {
       break L17114;
      }
      if (($355 | 0) == 0) {
       $crc30_i_i = $353; //@line 34934
      } else {
       $1356 = HEAP32[$265 + 24 >> 2] | 0; //@line 34937
       if ((_fread($1356 | 0, 1, $355 | 0, $fp | 0) | 0) != ($355 | 0)) {
        break L17114;
       }
       if (HEAP8[6648] | 0) {
        $_01011_i_i291_i = $355;
        $_012_i_i290_i = $353;
        $src_013_i_i289_i = $1356;
       } else {
        $i_017_i_i278_i = 0; //@line 34949
        do {
         $1361 = $i_017_i_i278_i << 25; //@line 34954
         $reg_1_i_i280_i = ($i_017_i_i278_i & 128 | 0) != 0 ? $1361 ^ 517762881 : $1361; //@line 34956
         $1364 = $reg_1_i_i280_i << 1; //@line 34958
         $reg_1_1_i_i281_i = ($reg_1_i_i280_i | 0) < 0 ? $1364 ^ 517762881 : $1364; //@line 34960
         $1367 = $reg_1_1_i_i281_i << 1; //@line 34962
         $reg_1_2_i_i282_i = ($reg_1_1_i_i281_i | 0) < 0 ? $1367 ^ 517762881 : $1367; //@line 34964
         $1370 = $reg_1_2_i_i282_i << 1; //@line 34966
         $reg_1_3_i_i283_i = ($reg_1_2_i_i282_i | 0) < 0 ? $1370 ^ 517762881 : $1370; //@line 34968
         $1373 = $reg_1_3_i_i283_i << 1; //@line 34970
         $reg_1_4_i_i284_i = ($reg_1_3_i_i283_i | 0) < 0 ? $1373 ^ 517762881 : $1373; //@line 34972
         $1376 = $reg_1_4_i_i284_i << 1; //@line 34974
         $reg_1_5_i_i285_i = ($reg_1_4_i_i284_i | 0) < 0 ? $1376 ^ 517762881 : $1376; //@line 34976
         $1379 = $reg_1_5_i_i285_i << 1; //@line 34978
         $reg_1_6_i_i286_i = ($reg_1_5_i_i285_i | 0) < 0 ? $1379 ^ 517762881 : $1379; //@line 34980
         $1382 = $reg_1_6_i_i286_i << 1; //@line 34982
         HEAP32[58216 + ($i_017_i_i278_i << 2) >> 2] = ($reg_1_6_i_i286_i | 0) < 0 ? $1382 ^ 517762881 : $1382; //@line 34986
         $i_017_i_i278_i = $i_017_i_i278_i + 1 | 0; //@line 34987
        } while ($i_017_i_i278_i >>> 0 < 256);
        HEAP8[6648] = 1; //@line 34996
        $_01011_i_i291_i = $355;
        $_012_i_i290_i = $353;
        $src_013_i_i289_i = $1356;
       }
       while (1) {
        $1396 = HEAP32[58216 + ((HEAPU8[$src_013_i_i289_i] ^ $_012_i_i290_i >>> 24) << 2) >> 2] ^ $_012_i_i290_i << 8; //@line 35012
        $1397 = $_01011_i_i291_i - 1 | 0; //@line 35013
        if (($1397 | 0) == 0) {
         $crc30_i_i = $1396; //@line 35017
         break;
        } else {
         $_01011_i_i291_i = $1397;
         $_012_i_i290_i = $1396;
         $src_013_i_i289_i = $src_013_i_i289_i + 1 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc30_i_i | 0)) {
       $_be_i = $265; //@line 35035
      } else {
       label = 13704; //@line 35037
       break L17159;
      }
     } else if (($354 | 0) == 1397048148) {
      if ($355 >>> 0 < 8) {
       break L17114;
      }
      if ((_fread($107 | 0, 1, 8, $fp | 0) | 0) != 8) {
       break L17114;
      }
      if (!(HEAP8[6648] | 0)) {
       $i_017_i_i76_i = 0; //@line 35055
       do {
        $420 = $i_017_i_i76_i << 25; //@line 35060
        $reg_1_i_i78_i = ($i_017_i_i76_i & 128 | 0) != 0 ? $420 ^ 517762881 : $420; //@line 35062
        $423 = $reg_1_i_i78_i << 1; //@line 35064
        $reg_1_1_i_i79_i = ($reg_1_i_i78_i | 0) < 0 ? $423 ^ 517762881 : $423; //@line 35066
        $426 = $reg_1_1_i_i79_i << 1; //@line 35068
        $reg_1_2_i_i80_i = ($reg_1_1_i_i79_i | 0) < 0 ? $426 ^ 517762881 : $426; //@line 35070
        $429 = $reg_1_2_i_i80_i << 1; //@line 35072
        $reg_1_3_i_i81_i = ($reg_1_2_i_i80_i | 0) < 0 ? $429 ^ 517762881 : $429; //@line 35074
        $432 = $reg_1_3_i_i81_i << 1; //@line 35076
        $reg_1_4_i_i82_i = ($reg_1_3_i_i81_i | 0) < 0 ? $432 ^ 517762881 : $432; //@line 35078
        $435 = $reg_1_4_i_i82_i << 1; //@line 35080
        $reg_1_5_i_i83_i = ($reg_1_4_i_i82_i | 0) < 0 ? $435 ^ 517762881 : $435; //@line 35082
        $438 = $reg_1_5_i_i83_i << 1; //@line 35084
        $reg_1_6_i_i84_i = ($reg_1_5_i_i83_i | 0) < 0 ? $438 ^ 517762881 : $438; //@line 35086
        $441 = $reg_1_6_i_i84_i << 1; //@line 35088
        HEAP32[58216 + ($i_017_i_i76_i << 2) >> 2] = ($reg_1_6_i_i84_i | 0) < 0 ? $441 ^ 517762881 : $441; //@line 35092
        $i_017_i_i76_i = $i_017_i_i76_i + 1 | 0; //@line 35093
       } while ($i_017_i_i76_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 35102
      }
      $454 = HEAP32[58216 + ((HEAPU8[$107] ^ $353 >>> 24) << 2) >> 2] ^ $353 << 8; //@line 35112
      $462 = HEAP32[58216 + ((HEAPU8[$142] ^ $454 >>> 24) << 2) >> 2] ^ $454 << 8; //@line 35120
      $470 = HEAP32[58216 + ((HEAPU8[$151] ^ $462 >>> 24) << 2) >> 2] ^ $462 << 8; //@line 35128
      $478 = HEAP32[58216 + ((HEAPU8[$160] ^ $470 >>> 24) << 2) >> 2] ^ $470 << 8; //@line 35136
      $486 = HEAP32[58216 + ((HEAPU8[$247] ^ $478 >>> 24) << 2) >> 2] ^ $478 << 8; //@line 35144
      $494 = HEAP32[58216 + ((HEAPU8[$248] ^ $486 >>> 24) << 2) >> 2] ^ $486 << 8; //@line 35152
      $502 = HEAP32[58216 + ((HEAPU8[$249] ^ $494 >>> 24) << 2) >> 2] ^ $494 << 8; //@line 35160
      $510 = HEAP32[58216 + ((HEAPU8[$250] ^ $502 >>> 24) << 2) >> 2] ^ $502 << 8; //@line 35168
      $511 = _psi_get_uint16_be($107, 0) | 0; //@line 35169
      $513 = HEAPU8[$151] | 0; //@line 35171
      $515 = HEAPU8[$160] | 0; //@line 35173
      $516 = _psi_get_uint16_be($107, 4) | 0; //@line 35174
      $518 = HEAPU8[$249] | 0; //@line 35176
      $519 = _psi_sct_new($511, $513, $515, $516) | 0; //@line 35177
      if (($519 | 0) == 0) {
       break L17114;
      }
      if (($518 & 2 | 0) == 0) {
       if ((_psi_img_add_sector($1, $519, $511, $513) | 0) != 0) {
        label = 13568; //@line 35191
        break L17159;
       }
      } else {
       if (($265 | 0) == 0) {
        label = 13565; //@line 35198
        break L17159;
       }
       _psi_sct_add_alternate($265, $519); //@line 35201
      }
      if (($518 & 4 | 0) != 0) {
       $538 = $519 + 12 | 0; //@line 35208
       HEAP32[$538 >> 2] = HEAP32[$538 >> 2] | 2; //@line 35211
      }
      _psi_sct_set_encoding($519, $enc_0_load359_i); //@line 35214
      $542 = $355 - 8 | 0; //@line 35215
      if (($518 & 1 | 0) != 0) {
       _psi_sct_fill($519, HEAPU8[$250] | 0); //@line 35222
      }
      if (($542 | 0) == 0) {
       $crc4951_lcssa_i_i = $510; //@line 35228
      } else {
       $crc495157_i_i = $510;
       $_08_i58_i_i = $542;
       while (1) {
        $551 = $_08_i58_i_i >>> 0 < 256 ? $_08_i58_i_i : 256; //@line 35235
        if ((_fread($191 | 0, 1, $551 | 0, $fp | 0) | 0) != ($551 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i26_i_i = 0; //@line 35245
         do {
          $556 = $i_017_i26_i_i << 25; //@line 35250
          $reg_1_i28_i_i = ($i_017_i26_i_i & 128 | 0) != 0 ? $556 ^ 517762881 : $556; //@line 35252
          $559 = $reg_1_i28_i_i << 1; //@line 35254
          $reg_1_1_i29_i_i = ($reg_1_i28_i_i | 0) < 0 ? $559 ^ 517762881 : $559; //@line 35256
          $562 = $reg_1_1_i29_i_i << 1; //@line 35258
          $reg_1_2_i30_i_i = ($reg_1_1_i29_i_i | 0) < 0 ? $562 ^ 517762881 : $562; //@line 35260
          $565 = $reg_1_2_i30_i_i << 1; //@line 35262
          $reg_1_3_i31_i_i = ($reg_1_2_i30_i_i | 0) < 0 ? $565 ^ 517762881 : $565; //@line 35264
          $568 = $reg_1_3_i31_i_i << 1; //@line 35266
          $reg_1_4_i32_i_i = ($reg_1_3_i31_i_i | 0) < 0 ? $568 ^ 517762881 : $568; //@line 35268
          $571 = $reg_1_4_i32_i_i << 1; //@line 35270
          $reg_1_5_i33_i_i = ($reg_1_4_i32_i_i | 0) < 0 ? $571 ^ 517762881 : $571; //@line 35272
          $574 = $reg_1_5_i33_i_i << 1; //@line 35274
          $reg_1_6_i34_i_i = ($reg_1_5_i33_i_i | 0) < 0 ? $574 ^ 517762881 : $574; //@line 35276
          $577 = $reg_1_6_i34_i_i << 1; //@line 35278
          HEAP32[58216 + ($i_017_i26_i_i << 2) >> 2] = ($reg_1_6_i34_i_i | 0) < 0 ? $577 ^ 517762881 : $577; //@line 35282
          $i_017_i26_i_i = $i_017_i26_i_i + 1 | 0; //@line 35283
         } while ($i_017_i26_i_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 35292
        }
        if (($551 | 0) == 0) {
         $crc4950_ph_i_i = $crc495157_i_i; //@line 35298
        } else {
         $_01011_i40_i_i = $551;
         $_012_i39_i_i = $crc495157_i_i;
         $src_013_i38_i_i = $191;
         while (1) {
          $592 = HEAP32[58216 + ((HEAPU8[$src_013_i38_i_i] ^ $_012_i39_i_i >>> 24) << 2) >> 2] ^ $_012_i39_i_i << 8; //@line 35313
          $593 = $_01011_i40_i_i - 1 | 0; //@line 35314
          if (($593 | 0) == 0) {
           $crc4950_ph_i_i = $592; //@line 35318
           break;
          } else {
           $_01011_i40_i_i = $593;
           $_012_i39_i_i = $592;
           $src_013_i38_i_i = $src_013_i38_i_i + 1 | 0;
          }
         }
        }
        if (($_08_i58_i_i | 0) == ($551 | 0)) {
         $crc4951_lcssa_i_i = $crc4950_ph_i_i; //@line 35330
         break;
        } else {
         $crc495157_i_i = $crc4950_ph_i_i;
         $_08_i58_i_i = $_08_i58_i_i - $551 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc4951_lcssa_i_i | 0)) {
       $_be_i = $519; //@line 35348
      } else {
       label = 13583; //@line 35350
       break L17159;
      }
     } else if (($354 | 0) == 1413830740) {
      if (($355 | 0) == 0) {
       if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
        break L17114;
       }
       if ((_psi_get_uint32_be($191, 0) | 0) == ($353 | 0)) {
        $_be_i = $265; //@line 35367
        break;
       } else {
        label = 13708; //@line 35370
        break L17159;
       }
      }
      $1419 = _malloc($355) | 0; //@line 35374
      if (($1419 | 0) == 0) {
       break L17114;
      }
      if ((_fread($1419 | 0, 1, $355 | 0, $fp | 0) | 0) != ($355 | 0)) {
       label = 13715; //@line 35384
       break L17159;
      }
      if (HEAP8[6648] | 0) {
       $_01011_i_i309_i = $355;
       $_012_i_i308_i = $353;
       $src_013_i_i307_i = $1419;
      } else {
       $i_017_i_i296_i = 0; //@line 35392
       do {
        $1426 = $i_017_i_i296_i << 25; //@line 35397
        $reg_1_i_i298_i = ($i_017_i_i296_i & 128 | 0) != 0 ? $1426 ^ 517762881 : $1426; //@line 35399
        $1429 = $reg_1_i_i298_i << 1; //@line 35401
        $reg_1_1_i_i299_i = ($reg_1_i_i298_i | 0) < 0 ? $1429 ^ 517762881 : $1429; //@line 35403
        $1432 = $reg_1_1_i_i299_i << 1; //@line 35405
        $reg_1_2_i_i300_i = ($reg_1_1_i_i299_i | 0) < 0 ? $1432 ^ 517762881 : $1432; //@line 35407
        $1435 = $reg_1_2_i_i300_i << 1; //@line 35409
        $reg_1_3_i_i301_i = ($reg_1_2_i_i300_i | 0) < 0 ? $1435 ^ 517762881 : $1435; //@line 35411
        $1438 = $reg_1_3_i_i301_i << 1; //@line 35413
        $reg_1_4_i_i302_i = ($reg_1_3_i_i301_i | 0) < 0 ? $1438 ^ 517762881 : $1438; //@line 35415
        $1441 = $reg_1_4_i_i302_i << 1; //@line 35417
        $reg_1_5_i_i303_i = ($reg_1_4_i_i302_i | 0) < 0 ? $1441 ^ 517762881 : $1441; //@line 35419
        $1444 = $reg_1_5_i_i303_i << 1; //@line 35421
        $reg_1_6_i_i304_i = ($reg_1_5_i_i303_i | 0) < 0 ? $1444 ^ 517762881 : $1444; //@line 35423
        $1447 = $reg_1_6_i_i304_i << 1; //@line 35425
        HEAP32[58216 + ($i_017_i_i296_i << 2) >> 2] = ($reg_1_6_i_i304_i | 0) < 0 ? $1447 ^ 517762881 : $1447; //@line 35429
        $i_017_i_i296_i = $i_017_i_i296_i + 1 | 0; //@line 35430
       } while ($i_017_i_i296_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 35439
       $_01011_i_i309_i = $355;
       $_012_i_i308_i = $353;
       $src_013_i_i307_i = $1419;
      }
      while (1) {
       $1461 = HEAP32[58216 + ((HEAPU8[$src_013_i_i307_i] ^ $_012_i_i308_i >>> 24) << 2) >> 2] ^ $_012_i_i308_i << 8; //@line 35455
       $1462 = $_01011_i_i309_i - 1 | 0; //@line 35456
       if (($1462 | 0) == 0) {
        break;
       } else {
        $_01011_i_i309_i = $1462;
        $_012_i_i308_i = $1461;
        $src_013_i_i307_i = $src_013_i_i307_i + 1 | 0;
       }
      }
      $1466 = (HEAP8[$1419] | 0) == 10; //@line 35466
      $_size_i_i = ($1466 << 31 >> 31) + $355 | 0; //@line 35469
      if (($_size_i_i | 0) == 0) {
       $n_1_i_i = 0; //@line 35473
      } else {
       $1470 = $_size_i_i - 1 | 0; //@line 35475
       $n_1_i_i = (HEAP8[$1419 + $1470 | 0] | 0) == 10 ? $1470 : $_size_i_i; //@line 35481
      }
      $1476 = _psi_img_add_comment($1, $1419 + ($1466 & 1) | 0, $n_1_i_i) | 0; //@line 35485
      _free($1419); //@line 35486
      do {
       if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) == 4) {
        if ((_psi_get_uint32_be($191, 0) | 0) == ($1461 | 0)) {
         $_0_i23_i_i = 0; //@line 35496
         break;
        }
        $1483 = HEAP32[_stderr >> 2] | 0; //@line 35499
        _fwrite(56464, 15, 1, $1483 | 0) | 0; //@line 35500
        $_0_i23_i_i = 1; //@line 35502
       } else {
        $_0_i23_i_i = 1; //@line 35504
       }
      } while (0);
      if (($_0_i23_i_i | $1476 | 0) == 0) {
       $_be_i = $265; //@line 35512
      } else {
       break L17114;
      }
     } else if (($354 | 0) == 1229081933) {
      if (($265 | 0) == 0 | $355 >>> 0 < 6) {
       break L17114;
      }
      if ((_fread($107 | 0, 1, 6, $fp | 0) | 0) != 6) {
       break L17114;
      }
      if (!(HEAP8[6648] | 0)) {
       $i_017_i_i113_i = 0; //@line 35533
       do {
        $790 = $i_017_i_i113_i << 25; //@line 35538
        $reg_1_i_i115_i = ($i_017_i_i113_i & 128 | 0) != 0 ? $790 ^ 517762881 : $790; //@line 35540
        $793 = $reg_1_i_i115_i << 1; //@line 35542
        $reg_1_1_i_i116_i = ($reg_1_i_i115_i | 0) < 0 ? $793 ^ 517762881 : $793; //@line 35544
        $796 = $reg_1_1_i_i116_i << 1; //@line 35546
        $reg_1_2_i_i117_i = ($reg_1_1_i_i116_i | 0) < 0 ? $796 ^ 517762881 : $796; //@line 35548
        $799 = $reg_1_2_i_i117_i << 1; //@line 35550
        $reg_1_3_i_i118_i = ($reg_1_2_i_i117_i | 0) < 0 ? $799 ^ 517762881 : $799; //@line 35552
        $802 = $reg_1_3_i_i118_i << 1; //@line 35554
        $reg_1_4_i_i119_i = ($reg_1_3_i_i118_i | 0) < 0 ? $802 ^ 517762881 : $802; //@line 35556
        $805 = $reg_1_4_i_i119_i << 1; //@line 35558
        $reg_1_5_i_i120_i = ($reg_1_4_i_i119_i | 0) < 0 ? $805 ^ 517762881 : $805; //@line 35560
        $808 = $reg_1_5_i_i120_i << 1; //@line 35562
        $reg_1_6_i_i121_i = ($reg_1_5_i_i120_i | 0) < 0 ? $808 ^ 517762881 : $808; //@line 35564
        $811 = $reg_1_6_i_i121_i << 1; //@line 35566
        HEAP32[58216 + ($i_017_i_i113_i << 2) >> 2] = ($reg_1_6_i_i121_i | 0) < 0 ? $811 ^ 517762881 : $811; //@line 35570
        $i_017_i_i113_i = $i_017_i_i113_i + 1 | 0; //@line 35571
       } while ($i_017_i_i113_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 35580
      }
      $818 = HEAP8[$107] | 0; //@line 35584
      $824 = HEAP32[58216 + (($818 & 255 ^ $353 >>> 24) << 2) >> 2] ^ $353 << 8; //@line 35590
      $826 = HEAP8[$142] | 0; //@line 35592
      $832 = HEAP32[58216 + (($826 & 255 ^ $824 >>> 24) << 2) >> 2] ^ $824 << 8; //@line 35598
      $834 = HEAP8[$151] | 0; //@line 35600
      $840 = HEAP32[58216 + (($834 & 255 ^ $832 >>> 24) << 2) >> 2] ^ $832 << 8; //@line 35606
      $842 = HEAP8[$160] | 0; //@line 35608
      $848 = HEAP32[58216 + (($842 & 255 ^ $840 >>> 24) << 2) >> 2] ^ $840 << 8; //@line 35614
      $850 = HEAP8[$247] | 0; //@line 35616
      $856 = HEAP32[58216 + (($850 & 255 ^ $848 >>> 24) << 2) >> 2] ^ $848 << 8; //@line 35622
      $859 = HEAPU8[$248] | 0; //@line 35625
      $864 = HEAP32[58216 + (($859 ^ $856 >>> 24) << 2) >> 2] ^ $856 << 8; //@line 35630
      HEAP16[$265 + 4 >> 1] = $818 & 255; //@line 35633
      HEAP16[$265 + 6 >> 1] = $826 & 255; //@line 35636
      HEAP16[$265 + 8 >> 1] = $834 & 255; //@line 35639
      _psi_sct_set_mfm_size($265, $842); //@line 35640
      if (($850 & 1) != 0) {
       $874 = $265 + 12 | 0; //@line 35645
       HEAP32[$874 >> 2] = HEAP32[$874 >> 2] | 1; //@line 35648
      }
      if (($850 & 2) != 0) {
       $881 = $265 + 12 | 0; //@line 35655
       HEAP32[$881 >> 2] = HEAP32[$881 >> 2] | 2; //@line 35658
      }
      if (($850 & 4) != 0) {
       $888 = $265 + 12 | 0; //@line 35665
       HEAP32[$888 >> 2] = HEAP32[$888 >> 2] | 4; //@line 35668
      }
      if (($850 & 8) != 0) {
       $895 = $265 + 12 | 0; //@line 35675
       HEAP32[$895 >> 2] = HEAP32[$895 >> 2] | 8; //@line 35678
      }
      if (($859 | 0) == 1) {
       _psi_sct_set_encoding($265, 32770); //@line 35682
      } else if (($859 | 0) == 2) {
       _psi_sct_set_encoding($265, 16386); //@line 35685
      } else {
       _psi_sct_set_encoding($265, 2); //@line 35688
      }
      $903 = $355 - 6 | 0; //@line 35691
      if (($903 | 0) == 0) {
       $crc2830_lcssa_i147_i = $864; //@line 35695
      } else {
       $crc283036_i126_i = $864;
       $_08_i37_i125_i = $903;
       while (1) {
        $906 = $_08_i37_i125_i >>> 0 < 256 ? $_08_i37_i125_i : 256; //@line 35702
        if ((_fread($191 | 0, 1, $906 | 0, $fp | 0) | 0) != ($906 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i5_i129_i = 0; //@line 35712
         do {
          $911 = $i_017_i5_i129_i << 25; //@line 35717
          $reg_1_i7_i131_i = ($i_017_i5_i129_i & 128 | 0) != 0 ? $911 ^ 517762881 : $911; //@line 35719
          $914 = $reg_1_i7_i131_i << 1; //@line 35721
          $reg_1_1_i8_i132_i = ($reg_1_i7_i131_i | 0) < 0 ? $914 ^ 517762881 : $914; //@line 35723
          $917 = $reg_1_1_i8_i132_i << 1; //@line 35725
          $reg_1_2_i9_i133_i = ($reg_1_1_i8_i132_i | 0) < 0 ? $917 ^ 517762881 : $917; //@line 35727
          $920 = $reg_1_2_i9_i133_i << 1; //@line 35729
          $reg_1_3_i10_i134_i = ($reg_1_2_i9_i133_i | 0) < 0 ? $920 ^ 517762881 : $920; //@line 35731
          $923 = $reg_1_3_i10_i134_i << 1; //@line 35733
          $reg_1_4_i11_i135_i = ($reg_1_3_i10_i134_i | 0) < 0 ? $923 ^ 517762881 : $923; //@line 35735
          $926 = $reg_1_4_i11_i135_i << 1; //@line 35737
          $reg_1_5_i12_i136_i = ($reg_1_4_i11_i135_i | 0) < 0 ? $926 ^ 517762881 : $926; //@line 35739
          $929 = $reg_1_5_i12_i136_i << 1; //@line 35741
          $reg_1_6_i13_i137_i = ($reg_1_5_i12_i136_i | 0) < 0 ? $929 ^ 517762881 : $929; //@line 35743
          $932 = $reg_1_6_i13_i137_i << 1; //@line 35745
          HEAP32[58216 + ($i_017_i5_i129_i << 2) >> 2] = ($reg_1_6_i13_i137_i | 0) < 0 ? $932 ^ 517762881 : $932; //@line 35749
          $i_017_i5_i129_i = $i_017_i5_i129_i + 1 | 0; //@line 35750
         } while ($i_017_i5_i129_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 35759
        }
        if (($906 | 0) == 0) {
         $crc2829_ph_i145_i = $crc283036_i126_i; //@line 35765
        } else {
         $_01011_i19_i143_i = $906;
         $_012_i18_i142_i = $crc283036_i126_i;
         $src_013_i17_i141_i = $191;
         while (1) {
          $947 = HEAP32[58216 + ((HEAPU8[$src_013_i17_i141_i] ^ $_012_i18_i142_i >>> 24) << 2) >> 2] ^ $_012_i18_i142_i << 8; //@line 35780
          $948 = $_01011_i19_i143_i - 1 | 0; //@line 35781
          if (($948 | 0) == 0) {
           $crc2829_ph_i145_i = $947; //@line 35785
           break;
          } else {
           $_01011_i19_i143_i = $948;
           $_012_i18_i142_i = $947;
           $src_013_i17_i141_i = $src_013_i17_i141_i + 1 | 0;
          }
         }
        }
        if (($_08_i37_i125_i | 0) == ($906 | 0)) {
         $crc2830_lcssa_i147_i = $crc2829_ph_i145_i; //@line 35797
         break;
        } else {
         $crc283036_i126_i = $crc2829_ph_i145_i;
         $_08_i37_i125_i = $_08_i37_i125_i - $906 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($crc2830_lcssa_i147_i | 0)) {
       $_be_i = $265; //@line 35815
      } else {
       label = 13638; //@line 35817
       break L17159;
      }
     } else {
      if (($355 | 0) == 0) {
       $_lcssa394_i = $353; //@line 35824
      } else {
       $1491 = $353;
       $_08_i396_i = $355;
       while (1) {
        $1493 = $_08_i396_i >>> 0 < 256 ? $_08_i396_i : 256; //@line 35831
        if ((_fread($191 | 0, 1, $1493 | 0, $fp | 0) | 0) != ($1493 | 0)) {
         break L17114;
        }
        if (!(HEAP8[6648] | 0)) {
         $i_017_i318_i = 0; //@line 35841
         do {
          $1498 = $i_017_i318_i << 25; //@line 35846
          $reg_1_i320_i = ($i_017_i318_i & 128 | 0) != 0 ? $1498 ^ 517762881 : $1498; //@line 35848
          $1501 = $reg_1_i320_i << 1; //@line 35850
          $reg_1_1_i321_i = ($reg_1_i320_i | 0) < 0 ? $1501 ^ 517762881 : $1501; //@line 35852
          $1504 = $reg_1_1_i321_i << 1; //@line 35854
          $reg_1_2_i322_i = ($reg_1_1_i321_i | 0) < 0 ? $1504 ^ 517762881 : $1504; //@line 35856
          $1507 = $reg_1_2_i322_i << 1; //@line 35858
          $reg_1_3_i323_i = ($reg_1_2_i322_i | 0) < 0 ? $1507 ^ 517762881 : $1507; //@line 35860
          $1510 = $reg_1_3_i323_i << 1; //@line 35862
          $reg_1_4_i324_i = ($reg_1_3_i323_i | 0) < 0 ? $1510 ^ 517762881 : $1510; //@line 35864
          $1513 = $reg_1_4_i324_i << 1; //@line 35866
          $reg_1_5_i325_i = ($reg_1_4_i324_i | 0) < 0 ? $1513 ^ 517762881 : $1513; //@line 35868
          $1516 = $reg_1_5_i325_i << 1; //@line 35870
          $reg_1_6_i326_i = ($reg_1_5_i325_i | 0) < 0 ? $1516 ^ 517762881 : $1516; //@line 35872
          $1519 = $reg_1_6_i326_i << 1; //@line 35874
          HEAP32[58216 + ($i_017_i318_i << 2) >> 2] = ($reg_1_6_i326_i | 0) < 0 ? $1519 ^ 517762881 : $1519; //@line 35878
          $i_017_i318_i = $i_017_i318_i + 1 | 0; //@line 35879
         } while ($i_017_i318_i >>> 0 < 256);
         HEAP8[6648] = 1; //@line 35888
        }
        if (($1493 | 0) == 0) {
         $_ph372_i = $1491; //@line 35894
        } else {
         $_01011_i332_i = $1493;
         $_012_i331_i = $1491;
         $src_013_i330_i = $191;
         while (1) {
          $1534 = HEAP32[58216 + ((HEAPU8[$src_013_i330_i] ^ $_012_i331_i >>> 24) << 2) >> 2] ^ $_012_i331_i << 8; //@line 35909
          $1535 = $_01011_i332_i - 1 | 0; //@line 35910
          if (($1535 | 0) == 0) {
           $_ph372_i = $1534; //@line 35914
           break;
          } else {
           $_01011_i332_i = $1535;
           $_012_i331_i = $1534;
           $src_013_i330_i = $src_013_i330_i + 1 | 0;
          }
         }
        }
        if (($_08_i396_i | 0) == ($1493 | 0)) {
         $_lcssa394_i = $_ph372_i; //@line 35926
         break;
        } else {
         $1491 = $_ph372_i;
         $_08_i396_i = $_08_i396_i - $1493 | 0;
        }
       }
      }
      if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
       break L17114;
      }
      if ((_psi_get_uint32_be($191, 0) | 0) == ($_lcssa394_i | 0)) {
       $_be_i = $265; //@line 35944
      } else {
       label = 13733; //@line 35946
       break L17159;
      }
     }
    } while (0);
    if ((_fread($4 | 0, 1, 8, $fp | 0) | 0) == 8) {
     $265 = $_be_i; //@line 35956
    } else {
     break L17114;
    }
   }
   if ((label | 0) == 13708) {
    $1416 = HEAP32[_stderr >> 2] | 0; //@line 35962
    _fwrite(56464, 15, 1, $1416 | 0) | 0; //@line 35963
    break;
   } else if ((label | 0) == 13677) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 35969
    break;
   } else if ((label | 0) == 13568) {
    _psi_sct_del($519); //@line 35974
    break;
   } else if ((label | 0) == 13546) {
    if (($355 | 0) == 0) {
     $crc11_lcssa_i_i = $353; //@line 35982
    } else {
     $crc1116_i_i = $353;
     $_08_i17_i_i = $355;
     while (1) {
      $359 = $_08_i17_i_i >>> 0 < 256 ? $_08_i17_i_i : 256; //@line 35989
      if ((_fread($191 | 0, 1, $359 | 0, $fp | 0) | 0) != ($359 | 0)) {
       break L17114;
      }
      if (!(HEAP8[6648] | 0)) {
       $i_017_i_i60_i = 0; //@line 35999
       do {
        $364 = $i_017_i_i60_i << 25; //@line 36004
        $reg_1_i_i62_i = ($i_017_i_i60_i & 128 | 0) != 0 ? $364 ^ 517762881 : $364; //@line 36006
        $367 = $reg_1_i_i62_i << 1; //@line 36008
        $reg_1_1_i_i63_i = ($reg_1_i_i62_i | 0) < 0 ? $367 ^ 517762881 : $367; //@line 36010
        $370 = $reg_1_1_i_i63_i << 1; //@line 36012
        $reg_1_2_i_i64_i = ($reg_1_1_i_i63_i | 0) < 0 ? $370 ^ 517762881 : $370; //@line 36014
        $373 = $reg_1_2_i_i64_i << 1; //@line 36016
        $reg_1_3_i_i65_i = ($reg_1_2_i_i64_i | 0) < 0 ? $373 ^ 517762881 : $373; //@line 36018
        $376 = $reg_1_3_i_i65_i << 1; //@line 36020
        $reg_1_4_i_i66_i = ($reg_1_3_i_i65_i | 0) < 0 ? $376 ^ 517762881 : $376; //@line 36022
        $379 = $reg_1_4_i_i66_i << 1; //@line 36024
        $reg_1_5_i_i67_i = ($reg_1_4_i_i66_i | 0) < 0 ? $379 ^ 517762881 : $379; //@line 36026
        $382 = $reg_1_5_i_i67_i << 1; //@line 36028
        $reg_1_6_i_i68_i = ($reg_1_5_i_i67_i | 0) < 0 ? $382 ^ 517762881 : $382; //@line 36030
        $385 = $reg_1_6_i_i68_i << 1; //@line 36032
        HEAP32[58216 + ($i_017_i_i60_i << 2) >> 2] = ($reg_1_6_i_i68_i | 0) < 0 ? $385 ^ 517762881 : $385; //@line 36036
        $i_017_i_i60_i = $i_017_i_i60_i + 1 | 0; //@line 36037
       } while ($i_017_i_i60_i >>> 0 < 256);
       HEAP8[6648] = 1; //@line 36046
      }
      if (($359 | 0) == 0) {
       $crc10_ph_i_i = $crc1116_i_i; //@line 36052
      } else {
       $_01011_i_i_i = $359;
       $_012_i_i_i = $crc1116_i_i;
       $src_013_i_i_i = $191;
       while (1) {
        $400 = HEAP32[58216 + ((HEAPU8[$src_013_i_i_i] ^ $_012_i_i_i >>> 24) << 2) >> 2] ^ $_012_i_i_i << 8; //@line 36067
        $401 = $_01011_i_i_i - 1 | 0; //@line 36068
        if (($401 | 0) == 0) {
         $crc10_ph_i_i = $400; //@line 36072
         break;
        } else {
         $_01011_i_i_i = $401;
         $_012_i_i_i = $400;
         $src_013_i_i_i = $src_013_i_i_i + 1 | 0;
        }
       }
      }
      if (($_08_i17_i_i | 0) == ($359 | 0)) {
       $crc11_lcssa_i_i = $crc10_ph_i_i; //@line 36084
       break;
      } else {
       $crc1116_i_i = $crc10_ph_i_i;
       $_08_i17_i_i = $_08_i17_i_i - $359 | 0;
      }
     }
    }
    if ((_fread($191 | 0, 1, 4, $fp | 0) | 0) != 4) {
     break;
    }
    if ((_psi_get_uint32_be($191, 0) | 0) != ($crc11_lcssa_i_i | 0)) {
     $411 = HEAP32[_stderr >> 2] | 0; //@line 36102
     _fwrite(56464, 15, 1, $411 | 0) | 0; //@line 36103
     break;
    }
    _psi_img_clean_comment($1); //@line 36107
    $_0 = $1; //@line 36109
    STACKTOP = sp; //@line 36111
    return $_0 | 0; //@line 36112
   } else if ((label | 0) == 13715) {
    _free($1419); //@line 36115
    break;
   } else if ((label | 0) == 13693) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36121
    break;
   } else if ((label | 0) == 13583) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36127
    break;
   } else if ((label | 0) == 13704) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36133
    break;
   } else if ((label | 0) == 13610) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36139
    break;
   } else if ((label | 0) == 13638) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36145
    break;
   } else if ((label | 0) == 13661) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36151
    break;
   } else if ((label | 0) == 13565) {
    _fwrite(49960, 31, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36157
    _psi_sct_del($519); //@line 36158
    break;
   } else if ((label | 0) == 13733) {
    _fwrite(56464, 15, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 36164
    break;
   }
  }
 } while (0);
 _psi_img_del($1); //@line 36170
 $_0 = 0; //@line 36172
 STACKTOP = sp; //@line 36174
 return $_0 | 0; //@line 36175
}
function _psi_save_psi($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $crc_i22 = 0, $buf_i23 = 0, $crc_i = 0, $buf_i20 = 0, $1 = 0, $2 = 0, $3 = 0, $6 = 0, $7 = 0, $c_010_i_i = 0, $10 = 0, $13 = 0, $14 = 0, $h_0_i_i = 0, $20 = 0, $26 = 0, $33 = 0, $enc_0_load28 = 0, $enc_0_load27 = 0, $val_0_i = 0, $42 = 0, $43 = 0, $48 = 0, $49 = 0, $54 = 0, $56 = 0, $61 = 0, $63 = 0, $64 = 0, $c_037 = 0, $67 = 0, $68 = 0, $69 = 0, $71 = 0, $72 = 0, $h_032 = 0, $75 = 0, $76 = 0, $79 = 0, $s_031 = 0, $83 = 0, $sct_pn_i = 0, $_014_i = 0, $96 = 0, $97 = 0, $100 = 0, $101 = 0, $105 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 36198
 STACKTOP = STACKTOP + 48 | 0; //@line 36198
 $crc_i22 = sp | 0; //@line 36199
 $buf_i23 = sp + 8 | 0; //@line 36200
 $crc_i = sp + 16 | 0; //@line 36201
 $buf_i20 = sp + 24 | 0; //@line 36202
 $1 = sp + 40 | 0; //@line 36204
 _psi_set_uint16_be($1, 0, 0); //@line 36205
 $2 = $img | 0; //@line 36206
 $3 = HEAP16[$2 >> 1] | 0; //@line 36207
 L17449 : do {
  if ($3 << 16 >> 16 == 0) {
   $enc_0_load28 = 0; //@line 36212
   label = 13752; //@line 36213
  } else {
   $6 = HEAP32[$img + 4 >> 2] | 0; //@line 36216
   $7 = $3 & 65535; //@line 36217
   $c_010_i_i = 0; //@line 36219
   L17451 : while (1) {
    $10 = HEAP32[$6 + ($c_010_i_i << 2) >> 2] | 0; //@line 36223
    $13 = HEAPU16[$10 + 2 >> 1] | 0; //@line 36226
    $14 = $10 + 4 | 0; //@line 36227
    $h_0_i_i = 0; //@line 36229
    while (1) {
     if ($h_0_i_i >>> 0 >= $13 >>> 0) {
      break;
     }
     $20 = HEAP32[(HEAP32[$14 >> 2] | 0) + ($h_0_i_i << 2) >> 2] | 0; //@line 36239
     if ((HEAP16[$20 + 2 >> 1] | 0) == 0) {
      $h_0_i_i = $h_0_i_i + 1 | 0; //@line 36246
     } else {
      break L17451;
     }
    }
    $26 = $c_010_i_i + 1 | 0; //@line 36251
    if ($26 >>> 0 < $7 >>> 0) {
     $c_010_i_i = $26; //@line 36255
    } else {
     $enc_0_load28 = 0; //@line 36257
     label = 13752; //@line 36258
     break L17449;
    }
   }
   $33 = HEAPU16[(HEAP32[HEAP32[$20 + 4 >> 2] >> 2] | 0) + 16 >> 1] | 0; //@line 36267
   if (($33 | 0) == 1) {
    $val_0_i = 256;
    $enc_0_load27 = 1;
    break;
   } else if (($33 | 0) == 32769) {
    $val_0_i = 257;
    $enc_0_load27 = $33;
    break;
   } else if (($33 | 0) == 32770) {
    $val_0_i = 513;
    $enc_0_load27 = $33;
    break;
   } else if (($33 | 0) == 3) {
    $val_0_i = 768;
    $enc_0_load27 = $33;
    break;
   } else if (($33 | 0) == 2) {
    $val_0_i = 512;
    $enc_0_load27 = $33;
    break;
   } else if (($33 | 0) == 16386) {
    $val_0_i = 514;
    $enc_0_load27 = $33;
    break;
   } else {
    $enc_0_load28 = $33; //@line 36292
    label = 13752; //@line 36293
    break;
   }
  }
 } while (0);
 if ((label | 0) == 13752) {
  $val_0_i = 0;
  $enc_0_load27 = $enc_0_load28;
 }
 _psi_set_uint16_be($1, 2, $val_0_i); //@line 36305
 if ((_psi_save_chunk($fp, 1347635488, 4, $1) | 0) != 0) {
  $_0 = 1; //@line 36310
  STACKTOP = sp; //@line 36312
  return $_0 | 0; //@line 36313
 }
 $42 = $buf_i20 | 0; //@line 36316
 $43 = $img + 8 | 0; //@line 36317
 do {
  if ((HEAP32[$43 >> 2] | 0) != 0) {
   _psi_set_uint32_be($42, 0, 1413830740); //@line 36323
   _psi_set_uint32_be($42, 4, (HEAP32[$43 >> 2] | 0) + 2 | 0); //@line 36326
   $48 = $buf_i20 + 8 | 0; //@line 36327
   HEAP8[$48] = 10; //@line 36328
   HEAP32[$crc_i >> 2] = 0; //@line 36329
   $49 = _psi_write_crc($fp, $42, 9, $crc_i) | 0; //@line 36330
   $54 = _psi_write_crc($fp, HEAP32[$img + 12 >> 2] | 0, HEAP32[$43 >> 2] | 0, $crc_i) | 0 | $49; //@line 36335
   $56 = $54 | (_psi_write_crc($fp, $48, 1, $crc_i) | 0); //@line 36337
   _psi_set_uint32_be($42, 0, HEAP32[$crc_i >> 2] | 0); //@line 36339
   if (($56 | (_fwrite($42 | 0, 1, 4, $fp | 0) | 0) != 4 | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 36349
   }
   STACKTOP = sp; //@line 36352
   return $_0 | 0; //@line 36353
  }
 } while (0);
 $61 = HEAP16[$2 >> 1] | 0; //@line 36356
 L17474 : do {
  if ($61 << 16 >> 16 != 0) {
   $63 = $img + 4 | 0; //@line 36361
   $c_037 = 0;
   $64 = $61;
   L17476 : while (1) {
    $67 = HEAP32[(HEAP32[$63 >> 2] | 0) + ($c_037 << 2) >> 2] | 0; //@line 36369
    $68 = $67 + 2 | 0; //@line 36370
    $69 = HEAP16[$68 >> 1] | 0; //@line 36371
    if ($69 << 16 >> 16 == 0) {
     $100 = $64; //@line 36375
    } else {
     $71 = $67 + 4 | 0; //@line 36377
     $h_032 = 0;
     $72 = $69;
     while (1) {
      $75 = HEAP32[(HEAP32[$71 >> 2] | 0) + ($h_032 << 2) >> 2] | 0; //@line 36385
      $76 = $75 + 2 | 0; //@line 36386
      if ((HEAP16[$76 >> 1] | 0) == 0) {
       $96 = $72; //@line 36391
      } else {
       $79 = $75 + 4 | 0; //@line 36393
       $s_031 = 0; //@line 36395
       do {
        $83 = HEAP32[(HEAP32[$79 >> 2] | 0) + ($s_031 << 2) >> 2] | 0; //@line 36400
        if ((_psi_save_sector($fp, $83, $c_037, $h_032, 0, $enc_0_load27) | 0) == 0) {
         $sct_pn_i = $83; //@line 36405
        } else {
         $_0 = 1; //@line 36407
         label = 13778; //@line 36408
         break L17476;
        }
        while (1) {
         $_014_i = HEAP32[$sct_pn_i >> 2] | 0; //@line 36414
         if (($_014_i | 0) == 0) {
          break;
         }
         if ((_psi_save_sector($fp, $_014_i, $c_037, $h_032, 1, $enc_0_load27) | 0) == 0) {
          $sct_pn_i = $_014_i; //@line 36424
         } else {
          $_0 = 1; //@line 36426
          label = 13777; //@line 36427
          break L17476;
         }
        }
        $s_031 = $s_031 + 1 | 0; //@line 36431
       } while ($s_031 >>> 0 < (HEAPU16[$76 >> 1] | 0) >>> 0);
       $96 = HEAP16[$68 >> 1] | 0; //@line 36444
      }
      $97 = $h_032 + 1 | 0; //@line 36447
      if ($97 >>> 0 < ($96 & 65535) >>> 0) {
       $h_032 = $97;
       $72 = $96;
      } else {
       break;
      }
     }
     $100 = HEAP16[$2 >> 1] | 0; //@line 36459
    }
    $101 = $c_037 + 1 | 0; //@line 36462
    if ($101 >>> 0 < ($100 & 65535) >>> 0) {
     $c_037 = $101;
     $64 = $100;
    } else {
     break L17474;
    }
   }
   if ((label | 0) == 13777) {
    STACKTOP = sp; //@line 36474
    return $_0 | 0; //@line 36475
   } else if ((label | 0) == 13778) {
    STACKTOP = sp; //@line 36479
    return $_0 | 0; //@line 36480
   }
  }
 } while (0);
 $105 = $buf_i23 | 0; //@line 36485
 _psi_set_uint32_be($105, 0, 1162757152); //@line 36486
 _psi_set_uint32_be($105, 4, 0); //@line 36487
 HEAP32[$crc_i22 >> 2] = 0; //@line 36488
 if ((_psi_write_crc($fp, $105, 8, $crc_i22) | 0) != 0) {
  $_0 = 1; //@line 36493
  STACKTOP = sp; //@line 36495
  return $_0 | 0; //@line 36496
 }
 _psi_set_uint32_be($105, 0, HEAP32[$crc_i22 >> 2] | 0); //@line 36499
 if ((_fwrite($105 | 0, 1, 4, $fp | 0) | 0) != 4) {
  $_0 = 1; //@line 36504
  STACKTOP = sp; //@line 36506
  return $_0 | 0; //@line 36507
 }
 _fflush($fp | 0) | 0; //@line 36509
 $_0 = 0; //@line 36511
 STACKTOP = sp; //@line 36513
 return $_0 | 0; //@line 36514
}
function _psi_save_chunk($fp, $ckid, $size, $data) {
 $fp = $fp | 0;
 $ckid = $ckid | 0;
 $size = $size | 0;
 $data = $data | 0;
 var $crc = 0, $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 36526
 STACKTOP = STACKTOP + 16 | 0; //@line 36526
 $crc = sp | 0; //@line 36527
 $1 = sp + 8 | 0; //@line 36529
 _psi_set_uint32_be($1, 0, $ckid); //@line 36530
 _psi_set_uint32_be($1, 4, $size); //@line 36531
 HEAP32[$crc >> 2] = 0; //@line 36532
 if ((_psi_write_crc($fp, $1, 8, $crc) | 0) != 0) {
  $_0 = 1; //@line 36537
  STACKTOP = sp; //@line 36539
  return $_0 | 0; //@line 36540
 }
 do {
  if (($size | 0) != 0) {
   if ((_psi_write_crc($fp, $data, $size, $crc) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 36552
   }
   STACKTOP = sp; //@line 36555
   return $_0 | 0; //@line 36556
  }
 } while (0);
 _psi_set_uint32_be($1, 0, HEAP32[$crc >> 2] | 0); //@line 36560
 $_0 = (_fwrite($1 | 0, 1, 4, $fp | 0) | 0) != 4 | 0; //@line 36565
 STACKTOP = sp; //@line 36567
 return $_0 | 0; //@line 36568
}
function _psi_probe_psi_fp($fp) {
 $fp = $fp | 0;
 var $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 36576
 STACKTOP = STACKTOP + 8 | 0; //@line 36576
 $1 = sp | 0; //@line 36578
 if ((_psi_read_ofs($fp, 0, $1, 4) | 0) != 0) {
  $_0 = 0; //@line 36583
  STACKTOP = sp; //@line 36585
  return $_0 | 0; //@line 36586
 }
 $_0 = (_psi_get_uint32_be($1, 0) | 0) == 1347635488 | 0; //@line 36592
 STACKTOP = sp; //@line 36594
 return $_0 | 0; //@line 36595
}
function _psi_write_crc($fp, $buf, $cnt, $crc) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 $crc = $crc | 0;
 var $3 = 0, $i_017_i = 0, $5 = 0, $reg_1_i = 0, $8 = 0, $reg_1_1_i = 0, $11 = 0, $reg_1_2_i = 0, $14 = 0, $reg_1_3_i = 0, $17 = 0, $reg_1_4_i = 0, $20 = 0, $reg_1_5_i = 0, $23 = 0, $reg_1_6_i = 0, $26 = 0, $src_013_i = 0, $_012_i = 0, $_01011_i = 0, $41 = 0, $42 = 0, $_0_lcssa_i = 0, $45 = 0, $not_ = 0, $_ = 0;
 if (($crc | 0) == 0) {
  $45 = _fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0; //@line 36617
  $not_ = ($45 | 0) != ($cnt | 0); //@line 36618
  $_ = $not_ & 1; //@line 36619
  return $_ | 0; //@line 36621
 }
 $3 = HEAP32[$crc >> 2] | 0; //@line 36623
 if (!(HEAP8[6648] | 0)) {
  $i_017_i = 0; //@line 36627
  do {
   $5 = $i_017_i << 25; //@line 36632
   $reg_1_i = ($i_017_i & 128 | 0) != 0 ? $5 ^ 517762881 : $5; //@line 36634
   $8 = $reg_1_i << 1; //@line 36636
   $reg_1_1_i = ($reg_1_i | 0) < 0 ? $8 ^ 517762881 : $8; //@line 36638
   $11 = $reg_1_1_i << 1; //@line 36640
   $reg_1_2_i = ($reg_1_1_i | 0) < 0 ? $11 ^ 517762881 : $11; //@line 36642
   $14 = $reg_1_2_i << 1; //@line 36644
   $reg_1_3_i = ($reg_1_2_i | 0) < 0 ? $14 ^ 517762881 : $14; //@line 36646
   $17 = $reg_1_3_i << 1; //@line 36648
   $reg_1_4_i = ($reg_1_3_i | 0) < 0 ? $17 ^ 517762881 : $17; //@line 36650
   $20 = $reg_1_4_i << 1; //@line 36652
   $reg_1_5_i = ($reg_1_4_i | 0) < 0 ? $20 ^ 517762881 : $20; //@line 36654
   $23 = $reg_1_5_i << 1; //@line 36656
   $reg_1_6_i = ($reg_1_5_i | 0) < 0 ? $23 ^ 517762881 : $23; //@line 36658
   $26 = $reg_1_6_i << 1; //@line 36660
   HEAP32[58216 + ($i_017_i << 2) >> 2] = ($reg_1_6_i | 0) < 0 ? $26 ^ 517762881 : $26; //@line 36664
   $i_017_i = $i_017_i + 1 | 0; //@line 36665
  } while ($i_017_i >>> 0 < 256);
  HEAP8[6648] = 1; //@line 36674
 }
 if (($cnt | 0) == 0) {
  $_0_lcssa_i = $3; //@line 36680
 } else {
  $_01011_i = $cnt;
  $_012_i = $3;
  $src_013_i = $buf;
  while (1) {
   $41 = HEAP32[58216 + (((HEAPU8[$src_013_i] | 0) ^ $_012_i >>> 24) << 2) >> 2] ^ $_012_i << 8; //@line 36695
   $42 = $_01011_i - 1 | 0; //@line 36696
   if (($42 | 0) == 0) {
    $_0_lcssa_i = $41; //@line 36700
    break;
   } else {
    $_01011_i = $42;
    $_012_i = $41;
    $src_013_i = $src_013_i + 1 | 0;
   }
  }
 }
 HEAP32[$crc >> 2] = $_0_lcssa_i; //@line 36708
 $45 = _fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0; //@line 36710
 $not_ = ($45 | 0) != ($cnt | 0); //@line 36711
 $_ = $not_ & 1; //@line 36712
 return $_ | 0; //@line 36714
}
function _psi_save_sector($fp, $sct, $c, $h, $alt, $enc) {
 $fp = $fp | 0;
 $sct = $sct | 0;
 $c = $c | 0;
 $h = $h | 0;
 $alt = $alt | 0;
 $enc = $enc | 0;
 var $buf_i50 = 0, $buf_i45 = 0, $buf_i = 0, $buf = 0, $2 = 0, $_pre60 = 0, $f_0 = 0, $8 = 0, $f_1 = 0, $13 = 0, $16 = 0, $24 = 0, $26 = 0, $35 = 0, $36 = 0, $37 = 0, $41 = 0, $43 = 0, $52 = 0, $60 = 0, $62 = 0, $67 = 0, $68 = 0, $93 = 0, $97 = 0, $99 = 0, $108 = 0, $116 = 0, $118 = 0, $123 = 0, $124 = 0, $151 = 0, $152 = 0, $156 = 0, $165 = 0, $174 = 0, $175 = 0, $req_1_i = 0, $252 = 0, $259 = 0, $260 = 0, $263 = 0, $272 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 36761
 STACKTOP = STACKTOP + 48 | 0; //@line 36761
 $buf_i50 = sp | 0; //@line 36762
 $buf_i45 = sp + 8 | 0; //@line 36763
 $buf_i = sp + 32 | 0; //@line 36764
 $buf = sp + 40 | 0; //@line 36765
 $2 = ($alt | 0) != 0 ? 2 : 0; //@line 36767
 $_pre60 = $sct + 10 | 0; //@line 36770
 if ((_psi_sct_uniform($sct) | 0) == 0) {
  $f_0 = $2; //@line 36773
 } else {
  $f_0 = (HEAP16[$_pre60 >> 1] | 0) != 0 | $2; //@line 36780
 }
 $8 = $sct + 12 | 0; //@line 36783
 $f_1 = (HEAP32[$8 >> 2] & 2 | 0) == 0 ? $f_0 : $f_0 | 4; //@line 36788
 $13 = $buf | 0; //@line 36789
 _psi_set_uint16_be($13, 0, $c); //@line 36790
 HEAP8[$buf + 2 | 0] = $h & 255; //@line 36793
 $16 = $sct + 8 | 0; //@line 36794
 HEAP8[$buf + 3 | 0] = HEAP16[$16 >> 1] & 255; //@line 36798
 _psi_set_uint16_be($13, 4, HEAPU16[$_pre60 >> 1] | 0); //@line 36801
 HEAP8[$buf + 6 | 0] = $f_1 & 255; //@line 36804
 $24 = $buf + 7 | 0; //@line 36805
 HEAP8[$24] = 0; //@line 36806
 $26 = ($f_1 & 1 | 0) == 0; //@line 36808
 if (!$26) {
  HEAP8[$24] = HEAP8[HEAP32[$sct + 24 >> 2] | 0] | 0; //@line 36814
 }
 if ((_psi_save_chunk($fp, 1397048148, 8, $13) | 0) != 0) {
  $_0 = 1; //@line 36821
  STACKTOP = sp; //@line 36823
  return $_0 | 0; //@line 36824
 }
 $35 = $buf_i | 0; //@line 36826
 $36 = $sct + 16 | 0; //@line 36827
 $37 = HEAP16[$36 >> 1] | 0; //@line 36828
 do {
  if (($37 & 4095) == 1) {
   $41 = _psi_sct_get_mfm_size($sct) | 0; //@line 36834
   $43 = HEAP16[$sct + 4 >> 1] | 0; //@line 36836
   if (($43 & 65535 | 0) == ($c | 0)) {
    $52 = (HEAPU16[$sct + 6 >> 1] | 0) != ($h | 0) | 0; //@line 36847
   } else {
    $52 = 1; //@line 36849
   }
   if ($41 >>> 0 > 8) {
    $60 = 1; //@line 36855
   } else {
    $60 = (HEAPU16[$_pre60 >> 1] | 0) != (128 << $41 | 0) | 0; //@line 36863
   }
   $62 = HEAP32[$8 >> 2] | 0; //@line 36867
   $67 = HEAP16[$36 >> 1] | 0; //@line 36872
   $68 = $67 & 65535; //@line 36873
   if (($60 | $52 | ($62 & 13 | 0) != 0 | ($68 | 0) != ($enc | 0) | 0) == 0) {
    $93 = $67; //@line 36880
    break;
   }
   HEAP8[$35] = $43 & 255; //@line 36884
   HEAP8[$buf_i + 1 | 0] = HEAP16[$sct + 6 >> 1] & 255; //@line 36889
   HEAP8[$buf_i + 2 | 0] = HEAP16[$16 >> 1] & 255; //@line 36893
   HEAP8[$buf_i + 3 | 0] = $41 & 255; //@line 36896
   HEAP8[$buf_i + 4 | 0] = $62 & 15; //@line 36900
   if (($68 | 0) == 32769) {
    HEAP8[$buf_i + 5 | 0] = 1; //@line 36903
   } else if (($68 | 0) == 1) {
    HEAP8[$buf_i + 5 | 0] = 0; //@line 36907
   } else {
    HEAP8[$buf_i + 5 | 0] = 0; //@line 36911
   }
   if ((_psi_save_chunk($fp, 1229081926, 6, $35) | 0) == 0) {
    $93 = HEAP16[$36 >> 1] | 0; //@line 36920
    break;
   } else {
    $_0 = 1; //@line 36923
    STACKTOP = sp; //@line 36925
    return $_0 | 0; //@line 36926
   }
  } else {
   $93 = $37; //@line 36929
  }
 } while (0);
 do {
  if (($93 & 4095) == 2) {
   $97 = _psi_sct_get_mfm_size($sct) | 0; //@line 36938
   $99 = HEAP16[$sct + 4 >> 1] | 0; //@line 36940
   if (($99 & 65535 | 0) == ($c | 0)) {
    $108 = (HEAPU16[$sct + 6 >> 1] | 0) != ($h | 0) | 0; //@line 36951
   } else {
    $108 = 1; //@line 36953
   }
   if ($97 >>> 0 > 8) {
    $116 = 1; //@line 36959
   } else {
    $116 = (HEAPU16[$_pre60 >> 1] | 0) != (128 << $97 | 0) | 0; //@line 36967
   }
   $118 = HEAP32[$8 >> 2] | 0; //@line 36971
   $123 = HEAP16[$36 >> 1] | 0; //@line 36976
   $124 = $123 & 65535; //@line 36977
   if (($116 | $108 | ($118 & 13 | 0) != 0 | ($124 | 0) != ($enc | 0) | 0) == 0) {
    $151 = $123; //@line 36984
    break;
   }
   HEAP8[$35] = $99 & 255; //@line 36988
   HEAP8[$buf_i + 1 | 0] = HEAP16[$sct + 6 >> 1] & 255; //@line 36993
   HEAP8[$buf_i + 2 | 0] = HEAP16[$16 >> 1] & 255; //@line 36997
   HEAP8[$buf_i + 3 | 0] = $97 & 255; //@line 37000
   HEAP8[$buf_i + 4 | 0] = $118 & 15; //@line 37004
   if (($124 | 0) == 2) {
    HEAP8[$buf_i + 5 | 0] = 0; //@line 37007
   } else if (($124 | 0) == 32770) {
    HEAP8[$buf_i + 5 | 0] = 1; //@line 37011
   } else if (($124 | 0) == 16386) {
    HEAP8[$buf_i + 5 | 0] = 2; //@line 37015
   } else {
    HEAP8[$buf_i + 5 | 0] = 0; //@line 37019
   }
   if ((_psi_save_chunk($fp, 1229081933, 6, $35) | 0) == 0) {
    $151 = HEAP16[$36 >> 1] | 0; //@line 37028
    break;
   } else {
    $_0 = 1; //@line 37031
    STACKTOP = sp; //@line 37033
    return $_0 | 0; //@line 37034
   }
  } else {
   $151 = $93; //@line 37037
  }
 } while (0);
 $152 = $buf_i45 | 0; //@line 37041
 do {
  if (($151 & 4095) == 3) {
   $156 = $sct + 4 | 0; //@line 37047
   if ((HEAPU16[$156 >> 1] | 0) == ($c | 0)) {
    $165 = (HEAPU16[$sct + 6 >> 1] | 0) != ($h | 0) | 0; //@line 37059
   } else {
    $165 = 1; //@line 37061
   }
   $174 = $165 | ($151 & 65535 | 0) != ($enc | 0) | (HEAP32[$8 >> 2] & 9 | 0) != 0; //@line 37072
   $175 = $buf_i45 + 6 | 0; //@line 37073
   if ((_psi_sct_get_tags($sct, $175, 12) | 0) == 0) {
    $req_1_i = $174; //@line 37078
   } else {
    $req_1_i = (HEAP8[$175] | 0) != 0 | $174 | (HEAP8[$buf_i45 + 7 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 8 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 9 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 10 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 11 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 12 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 13 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 14 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 15 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 16 | 0] | 0) != 0 | (HEAP8[$buf_i45 + 17 | 0] | 0) != 0; //@line 37139
   }
   if (($req_1_i | 0) == 0) {
    break;
   }
   _psi_set_uint16_be($152, 0, HEAPU16[$156 >> 1] | 0); //@line 37149
   HEAP8[$buf_i45 + 2 | 0] = HEAP16[$sct + 6 >> 1] & 255; //@line 37154
   HEAP8[$buf_i45 + 3 | 0] = HEAP16[$16 >> 1] & 255; //@line 37158
   HEAP8[$buf_i45 + 4 | 0] = (_psi_sct_get_gcr_format($sct) | 0) & 255; //@line 37162
   $252 = HEAP32[$8 >> 2] | 0; //@line 37164
   HEAP8[$buf_i45 + 5 | 0] = ($252 >>> 1 & 4 | $252 & 3) & 255; //@line 37170
   if ((_psi_save_chunk($fp, 1296122695, 18, $152) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 37177
   }
   STACKTOP = sp; //@line 37180
   return $_0 | 0; //@line 37181
  }
 } while (0);
 $259 = $buf_i50 | 0; //@line 37184
 $260 = _psi_sct_get_position($sct) | 0; //@line 37185
 do {
  if (($260 | 0) != -1) {
   _psi_set_uint32_be($259, 0, $260); //@line 37190
   if ((_psi_save_chunk($fp, 1330005587, 4, $259) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 37197
   }
   STACKTOP = sp; //@line 37200
   return $_0 | 0; //@line 37201
  }
 } while (0);
 $263 = _psi_sct_get_read_time($sct) | 0; //@line 37204
 do {
  if (($263 | 0) != 0) {
   if (($263 | 0) == (HEAPU16[$_pre60 >> 1] << 3 | 0)) {
    break;
   }
   _psi_set_uint32_be($259, 0, $263); //@line 37217
   if ((_psi_save_chunk($fp, 1414090053, 4, $259) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 37224
   }
   STACKTOP = sp; //@line 37227
   return $_0 | 0; //@line 37228
  }
 } while (0);
 do {
  if ($26) {
   $272 = HEAP16[$_pre60 >> 1] | 0; //@line 37234
   if ($272 << 16 >> 16 == 0) {
    break;
   }
   if ((_psi_save_chunk($fp, 1145132097, $272 & 65535, HEAP32[$sct + 24 >> 2] | 0) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 37249
   }
   STACKTOP = sp; //@line 37252
   return $_0 | 0; //@line 37253
  }
 } while (0);
 $_0 = 0; //@line 37257
 STACKTOP = sp; //@line 37259
 return $_0 | 0; //@line 37260
}
function _psi_load_st($fp) {
 $fp = $fp | 0;
 var $1 = 0, $_0 = 0;
 $1 = _psi_img_new() | 0; //@line 37269
 do {
  if (($1 | 0) == 0) {
   $_0 = 0; //@line 37274
  } else {
   if ((_raw_load_fp($fp, $1, 29104) | 0) == 0) {
    $_0 = $1; //@line 37280
    break;
   }
   _psi_img_del($1); //@line 37283
   $_0 = 0; //@line 37285
  }
 } while (0);
 return $_0 | 0; //@line 37290
}
function _raw_load_fp($fp, $img, $geo) {
 $fp = $fp | 0;
 $img = $img | 0;
 $geo = $geo | 0;
 var $1 = 0, $4 = 0, $_08_i = 0, $7 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $c_032 = 0, $h_029 = 0, $23 = 0, $s_0 = 0, $28 = 0, $30 = 0, $41 = 0, $46 = 0, $49 = 0, $50 = 0, $51 = 0, $_0 = 0, label = 0;
 $1 = _ftell($fp | 0) | 0; //@line 37307
 if ((_fseek($fp | 0, 0, 2) | 0) != 0) {
  $_0 = 1; //@line 37312
  return $_0 | 0; //@line 37315
 }
 $4 = _ftell($fp | 0) | 0; //@line 37317
 if ((_fseek($fp | 0, $1 | 0, 0) | 0) == 0) {
  $_08_i = $geo; //@line 37322
 } else {
  $_0 = 1; //@line 37324
  return $_0 | 0; //@line 37327
 }
 while (1) {
  $7 = HEAP32[$_08_i >> 2] | 0; //@line 37332
  if (($7 | 0) == 0) {
   $_0 = 1; //@line 37336
   label = 13890; //@line 37337
   break;
  }
  if (($7 | 0) == ($4 | 0)) {
   break;
  } else {
   $_08_i = $_08_i + 24 | 0; //@line 37346
  }
 }
 if ((label | 0) == 13890) {
  return $_0 | 0; //@line 37352
 }
 if (($_08_i | 0) == 0) {
  $_0 = 1; //@line 37357
  return $_0 | 0; //@line 37360
 }
 $13 = $_08_i + 4 | 0; //@line 37362
 $14 = HEAP32[$13 >> 2] | 0; //@line 37363
 if (($14 | 0) == 0) {
  $_0 = 0; //@line 37367
  return $_0 | 0; //@line 37370
 }
 $16 = $_08_i + 8 | 0; //@line 37372
 $17 = $_08_i + 12 | 0; //@line 37373
 $18 = $_08_i + 16 | 0; //@line 37374
 $19 = $_08_i + 20 | 0; //@line 37375
 $c_032 = 0;
 $21 = HEAP32[$16 >> 2] | 0;
 $20 = $14;
 L17629 : while (1) {
  if (($21 | 0) == 0) {
   $50 = 0;
   $49 = $20;
  } else {
   $h_029 = 0; //@line 37388
   do {
    $23 = _psi_img_get_track($img, $c_032, $h_029, 1) | 0; //@line 37391
    if (($23 | 0) == 0) {
     $_0 = 1; //@line 37395
     label = 13887; //@line 37396
     break L17629;
    } else {
     $s_0 = 0; //@line 37399
    }
    while (1) {
     if ($s_0 >>> 0 >= (HEAP32[$17 >> 2] | 0) >>> 0) {
      break;
     }
     $28 = $s_0 + 1 | 0; //@line 37409
     $30 = _psi_sct_new($c_032, $h_029, $28, HEAP32[$18 >> 2] | 0) | 0; //@line 37411
     if (($30 | 0) == 0) {
      $_0 = 1; //@line 37415
      label = 13883; //@line 37416
      break L17629;
     }
     _psi_sct_set_encoding($30, HEAP32[$19 >> 2] | 0); //@line 37420
     if ((_psi_trk_add_sector($23, $30) | 0) != 0) {
      label = 13875; //@line 37425
      break L17629;
     }
     $41 = _fread(HEAP32[$30 + 24 >> 2] | 0, 1, HEAP32[$18 >> 2] | 0, $fp | 0) | 0; //@line 37431
     if (($41 | 0) == (HEAP32[$18 >> 2] | 0)) {
      $s_0 = $28; //@line 37436
     } else {
      $_0 = 1; //@line 37438
      label = 13884; //@line 37439
      break L17629;
     }
    }
    $h_029 = $h_029 + 1 | 0; //@line 37443
    $46 = HEAP32[$16 >> 2] | 0; //@line 37444
   } while ($h_029 >>> 0 < $46 >>> 0);
   $50 = $46;
   $49 = HEAP32[$13 >> 2] | 0;
  }
  $51 = $c_032 + 1 | 0; //@line 37459
  if ($51 >>> 0 < $49 >>> 0) {
   $c_032 = $51;
   $21 = $50;
   $20 = $49;
  } else {
   $_0 = 0; //@line 37465
   label = 13888; //@line 37466
   break;
  }
 }
 if ((label | 0) == 13883) {
  return $_0 | 0; //@line 37473
 } else if ((label | 0) == 13888) {
  return $_0 | 0; //@line 37478
 } else if ((label | 0) == 13875) {
  _psi_sct_del($30); //@line 37481
  $_0 = 1; //@line 37483
  return $_0 | 0; //@line 37486
 } else if ((label | 0) == 13887) {
  return $_0 | 0; //@line 37491
 } else if ((label | 0) == 13884) {
  return $_0 | 0; //@line 37496
 }
 return 0;
}
function _psi_load_raw($fp) {
 $fp = $fp | 0;
 var $1 = 0, $_0 = 0;
 $1 = _psi_img_new() | 0; //@line 37506
 do {
  if (($1 | 0) == 0) {
   $_0 = 0; //@line 37511
  } else {
   if ((_raw_load_fp($fp, $1, 29752) | 0) == 0) {
    $_0 = $1; //@line 37517
    break;
   }
   _psi_img_del($1); //@line 37520
   $_0 = 0; //@line 37522
  }
 } while (0);
 return $_0 | 0; //@line 37527
}
function _psi_save_st($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 return _psi_save_raw($fp, $img) | 0; //@line 37539
}
function _psi_save_raw($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $c_033 = 0, $8 = 0, $9 = 0, $12 = 0, $h_031 = 0, $15 = 0, $16 = 0, $17 = 0, $20 = 0, $21 = 0, $sct_016_i = 0, $j_015_i = 0, $i_014_i = 0, $24 = 0, $27 = 0, $28 = 0, $sct_1_i = 0, $29 = 0, $32 = 0, $sct_0_ph2630 = 0, $sct_1_i_pn = 0, $_ph2529 = 0, $35 = 0, $38 = 0, $43 = 0, $45 = 0, $46 = 0, $sct_016_i15 = 0, $j_015_i16 = 0, $i_014_i17 = 0, $49 = 0, $52 = 0, $or_cond_i18 = 0, $sct_1_i20 = 0, $55 = 0, $63 = 0, $64 = 0, $_0 = 0;
 $1 = $img | 0; //@line 37559
 $2 = HEAP16[$1 >> 1] | 0; //@line 37560
 L17656 : do {
  if ($2 << 16 >> 16 != 0) {
   $4 = $img + 4 | 0; //@line 37565
   $c_033 = 0;
   $5 = $2;
   L17658 : while (1) {
    $8 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($c_033 << 2) >> 2] | 0; //@line 37573
    $9 = $8 + 2 | 0; //@line 37574
    if ((HEAP16[$9 >> 1] | 0) == 0) {
     $63 = $5; //@line 37579
    } else {
     $12 = $8 + 4 | 0; //@line 37581
     $h_031 = 0; //@line 37583
     do {
      $15 = HEAP32[(HEAP32[$12 >> 2] | 0) + ($h_031 << 2) >> 2] | 0; //@line 37588
      $16 = $15 + 2 | 0; //@line 37589
      $17 = HEAP16[$16 >> 1] | 0; //@line 37590
      L17664 : do {
       if ($17 << 16 >> 16 != 0) {
        $20 = HEAP32[$15 + 4 >> 2] | 0; //@line 37596
        $21 = $17 & 65535; //@line 37597
        $i_014_i = 0;
        $j_015_i = 65535;
        $sct_016_i = 0;
        while (1) {
         $24 = HEAP32[$20 + ($i_014_i << 2) >> 2] | 0; //@line 37605
         $27 = HEAPU16[$24 + 8 >> 1] | 0; //@line 37608
         $28 = $27 >>> 0 < $j_015_i >>> 0; //@line 37609
         $sct_1_i = $28 ? $24 : $sct_016_i; //@line 37611
         $29 = $i_014_i + 1 | 0; //@line 37612
         if ($29 >>> 0 < $21 >>> 0) {
          $i_014_i = $29;
          $j_015_i = $28 ? $27 : $j_015_i;
          $sct_016_i = $sct_1_i;
         } else {
          break;
         }
        }
        if (($sct_1_i | 0) == 0) {
         break;
        }
        $32 = $15 + 4 | 0; //@line 37626
        $sct_1_i_pn = $sct_1_i;
        $sct_0_ph2630 = $sct_1_i;
        while (1) {
         $_ph2529 = (HEAPU16[$sct_1_i_pn + 8 >> 1] | 0) + 1 | 0; //@line 37635
         $35 = $sct_0_ph2630 + 10 | 0; //@line 37638
         $38 = _fwrite(HEAP32[$sct_0_ph2630 + 24 >> 2] | 0, 1, HEAPU16[$35 >> 1] | 0, $fp | 0) | 0; //@line 37641
         if (($38 | 0) != (HEAPU16[$35 >> 1] | 0)) {
          $_0 = 1; //@line 37647
          break L17658;
         }
         $43 = HEAP16[$16 >> 1] | 0; //@line 37650
         if ($43 << 16 >> 16 == 0) {
          break L17664;
         }
         $45 = HEAP32[$32 >> 2] | 0; //@line 37656
         $46 = $43 & 65535; //@line 37657
         $i_014_i17 = 0;
         $j_015_i16 = 65535;
         $sct_016_i15 = 0;
         while (1) {
          $49 = HEAP32[$45 + ($i_014_i17 << 2) >> 2] | 0; //@line 37665
          $52 = HEAPU16[$49 + 8 >> 1] | 0; //@line 37668
          $or_cond_i18 = $52 >>> 0 >= $_ph2529 >>> 0 & $52 >>> 0 < $j_015_i16 >>> 0; //@line 37671
          $sct_1_i20 = $or_cond_i18 ? $49 : $sct_016_i15; //@line 37673
          $55 = $i_014_i17 + 1 | 0; //@line 37674
          if ($55 >>> 0 < $46 >>> 0) {
           $i_014_i17 = $55;
           $j_015_i16 = $or_cond_i18 ? $52 : $j_015_i16;
           $sct_016_i15 = $sct_1_i20;
          } else {
           break;
          }
         }
         if (($sct_1_i20 | 0) == 0) {
          break L17664;
         }
         $sct_1_i_pn = $sct_1_i20;
         $sct_0_ph2630 = $sct_1_i20;
        }
       }
      } while (0);
      $h_031 = $h_031 + 1 | 0; //@line 37693
     } while ($h_031 >>> 0 < (HEAPU16[$9 >> 1] | 0) >>> 0);
     $63 = HEAP16[$1 >> 1] | 0; //@line 37706
    }
    $64 = $c_033 + 1 | 0; //@line 37709
    if ($64 >>> 0 < ($63 & 65535) >>> 0) {
     $c_033 = $64;
     $5 = $63;
    } else {
     break L17656;
    }
   }
   return $_0 | 0; //@line 37721
  }
 } while (0);
 _fflush($fp | 0) | 0; //@line 37724
 $_0 = 0; //@line 37726
 return $_0 | 0; //@line 37729
}
function _psi_probe_raw_fp($fp) {
 $fp = $fp | 0;
 var $4 = 0, $_08_i_i = 0, $7 = 0, $_08_i6_i = 0, $14 = 0, $_0_i = 0, $_0 = 0, label = 0;
 if ((_fseek($fp | 0, 0, 2) | 0) != 0) {
  $_0 = 0; //@line 37744
  return $_0 | 0; //@line 37747
 }
 $4 = _ftell($fp | 0) | 0; //@line 37749
 $_08_i_i = 29752; //@line 37751
 while (1) {
  $7 = HEAP32[$_08_i_i >> 2] | 0; //@line 37755
  if (($7 | 0) == 0) {
   $_08_i6_i = 29104; //@line 37759
   label = 13923; //@line 37760
   break;
  }
  if (($7 | 0) == ($4 | 0)) {
   label = 13922; //@line 37767
   break;
  } else {
   $_08_i_i = $_08_i_i + 24 | 0; //@line 37770
  }
 }
 if ((label | 0) == 13922) {
  if (($_08_i_i | 0) == 0) {
   $_08_i6_i = 29104; //@line 37777
   label = 13923; //@line 37778
  } else {
   $_0_i = $_08_i_i; //@line 37780
  }
 }
 L17693 : do {
  if ((label | 0) == 13923) {
   while (1) {
    label = 0; //@line 37786
    $14 = HEAP32[$_08_i6_i >> 2] | 0; //@line 37789
    if (($14 | 0) == 0) {
     $_0_i = 0; //@line 37793
     break L17693;
    }
    if (($14 | 0) == ($4 | 0)) {
     $_0_i = $_08_i6_i; //@line 37800
     break;
    } else {
     $_08_i6_i = $_08_i6_i + 24 | 0; //@line 37803
     label = 13923; //@line 37804
    }
   }
  }
 } while (0);
 $_0 = ($_0_i | 0) != 0 | 0; //@line 37813
 return $_0 | 0; //@line 37816
}
function _psi_save_stx($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 return 1; //@line 37826
}
function _psi_load_stx($fp) {
 $fp = $fp | 0;
 var $buf_i_i_i = 0, $buf_i_i = 0, $buf_i = 0, $1 = 0, $4 = 0, $11 = 0, $15 = 0, $16 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $i_016_i = 0, $27 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $44 = 0, $45 = 0, $46 = 0, $i_032_i_i = 0, $hpos_031_i_i = 0, $52 = 0, $56 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $src_05_i28_i_i_i = 0, $_04_i29_i_i_i = 0, $_093_i30_i_i_i = 0, $71 = 0, $74 = 0, $_2_i31_i_i_i = 0, $78 = 0, $_2_1_i32_i_i_i = 0, $82 = 0, $_2_2_i33_i_i_i = 0, $86 = 0, $_2_3_i34_i_i_i = 0, $90 = 0, $_2_4_i35_i_i_i = 0, $94 = 0, $_2_5_i36_i_i_i = 0, $98 = 0, $_2_6_i37_i_i_i = 0, $102 = 0, $_2_7_i38_i_i_i = 0, $105 = 0, $107 = 0, $109 = 0, $110 = 0, $111 = 0, $114 = 0, $115 = 0, $147 = 0, $150 = 0, $157 = 0, $160 = 0, $i_015_i_i_i_i = 0, $166 = 0, $_ph_i_i = 0, $177 = 0, $hpos_1_i_i = 0, $i_1_i_i = 0, $181 = 0, $182 = 0, $192 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 37857
 STACKTOP = STACKTOP + 48 | 0; //@line 37857
 $buf_i_i_i = sp | 0; //@line 37858
 $buf_i_i = sp + 16 | 0; //@line 37859
 $buf_i = sp + 32 | 0; //@line 37860
 $1 = _psi_img_new() | 0; //@line 37861
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 37865
  STACKTOP = sp; //@line 37867
  return $_0 | 0; //@line 37868
 }
 $4 = $buf_i | 0; //@line 37870
 L17704 : do {
  if ((_psi_read_ofs($fp, 0, $4, 16) | 0) == 0) {
   if ((_psi_get_uint32_be($4, 0) | 0) != 1381193984) {
    $11 = HEAP32[_stderr >> 2] | 0; //@line 37880
    _fwrite(56448, 15, 1, $11 | 0) | 0; //@line 37881
    break;
   }
   $15 = HEAP8[$buf_i + 10 | 0] | 0; //@line 37886
   $16 = $15 & 255; //@line 37887
   if ($15 << 24 >> 24 == 0) {
    $_0 = $1; //@line 37891
    STACKTOP = sp; //@line 37893
    return $_0 | 0; //@line 37894
   }
   $18 = $buf_i_i | 0; //@line 37896
   $19 = $buf_i_i + 14 | 0; //@line 37897
   $20 = $buf_i_i_i | 0; //@line 37898
   $21 = $buf_i_i_i + 8 | 0; //@line 37899
   $22 = $buf_i_i_i + 9 | 0; //@line 37900
   $23 = $buf_i_i_i + 10 | 0; //@line 37901
   $24 = $buf_i_i_i + 11 | 0; //@line 37902
   $25 = $buf_i_i_i + 14 | 0; //@line 37903
   $27 = 16;
   $i_016_i = 0;
   L17712 : while (1) {
    if ((_psi_read_ofs($fp, $27, $18, 16) | 0) != 0) {
     label = 13937; //@line 37913
     break;
    }
    $34 = _psi_get_uint32_le($18, 0) | 0; //@line 37916
    $35 = _psi_get_uint32_le($18, 4) | 0; //@line 37917
    $36 = _psi_get_uint16_le($18, 8) | 0; //@line 37918
    $37 = _psi_get_uint16_le($18, 10) | 0; //@line 37919
    $39 = HEAPU8[$19] | 0; //@line 37921
    $40 = $39 & 127; //@line 37922
    $41 = $39 >>> 7; //@line 37923
    $42 = $27 + 16 | 0; //@line 37924
    $44 = ($36 << 4) + $42 | 0; //@line 37926
    $45 = $44 + $35 | 0; //@line 37927
    $46 = _psi_img_get_track($1, $40, $41, 1) | 0; //@line 37928
    if (($46 | 0) == 0) {
     break L17704;
    }
    L17716 : do {
     if (($37 & 1 | 0) == 0) {
      $i_1_i_i = 0;
      $hpos_1_i_i = $42;
      while (1) {
       if ($i_1_i_i >>> 0 >= $36 >>> 0) {
        break L17716;
       }
       $181 = $i_1_i_i + 1 | 0; //@line 37948
       $182 = _psi_sct_new($40, $41, $181, 512) | 0; //@line 37949
       if (($182 | 0) == 0) {
        break L17704;
       }
       _psi_trk_add_sector($46, $182) | 0; //@line 37955
       if ((_psi_read_ofs($fp, $hpos_1_i_i, HEAP32[$182 + 24 >> 2] | 0, 512) | 0) == 0) {
        $i_1_i_i = $181;
        $hpos_1_i_i = $hpos_1_i_i + 512 | 0;
       } else {
        break L17704;
       }
      }
     } else {
      if (($36 | 0) == 0) {
       break;
      } else {
       $52 = $44;
       $hpos_031_i_i = $42;
       $i_032_i_i = 0;
      }
      while (1) {
       if ((_psi_read_ofs($fp, $hpos_031_i_i, $20, 16) | 0) != 0) {
        label = 13942; //@line 37984
        break L17712;
       }
       $58 = _psi_get_uint32_le($20, 0) | 0; //@line 37987
       $59 = _psi_get_uint16_le($20, 4) | 0; //@line 37988
       $60 = _psi_get_uint16_le($20, 6) | 0; //@line 37989
       $61 = HEAP8[$21] | 0; //@line 37990
       $62 = HEAP8[$22] | 0; //@line 37991
       $63 = HEAP8[$23] | 0; //@line 37992
       $64 = HEAP8[$24] | 0; //@line 37993
       $65 = _psi_get_uint16_be($20, 12) | 0; //@line 37994
       $66 = HEAP8[$25] | 0; //@line 37995
       $_093_i30_i_i_i = 45616;
       $_04_i29_i_i_i = 4;
       $src_05_i28_i_i_i = $21;
       while (1) {
        $71 = HEAPU8[$src_05_i28_i_i_i] << 8 ^ $_093_i30_i_i_i; //@line 38005
        $74 = $71 << 1; //@line 38008
        $_2_i31_i_i_i = ($71 & 32768 | 0) == 0 ? $74 : $74 ^ 4129; //@line 38010
        $78 = $_2_i31_i_i_i << 1; //@line 38013
        $_2_1_i32_i_i_i = ($_2_i31_i_i_i & 32768 | 0) == 0 ? $78 : $78 ^ 4129; //@line 38015
        $82 = $_2_1_i32_i_i_i << 1; //@line 38018
        $_2_2_i33_i_i_i = ($_2_1_i32_i_i_i & 32768 | 0) == 0 ? $82 : $82 ^ 4129; //@line 38020
        $86 = $_2_2_i33_i_i_i << 1; //@line 38023
        $_2_3_i34_i_i_i = ($_2_2_i33_i_i_i & 32768 | 0) == 0 ? $86 : $86 ^ 4129; //@line 38025
        $90 = $_2_3_i34_i_i_i << 1; //@line 38028
        $_2_4_i35_i_i_i = ($_2_3_i34_i_i_i & 32768 | 0) == 0 ? $90 : $90 ^ 4129; //@line 38030
        $94 = $_2_4_i35_i_i_i << 1; //@line 38033
        $_2_5_i36_i_i_i = ($_2_4_i35_i_i_i & 32768 | 0) == 0 ? $94 : $94 ^ 4129; //@line 38035
        $98 = $_2_5_i36_i_i_i << 1; //@line 38038
        $_2_6_i37_i_i_i = ($_2_5_i36_i_i_i & 32768 | 0) == 0 ? $98 : $98 ^ 4129; //@line 38040
        $102 = $_2_6_i37_i_i_i << 1; //@line 38043
        $_2_7_i38_i_i_i = ($_2_6_i37_i_i_i & 32768 | 0) == 0 ? $102 : $102 ^ 4129; //@line 38045
        $105 = $_04_i29_i_i_i - 1 | 0; //@line 38047
        if (($105 | 0) == 0) {
         break;
        } else {
         $_093_i30_i_i_i = $_2_7_i38_i_i_i;
         $_04_i29_i_i_i = $105;
         $src_05_i28_i_i_i = $src_05_i28_i_i_i + 1 | 0;
        }
       }
       $107 = $62 & 255; //@line 38056
       $109 = $61 & 255; //@line 38058
       $110 = $63 & 255; //@line 38059
       $111 = $66 & 255; //@line 38060
       $114 = 128 << ($64 & 3); //@line 38063
       $115 = _psi_sct_new($109, $107, $110, $114) | 0; //@line 38064
       if (($115 | 0) == 0) {
        break L17704;
       }
       _psi_trk_add_sector($46, $115) | 0; //@line 38070
       _psi_sct_set_position($115, $59); //@line 38071
       _psi_sct_set_mfm_size($115, $64); //@line 38072
       _psi_sct_set_read_time($115, ($60 + 2 | 0) >>> 2); //@line 38075
       if (($111 & 8 | 0) != 0) {
        _psi_sct_set_flags($115, 2, 1); //@line 38080
       }
       if (($65 | 0) != ($_2_7_i38_i_i_i & 65535 | 0)) {
        _psi_sct_set_flags($115, 1, 1); //@line 38086
       }
       if (($111 & 16 | 0) == 0) {
        if ((_psi_read_ofs($fp, $45 + $58 | 0, HEAP32[$115 + 24 >> 2] | 0, $114) | 0) != 0) {
         label = 13953; //@line 38100
         break L17712;
        }
       } else {
        _psi_sct_set_size($115, 0, 0) | 0; //@line 38104
        _psi_sct_set_flags($115, 8, 1); //@line 38105
        _psi_sct_set_read_time($115, 0); //@line 38106
       }
       if (($111 & 128 | 0) == 0) {
        $_ph_i_i = $52; //@line 38113
       } else {
        $147 = _psi_sct_clone($115, 0) | 0; //@line 38115
        if (($147 | 0) == 0) {
         break L17704;
        }
        $150 = $147 + 24 | 0; //@line 38121
        if ((_psi_read_ofs($fp, $52, HEAP32[$150 >> 2] | 0, HEAPU16[$147 + 10 >> 1] | 0) | 0) != 0) {
         break L17704;
        }
        $157 = $115 + 10 | 0; //@line 38132
        if ((HEAP16[$157 >> 1] | 0) != 0) {
         $160 = $115 + 24 | 0; //@line 38137
         $i_015_i_i_i_i = 0; //@line 38139
         do {
          $166 = (HEAP32[$150 >> 2] | 0) + $i_015_i_i_i_i | 0; //@line 38146
          HEAP8[$166] = HEAP8[$166] ^ ~HEAP8[(HEAP32[$160 >> 2] | 0) + $i_015_i_i_i_i | 0]; //@line 38150
          $i_015_i_i_i_i = $i_015_i_i_i_i + 1 | 0; //@line 38151
         } while ($i_015_i_i_i_i >>> 0 < (HEAPU16[$157 >> 1] | 0) >>> 0);
        }
        _psi_sct_add_alternate($115, $147); //@line 38163
        $_ph_i_i = $114 + $52 | 0; //@line 38166
       }
       $177 = $i_032_i_i + 1 | 0; //@line 38170
       if ($177 >>> 0 < $36 >>> 0) {
        $52 = $_ph_i_i;
        $hpos_031_i_i = $hpos_031_i_i + 16 | 0;
        $i_032_i_i = $177;
       } else {
        break;
       }
      }
     }
    } while (0);
    $192 = $i_016_i + 1 | 0; //@line 38182
    if ($192 >>> 0 < $16 >>> 0) {
     $27 = $34 + $27 | 0;
     $i_016_i = $192;
    } else {
     $_0 = $1; //@line 38188
     label = 13969; //@line 38189
     break;
    }
   }
   if ((label | 0) == 13942) {
    $56 = HEAP32[_stderr >> 2] | 0; //@line 38194
    _fwrite(46096, 32, 1, $56 | 0) | 0; //@line 38195
    break;
   } else if ((label | 0) == 13953) {
    _fprintf(HEAP32[_stderr >> 2] | 0, 39552, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $109, HEAP32[tempInt + 8 >> 2] = $107, HEAP32[tempInt + 16 >> 2] = $110, tempInt) | 0) | 0; //@line 38201
    _fwrite(36600, 30, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 38203
    break;
   } else if ((label | 0) == 13969) {
    STACKTOP = sp; //@line 38209
    return $_0 | 0; //@line 38210
   } else if ((label | 0) == 13937) {
    _fwrite(49928, 31, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 38214
    break;
   }
  }
 } while (0);
 _psi_img_del($1); //@line 38220
 $_0 = 0; //@line 38222
 STACKTOP = sp; //@line 38224
 return $_0 | 0; //@line 38225
}
function _psi_probe_stx_fp($fp) {
 $fp = $fp | 0;
 var $1 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 38233
 STACKTOP = STACKTOP + 16 | 0; //@line 38233
 $1 = sp | 0; //@line 38235
 if ((_psi_read_ofs($fp, 0, $1, 8) | 0) != 0) {
  $_0 = 0; //@line 38240
  STACKTOP = sp; //@line 38242
  return $_0 | 0; //@line 38243
 }
 $_0 = (_psi_get_uint32_be($1, 0) | 0) == 1381193984 | 0; //@line 38249
 STACKTOP = sp; //@line 38251
 return $_0 | 0; //@line 38252
}
function _psi_load_tc($fp) {
 $fp = $fp | 0;
 var $buf_i22_i_i_i = 0, $buf_i_i_i_i = 0, $fm2_i_i_i = 0, $mark2_i_i_i = 0, $fm_i_i = 0, $mark_i_i = 0, $mfm_i = 0, $1 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $c_018_i = 0, $24 = 0, $h_014_i = 0, $26 = 0, $27 = 0, $36 = 0, $46 = 0, $53 = 0, $i_0_i_i = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $src_014_i_i_i_i_i = 0, $_013_i_i_i_i_i = 0, $_0912_i_i_i_i_i = 0, $82 = 0, $85 = 0, $_2_i_i_i_i_i = 0, $89 = 0, $_2_1_i_i_i_i_i = 0, $93 = 0, $_2_2_i_i_i_i_i = 0, $97 = 0, $_2_3_i_i_i_i_i = 0, $101 = 0, $_2_4_i_i_i_i_i = 0, $105 = 0, $_2_5_i_i_i_i_i = 0, $109 = 0, $_2_6_i_i_i_i_i = 0, $113 = 0, $_2_7_i_i_i_i_i = 0, $116 = 0, $125 = 0, $129 = 0, $145 = 0, $147 = 0, $148 = 0, $149 = 0, $150 = 0, $151 = 0, $i_07_i_i_i_i_i = 0, $159 = 0, $161 = 0, $162 = 0, $src_014_i_i23_i_i_i = 0, $_013_i_i24_i_i_i = 0, $_0912_i_i25_i_i_i = 0, $169 = 0, $172 = 0, $_2_i_i26_i_i_i = 0, $176 = 0, $_2_1_i_i27_i_i_i = 0, $180 = 0, $_2_2_i_i28_i_i_i = 0, $184 = 0, $_2_3_i_i29_i_i_i = 0, $188 = 0, $_2_4_i_i30_i_i_i = 0, $192 = 0, $_2_5_i_i31_i_i_i = 0, $196 = 0, $_2_6_i_i32_i_i_i = 0, $200 = 0, $_2_7_i_i33_i_i_i = 0, $203 = 0, $_09_lcssa_i_i_i_i_i = 0, $213 = 0, $221 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 38289
 STACKTOP = STACKTOP + 65616 | 0; //@line 38289
 $buf_i22_i_i_i = sp + 8 | 0; //@line 38291
 $buf_i_i_i_i = sp + 16 | 0; //@line 38292
 $fm2_i_i_i = sp + 24 | 0; //@line 38293
 $mark2_i_i_i = sp + 32 | 0; //@line 38294
 $fm_i_i = sp + 40 | 0; //@line 38295
 $mark_i_i = sp + 48 | 0; //@line 38296
 $mfm_i = sp + 56 | 0; //@line 38297
 $1 = _psi_img_new() | 0; //@line 38298
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 38302
  STACKTOP = sp; //@line 38304
  return $_0 | 0; //@line 38305
 }
 $6 = $mfm_i | 0; //@line 38309
 HEAP32[$6 >> 2] = $fp; //@line 38310
 $7 = $mfm_i + 65540 | 0; //@line 38311
 _memset($7 | 0, 0, 16); //@line 38313
 $9 = sp | 0; //@line 38314
 $10 = $mfm_i + 65544 | 0; //@line 38315
 $11 = $mfm_i + 65554 | 0; //@line 38316
 $12 = $mfm_i + 65548 | 0; //@line 38317
 $14 = $buf_i_i_i_i | 0; //@line 38319
 $15 = $buf_i_i_i_i + 1 | 0; //@line 38320
 $16 = $buf_i_i_i_i + 2 | 0; //@line 38321
 $17 = $buf_i_i_i_i + 3 | 0; //@line 38322
 $18 = $buf_i_i_i_i + 4 | 0; //@line 38323
 $19 = $buf_i_i_i_i + 5 | 0; //@line 38324
 $20 = $mfm_i + 65552 | 0; //@line 38325
 $21 = $buf_i22_i_i_i | 0; //@line 38326
 $22 = $buf_i22_i_i_i + 1 | 0; //@line 38327
 $23 = $mfm_i + 4 | 0; //@line 38328
 $c_018_i = 0; //@line 38330
 L17766 : while (1) {
  $24 = $c_018_i << 1; //@line 38333
  $h_014_i = 0; //@line 38335
  do {
   HEAP32[$10 >> 2] = 0; //@line 38338
   HEAP32[$7 >> 2] = 0; //@line 38339
   HEAP8[$11] = 0; //@line 38340
   $26 = HEAP32[$6 >> 2] | 0; //@line 38342
   $27 = $h_014_i + $24 << 1; //@line 38343
   if ((_fseek($26 | 0, $27 + 773 | 0, 0) | 0) != 0) {
    break L17766;
   }
   if ((_fread($9 | 0, 1, 2, $26 | 0) | 0) != 2) {
    break L17766;
   }
   $36 = (_psi_get_uint16_be($9, 0) | 0) << 8; //@line 38358
   L17772 : do {
    if (($36 | 0) != 0) {
     if ((_fseek($26 | 0, $27 + 1285 | 0, 0) | 0) != 0) {
      break L17766;
     }
     if ((_fread($9 | 0, 1, 2, $26 | 0) | 0) != 2) {
      break L17766;
     }
     $46 = _psi_get_uint16_le($9, 0) | 0; //@line 38376
     if ((_fseek($26 | 0, $36 | 0, 0) | 0) != 0) {
      break L17766;
     }
     if ((_fread($23 | 0, 1, $46 | 0, $26 | 0) | 0) != ($46 | 0)) {
      break L17766;
     }
     HEAP32[$10 >> 2] = 0; //@line 38389
     $53 = $46 << 3; //@line 38390
     HEAP32[$7 >> 2] = $53; //@line 38391
     if (($53 | 0) == 0) {
      break;
     } else {
      $i_0_i_i = 0; //@line 38397
     }
     while (1) {
      if ($i_0_i_i >>> 0 >= 2) {
       break L17772;
      }
      HEAP32[$12 >> 2] = 0; //@line 38406
      HEAP32[$10 >> 2] = 0; //@line 38407
      L17781 : do {
       do {
        if ((_mfm_sync_mark($mfm_i, $mark_i_i, $fm_i_i) | 0) == 0) {
         if (($i_0_i_i | 0) == 1) {
          if ((HEAP32[$fm_i_i >> 2] | 0) == 0) {
           break;
          }
         } else if (($i_0_i_i | 0) == 0) {
          if ((HEAP32[$fm_i_i >> 2] | 0) != 0) {
           break;
          }
         }
         if ((HEAP32[$12 >> 2] | 0) != 0) {
          break L17781;
         }
         $72 = HEAPU8[$mark_i_i] | 0; //@line 38437
         $73 = HEAP32[$fm_i_i >> 2] | 0; //@line 38438
         $74 = HEAP32[$10 >> 2] | 0; //@line 38439
         do {
          if (($72 | 0) == 254) {
           _mfm_read_byte($mfm_i, $14); //@line 38442
           _mfm_read_byte($mfm_i, $15); //@line 38443
           _mfm_read_byte($mfm_i, $16); //@line 38444
           _mfm_read_byte($mfm_i, $17); //@line 38445
           _mfm_read_byte($mfm_i, $18); //@line 38446
           _mfm_read_byte($mfm_i, $19); //@line 38447
           $76 = _psi_get_uint16_be($14, 4) | 0; //@line 38448
           $_0912_i_i_i_i_i = HEAPU16[$20 >> 1] | 0;
           $_013_i_i_i_i_i = 4;
           $src_014_i_i_i_i_i = $14;
           while (1) {
            $82 = HEAPU8[$src_014_i_i_i_i_i] << 8 ^ $_0912_i_i_i_i_i; //@line 38459
            $85 = $82 << 1; //@line 38462
            $_2_i_i_i_i_i = ($82 & 32768 | 0) == 0 ? $85 : $85 ^ 4129; //@line 38464
            $89 = $_2_i_i_i_i_i << 1; //@line 38467
            $_2_1_i_i_i_i_i = ($_2_i_i_i_i_i & 32768 | 0) == 0 ? $89 : $89 ^ 4129; //@line 38469
            $93 = $_2_1_i_i_i_i_i << 1; //@line 38472
            $_2_2_i_i_i_i_i = ($_2_1_i_i_i_i_i & 32768 | 0) == 0 ? $93 : $93 ^ 4129; //@line 38474
            $97 = $_2_2_i_i_i_i_i << 1; //@line 38477
            $_2_3_i_i_i_i_i = ($_2_2_i_i_i_i_i & 32768 | 0) == 0 ? $97 : $97 ^ 4129; //@line 38479
            $101 = $_2_3_i_i_i_i_i << 1; //@line 38482
            $_2_4_i_i_i_i_i = ($_2_3_i_i_i_i_i & 32768 | 0) == 0 ? $101 : $101 ^ 4129; //@line 38484
            $105 = $_2_4_i_i_i_i_i << 1; //@line 38487
            $_2_5_i_i_i_i_i = ($_2_4_i_i_i_i_i & 32768 | 0) == 0 ? $105 : $105 ^ 4129; //@line 38489
            $109 = $_2_5_i_i_i_i_i << 1; //@line 38492
            $_2_6_i_i_i_i_i = ($_2_5_i_i_i_i_i & 32768 | 0) == 0 ? $109 : $109 ^ 4129; //@line 38494
            $113 = $_2_6_i_i_i_i_i << 1; //@line 38497
            $_2_7_i_i_i_i_i = ($_2_6_i_i_i_i_i & 32768 | 0) == 0 ? $113 : $113 ^ 4129; //@line 38499
            $116 = $_013_i_i_i_i_i - 1 | 0; //@line 38501
            if (($116 | 0) == 0) {
             break;
            } else {
             $_0912_i_i_i_i_i = $_2_7_i_i_i_i_i;
             $_013_i_i_i_i_i = $116;
             $src_014_i_i_i_i_i = $src_014_i_i_i_i_i + 1 | 0;
            }
           }
           HEAP16[$20 >> 1] = $_2_7_i_i_i_i_i & 65535; //@line 38511
           $125 = HEAP8[$17] | 0; //@line 38518
           $129 = _psi_sct_new(HEAPU8[$14] | 0, HEAPU8[$15] | 0, HEAPU8[$16] | 0, ($125 & 255) < 6 ? 128 << ($125 & 255) : 8192) | 0; //@line 38523
           if (($129 | 0) == 0) {
            break L17766;
           }
           _psi_sct_set_mfm_size($129, HEAP8[$17] | 0); //@line 38530
           _psi_sct_set_flags($129, 8, 1); //@line 38531
           if (($_2_7_i_i_i_i_i & 65535 | 0) != ($76 | 0)) {
            _psi_sct_set_flags($129, 1, 1); //@line 38536
           }
           _psi_sct_fill($129, 0); //@line 38539
           if (($73 | 0) == 0) {
            _psi_sct_set_encoding($129, 2); //@line 38543
           } else {
            _psi_sct_set_encoding($129, 1); //@line 38545
           }
           _psi_img_add_sector($1, $129, $c_018_i, $h_014_i) | 0; //@line 38548
           if ((_mfm_sync_mark($mfm_i, $mark2_i_i_i, $fm2_i_i_i) | 0) != 0) {
            break;
           }
           $145 = HEAP8[$mark2_i_i_i] | 0; //@line 38555
           if (!(($145 << 24 >> 24 | 0) == (-8 | 0) | ($145 << 24 >> 24 | 0) == (-5 | 0))) {
            break;
           }
           $147 = $129 + 24 | 0; //@line 38559
           $148 = HEAP32[$147 >> 2] | 0; //@line 38560
           $149 = $129 + 10 | 0; //@line 38561
           $150 = HEAP16[$149 >> 1] | 0; //@line 38562
           $151 = $150 & 65535; //@line 38563
           if ($150 << 16 >> 16 != 0) {
            $i_07_i_i_i_i_i = 0; //@line 38567
            do {
             _mfm_read_byte($mfm_i, $148 + $i_07_i_i_i_i_i | 0); //@line 38571
             $i_07_i_i_i_i_i = $i_07_i_i_i_i_i + 1 | 0; //@line 38572
            } while ($i_07_i_i_i_i_i >>> 0 < $151 >>> 0);
            if ($150 << 16 >> 16 != (HEAP16[$149 >> 1] | 0)) {
             break L17766;
            }
           }
           _mfm_read_byte($mfm_i, $21); //@line 38588
           _mfm_read_byte($mfm_i, $22); //@line 38589
           _psi_sct_set_flags($129, 8, 0); //@line 38590
           _psi_sct_set_flags($129, 4, $145 << 24 >> 24 == -8 | 0); //@line 38593
           $159 = _psi_get_uint16_be($21, 0) | 0; //@line 38594
           $161 = HEAPU16[$20 >> 1] | 0; //@line 38596
           $162 = HEAP16[$149 >> 1] | 0; //@line 38597
           if ($162 << 16 >> 16 == 0) {
            $_09_lcssa_i_i_i_i_i = $161; //@line 38601
           } else {
            $_0912_i_i25_i_i_i = $161;
            $_013_i_i24_i_i_i = $162 & 65535;
            $src_014_i_i23_i_i_i = HEAP32[$147 >> 2] | 0;
            while (1) {
             $169 = HEAPU8[$src_014_i_i23_i_i_i] << 8 ^ $_0912_i_i25_i_i_i; //@line 38614
             $172 = $169 << 1; //@line 38617
             $_2_i_i26_i_i_i = ($169 & 32768 | 0) == 0 ? $172 : $172 ^ 4129; //@line 38619
             $176 = $_2_i_i26_i_i_i << 1; //@line 38622
             $_2_1_i_i27_i_i_i = ($_2_i_i26_i_i_i & 32768 | 0) == 0 ? $176 : $176 ^ 4129; //@line 38624
             $180 = $_2_1_i_i27_i_i_i << 1; //@line 38627
             $_2_2_i_i28_i_i_i = ($_2_1_i_i27_i_i_i & 32768 | 0) == 0 ? $180 : $180 ^ 4129; //@line 38629
             $184 = $_2_2_i_i28_i_i_i << 1; //@line 38632
             $_2_3_i_i29_i_i_i = ($_2_2_i_i28_i_i_i & 32768 | 0) == 0 ? $184 : $184 ^ 4129; //@line 38634
             $188 = $_2_3_i_i29_i_i_i << 1; //@line 38637
             $_2_4_i_i30_i_i_i = ($_2_3_i_i29_i_i_i & 32768 | 0) == 0 ? $188 : $188 ^ 4129; //@line 38639
             $192 = $_2_4_i_i30_i_i_i << 1; //@line 38642
             $_2_5_i_i31_i_i_i = ($_2_4_i_i30_i_i_i & 32768 | 0) == 0 ? $192 : $192 ^ 4129; //@line 38644
             $196 = $_2_5_i_i31_i_i_i << 1; //@line 38647
             $_2_6_i_i32_i_i_i = ($_2_5_i_i31_i_i_i & 32768 | 0) == 0 ? $196 : $196 ^ 4129; //@line 38649
             $200 = $_2_6_i_i32_i_i_i << 1; //@line 38652
             $_2_7_i_i33_i_i_i = ($_2_6_i_i32_i_i_i & 32768 | 0) == 0 ? $200 : $200 ^ 4129; //@line 38654
             $203 = $_013_i_i24_i_i_i - 1 | 0; //@line 38656
             if (($203 | 0) == 0) {
              $_09_lcssa_i_i_i_i_i = $_2_7_i_i33_i_i_i; //@line 38660
              break;
             } else {
              $_0912_i_i25_i_i_i = $_2_7_i_i33_i_i_i;
              $_013_i_i24_i_i_i = $203;
              $src_014_i_i23_i_i_i = $src_014_i_i23_i_i_i + 1 | 0;
             }
            }
           }
           HEAP16[$20 >> 1] = $_09_lcssa_i_i_i_i_i & 65535; //@line 38670
           if (($_09_lcssa_i_i_i_i_i & 65535 | 0) == ($159 | 0)) {
            break;
           }
           _psi_sct_set_flags($129, 2, 1); //@line 38676
          } else if (!(($72 | 0) == 248 | ($72 | 0) == 251)) {
           $213 = HEAP32[$7 >> 2] | 0; //@line 38682
           _fprintf(HEAP32[_stderr >> 2] | 0, 52600, (tempInt = STACKTOP, STACKTOP = STACKTOP + 48 | 0, HEAP32[tempInt >> 2] = $72, HEAP32[tempInt + 8 >> 2] = ($73 | 0) != 0 ? 56432 : 49920, HEAP32[tempInt + 16 >> 2] = $c_018_i, HEAP32[tempInt + 24 >> 2] = $h_014_i, HEAP32[tempInt + 32 >> 2] = $74, HEAP32[tempInt + 40 >> 2] = $213, tempInt) | 0) | 0; //@line 38683
          }
         } while (0);
         HEAP32[$12 >> 2] = 0; //@line 38687
         HEAP32[$10 >> 2] = $74; //@line 38688
        }
       } while (0);
      } while ((HEAP32[$12 >> 2] | 0) == 0);
      if ((_psi_img_get_sector($1, $c_018_i, $h_014_i, 0, 1) | 0) == 0) {
       $i_0_i_i = $i_0_i_i + 1 | 0; //@line 38704
      } else {
       break;
      }
     }
    }
   } while (0);
   $h_014_i = $h_014_i + 1 | 0; //@line 38711
  } while ($h_014_i >>> 0 < 2);
  $221 = $c_018_i + 1 | 0; //@line 38720
  if ($221 >>> 0 < 80) {
   $c_018_i = $221; //@line 38724
  } else {
   $_0 = $1; //@line 38726
   label = 14023; //@line 38727
   break;
  }
 }
 if ((label | 0) == 14023) {
  STACKTOP = sp; //@line 38733
  return $_0 | 0; //@line 38734
 }
 _psi_img_del($1); //@line 38736
 $_0 = 0; //@line 38738
 STACKTOP = sp; //@line 38740
 return $_0 | 0; //@line 38741
}
function _mfm_sync_mark($mfm, $mark, $fm) {
 $mfm = $mfm | 0;
 $mark = $mark | 0;
 $fm = $fm | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $_pre20_i = 0, $9 = 0, $10 = 0, $val_0_i = 0, $20 = 0, $21 = 0, $24 = 0, $25 = 0, $26 = 0, $30 = 0, $31 = 0, $44 = 0, $47 = 0, $_2_i21 = 0, $51 = 0, $_2_1_i22 = 0, $55 = 0, $_2_2_i23 = 0, $59 = 0, $_2_3_i24 = 0, $63 = 0, $_2_4_i25 = 0, $67 = 0, $_2_5_i26 = 0, $71 = 0, $_2_6_i27 = 0, $75 = 0, $78 = 0, $i_0 = 0, $87 = 0, $90 = 0, $_2_i = 0, $94 = 0, $_2_1_i = 0, $98 = 0, $_2_2_i = 0, $102 = 0, $_2_3_i = 0, $106 = 0, $_2_4_i = 0, $110 = 0, $_2_5_i = 0, $114 = 0, $_2_6_i = 0, $118 = 0, $_0 = 0, label = 0;
 HEAP32[$fm >> 2] = 0; //@line 38768
 HEAP8[$mark] = 0; //@line 38769
 $1 = $mfm + 65554 | 0; //@line 38770
 HEAP8[$1] = 0; //@line 38771
 $2 = $mfm + 65548 | 0; //@line 38772
 $3 = HEAP32[$2 >> 2] | 0; //@line 38773
 $4 = $3 + 2 | 0; //@line 38774
 $5 = $mfm + 65544 | 0; //@line 38775
 $7 = $mfm + 65555 | 0; //@line 38777
 $_pre20_i = HEAP32[$mfm + 65540 >> 2] | 0; //@line 38779
 $val_0_i = 0;
 $10 = HEAP32[$5 >> 2] | 0;
 $9 = $3;
 while (1) {
  $20 = (HEAPU8[($10 >>> 3) + ($mfm + 4) | 0] & 128 >>> (($10 & 7) >>> 0) | 0) != 0 | 0; //@line 38795
  $21 = $10 + 1 | 0; //@line 38796
  HEAP32[$5 >> 2] = $21; //@line 38797
  if ($21 >>> 0 < $_pre20_i >>> 0) {
   $26 = $21;
   $25 = $9;
  } else {
   HEAP32[$5 >> 2] = 0; //@line 38803
   $24 = $9 + 1 | 0; //@line 38804
   HEAP32[$2 >> 2] = $24; //@line 38805
   $26 = 0;
   $25 = $24;
  }
  HEAP8[$7] = (HEAP8[$7] | 0) == 0 | 0; //@line 38814
  $30 = $20 | $val_0_i << 1; //@line 38815
  $31 = $30 & 65535; //@line 38816
  if (($31 | 0) == 62846) {
   label = 14031; //@line 38818
   break;
  } else if (($31 | 0) == 63338) {
   label = 14030; //@line 38821
   break;
  } else if (($31 | 0) == 17545) {
   label = 14029; //@line 38824
   break;
  } else if (($31 | 0) == 62831) {
   label = 14032; //@line 38827
   break;
  } else if (($31 | 0) == 62826) {
   label = 14033; //@line 38830
   break;
  }
  if ((HEAP8[$mark] | 0) != 0) {
   break;
  }
  if ($25 >>> 0 < $4 >>> 0) {
   $val_0_i = $30;
   $10 = $26;
   $9 = $25;
  } else {
   $_0 = 1; //@line 38844
   label = 14042; //@line 38845
   break;
  }
 }
 if ((label | 0) == 14031) {
  HEAP8[$mark] = -2; //@line 38850
 } else if ((label | 0) == 14030) {
  HEAP8[$mark] = -4; //@line 38854
 } else if ((label | 0) == 14042) {
  return $_0 | 0; //@line 38860
 } else if ((label | 0) == 14029) {
  HEAP8[$mark] = -95; //@line 38863
 } else if ((label | 0) == 14032) {
  HEAP8[$mark] = -5; //@line 38867
 } else if ((label | 0) == 14033) {
  HEAP8[$mark] = -8; //@line 38871
 }
 HEAP8[$1] = 1; //@line 38874
 HEAP8[$7] = 1; //@line 38875
 $44 = HEAPU8[$mark] << 8 ^ 65535; //@line 38879
 $47 = $44 << 1; //@line 38882
 $_2_i21 = ($44 & 32768 | 0) == 0 ? $47 : $47 ^ 4129; //@line 38884
 $51 = $_2_i21 << 1; //@line 38887
 $_2_1_i22 = ($_2_i21 & 32768 | 0) == 0 ? $51 : $51 ^ 4129; //@line 38889
 $55 = $_2_1_i22 << 1; //@line 38892
 $_2_2_i23 = ($_2_1_i22 & 32768 | 0) == 0 ? $55 : $55 ^ 4129; //@line 38894
 $59 = $_2_2_i23 << 1; //@line 38897
 $_2_3_i24 = ($_2_2_i23 & 32768 | 0) == 0 ? $59 : $59 ^ 4129; //@line 38899
 $63 = $_2_3_i24 << 1; //@line 38902
 $_2_4_i25 = ($_2_3_i24 & 32768 | 0) == 0 ? $63 : $63 ^ 4129; //@line 38904
 $67 = $_2_4_i25 << 1; //@line 38907
 $_2_5_i26 = ($_2_4_i25 & 32768 | 0) == 0 ? $67 : $67 ^ 4129; //@line 38909
 $71 = $_2_5_i26 << 1; //@line 38912
 $_2_6_i27 = ($_2_5_i26 & 32768 | 0) == 0 ? $71 : $71 ^ 4129; //@line 38914
 $75 = $_2_6_i27 << 1; //@line 38917
 $78 = $mfm + 65552 | 0; //@line 38921
 HEAP16[$78 >> 1] = (($_2_6_i27 & 32768 | 0) == 0 ? $75 : $75 ^ 4129) & 65535; //@line 38922
 if ((HEAP8[$mark] | 0) == -95) {
  $i_0 = 0; //@line 38927
 } else {
  HEAP32[$fm >> 2] = 1; //@line 38929
  $_0 = 0; //@line 38931
  return $_0 | 0; //@line 38934
 }
 while (1) {
  _mfm_read_byte($mfm, $mark); //@line 38938
  $87 = HEAPU8[$mark] << 8 ^ HEAPU16[$78 >> 1]; //@line 38944
  $90 = $87 << 1; //@line 38947
  $_2_i = ($87 & 32768 | 0) == 0 ? $90 : $90 ^ 4129; //@line 38949
  $94 = $_2_i << 1; //@line 38952
  $_2_1_i = ($_2_i & 32768 | 0) == 0 ? $94 : $94 ^ 4129; //@line 38954
  $98 = $_2_1_i << 1; //@line 38957
  $_2_2_i = ($_2_1_i & 32768 | 0) == 0 ? $98 : $98 ^ 4129; //@line 38959
  $102 = $_2_2_i << 1; //@line 38962
  $_2_3_i = ($_2_2_i & 32768 | 0) == 0 ? $102 : $102 ^ 4129; //@line 38964
  $106 = $_2_3_i << 1; //@line 38967
  $_2_4_i = ($_2_3_i & 32768 | 0) == 0 ? $106 : $106 ^ 4129; //@line 38969
  $110 = $_2_4_i << 1; //@line 38972
  $_2_5_i = ($_2_4_i & 32768 | 0) == 0 ? $110 : $110 ^ 4129; //@line 38974
  $114 = $_2_5_i << 1; //@line 38977
  $_2_6_i = ($_2_5_i & 32768 | 0) == 0 ? $114 : $114 ^ 4129; //@line 38979
  $118 = $_2_6_i << 1; //@line 38982
  HEAP16[$78 >> 1] = (($_2_6_i & 32768 | 0) == 0 ? $118 : $118 ^ 4129) & 65535; //@line 38987
  if ($i_0 >>> 0 >= 2) {
   $_0 = 0; //@line 38990
   label = 14043; //@line 38991
   break;
  }
  if ((HEAP8[$mark] | 0) == -95) {
   $i_0 = $i_0 + 1 | 0; //@line 38999
  } else {
   $_0 = 0; //@line 39001
   label = 14044; //@line 39002
   break;
  }
 }
 if ((label | 0) == 14044) {
  return $_0 | 0; //@line 39009
 } else if ((label | 0) == 14043) {
  return $_0 | 0; //@line 39014
 }
 return 0;
}
function _mfm_read_bit($mfm) {
 $mfm = $mfm | 0;
 var $1 = 0, $2 = 0, $11 = 0, $12 = 0, $17 = 0, $21 = 0;
 $1 = $mfm + 65544 | 0; //@line 39026
 $2 = HEAP32[$1 >> 2] | 0; //@line 39027
 $11 = (HEAPU8[($2 >>> 3) + ($mfm + 4) | 0] & 128 >>> (($2 & 7) >>> 0) | 0) != 0 | 0; //@line 39036
 $12 = $2 + 1 | 0; //@line 39037
 HEAP32[$1 >> 2] = $12; //@line 39038
 if ($12 >>> 0 >= (HEAP32[$mfm + 65540 >> 2] | 0) >>> 0) {
  HEAP32[$1 >> 2] = 0; //@line 39044
  $17 = $mfm + 65548 | 0; //@line 39045
  HEAP32[$17 >> 2] = (HEAP32[$17 >> 2] | 0) + 1; //@line 39048
 }
 $21 = $mfm + 65555 | 0; //@line 39051
 HEAP8[$21] = (HEAP8[$21] | 0) == 0 | 0; //@line 39055
 return $11 | 0; //@line 39057
}
function _mfm_read_byte($mfm, $val) {
 $mfm = $mfm | 0;
 $val = $val | 0;
 var $1 = 0, $5 = 0, $7 = 0, $12 = 0, $15 = 0, $85 = 0;
 HEAP8[$val] = 0; //@line 39075
 $1 = $mfm + 65555 | 0; //@line 39076
 if ((HEAP8[$1] | 0) == 0) {
  $15 = 0; //@line 39081
 } else {
  $5 = $mfm + 65544 | 0; //@line 39083
  $7 = (HEAP32[$5 >> 2] | 0) + 1 | 0; //@line 39085
  HEAP32[$5 >> 2] = $7; //@line 39086
  if ($7 >>> 0 >= (HEAP32[$mfm + 65540 >> 2] | 0) >>> 0) {
   HEAP32[$5 >> 2] = 0; //@line 39092
   $12 = $mfm + 65548 | 0; //@line 39093
   HEAP32[$12 >> 2] = (HEAP32[$12 >> 2] | 0) + 1; //@line 39096
  }
  HEAP8[$1] = 0; //@line 39099
  $15 = HEAP8[$val] << 1; //@line 39103
 }
 HEAP8[$val] = $15; //@line 39106
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39113
 }
 _mfm_read_bit($mfm) | 0; //@line 39116
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39119
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39126
 }
 _mfm_read_bit($mfm) | 0; //@line 39129
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39132
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39139
 }
 _mfm_read_bit($mfm) | 0; //@line 39142
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39145
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39152
 }
 _mfm_read_bit($mfm) | 0; //@line 39155
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39158
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39165
 }
 _mfm_read_bit($mfm) | 0; //@line 39168
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39171
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39178
 }
 _mfm_read_bit($mfm) | 0; //@line 39181
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39184
 if ((_mfm_read_bit($mfm) | 0) != 0) {
  HEAP8[$val] = HEAP8[$val] | 1; //@line 39191
 }
 _mfm_read_bit($mfm) | 0; //@line 39194
 HEAP8[$val] = HEAP8[$val] << 1; //@line 39197
 if ((_mfm_read_bit($mfm) | 0) == 0) {
  $85 = _mfm_read_bit($mfm) | 0; //@line 39202
  return;
 }
 HEAP8[$val] = HEAP8[$val] | 1; //@line 39208
 $85 = _mfm_read_bit($mfm) | 0; //@line 39210
 return;
}
function _psi_load_td0($fp) {
 $fp = $fp | 0;
 var $buf_i_i_i_i = 0, $buf_i_i_i = 0, $buf_i_i = 0, $buf_i = 0, $1 = 0, $4 = 0, $8 = 0, $14 = 0, $30 = 0, $32 = 0, $33 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_0912_i_i = 0, $37 = 0, $40 = 0, $_2_i_i = 0, $44 = 0, $_2_1_i_i = 0, $48 = 0, $_2_2_i_i = 0, $52 = 0, $_2_3_i_i = 0, $56 = 0, $_2_4_i_i = 0, $60 = 0, $_2_5_i_i = 0, $64 = 0, $_2_6_i_i = 0, $68 = 0, $_2_7_i_i = 0, $71 = 0, $73 = 0, $74 = 0, $77 = 0, $81 = 0, $86 = 0, $tmp_014_i_i_i = 0, $_013_i_i_i = 0, $_0912_i_i_i = 0, $91 = 0, $94 = 0, $_2_i_i10_i = 0, $98 = 0, $_2_1_i_i11_i = 0, $102 = 0, $_2_2_i_i12_i = 0, $106 = 0, $_2_3_i_i13_i = 0, $110 = 0, $_2_4_i_i14_i = 0, $114 = 0, $_2_5_i_i15_i = 0, $118 = 0, $_2_6_i_i16_i = 0, $122 = 0, $_2_7_i_i17_i = 0, $125 = 0, $127 = 0, $128 = 0, $131 = 0, $tmp_014_i36_i_i = 0, $_013_i37_i_i = 0, $_0912_i38_i_i = 0, $140 = 0, $143 = 0, $_2_i39_i_i = 0, $147 = 0, $_2_1_i40_i_i = 0, $151 = 0, $_2_2_i41_i_i = 0, $155 = 0, $_2_3_i42_i_i = 0, $159 = 0, $_2_4_i43_i_i = 0, $163 = 0, $_2_5_i44_i_i = 0, $167 = 0, $_2_6_i45_i_i = 0, $171 = 0, $_2_7_i46_i_i = 0, $174 = 0, $176 = 0, $i_0_i_i = 0, $j_0_i_i = 0, $186 = 0, $k_049_i_i = 0, $190 = 0, $194 = 0, $crc2_0_i_i = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $228 = 0, $229 = 0, $232 = 0, $_2_i_i_i = 0, $236 = 0, $_2_1_i_i_i = 0, $240 = 0, $_2_2_i_i_i = 0, $244 = 0, $_2_3_i_i_i = 0, $248 = 0, $_2_4_i_i_i = 0, $252 = 0, $_2_5_i_i_i = 0, $256 = 0, $_2_6_i_i_i = 0, $260 = 0, $263 = 0, $265 = 0, $268 = 0, $_2_i_1_i_i = 0, $272 = 0, $_2_1_i_1_i_i = 0, $276 = 0, $_2_2_i_1_i_i = 0, $280 = 0, $_2_3_i_1_i_i = 0, $284 = 0, $_2_4_i_1_i_i = 0, $288 = 0, $_2_5_i_1_i_i = 0, $292 = 0, $_2_6_i_1_i_i = 0, $296 = 0, $299 = 0, $301 = 0, $304 = 0, $_2_i_2_i_i = 0, $308 = 0, $_2_1_i_2_i_i = 0, $312 = 0, $_2_2_i_2_i_i = 0, $316 = 0, $_2_3_i_2_i_i = 0, $320 = 0, $_2_4_i_2_i_i = 0, $324 = 0, $_2_5_i_2_i_i = 0, $328 = 0, $_2_6_i_2_i_i = 0, $332 = 0, $_2_7_i_2_i_i = 0, $335 = 0, $343 = 0, $dr__i_i = 0, $348 = 0, $enc_0_i_i_i_i = 0, $i_035_i_i = 0, $357 = 0, $358 = 0, $360 = 0, $365 = 0, $370 = 0, $371 = 0, $387 = 0, $tmp_014_i_i_i_i = 0, $_013_i_i_i_i = 0, $_0912_i_i_i_i = 0, $391 = 0, $394 = 0, $_2_i_i_i_i = 0, $398 = 0, $_2_1_i_i_i_i = 0, $402 = 0, $_2_2_i_i_i_i = 0, $406 = 0, $_2_3_i_i_i_i = 0, $410 = 0, $_2_4_i_i_i_i = 0, $414 = 0, $_2_5_i_i_i_i = 0, $418 = 0, $_2_6_i_i_i_i = 0, $422 = 0, $_2_7_i_i_i_i = 0, $425 = 0, $427 = 0, $428 = 0, $438 = 0, $449 = 0, $455 = 0, $456 = 0, $458 = 0, $468 = 0, $476 = 0, $478 = 0, $483 = 0, $i_010_i_i_i_i = 0, $486 = 0, $493 = 0, $_pre_i_i_i_i = 0, $497 = 0, $idx_037_i_i_i_i = 0, $_036_i_i_i_i = 0, $504 = 0, $505 = 0, $508 = 0, $511 = 0, $_0_be_i_i_i_i = 0, $idx_0_be_i_i_i_i = 0, $524 = 0, $525 = 0, $529 = 0, $537 = 0, $rep_033_i_i_i_i = 0, $idx_132_i_i_i_i = 0, $547 = 0, $idx_0_lcssa_i_i_i_i = 0, $_pre_phi_i = 0, $556 = 0, $559 = 0, $560 = 0, $tmp_014_i70_i_i_i = 0, $_013_i71_i_i_i = 0, $_0912_i72_i_i_i = 0, $564 = 0, $567 = 0, $_2_i73_i_i_i = 0, $571 = 0, $_2_1_i74_i_i_i = 0, $575 = 0, $_2_2_i75_i_i_i = 0, $579 = 0, $_2_3_i76_i_i_i = 0, $583 = 0, $_2_4_i77_i_i_i = 0, $587 = 0, $_2_5_i78_i_i_i = 0, $591 = 0, $_2_6_i79_i_i_i = 0, $595 = 0, $_2_7_i80_i_i_i = 0, $598 = 0, $tmp_014_i57_i_i_i = 0, $_013_i58_i_i_i = 0, $_0912_i59_i_i_i = 0, $603 = 0, $606 = 0, $_2_i60_i_i_i = 0, $610 = 0, $_2_1_i61_i_i_i = 0, $614 = 0, $_2_2_i62_i_i_i = 0, $618 = 0, $_2_3_i63_i_i_i = 0, $622 = 0, $_2_4_i64_i_i_i = 0, $626 = 0, $_2_5_i65_i_i_i = 0, $630 = 0, $_2_6_i66_i_i_i = 0, $634 = 0, $_2_7_i67_i_i_i = 0, $637 = 0, $640 = 0, $_09_lcssa_i8292_i_i_i = 0, $_09_lcssa_i_i_i_i = 0, $644 = 0, $653 = 0, $659 = 0, $662 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 39308
 STACKTOP = STACKTOP + 48 | 0; //@line 39308
 $buf_i_i_i_i = sp | 0; //@line 39309
 $buf_i_i_i = sp + 8 | 0; //@line 39310
 $buf_i_i = sp + 16 | 0; //@line 39311
 $buf_i = sp + 32 | 0; //@line 39312
 $1 = _psi_img_new() | 0; //@line 39313
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 39317
  STACKTOP = sp; //@line 39319
  return $_0 | 0; //@line 39320
 }
 $4 = $buf_i | 0; //@line 39322
 L17891 : do {
  if ((_psi_read($fp, $4, 12) | 0) == 0) {
   $8 = HEAP8[$4] | 0; //@line 39328
   if (($8 << 24 >> 24 | 0) == 116) {
    if ((HEAP8[$buf_i + 1 | 0] | 0) != 100) {
     break;
    }
    $14 = HEAP32[_stderr >> 2] | 0; //@line 39337
    _fwrite(56368, 40, 1, $14 | 0) | 0; //@line 39338
    break;
   } else if (($8 << 24 >> 24 | 0) != 84) {
    break;
   }
   if ((HEAP8[$buf_i + 1 | 0] | 0) != 68) {
    break;
   }
   if ((HEAP8[$buf_i + 2 | 0] | 0) != 0) {
    break;
   }
   if ((HEAPU8[$buf_i + 4 | 0] | 0) > 21) {
    break;
   }
   $30 = HEAP8[$buf_i + 5 | 0] | 0; //@line 39366
   $32 = HEAP8[$buf_i + 7 | 0] | 0; //@line 39368
   $33 = _psi_get_uint16_le($4, 10) | 0; //@line 39369
   $_0912_i_i = 0;
   $_013_i_i = 10;
   $tmp_014_i_i = $4;
   while (1) {
    $37 = HEAPU8[$tmp_014_i_i] << 8 ^ $_0912_i_i; //@line 39378
    $40 = $37 << 1; //@line 39381
    $_2_i_i = ($37 & 32768 | 0) == 0 ? $40 : $40 ^ 41111; //@line 39383
    $44 = $_2_i_i << 1; //@line 39386
    $_2_1_i_i = ($_2_i_i & 32768 | 0) == 0 ? $44 : $44 ^ 41111; //@line 39388
    $48 = $_2_1_i_i << 1; //@line 39391
    $_2_2_i_i = ($_2_1_i_i & 32768 | 0) == 0 ? $48 : $48 ^ 41111; //@line 39393
    $52 = $_2_2_i_i << 1; //@line 39396
    $_2_3_i_i = ($_2_2_i_i & 32768 | 0) == 0 ? $52 : $52 ^ 41111; //@line 39398
    $56 = $_2_3_i_i << 1; //@line 39401
    $_2_4_i_i = ($_2_3_i_i & 32768 | 0) == 0 ? $56 : $56 ^ 41111; //@line 39403
    $60 = $_2_4_i_i << 1; //@line 39406
    $_2_5_i_i = ($_2_4_i_i & 32768 | 0) == 0 ? $60 : $60 ^ 41111; //@line 39408
    $64 = $_2_5_i_i << 1; //@line 39411
    $_2_6_i_i = ($_2_5_i_i & 32768 | 0) == 0 ? $64 : $64 ^ 41111; //@line 39413
    $68 = $_2_6_i_i << 1; //@line 39416
    $_2_7_i_i = ($_2_6_i_i & 32768 | 0) == 0 ? $68 : $68 ^ 41111; //@line 39418
    $71 = $_013_i_i - 1 | 0; //@line 39420
    if (($71 | 0) == 0) {
     break;
    } else {
     $_0912_i_i = $_2_7_i_i;
     $_013_i_i = $71;
     $tmp_014_i_i = $tmp_014_i_i + 1 | 0;
    }
   }
   $73 = $30 & 255; //@line 39429
   $74 = $_2_7_i_i & 65535; //@line 39430
   if (($33 | 0) != ($74 | 0)) {
    $77 = HEAP32[_stderr >> 2] | 0; //@line 39434
    _fprintf($77 | 0, 49872, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $33, HEAP32[tempInt + 8 >> 2] = $74, tempInt) | 0) | 0; //@line 39435
    break;
   }
   $81 = $buf_i_i | 0; //@line 39440
   do {
    if ($32 << 24 >> 24 < 0) {
     if ((_psi_read($fp, $81, 10) | 0) != 0) {
      break L17891;
     }
     $86 = _psi_get_uint16_le($81, 0) | 0; //@line 39450
     $_0912_i_i_i = 0;
     $_013_i_i_i = 8;
     $tmp_014_i_i_i = $buf_i_i + 2 | 0;
     while (1) {
      $91 = HEAPU8[$tmp_014_i_i_i] << 8 ^ $_0912_i_i_i; //@line 39460
      $94 = $91 << 1; //@line 39463
      $_2_i_i10_i = ($91 & 32768 | 0) == 0 ? $94 : $94 ^ 41111; //@line 39465
      $98 = $_2_i_i10_i << 1; //@line 39468
      $_2_1_i_i11_i = ($_2_i_i10_i & 32768 | 0) == 0 ? $98 : $98 ^ 41111; //@line 39470
      $102 = $_2_1_i_i11_i << 1; //@line 39473
      $_2_2_i_i12_i = ($_2_1_i_i11_i & 32768 | 0) == 0 ? $102 : $102 ^ 41111; //@line 39475
      $106 = $_2_2_i_i12_i << 1; //@line 39478
      $_2_3_i_i13_i = ($_2_2_i_i12_i & 32768 | 0) == 0 ? $106 : $106 ^ 41111; //@line 39480
      $110 = $_2_3_i_i13_i << 1; //@line 39483
      $_2_4_i_i14_i = ($_2_3_i_i13_i & 32768 | 0) == 0 ? $110 : $110 ^ 41111; //@line 39485
      $114 = $_2_4_i_i14_i << 1; //@line 39488
      $_2_5_i_i15_i = ($_2_4_i_i14_i & 32768 | 0) == 0 ? $114 : $114 ^ 41111; //@line 39490
      $118 = $_2_5_i_i15_i << 1; //@line 39493
      $_2_6_i_i16_i = ($_2_5_i_i15_i & 32768 | 0) == 0 ? $118 : $118 ^ 41111; //@line 39495
      $122 = $_2_6_i_i16_i << 1; //@line 39498
      $_2_7_i_i17_i = ($_2_6_i_i16_i & 32768 | 0) == 0 ? $122 : $122 ^ 41111; //@line 39500
      $125 = $_013_i_i_i - 1 | 0; //@line 39502
      if (($125 | 0) == 0) {
       break;
      } else {
       $_0912_i_i_i = $_2_7_i_i17_i;
       $_013_i_i_i = $125;
       $tmp_014_i_i_i = $tmp_014_i_i_i + 1 | 0;
      }
     }
     $127 = $_2_7_i_i17_i & 65535; //@line 39511
     $128 = _psi_get_uint16_le($81, 2) | 0; //@line 39512
     if (($128 | 0) == 0) {
      $crc2_0_i_i = $127; //@line 39516
     } else {
      $131 = _malloc($128) | 0; //@line 39518
      if (($131 | 0) == 0) {
       break L17891;
      }
      if ((_psi_read($fp, $131, $128) | 0) == 0) {
       $_0912_i38_i_i = $127;
       $_013_i37_i_i = $128;
       $tmp_014_i36_i_i = $131;
      } else {
       _free($131); //@line 39530
       break L17891;
      }
      while (1) {
       $140 = HEAPU8[$tmp_014_i36_i_i] << 8 ^ $_0912_i38_i_i; //@line 39541
       $143 = $140 << 1; //@line 39544
       $_2_i39_i_i = ($140 & 32768 | 0) == 0 ? $143 : $143 ^ 41111; //@line 39546
       $147 = $_2_i39_i_i << 1; //@line 39549
       $_2_1_i40_i_i = ($_2_i39_i_i & 32768 | 0) == 0 ? $147 : $147 ^ 41111; //@line 39551
       $151 = $_2_1_i40_i_i << 1; //@line 39554
       $_2_2_i41_i_i = ($_2_1_i40_i_i & 32768 | 0) == 0 ? $151 : $151 ^ 41111; //@line 39556
       $155 = $_2_2_i41_i_i << 1; //@line 39559
       $_2_3_i42_i_i = ($_2_2_i41_i_i & 32768 | 0) == 0 ? $155 : $155 ^ 41111; //@line 39561
       $159 = $_2_3_i42_i_i << 1; //@line 39564
       $_2_4_i43_i_i = ($_2_3_i42_i_i & 32768 | 0) == 0 ? $159 : $159 ^ 41111; //@line 39566
       $163 = $_2_4_i43_i_i << 1; //@line 39569
       $_2_5_i44_i_i = ($_2_4_i43_i_i & 32768 | 0) == 0 ? $163 : $163 ^ 41111; //@line 39571
       $167 = $_2_5_i44_i_i << 1; //@line 39574
       $_2_6_i45_i_i = ($_2_5_i44_i_i & 32768 | 0) == 0 ? $167 : $167 ^ 41111; //@line 39576
       $171 = $_2_6_i45_i_i << 1; //@line 39579
       $_2_7_i46_i_i = ($_2_6_i45_i_i & 32768 | 0) == 0 ? $171 : $171 ^ 41111; //@line 39581
       $174 = $_013_i37_i_i - 1 | 0; //@line 39583
       if (($174 | 0) == 0) {
        break;
       } else {
        $_0912_i38_i_i = $_2_7_i46_i_i;
        $_013_i37_i_i = $174;
        $tmp_014_i36_i_i = $tmp_014_i36_i_i + 1 | 0;
       }
      }
      $176 = $_2_7_i46_i_i & 65535; //@line 39592
      $i_0_i_i = 0; //@line 39594
      while (1) {
       if ($i_0_i_i >>> 0 >= $128 >>> 0) {
        $j_0_i_i = $128; //@line 39600
        break;
       }
       if ((HEAP8[$131 + $i_0_i_i | 0] | 0) == 0) {
        $i_0_i_i = $i_0_i_i + 1 | 0; //@line 39608
       } else {
        $j_0_i_i = $128; //@line 39610
        break;
       }
      }
      while (1) {
       if ($i_0_i_i >>> 0 >= $j_0_i_i >>> 0) {
        break;
       }
       $186 = $j_0_i_i - 1 | 0; //@line 39621
       if ((HEAP8[$131 + $186 | 0] | 0) == 0) {
        $j_0_i_i = $186; //@line 39626
       } else {
        $k_049_i_i = $i_0_i_i; //@line 39628
        label = 14097; //@line 39629
        break;
       }
      }
      if ((label | 0) == 14097) {
       while (1) {
        label = 0; //@line 39635
        $190 = $131 + $k_049_i_i | 0; //@line 39637
        if ((HEAP8[$190] | 0) == 0) {
         HEAP8[$190] = 10; //@line 39642
        }
        $194 = $k_049_i_i + 1 | 0; //@line 39645
        if ($194 >>> 0 < $j_0_i_i >>> 0) {
         $k_049_i_i = $194; //@line 39649
         label = 14097; //@line 39650
        } else {
         break;
        }
       }
      }
      _psi_img_set_comment($1, $131 + $i_0_i_i | 0, $j_0_i_i - $i_0_i_i | 0) | 0; //@line 39658
      _free($131); //@line 39659
      _psi_img_clean_comment($1); //@line 39660
      $crc2_0_i_i = $176; //@line 39662
     }
     if (($86 | 0) == ($crc2_0_i_i | 0)) {
      break;
     }
     _fprintf(HEAP32[_stderr >> 2] | 0, 57192, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $86, HEAP32[tempInt + 8 >> 2] = $crc2_0_i_i, tempInt) | 0) | 0; //@line 39671
     break L17891;
    }
   } while (0);
   if ((_psi_read($fp, $81, 1) | 0) != 0) {
    break;
   }
   $206 = $buf_i_i + 1 | 0; //@line 39682
   $207 = $buf_i_i + 3 | 0; //@line 39683
   $208 = $73 | 128; //@line 39684
   $209 = $buf_i_i_i | 0; //@line 39685
   $210 = $buf_i_i_i + 2 | 0; //@line 39686
   $211 = $buf_i_i_i + 3 | 0; //@line 39687
   $212 = $buf_i_i_i + 4 | 0; //@line 39688
   $213 = $buf_i_i_i + 1 | 0; //@line 39689
   $214 = $buf_i_i_i + 5 | 0; //@line 39690
   $215 = $buf_i_i_i_i | 0; //@line 39691
   $216 = $buf_i_i_i_i + 2 | 0; //@line 39692
   $217 = $buf_i_i_i_i + 3 | 0; //@line 39693
   $218 = $buf_i_i_i_i + 1 | 0; //@line 39694
   $219 = $buf_i_i + 2 | 0; //@line 39695
   L17937 : while (1) {
    if ((HEAP8[$81] | 0) == -1) {
     $_0 = $1; //@line 39702
     label = 14174; //@line 39703
     break;
    }
    if ((_psi_read($fp, $206, 3) | 0) != 0) {
     break L17891;
    }
    $228 = HEAP8[$81] | 0; //@line 39712
    $229 = $228 & 255; //@line 39713
    $232 = $229 << 9; //@line 39716
    $_2_i_i_i = ($229 & 128 | 0) == 0 ? $232 : $232 ^ 41111; //@line 39718
    $236 = $_2_i_i_i << 1; //@line 39721
    $_2_1_i_i_i = ($_2_i_i_i & 32768 | 0) == 0 ? $236 : $236 ^ 41111; //@line 39723
    $240 = $_2_1_i_i_i << 1; //@line 39726
    $_2_2_i_i_i = ($_2_1_i_i_i & 32768 | 0) == 0 ? $240 : $240 ^ 41111; //@line 39728
    $244 = $_2_2_i_i_i << 1; //@line 39731
    $_2_3_i_i_i = ($_2_2_i_i_i & 32768 | 0) == 0 ? $244 : $244 ^ 41111; //@line 39733
    $248 = $_2_3_i_i_i << 1; //@line 39736
    $_2_4_i_i_i = ($_2_3_i_i_i & 32768 | 0) == 0 ? $248 : $248 ^ 41111; //@line 39738
    $252 = $_2_4_i_i_i << 1; //@line 39741
    $_2_5_i_i_i = ($_2_4_i_i_i & 32768 | 0) == 0 ? $252 : $252 ^ 41111; //@line 39743
    $256 = $_2_5_i_i_i << 1; //@line 39746
    $_2_6_i_i_i = ($_2_5_i_i_i & 32768 | 0) == 0 ? $256 : $256 ^ 41111; //@line 39748
    $260 = $_2_6_i_i_i << 1; //@line 39751
    $263 = HEAPU8[$206] | 0; //@line 39755
    $265 = (($_2_6_i_i_i & 32768 | 0) == 0 ? $260 : $260 ^ 41111) ^ $263 << 8; //@line 39757
    $268 = $265 << 1; //@line 39760
    $_2_i_1_i_i = ($265 & 32768 | 0) == 0 ? $268 : $268 ^ 41111; //@line 39762
    $272 = $_2_i_1_i_i << 1; //@line 39765
    $_2_1_i_1_i_i = ($_2_i_1_i_i & 32768 | 0) == 0 ? $272 : $272 ^ 41111; //@line 39767
    $276 = $_2_1_i_1_i_i << 1; //@line 39770
    $_2_2_i_1_i_i = ($_2_1_i_1_i_i & 32768 | 0) == 0 ? $276 : $276 ^ 41111; //@line 39772
    $280 = $_2_2_i_1_i_i << 1; //@line 39775
    $_2_3_i_1_i_i = ($_2_2_i_1_i_i & 32768 | 0) == 0 ? $280 : $280 ^ 41111; //@line 39777
    $284 = $_2_3_i_1_i_i << 1; //@line 39780
    $_2_4_i_1_i_i = ($_2_3_i_1_i_i & 32768 | 0) == 0 ? $284 : $284 ^ 41111; //@line 39782
    $288 = $_2_4_i_1_i_i << 1; //@line 39785
    $_2_5_i_1_i_i = ($_2_4_i_1_i_i & 32768 | 0) == 0 ? $288 : $288 ^ 41111; //@line 39787
    $292 = $_2_5_i_1_i_i << 1; //@line 39790
    $_2_6_i_1_i_i = ($_2_5_i_1_i_i & 32768 | 0) == 0 ? $292 : $292 ^ 41111; //@line 39792
    $296 = $_2_6_i_1_i_i << 1; //@line 39795
    $299 = HEAPU8[$219] | 0; //@line 39799
    $301 = (($_2_6_i_1_i_i & 32768 | 0) == 0 ? $296 : $296 ^ 41111) ^ $299 << 8; //@line 39801
    $304 = $301 << 1; //@line 39804
    $_2_i_2_i_i = ($301 & 32768 | 0) == 0 ? $304 : $304 ^ 41111; //@line 39806
    $308 = $_2_i_2_i_i << 1; //@line 39809
    $_2_1_i_2_i_i = ($_2_i_2_i_i & 32768 | 0) == 0 ? $308 : $308 ^ 41111; //@line 39811
    $312 = $_2_1_i_2_i_i << 1; //@line 39814
    $_2_2_i_2_i_i = ($_2_1_i_2_i_i & 32768 | 0) == 0 ? $312 : $312 ^ 41111; //@line 39816
    $316 = $_2_2_i_2_i_i << 1; //@line 39819
    $_2_3_i_2_i_i = ($_2_2_i_2_i_i & 32768 | 0) == 0 ? $316 : $316 ^ 41111; //@line 39821
    $320 = $_2_3_i_2_i_i << 1; //@line 39824
    $_2_4_i_2_i_i = ($_2_3_i_2_i_i & 32768 | 0) == 0 ? $320 : $320 ^ 41111; //@line 39826
    $324 = $_2_4_i_2_i_i << 1; //@line 39829
    $_2_5_i_2_i_i = ($_2_4_i_2_i_i & 32768 | 0) == 0 ? $324 : $324 ^ 41111; //@line 39831
    $328 = $_2_5_i_2_i_i << 1; //@line 39834
    $_2_6_i_2_i_i = ($_2_5_i_2_i_i & 32768 | 0) == 0 ? $328 : $328 ^ 41111; //@line 39836
    $332 = $_2_6_i_2_i_i << 1; //@line 39839
    $_2_7_i_2_i_i = ($_2_6_i_2_i_i & 32768 | 0) == 0 ? $332 : $332 ^ 41111; //@line 39841
    $335 = HEAPU8[$207] | 0; //@line 39843
    if (($335 | 0) != ($_2_7_i_2_i_i & 255 | 0)) {
     label = 14109; //@line 39848
     break;
    }
    $343 = $299 & 127; //@line 39851
    $dr__i_i = ($299 & 128 | 0) == 0 ? $73 : $208; //@line 39854
    if ($228 << 24 >> 24 != 0) {
     $348 = 2 - ($dr__i_i >>> 7) | 0; //@line 39859
     $enc_0_i_i_i_i = ($dr__i_i & 127 | 0) == 2 ? $348 | 32768 : $348; //@line 39863
     $i_035_i_i = 0; //@line 39865
     do {
      if ((_psi_read($fp, $209, 6) | 0) != 0) {
       break L17891;
      }
      $357 = HEAPU8[$210] | 0; //@line 39875
      $358 = HEAP8[$211] | 0; //@line 39876
      $360 = HEAPU8[$212] | 0; //@line 39878
      $365 = ($358 & 255) < 7; //@line 39883
      if ($365) {
       $370 = 128 << ($358 & 255); //@line 39889
      } else {
       $370 = 0; //@line 39891
      }
      $371 = _psi_sct_new(HEAPU8[$209] | 0, HEAPU8[$213] | 0, $357, $370) | 0; //@line 39894
      if (($371 | 0) == 0) {
       break L17891;
      }
      _psi_sct_set_mfm_size($371, HEAP8[$211] | 0); //@line 39901
      if ((_psi_img_add_sector($1, $371, $263, $343) | 0) != 0) {
       label = 14117; //@line 39906
       break L17937;
      }
      _psi_sct_set_encoding($371, $enc_0_i_i_i_i); //@line 39909
      if (($360 & 2 | 0) != 0) {
       _psi_sct_set_flags($371, 2, 1); //@line 39914
      }
      if (($360 & 4 | 0) != 0) {
       _psi_sct_set_flags($371, 4, 1); //@line 39921
      }
      $387 = HEAP8[$214] | 0; //@line 39924
      $_0912_i_i_i_i = 0;
      $_013_i_i_i_i = 5;
      $tmp_014_i_i_i_i = $209;
      while (1) {
       $391 = HEAPU8[$tmp_014_i_i_i_i] << 8 ^ $_0912_i_i_i_i; //@line 39933
       $394 = $391 << 1; //@line 39936
       $_2_i_i_i_i = ($391 & 32768 | 0) == 0 ? $394 : $394 ^ 41111; //@line 39938
       $398 = $_2_i_i_i_i << 1; //@line 39941
       $_2_1_i_i_i_i = ($_2_i_i_i_i & 32768 | 0) == 0 ? $398 : $398 ^ 41111; //@line 39943
       $402 = $_2_1_i_i_i_i << 1; //@line 39946
       $_2_2_i_i_i_i = ($_2_1_i_i_i_i & 32768 | 0) == 0 ? $402 : $402 ^ 41111; //@line 39948
       $406 = $_2_2_i_i_i_i << 1; //@line 39951
       $_2_3_i_i_i_i = ($_2_2_i_i_i_i & 32768 | 0) == 0 ? $406 : $406 ^ 41111; //@line 39953
       $410 = $_2_3_i_i_i_i << 1; //@line 39956
       $_2_4_i_i_i_i = ($_2_3_i_i_i_i & 32768 | 0) == 0 ? $410 : $410 ^ 41111; //@line 39958
       $414 = $_2_4_i_i_i_i << 1; //@line 39961
       $_2_5_i_i_i_i = ($_2_4_i_i_i_i & 32768 | 0) == 0 ? $414 : $414 ^ 41111; //@line 39963
       $418 = $_2_5_i_i_i_i << 1; //@line 39966
       $_2_6_i_i_i_i = ($_2_5_i_i_i_i & 32768 | 0) == 0 ? $418 : $418 ^ 41111; //@line 39968
       $422 = $_2_6_i_i_i_i << 1; //@line 39971
       $_2_7_i_i_i_i = ($_2_6_i_i_i_i & 32768 | 0) == 0 ? $422 : $422 ^ 41111; //@line 39973
       $425 = $_013_i_i_i_i - 1 | 0; //@line 39975
       if (($425 | 0) == 0) {
        break;
       } else {
        $_0912_i_i_i_i = $_2_7_i_i_i_i;
        $_013_i_i_i_i = $425;
        $tmp_014_i_i_i_i = $tmp_014_i_i_i_i + 1 | 0;
       }
      }
      $427 = $387 & 255; //@line 39984
      $428 = $_2_7_i_i_i_i & 65535; //@line 39985
      do {
       if (($360 & 48 | 0) == 0) {
        do {
         if ($365) {
          if ((_psi_read($fp, $209, 3) | 0) != 0) {
           break L17891;
          }
          $449 = _psi_get_uint16_le($209, 0) | 0; //@line 40000
          if (($449 | 0) == 0) {
           label = 14132; //@line 40004
           break L17937;
          }
          $455 = $449 - 1 | 0; //@line 40007
          $456 = HEAP8[$210] | 0; //@line 40008
          if (($456 << 24 >> 24 | 0) == 1) {
           if (($455 | 0) != 4) {
            break L17891;
           }
           if ((_psi_read($fp, $215, 4) | 0) != 0) {
            break L17891;
           }
           $476 = _psi_get_uint16_le($215, 0) | 0; //@line 40021
           $478 = $371 + 10 | 0; //@line 40023
           if (($476 << 1 | 0) != (HEAPU16[$478 >> 1] | 0)) {
            break L17891;
           }
           if (($476 | 0) == 0) {
            $_pre_phi_i = $478; //@line 40034
            break;
           }
           $483 = $371 + 24 | 0; //@line 40037
           $i_010_i_i_i_i = 0; //@line 40039
           while (1) {
            $486 = $i_010_i_i_i_i << 1; //@line 40043
            HEAP8[(HEAP32[$483 >> 2] | 0) + $486 | 0] = HEAP8[$216] | 0; //@line 40046
            HEAP8[(HEAP32[$483 >> 2] | 0) + ($486 | 1) | 0] = HEAP8[$217] | 0; //@line 40051
            $493 = $i_010_i_i_i_i + 1 | 0; //@line 40052
            if ($493 >>> 0 < $476 >>> 0) {
             $i_010_i_i_i_i = $493; //@line 40056
            } else {
             $_pre_phi_i = $478; //@line 40058
             break;
            }
           }
          } else if (($456 << 24 >> 24 | 0) == 2) {
           $_pre_i_i_i_i = $371 + 10 | 0; //@line 40064
           if (($455 | 0) == 0) {
            $idx_0_lcssa_i_i_i_i = 0; //@line 40067
           } else {
            $497 = $371 + 24 | 0; //@line 40069
            $_036_i_i_i_i = $455;
            $idx_037_i_i_i_i = 0;
            while (1) {
             if ($_036_i_i_i_i >>> 0 < 2) {
              break L17891;
             }
             if ((_psi_read($fp, $215, 2) | 0) != 0) {
              break L17891;
             }
             $504 = $_036_i_i_i_i - 2 | 0; //@line 40086
             $505 = HEAP8[$215] | 0; //@line 40087
             do {
              if (($505 << 24 >> 24 | 0) == 1) {
               $524 = HEAP8[$218] | 0; //@line 40090
               $525 = $524 & 255; //@line 40091
               if ($504 >>> 0 < 2) {
                break L17891;
               }
               $529 = ($525 << 1) + $idx_037_i_i_i_i | 0; //@line 40098
               if ($529 >>> 0 > (HEAPU16[$_pre_i_i_i_i >> 1] | 0) >>> 0) {
                break L17891;
               }
               if ((_psi_read($fp, $216, 2) | 0) != 0) {
                break L17891;
               }
               $537 = $_036_i_i_i_i - 4 | 0; //@line 40112
               if ($524 << 24 >> 24 == 0) {
                $idx_0_be_i_i_i_i = $idx_037_i_i_i_i;
                $_0_be_i_i_i_i = $537;
                break;
               } else {
                $idx_132_i_i_i_i = $idx_037_i_i_i_i;
                $rep_033_i_i_i_i = $525;
               }
               while (1) {
                HEAP8[(HEAP32[$497 >> 2] | 0) + $idx_132_i_i_i_i | 0] = HEAP8[$216] | 0; //@line 40127
                HEAP8[(HEAP32[$497 >> 2] | 0) + ($idx_132_i_i_i_i + 1) | 0] = HEAP8[$217] | 0; //@line 40132
                $547 = $rep_033_i_i_i_i - 1 | 0; //@line 40134
                if (($547 | 0) == 0) {
                 $idx_0_be_i_i_i_i = $529;
                 $_0_be_i_i_i_i = $537;
                 break;
                } else {
                 $idx_132_i_i_i_i = $idx_132_i_i_i_i + 2 | 0;
                 $rep_033_i_i_i_i = $547;
                }
               }
              } else if (($505 << 24 >> 24 | 0) == 0) {
               $508 = HEAPU8[$218] | 0; //@line 40146
               if ($508 >>> 0 > $504 >>> 0) {
                break L17891;
               }
               $511 = $508 + $idx_037_i_i_i_i | 0; //@line 40152
               if ($511 >>> 0 > (HEAPU16[$_pre_i_i_i_i >> 1] | 0) >>> 0) {
                break L17891;
               }
               if ((_psi_read($fp, (HEAP32[$497 >> 2] | 0) + $idx_037_i_i_i_i | 0, $508) | 0) != 0) {
                break L17891;
               }
               $idx_0_be_i_i_i_i = $511;
               $_0_be_i_i_i_i = $504 - $508 | 0;
              } else {
               break L17891;
              }
             } while (0);
             if (($_0_be_i_i_i_i | 0) == 0) {
              $idx_0_lcssa_i_i_i_i = $idx_0_be_i_i_i_i; //@line 40180
              break;
             } else {
              $_036_i_i_i_i = $_0_be_i_i_i_i;
              $idx_037_i_i_i_i = $idx_0_be_i_i_i_i;
             }
            }
           }
           if ($idx_0_lcssa_i_i_i_i >>> 0 < (HEAPU16[$_pre_i_i_i_i >> 1] | 0) >>> 0) {
            break L17891;
           } else {
            $_pre_phi_i = $_pre_i_i_i_i; //@line 40195
            break;
           }
          } else if (($456 << 24 >> 24 | 0) == 0) {
           $458 = $371 + 10 | 0; //@line 40199
           if ((HEAPU16[$458 >> 1] | 0) != ($455 | 0)) {
            break L17891;
           }
           if ((_psi_read($fp, HEAP32[$371 + 24 >> 2] | 0, $455) | 0) == 0) {
            $_pre_phi_i = $458; //@line 40213
            break;
           } else {
            label = 14136; //@line 40216
            break L17937;
           }
          } else {
           label = 14159; //@line 40220
           break L17937;
          }
         } else {
          $_pre_phi_i = $371 + 10 | 0; //@line 40226
         }
        } while (0);
        $556 = HEAP16[$_pre_phi_i >> 1] | 0; //@line 40230
        if ($556 << 16 >> 16 == 0) {
         $_09_lcssa_i_i_i_i = 0;
         $_09_lcssa_i8292_i_i_i = $428;
         $640 = $428;
        } else {
         $559 = $556 & 65535; //@line 40237
         $560 = HEAP32[$371 + 24 >> 2] | 0; //@line 40238
         $_0912_i72_i_i_i = $428;
         $_013_i71_i_i_i = $559;
         $tmp_014_i70_i_i_i = $560;
         while (1) {
          $564 = HEAPU8[$tmp_014_i70_i_i_i] << 8 ^ $_0912_i72_i_i_i; //@line 40248
          $567 = $564 << 1; //@line 40251
          $_2_i73_i_i_i = ($564 & 32768 | 0) == 0 ? $567 : $567 ^ 41111; //@line 40253
          $571 = $_2_i73_i_i_i << 1; //@line 40256
          $_2_1_i74_i_i_i = ($_2_i73_i_i_i & 32768 | 0) == 0 ? $571 : $571 ^ 41111; //@line 40258
          $575 = $_2_1_i74_i_i_i << 1; //@line 40261
          $_2_2_i75_i_i_i = ($_2_1_i74_i_i_i & 32768 | 0) == 0 ? $575 : $575 ^ 41111; //@line 40263
          $579 = $_2_2_i75_i_i_i << 1; //@line 40266
          $_2_3_i76_i_i_i = ($_2_2_i75_i_i_i & 32768 | 0) == 0 ? $579 : $579 ^ 41111; //@line 40268
          $583 = $_2_3_i76_i_i_i << 1; //@line 40271
          $_2_4_i77_i_i_i = ($_2_3_i76_i_i_i & 32768 | 0) == 0 ? $583 : $583 ^ 41111; //@line 40273
          $587 = $_2_4_i77_i_i_i << 1; //@line 40276
          $_2_5_i78_i_i_i = ($_2_4_i77_i_i_i & 32768 | 0) == 0 ? $587 : $587 ^ 41111; //@line 40278
          $591 = $_2_5_i78_i_i_i << 1; //@line 40281
          $_2_6_i79_i_i_i = ($_2_5_i78_i_i_i & 32768 | 0) == 0 ? $591 : $591 ^ 41111; //@line 40283
          $595 = $_2_6_i79_i_i_i << 1; //@line 40286
          $_2_7_i80_i_i_i = ($_2_6_i79_i_i_i & 32768 | 0) == 0 ? $595 : $595 ^ 41111; //@line 40288
          $598 = $_013_i71_i_i_i - 1 | 0; //@line 40290
          if (($598 | 0) == 0) {
           $_0912_i59_i_i_i = 0;
           $_013_i58_i_i_i = $559;
           $tmp_014_i57_i_i_i = $560;
           break;
          } else {
           $_0912_i72_i_i_i = $_2_7_i80_i_i_i;
           $_013_i71_i_i_i = $598;
           $tmp_014_i70_i_i_i = $tmp_014_i70_i_i_i + 1 | 0;
          }
         }
         while (1) {
          $603 = HEAPU8[$tmp_014_i57_i_i_i] << 8 ^ $_0912_i59_i_i_i; //@line 40307
          $606 = $603 << 1; //@line 40310
          $_2_i60_i_i_i = ($603 & 32768 | 0) == 0 ? $606 : $606 ^ 41111; //@line 40312
          $610 = $_2_i60_i_i_i << 1; //@line 40315
          $_2_1_i61_i_i_i = ($_2_i60_i_i_i & 32768 | 0) == 0 ? $610 : $610 ^ 41111; //@line 40317
          $614 = $_2_1_i61_i_i_i << 1; //@line 40320
          $_2_2_i62_i_i_i = ($_2_1_i61_i_i_i & 32768 | 0) == 0 ? $614 : $614 ^ 41111; //@line 40322
          $618 = $_2_2_i62_i_i_i << 1; //@line 40325
          $_2_3_i63_i_i_i = ($_2_2_i62_i_i_i & 32768 | 0) == 0 ? $618 : $618 ^ 41111; //@line 40327
          $622 = $_2_3_i63_i_i_i << 1; //@line 40330
          $_2_4_i64_i_i_i = ($_2_3_i63_i_i_i & 32768 | 0) == 0 ? $622 : $622 ^ 41111; //@line 40332
          $626 = $_2_4_i64_i_i_i << 1; //@line 40335
          $_2_5_i65_i_i_i = ($_2_4_i64_i_i_i & 32768 | 0) == 0 ? $626 : $626 ^ 41111; //@line 40337
          $630 = $_2_5_i65_i_i_i << 1; //@line 40340
          $_2_6_i66_i_i_i = ($_2_5_i65_i_i_i & 32768 | 0) == 0 ? $630 : $630 ^ 41111; //@line 40342
          $634 = $_2_6_i66_i_i_i << 1; //@line 40345
          $_2_7_i67_i_i_i = ($_2_6_i66_i_i_i & 32768 | 0) == 0 ? $634 : $634 ^ 41111; //@line 40347
          $637 = $_013_i58_i_i_i - 1 | 0; //@line 40349
          if (($637 | 0) == 0) {
           break;
          } else {
           $_0912_i59_i_i_i = $_2_7_i67_i_i_i;
           $_013_i58_i_i_i = $637;
           $tmp_014_i57_i_i_i = $tmp_014_i57_i_i_i + 1 | 0;
          }
         }
         $_09_lcssa_i_i_i_i = $_2_7_i67_i_i_i;
         $_09_lcssa_i8292_i_i_i = $_2_7_i80_i_i_i;
         $640 = $_2_7_i80_i_i_i & 65535;
        }
        if (($427 | 0) != ($_09_lcssa_i_i_i_i & 255 | 0)) {
         $644 = HEAP32[_stderr >> 2] | 0; //@line 40368
         _fwrite(33568, 33, 1, $644 | 0) | 0; //@line 40369
         if (($427 | 0) != ($_09_lcssa_i8292_i_i_i & 255 | 0)) {
          label = 14167; //@line 40374
          break L17937;
         }
        }
        if (($360 & 64 | 0) == 0) {
         break;
        }
        $659 = HEAP32[_stderr >> 2] | 0; //@line 40384
        $662 = HEAPU16[$371 + 8 >> 1] | 0; //@line 40387
        _fprintf($659 | 0, 30808, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $263, HEAP32[tempInt + 8 >> 2] = $343, HEAP32[tempInt + 16 >> 2] = $662, tempInt) | 0) | 0; //@line 40388
        _psi_img_remove_sector($1, $371); //@line 40389
        _psi_sct_del($371); //@line 40390
       } else {
        if (($427 | 0) != ($_2_7_i_i_i_i & 255 | 0)) {
         label = 14126; //@line 40397
         break L17937;
        }
        _psi_sct_fill($371, ($360 & 16 | 0) != 0 ? 246 : 0); //@line 40403
       }
      } while (0);
      $i_035_i_i = $i_035_i_i + 1 | 0; //@line 40407
     } while ($i_035_i_i >>> 0 < $229 >>> 0);
    }
    if ((_psi_read($fp, $81, 1) | 0) != 0) {
     break L17891;
    }
   }
   if ((label | 0) == 14136) {
    $468 = HEAP32[_stderr >> 2] | 0; //@line 40425
    _fwrite(57976, 16, 1, $468 | 0) | 0; //@line 40426
    break;
   } else if ((label | 0) == 14126) {
    $438 = HEAPU16[$371 + 8 >> 1] | 0; //@line 40434
    _fprintf(HEAP32[_stderr >> 2] | 0, 42600, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $263, HEAP32[tempInt + 8 >> 2] = $343, HEAP32[tempInt + 16 >> 2] = $438, tempInt) | 0) | 0; //@line 40435
    break;
   } else if ((label | 0) == 14117) {
    _psi_sct_del($371); //@line 40440
    break;
   } else if ((label | 0) == 14132) {
    _fprintf(HEAP32[_stderr >> 2] | 0, 39496, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $263, HEAP32[tempInt + 8 >> 2] = $343, HEAP32[tempInt + 16 >> 2] = $357, tempInt) | 0) | 0; //@line 40446
    break;
   } else if ((label | 0) == 14174) {
    STACKTOP = sp; //@line 40452
    return $_0 | 0; //@line 40453
   } else if ((label | 0) == 14159) {
    _fprintf(HEAP32[_stderr >> 2] | 0, 36544, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $263, HEAP32[tempInt + 8 >> 2] = $343, HEAP32[tempInt + 16 >> 2] = $357, HEAP32[tempInt + 24 >> 2] = $456 & 255, tempInt) | 0) | 0; //@line 40458
    break;
   } else if ((label | 0) == 14167) {
    $653 = HEAPU16[$371 + 8 >> 1] | 0; //@line 40467
    _fprintf(HEAP32[_stderr >> 2] | 0, 31752, (tempInt = STACKTOP, STACKTOP = STACKTOP + 48 | 0, HEAP32[tempInt >> 2] = $263, HEAP32[tempInt + 8 >> 2] = $343, HEAP32[tempInt + 16 >> 2] = $653, HEAP32[tempInt + 24 >> 2] = $427, HEAP32[tempInt + 32 >> 2] = $_09_lcssa_i_i_i_i & 65535, HEAP32[tempInt + 40 >> 2] = $640, tempInt) | 0) | 0; //@line 40468
    break;
   } else if ((label | 0) == 14109) {
    _fprintf(HEAP32[_stderr >> 2] | 0, 46048, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $335, HEAP32[tempInt + 8 >> 2] = $_2_7_i_2_i_i & 65535, tempInt) | 0) | 0; //@line 40475
    break;
   }
  }
 } while (0);
 _psi_img_del($1); //@line 40481
 $_0 = 0; //@line 40483
 STACKTOP = sp; //@line 40485
 return $_0 | 0; //@line 40486
}
function _psi_save_td0($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $buf_i36 = 0, $t_i = 0, $buf_i = 0, $buf = 0, $1 = 0, $2 = 0, $3 = 0, $6 = 0, $7 = 0, $c_037_i = 0, $enc_036_i = 0, $sn_035_i = 0, $hn_034_i = 0, $10 = 0, $12 = 0, $13 = 0, $_hn_0_i = 0, $17 = 0, $h_028_i = 0, $enc_127_i = 0, $sn_126_i = 0, $20 = 0, $22 = 0, $23 = 0, $_sn_1_i = 0, $26 = 0, $s_025_i = 0, $enc_224_i = 0, $enc_3_i = 0, $37 = 0, $enc_2_lcssa_i = 0, $39 = 0, $enc_1_lcssa_i = 0, $sn_1_lcssa_i = 0, $41 = 0, $extract_t_i = 0, $hn_0_lcssa_off049_i = 0, $sn_0_lcssa47_i = 0, $hn_0_lcssa_off048_i = 0, $sn_0_lcssa46_i = 0, $enc_4_off0_i = 0, $dt_0_off0_i = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $67 = 0, $tmp_014_i_i = 0, $_013_i_i = 0, $_0912_i_i = 0, $68 = 0, $71 = 0, $_2_i_i = 0, $75 = 0, $_2_1_i_i = 0, $79 = 0, $_2_2_i_i = 0, $83 = 0, $_2_3_i_i = 0, $87 = 0, $_2_4_i_i = 0, $91 = 0, $_2_5_i_i = 0, $95 = 0, $_2_6_i_i = 0, $99 = 0, $_2_7_i_i = 0, $101 = 0, $106 = 0, $__i19 = 0, $112 = 0, $131 = 0, $133 = 0, $_pre_i20 = 0, $i_042_i = 0, $137 = 0, $140 = 0, $tmp_014_i_i23 = 0, $_013_i_i24 = 0, $_0912_i_i25 = 0, $145 = 0, $148 = 0, $_2_i_i26 = 0, $152 = 0, $_2_1_i_i27 = 0, $156 = 0, $_2_2_i_i28 = 0, $160 = 0, $_2_3_i_i29 = 0, $164 = 0, $_2_4_i_i30 = 0, $168 = 0, $_2_5_i_i31 = 0, $172 = 0, $_2_6_i_i32 = 0, $176 = 0, $_2_7_i_i33 = 0, $179 = 0, $181 = 0, $tmp_014_i28_i = 0, $_013_i29_i = 0, $_0912_i30_i = 0, $185 = 0, $188 = 0, $_2_i31_i = 0, $192 = 0, $_2_1_i32_i = 0, $196 = 0, $_2_2_i33_i = 0, $200 = 0, $_2_3_i34_i = 0, $204 = 0, $_2_4_i35_i = 0, $208 = 0, $_2_5_i36_i = 0, $212 = 0, $_2_6_i37_i = 0, $216 = 0, $_2_7_i38_i = 0, $218 = 0, $_09_lcssa_i_i = 0, $225 = 0, $226 = 0, $228 = 0, $229 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $c_055 = 0, $236 = 0, $237 = 0, $240 = 0, $241 = 0, $243 = 0, $h_054 = 0, $247 = 0, $248 = 0, $249 = 0, $252 = 0, $255 = 0, $_2_i_i37 = 0, $259 = 0, $_2_1_i_i38 = 0, $263 = 0, $_2_2_i_i39 = 0, $267 = 0, $_2_3_i_i40 = 0, $271 = 0, $_2_4_i_i41 = 0, $275 = 0, $_2_5_i_i42 = 0, $279 = 0, $_2_6_i_i43 = 0, $283 = 0, $285 = 0, $288 = 0, $_2_i_1_i = 0, $292 = 0, $_2_1_i_1_i = 0, $296 = 0, $_2_2_i_1_i = 0, $300 = 0, $_2_3_i_1_i = 0, $304 = 0, $_2_4_i_1_i = 0, $308 = 0, $_2_5_i_1_i = 0, $312 = 0, $_2_6_i_1_i = 0, $316 = 0, $320 = 0, $323 = 0, $_2_i_2_i = 0, $327 = 0, $_2_1_i_2_i = 0, $331 = 0, $_2_2_i_2_i = 0, $335 = 0, $_2_3_i_2_i = 0, $339 = 0, $_2_4_i_2_i = 0, $343 = 0, $_2_5_i_2_i = 0, $347 = 0, $_2_6_i_2_i = 0, $351 = 0, $356 = 0, $s_014_i = 0, $361 = 0, $362 = 0, $364 = 0, $381 = 0, $386 = 0, $391 = 0, $392 = 0, $tmp_014_i_i_i = 0, $_013_i_i_i = 0, $_0912_i_i_i = 0, $399 = 0, $402 = 0, $_2_i_i_i = 0, $406 = 0, $_2_1_i_i_i = 0, $410 = 0, $_2_2_i_i_i = 0, $414 = 0, $_2_3_i_i_i = 0, $418 = 0, $_2_4_i_i_i = 0, $422 = 0, $_2_5_i_i_i = 0, $426 = 0, $_2_6_i_i_i = 0, $430 = 0, $_2_7_i_i_i = 0, $433 = 0, $_09_lcssa_i_off0_i_i = 0, $441 = 0, $_pre_i_i = 0, $i_0_i_i = 0, $447 = 0, $458 = 0, $483 = 0, $484 = 0, $487 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 40567
 STACKTOP = STACKTOP + 40 | 0; //@line 40567
 $buf_i36 = sp | 0; //@line 40568
 $t_i = sp + 8 | 0; //@line 40569
 $buf_i = sp + 16 | 0; //@line 40570
 $buf = sp + 32 | 0; //@line 40571
 $1 = $buf_i | 0; //@line 40572
 $2 = $img | 0; //@line 40573
 $3 = HEAP16[$2 >> 1] | 0; //@line 40574
 do {
  if ($3 << 16 >> 16 == 0) {
   $sn_0_lcssa47_i = 0;
   $hn_0_lcssa_off049_i = 0;
   label = 14191; //@line 40580
  } else {
   $6 = HEAP32[$img + 4 >> 2] | 0; //@line 40583
   $7 = $3 & 65535; //@line 40584
   $hn_034_i = 0;
   $sn_035_i = 0;
   $enc_036_i = 0;
   $c_037_i = 0;
   while (1) {
    $10 = HEAP32[$6 + ($c_037_i << 2) >> 2] | 0; //@line 40593
    $12 = HEAP16[$10 + 2 >> 1] | 0; //@line 40595
    $13 = $12 & 65535; //@line 40596
    $_hn_0_i = $13 >>> 0 > $hn_034_i >>> 0 ? $13 : $hn_034_i; //@line 40598
    if ($12 << 16 >> 16 == 0) {
     $sn_1_lcssa_i = $sn_035_i;
     $enc_1_lcssa_i = $enc_036_i;
    } else {
     $17 = HEAP32[$10 + 4 >> 2] | 0; //@line 40605
     $sn_126_i = $sn_035_i;
     $enc_127_i = $enc_036_i;
     $h_028_i = 0;
     while (1) {
      $20 = HEAP32[$17 + ($h_028_i << 2) >> 2] | 0; //@line 40613
      $22 = HEAP16[$20 + 2 >> 1] | 0; //@line 40615
      $23 = $22 & 65535; //@line 40616
      $_sn_1_i = $23 >>> 0 > $sn_126_i >>> 0 ? $23 : $sn_126_i; //@line 40618
      if ($22 << 16 >> 16 == 0) {
       $enc_2_lcssa_i = $enc_127_i; //@line 40622
      } else {
       $26 = $20 + 4 | 0; //@line 40624
       $enc_224_i = $enc_127_i;
       $s_025_i = 0;
       while (1) {
        if (($enc_224_i | 0) == 0) {
         $enc_3_i = HEAPU16[(HEAP32[(HEAP32[$26 >> 2] | 0) + ($s_025_i << 2) >> 2] | 0) + 16 >> 1] | 0; //@line 40640
        } else {
         $enc_3_i = $enc_224_i; //@line 40642
        }
        $37 = $s_025_i + 1 | 0; //@line 40645
        if ($37 >>> 0 < $23 >>> 0) {
         $enc_224_i = $enc_3_i;
         $s_025_i = $37;
        } else {
         $enc_2_lcssa_i = $enc_3_i; //@line 40651
         break;
        }
       }
      }
      $39 = $h_028_i + 1 | 0; //@line 40657
      if ($39 >>> 0 < $13 >>> 0) {
       $sn_126_i = $_sn_1_i;
       $enc_127_i = $enc_2_lcssa_i;
       $h_028_i = $39;
      } else {
       $sn_1_lcssa_i = $_sn_1_i;
       $enc_1_lcssa_i = $enc_2_lcssa_i;
       break;
      }
     }
    }
    $41 = $c_037_i + 1 | 0; //@line 40670
    if ($41 >>> 0 < $7 >>> 0) {
     $hn_034_i = $_hn_0_i;
     $sn_035_i = $sn_1_lcssa_i;
     $enc_036_i = $enc_1_lcssa_i;
     $c_037_i = $41;
    } else {
     break;
    }
   }
   $extract_t_i = $_hn_0_i & 255; //@line 40679
   if (($enc_1_lcssa_i | 0) == 32769) {
    $enc_4_off0_i = -126;
    $sn_0_lcssa46_i = $sn_1_lcssa_i;
    $hn_0_lcssa_off048_i = $extract_t_i;
    break;
   } else if (($enc_1_lcssa_i | 0) == 1) {
    $enc_4_off0_i = -128;
    $sn_0_lcssa46_i = $sn_1_lcssa_i;
    $hn_0_lcssa_off048_i = $extract_t_i;
    break;
   } else if (($enc_1_lcssa_i | 0) == 2) {
    $enc_4_off0_i = 0;
    $sn_0_lcssa46_i = $sn_1_lcssa_i;
    $hn_0_lcssa_off048_i = $extract_t_i;
    break;
   } else if (($enc_1_lcssa_i | 0) == 32770) {
    $enc_4_off0_i = 2;
    $sn_0_lcssa46_i = $sn_1_lcssa_i;
    $hn_0_lcssa_off048_i = $extract_t_i;
    break;
   } else {
    $sn_0_lcssa47_i = $sn_1_lcssa_i;
    $hn_0_lcssa_off049_i = $extract_t_i;
    label = 14191; //@line 40697
    break;
   }
  }
 } while (0);
 if ((label | 0) == 14191) {
  $enc_4_off0_i = 0;
  $sn_0_lcssa46_i = $sn_0_lcssa47_i;
  $hn_0_lcssa_off048_i = $hn_0_lcssa_off049_i;
 }
 do {
  if (($3 & 65535) < 45) {
   $dt_0_off0_i = 1; //@line 40715
  } else {
   if ($sn_0_lcssa46_i >>> 0 < 12) {
    $dt_0_off0_i = 3; //@line 40720
    break;
   }
   $dt_0_off0_i = $sn_0_lcssa46_i >>> 0 < 17 ? 2 : 4; //@line 40726
  }
 } while (0);
 HEAP8[$1] = 84; //@line 40730
 $54 = $buf_i + 1 | 0; //@line 40731
 HEAP8[$54] = 68; //@line 40732
 $55 = $buf_i + 2 | 0; //@line 40733
 HEAP8[$55] = 0; //@line 40734
 $56 = $buf_i + 3 | 0; //@line 40735
 HEAP8[$56] = 0; //@line 40736
 $57 = $buf_i + 4 | 0; //@line 40737
 HEAP8[$57] = 21; //@line 40738
 $58 = $buf_i + 5 | 0; //@line 40739
 HEAP8[$58] = $enc_4_off0_i; //@line 40740
 $59 = $buf_i + 6 | 0; //@line 40741
 HEAP8[$59] = $dt_0_off0_i; //@line 40742
 $60 = $buf_i + 7 | 0; //@line 40743
 HEAP8[$60] = 0; //@line 40744
 $61 = $buf_i + 8 | 0; //@line 40745
 HEAP8[$61] = 0; //@line 40746
 $62 = $buf_i + 9 | 0; //@line 40747
 HEAP8[$62] = $hn_0_lcssa_off048_i; //@line 40748
 $63 = $img + 8 | 0; //@line 40749
 if ((HEAP32[$63 >> 2] | 0) == 0) {
  $_0912_i_i = 0;
  $_013_i_i = 9;
  $tmp_014_i_i = $1;
  $67 = 21504;
 } else {
  HEAP8[$60] = -128; //@line 40756
  $_0912_i_i = 0;
  $_013_i_i = 9;
  $tmp_014_i_i = $1;
  $67 = 21504;
 }
 while (1) {
  $68 = $_0912_i_i ^ $67; //@line 40765
  $71 = $68 << 1; //@line 40768
  $_2_i_i = ($68 & 32768 | 0) == 0 ? $71 : $71 ^ 41111; //@line 40770
  $75 = $_2_i_i << 1; //@line 40773
  $_2_1_i_i = ($_2_i_i & 32768 | 0) == 0 ? $75 : $75 ^ 41111; //@line 40775
  $79 = $_2_1_i_i << 1; //@line 40778
  $_2_2_i_i = ($_2_1_i_i & 32768 | 0) == 0 ? $79 : $79 ^ 41111; //@line 40780
  $83 = $_2_2_i_i << 1; //@line 40783
  $_2_3_i_i = ($_2_2_i_i & 32768 | 0) == 0 ? $83 : $83 ^ 41111; //@line 40785
  $87 = $_2_3_i_i << 1; //@line 40788
  $_2_4_i_i = ($_2_3_i_i & 32768 | 0) == 0 ? $87 : $87 ^ 41111; //@line 40790
  $91 = $_2_4_i_i << 1; //@line 40793
  $_2_5_i_i = ($_2_4_i_i & 32768 | 0) == 0 ? $91 : $91 ^ 41111; //@line 40795
  $95 = $_2_5_i_i << 1; //@line 40798
  $_2_6_i_i = ($_2_5_i_i & 32768 | 0) == 0 ? $95 : $95 ^ 41111; //@line 40800
  $99 = $_2_6_i_i << 1; //@line 40803
  $_2_7_i_i = ($_2_6_i_i & 32768 | 0) == 0 ? $99 : $99 ^ 41111; //@line 40805
  $101 = $tmp_014_i_i + 1 | 0; //@line 40806
  if (($_013_i_i | 0) == 0) {
   break;
  }
  $_0912_i_i = $_2_7_i_i;
  $_013_i_i = $_013_i_i - 1 | 0;
  $tmp_014_i_i = $101;
  $67 = HEAPU8[$101] << 8;
 }
 _psi_set_uint16_le($1, 10, $_2_7_i_i & 65535); //@line 40820
 if ((_psi_write($fp, $1, 12) | 0) != 0) {
  $_0 = 1; //@line 40825
  STACKTOP = sp; //@line 40827
  return $_0 | 0; //@line 40828
 }
 $106 = HEAP32[$63 >> 2] | 0; //@line 40830
 do {
  if (($106 | 0) != 0) {
   $__i19 = $106 >>> 0 > 65535 ? 65535 : $106; //@line 40837
   _psi_set_uint16_le($1, 2, $__i19); //@line 40838
   HEAP32[$t_i >> 2] = _time(0) | 0; //@line 40840
   $112 = _gmtime($t_i | 0) | 0; //@line 40841
   HEAP8[$57] = HEAP32[$112 + 20 >> 2] & 255; //@line 40845
   HEAP8[$58] = HEAP32[$112 + 16 >> 2] & 255; //@line 40849
   HEAP8[$59] = HEAP32[$112 + 12 >> 2] & 255; //@line 40853
   HEAP8[$60] = HEAP32[$112 + 8 >> 2] & 255; //@line 40857
   HEAP8[$61] = HEAP32[$112 + 4 >> 2] & 255; //@line 40861
   HEAP8[$62] = HEAP32[$112 >> 2] & 255; //@line 40865
   $131 = _malloc($__i19) | 0; //@line 40866
   if (($131 | 0) == 0) {
    $_0 = 1; //@line 40870
    STACKTOP = sp; //@line 40872
    return $_0 | 0; //@line 40873
   }
   $133 = ($__i19 | 0) == 0; //@line 40875
   if ($133) {
    $_0912_i_i25 = 0;
    $_013_i_i24 = 8;
    $tmp_014_i_i23 = $55;
   } else {
    $_pre_i20 = HEAP32[$img + 12 >> 2] | 0; //@line 40881
    $i_042_i = 0; //@line 40883
    while (1) {
     $137 = HEAP8[$_pre_i20 + $i_042_i | 0] | 0; //@line 40887
     HEAP8[$131 + $i_042_i | 0] = $137 << 24 >> 24 == 10 ? 0 : $137; //@line 40891
     $140 = $i_042_i + 1 | 0; //@line 40892
     if ($140 >>> 0 < $__i19 >>> 0) {
      $i_042_i = $140; //@line 40896
     } else {
      $_0912_i_i25 = 0;
      $_013_i_i24 = 8;
      $tmp_014_i_i23 = $55;
      break;
     }
    }
   }
   while (1) {
    $145 = HEAPU8[$tmp_014_i_i23] << 8 ^ $_0912_i_i25; //@line 40910
    $148 = $145 << 1; //@line 40913
    $_2_i_i26 = ($145 & 32768 | 0) == 0 ? $148 : $148 ^ 41111; //@line 40915
    $152 = $_2_i_i26 << 1; //@line 40918
    $_2_1_i_i27 = ($_2_i_i26 & 32768 | 0) == 0 ? $152 : $152 ^ 41111; //@line 40920
    $156 = $_2_1_i_i27 << 1; //@line 40923
    $_2_2_i_i28 = ($_2_1_i_i27 & 32768 | 0) == 0 ? $156 : $156 ^ 41111; //@line 40925
    $160 = $_2_2_i_i28 << 1; //@line 40928
    $_2_3_i_i29 = ($_2_2_i_i28 & 32768 | 0) == 0 ? $160 : $160 ^ 41111; //@line 40930
    $164 = $_2_3_i_i29 << 1; //@line 40933
    $_2_4_i_i30 = ($_2_3_i_i29 & 32768 | 0) == 0 ? $164 : $164 ^ 41111; //@line 40935
    $168 = $_2_4_i_i30 << 1; //@line 40938
    $_2_5_i_i31 = ($_2_4_i_i30 & 32768 | 0) == 0 ? $168 : $168 ^ 41111; //@line 40940
    $172 = $_2_5_i_i31 << 1; //@line 40943
    $_2_6_i_i32 = ($_2_5_i_i31 & 32768 | 0) == 0 ? $172 : $172 ^ 41111; //@line 40945
    $176 = $_2_6_i_i32 << 1; //@line 40948
    $_2_7_i_i33 = ($_2_6_i_i32 & 32768 | 0) == 0 ? $176 : $176 ^ 41111; //@line 40950
    $179 = $_013_i_i24 - 1 | 0; //@line 40952
    if (($179 | 0) == 0) {
     break;
    } else {
     $_0912_i_i25 = $_2_7_i_i33;
     $_013_i_i24 = $179;
     $tmp_014_i_i23 = $tmp_014_i_i23 + 1 | 0;
    }
   }
   $181 = $_2_7_i_i33 & 65535; //@line 40961
   L18077 : do {
    if ($133) {
     $_09_lcssa_i_i = $181; //@line 40965
    } else {
     $_0912_i30_i = $181;
     $_013_i29_i = $__i19;
     $tmp_014_i28_i = $131;
     while (1) {
      $185 = HEAPU8[$tmp_014_i28_i] << 8 ^ $_0912_i30_i; //@line 40975
      $188 = $185 << 1; //@line 40978
      $_2_i31_i = ($185 & 32768 | 0) == 0 ? $188 : $188 ^ 41111; //@line 40980
      $192 = $_2_i31_i << 1; //@line 40983
      $_2_1_i32_i = ($_2_i31_i & 32768 | 0) == 0 ? $192 : $192 ^ 41111; //@line 40985
      $196 = $_2_1_i32_i << 1; //@line 40988
      $_2_2_i33_i = ($_2_1_i32_i & 32768 | 0) == 0 ? $196 : $196 ^ 41111; //@line 40990
      $200 = $_2_2_i33_i << 1; //@line 40993
      $_2_3_i34_i = ($_2_2_i33_i & 32768 | 0) == 0 ? $200 : $200 ^ 41111; //@line 40995
      $204 = $_2_3_i34_i << 1; //@line 40998
      $_2_4_i35_i = ($_2_3_i34_i & 32768 | 0) == 0 ? $204 : $204 ^ 41111; //@line 41000
      $208 = $_2_4_i35_i << 1; //@line 41003
      $_2_5_i36_i = ($_2_4_i35_i & 32768 | 0) == 0 ? $208 : $208 ^ 41111; //@line 41005
      $212 = $_2_5_i36_i << 1; //@line 41008
      $_2_6_i37_i = ($_2_5_i36_i & 32768 | 0) == 0 ? $212 : $212 ^ 41111; //@line 41010
      $216 = $_2_6_i37_i << 1; //@line 41013
      $_2_7_i38_i = ($_2_6_i37_i & 32768 | 0) == 0 ? $216 : $216 ^ 41111; //@line 41015
      $218 = $_013_i29_i - 1 | 0; //@line 41016
      if (($218 | 0) == 0) {
       $_09_lcssa_i_i = $_2_7_i38_i; //@line 41020
       break L18077;
      }
      $_0912_i30_i = $_2_7_i38_i;
      $_013_i29_i = $218;
      $tmp_014_i28_i = $tmp_014_i28_i + 1 | 0;
     }
    }
   } while (0);
   _psi_set_uint16_le($1, 0, $_09_lcssa_i_i & 65535); //@line 41031
   if ((_psi_write($fp, $1, 10) | 0) == 0) {
    $225 = _psi_write($fp, $131, $__i19) | 0; //@line 41036
    _free($131); //@line 41037
    if (($225 | 0) == 0) {
     break;
    } else {
     $_0 = 1; //@line 41043
    }
    STACKTOP = sp; //@line 41046
    return $_0 | 0; //@line 41047
   } else {
    _free($131); //@line 41049
    $_0 = 1; //@line 41051
    STACKTOP = sp; //@line 41053
    return $_0 | 0; //@line 41054
   }
  }
 } while (0);
 $226 = HEAP16[$2 >> 1] | 0; //@line 41058
 L18088 : do {
  if ($226 << 16 >> 16 != 0) {
   $228 = $img + 4 | 0; //@line 41063
   $229 = $buf_i36 | 0; //@line 41064
   $230 = $buf_i36 + 1 | 0; //@line 41065
   $231 = $buf_i36 + 2 | 0; //@line 41066
   $232 = $buf_i36 + 3 | 0; //@line 41067
   $c_055 = 0;
   $233 = $226;
   L18090 : while (1) {
    $236 = HEAP32[(HEAP32[$228 >> 2] | 0) + ($c_055 << 2) >> 2] | 0; //@line 41075
    $237 = $236 + 2 | 0; //@line 41076
    if ((HEAP16[$237 >> 1] | 0) == 0) {
     $483 = $233; //@line 41081
    } else {
     $240 = $236 + 4 | 0; //@line 41083
     $241 = $c_055 & 255; //@line 41084
     $243 = $c_055 << 8 & 65280; //@line 41086
     $h_054 = 0; //@line 41088
     do {
      $247 = HEAP32[(HEAP32[$240 >> 2] | 0) + ($h_054 << 2) >> 2] | 0; //@line 41093
      $248 = $247 + 2 | 0; //@line 41094
      $249 = HEAP16[$248 >> 1] | 0; //@line 41095
      HEAP8[$229] = $249 & 255; //@line 41097
      HEAP8[$230] = $241; //@line 41098
      HEAP8[$231] = $h_054 & 255; //@line 41100
      $252 = $249 & 255; //@line 41102
      $255 = $252 << 9; //@line 41105
      $_2_i_i37 = ($252 & 128 | 0) == 0 ? $255 : $255 ^ 41111; //@line 41107
      $259 = $_2_i_i37 << 1; //@line 41110
      $_2_1_i_i38 = ($_2_i_i37 & 32768 | 0) == 0 ? $259 : $259 ^ 41111; //@line 41112
      $263 = $_2_1_i_i38 << 1; //@line 41115
      $_2_2_i_i39 = ($_2_1_i_i38 & 32768 | 0) == 0 ? $263 : $263 ^ 41111; //@line 41117
      $267 = $_2_2_i_i39 << 1; //@line 41120
      $_2_3_i_i40 = ($_2_2_i_i39 & 32768 | 0) == 0 ? $267 : $267 ^ 41111; //@line 41122
      $271 = $_2_3_i_i40 << 1; //@line 41125
      $_2_4_i_i41 = ($_2_3_i_i40 & 32768 | 0) == 0 ? $271 : $271 ^ 41111; //@line 41127
      $275 = $_2_4_i_i41 << 1; //@line 41130
      $_2_5_i_i42 = ($_2_4_i_i41 & 32768 | 0) == 0 ? $275 : $275 ^ 41111; //@line 41132
      $279 = $_2_5_i_i42 << 1; //@line 41135
      $_2_6_i_i43 = ($_2_5_i_i42 & 32768 | 0) == 0 ? $279 : $279 ^ 41111; //@line 41137
      $283 = $_2_6_i_i43 << 1; //@line 41140
      $285 = (($_2_6_i_i43 & 32768 | 0) == 0 ? $283 : $283 ^ 41111) ^ $243; //@line 41143
      $288 = $285 << 1; //@line 41146
      $_2_i_1_i = ($285 & 32768 | 0) == 0 ? $288 : $288 ^ 41111; //@line 41148
      $292 = $_2_i_1_i << 1; //@line 41151
      $_2_1_i_1_i = ($_2_i_1_i & 32768 | 0) == 0 ? $292 : $292 ^ 41111; //@line 41153
      $296 = $_2_1_i_1_i << 1; //@line 41156
      $_2_2_i_1_i = ($_2_1_i_1_i & 32768 | 0) == 0 ? $296 : $296 ^ 41111; //@line 41158
      $300 = $_2_2_i_1_i << 1; //@line 41161
      $_2_3_i_1_i = ($_2_2_i_1_i & 32768 | 0) == 0 ? $300 : $300 ^ 41111; //@line 41163
      $304 = $_2_3_i_1_i << 1; //@line 41166
      $_2_4_i_1_i = ($_2_3_i_1_i & 32768 | 0) == 0 ? $304 : $304 ^ 41111; //@line 41168
      $308 = $_2_4_i_1_i << 1; //@line 41171
      $_2_5_i_1_i = ($_2_4_i_1_i & 32768 | 0) == 0 ? $308 : $308 ^ 41111; //@line 41173
      $312 = $_2_5_i_1_i << 1; //@line 41176
      $_2_6_i_1_i = ($_2_5_i_1_i & 32768 | 0) == 0 ? $312 : $312 ^ 41111; //@line 41178
      $316 = $_2_6_i_1_i << 1; //@line 41181
      $320 = (($_2_6_i_1_i & 32768 | 0) == 0 ? $316 : $316 ^ 41111) ^ $h_054 << 8 & 65280; //@line 41186
      $323 = $320 << 1; //@line 41189
      $_2_i_2_i = ($320 & 32768 | 0) == 0 ? $323 : $323 ^ 41111; //@line 41191
      $327 = $_2_i_2_i << 1; //@line 41194
      $_2_1_i_2_i = ($_2_i_2_i & 32768 | 0) == 0 ? $327 : $327 ^ 41111; //@line 41196
      $331 = $_2_1_i_2_i << 1; //@line 41199
      $_2_2_i_2_i = ($_2_1_i_2_i & 32768 | 0) == 0 ? $331 : $331 ^ 41111; //@line 41201
      $335 = $_2_2_i_2_i << 1; //@line 41204
      $_2_3_i_2_i = ($_2_2_i_2_i & 32768 | 0) == 0 ? $335 : $335 ^ 41111; //@line 41206
      $339 = $_2_3_i_2_i << 1; //@line 41209
      $_2_4_i_2_i = ($_2_3_i_2_i & 32768 | 0) == 0 ? $339 : $339 ^ 41111; //@line 41211
      $343 = $_2_4_i_2_i << 1; //@line 41214
      $_2_5_i_2_i = ($_2_4_i_2_i & 32768 | 0) == 0 ? $343 : $343 ^ 41111; //@line 41216
      $347 = $_2_5_i_2_i << 1; //@line 41219
      $_2_6_i_2_i = ($_2_5_i_2_i & 32768 | 0) == 0 ? $347 : $347 ^ 41111; //@line 41221
      $351 = $_2_6_i_2_i << 1; //@line 41224
      HEAP8[$232] = (($_2_6_i_2_i & 32768 | 0) == 0 ? $351 : $351 ^ 151) & 255; //@line 41228
      if ((_psi_write($fp, $229, 4) | 0) != 0) {
       $_0 = 1; //@line 41233
       label = 14252; //@line 41234
       break L18090;
      }
      $356 = $247 + 4 | 0; //@line 41237
      if ((HEAP16[$248 >> 1] | 0) != 0) {
       $s_014_i = 0; //@line 41242
       do {
        $361 = HEAP32[(HEAP32[$356 >> 2] | 0) + ($s_014_i << 2) >> 2] | 0; //@line 41247
        $362 = $361 + 10 | 0; //@line 41248
        $364 = HEAPU16[$362 >> 1] | 0; //@line 41250
        if (($364 + 65535 & $364 | 0) != 0) {
         $_0 = 1; //@line 41256
         label = 14247; //@line 41257
         break L18090;
        }
        HEAP8[$1] = HEAP16[$361 + 4 >> 1] & 255; //@line 41263
        HEAP8[$54] = HEAP16[$361 + 6 >> 1] & 255; //@line 41267
        HEAP8[$55] = HEAP16[$361 + 8 >> 1] & 255; //@line 41271
        HEAP8[$56] = (_psi_sct_get_mfm_size($361) | 0) & 255; //@line 41274
        HEAP8[$57] = 0; //@line 41275
        $381 = HEAP32[$361 + 12 >> 2] | 0; //@line 41277
        if (($381 & 2 | 0) == 0) {
         $386 = 4; //@line 41282
        } else {
         HEAP8[$57] = 2; //@line 41284
         $386 = 6; //@line 41286
        }
        if (($381 & 4 | 0) != 0) {
         HEAP8[$57] = $386; //@line 41293
        }
        $391 = $361 + 24 | 0; //@line 41296
        $392 = HEAP16[$362 >> 1] | 0; //@line 41297
        if ($392 << 16 >> 16 == 0) {
         $_09_lcssa_i_off0_i_i = 0; //@line 41301
        } else {
         $_0912_i_i_i = 0;
         $_013_i_i_i = $392 & 65535;
         $tmp_014_i_i_i = HEAP32[$391 >> 2] | 0;
         while (1) {
          $399 = HEAPU8[$tmp_014_i_i_i] << 8 ^ $_0912_i_i_i; //@line 41314
          $402 = $399 << 1; //@line 41317
          $_2_i_i_i = ($399 & 32768 | 0) == 0 ? $402 : $402 ^ 41111; //@line 41319
          $406 = $_2_i_i_i << 1; //@line 41322
          $_2_1_i_i_i = ($_2_i_i_i & 32768 | 0) == 0 ? $406 : $406 ^ 41111; //@line 41324
          $410 = $_2_1_i_i_i << 1; //@line 41327
          $_2_2_i_i_i = ($_2_1_i_i_i & 32768 | 0) == 0 ? $410 : $410 ^ 41111; //@line 41329
          $414 = $_2_2_i_i_i << 1; //@line 41332
          $_2_3_i_i_i = ($_2_2_i_i_i & 32768 | 0) == 0 ? $414 : $414 ^ 41111; //@line 41334
          $418 = $_2_3_i_i_i << 1; //@line 41337
          $_2_4_i_i_i = ($_2_3_i_i_i & 32768 | 0) == 0 ? $418 : $418 ^ 41111; //@line 41339
          $422 = $_2_4_i_i_i << 1; //@line 41342
          $_2_5_i_i_i = ($_2_4_i_i_i & 32768 | 0) == 0 ? $422 : $422 ^ 41111; //@line 41344
          $426 = $_2_5_i_i_i << 1; //@line 41347
          $_2_6_i_i_i = ($_2_5_i_i_i & 32768 | 0) == 0 ? $426 : $426 ^ 41111; //@line 41349
          $430 = $_2_6_i_i_i << 1; //@line 41352
          $_2_7_i_i_i = ($_2_6_i_i_i & 32768 | 0) == 0 ? $430 : $430 ^ 41111; //@line 41354
          $433 = $_013_i_i_i - 1 | 0; //@line 41356
          if (($433 | 0) == 0) {
           break;
          } else {
           $_0912_i_i_i = $_2_7_i_i_i;
           $_013_i_i_i = $433;
           $tmp_014_i_i_i = $tmp_014_i_i_i + 1 | 0;
          }
         }
         $_09_lcssa_i_off0_i_i = $_2_7_i_i_i & 255; //@line 41366
        }
        HEAP8[$58] = $_09_lcssa_i_off0_i_i; //@line 41369
        if ((_psi_write($fp, $1, 6) | 0) != 0) {
         $_0 = 1; //@line 41374
         label = 14253; //@line 41375
         break L18090;
        }
        L18114 : do {
         if ((HEAPU8[$56] | 0) <= 6) {
          $441 = HEAP16[$362 >> 1] | 0; //@line 41383
          $_pre_i_i = $441 & 65535; //@line 41388
          L18116 : do {
           if (!(($441 & 1) != 0 | ($441 & 65535) < 2)) {
            $i_0_i_i = 2; //@line 41392
            while (1) {
             if ($i_0_i_i >>> 0 >= $_pre_i_i >>> 0) {
              break;
             }
             $447 = HEAP32[$391 >> 2] | 0; //@line 41400
             if ((HEAP8[$447 + $i_0_i_i | 0] | 0) == (HEAP8[$447 + ($i_0_i_i & 1) | 0] | 0)) {
              $i_0_i_i = $i_0_i_i + 1 | 0; //@line 41410
             } else {
              break L18116;
             }
            }
            _psi_set_uint16_le($1, 0, 5); //@line 41415
            HEAP8[$55] = 1; //@line 41416
            _psi_set_uint16_le($1, 3, (HEAPU16[$362 >> 1] | 0) >>> 1); //@line 41420
            $458 = HEAP32[$391 >> 2] | 0; //@line 41421
            HEAP8[$58] = HEAP8[$458] | 0; //@line 41423
            HEAP8[$59] = HEAP8[$458 + 1 | 0] | 0; //@line 41426
            if ((_psi_write($fp, $1, 7) | 0) == 0) {
             break L18114;
            } else {
             $_0 = 1; //@line 41433
             label = 14249; //@line 41434
             break L18090;
            }
           }
          } while (0);
          _psi_set_uint16_le($1, 0, $_pre_i_i + 1 | 0); //@line 41440
          HEAP8[$55] = 0; //@line 41441
          if ((_psi_write($fp, $1, 3) | 0) != 0) {
           $_0 = 1; //@line 41446
           label = 14244; //@line 41447
           break L18090;
          }
          if ((_psi_write($fp, HEAP32[$391 >> 2] | 0, HEAPU16[$362 >> 1] | 0) | 0) != 0) {
           $_0 = 1; //@line 41457
           label = 14250; //@line 41458
           break L18090;
          }
         }
        } while (0);
        $s_014_i = $s_014_i + 1 | 0; //@line 41463
       } while ($s_014_i >>> 0 < (HEAPU16[$248 >> 1] | 0) >>> 0);
      }
      $h_054 = $h_054 + 1 | 0; //@line 41475
     } while ($h_054 >>> 0 < (HEAPU16[$237 >> 1] | 0) >>> 0);
     $483 = HEAP16[$2 >> 1] | 0; //@line 41488
    }
    $484 = $c_055 + 1 | 0; //@line 41491
    if ($484 >>> 0 < ($483 & 65535) >>> 0) {
     $c_055 = $484;
     $233 = $483;
    } else {
     break L18088;
    }
   }
   if ((label | 0) == 14247) {
    STACKTOP = sp; //@line 41503
    return $_0 | 0; //@line 41504
   } else if ((label | 0) == 14244) {
    STACKTOP = sp; //@line 41508
    return $_0 | 0; //@line 41509
   } else if ((label | 0) == 14249) {
    STACKTOP = sp; //@line 41513
    return $_0 | 0; //@line 41514
   } else if ((label | 0) == 14250) {
    STACKTOP = sp; //@line 41518
    return $_0 | 0; //@line 41519
   } else if ((label | 0) == 14252) {
    STACKTOP = sp; //@line 41523
    return $_0 | 0; //@line 41524
   } else if ((label | 0) == 14253) {
    STACKTOP = sp; //@line 41528
    return $_0 | 0; //@line 41529
   }
  }
 } while (0);
 $487 = $buf | 0; //@line 41533
 HEAP8[$487] = -1; //@line 41534
 HEAP8[$buf + 1 | 0] = 0; //@line 41536
 HEAP8[$buf + 2 | 0] = 0; //@line 41538
 HEAP8[$buf + 3 | 0] = 53; //@line 41540
 if ((_psi_write($fp, $487, 4) | 0) != 0) {
  $_0 = 1; //@line 41545
  STACKTOP = sp; //@line 41547
  return $_0 | 0; //@line 41548
 }
 _fflush($fp | 0) | 0; //@line 41550
 $_0 = 0; //@line 41552
 STACKTOP = sp; //@line 41554
 return $_0 | 0; //@line 41555
}
function _psi_get_uint16_be($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (HEAPU8[$buf + $idx | 0] | 0) << 8 | (HEAPU8[$buf + ($idx + 1) | 0] | 0) | 0; //@line 41576
}
function _psi_get_uint32_be($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (((HEAPU8[$buf + $idx | 0] | 0) << 8 | (HEAPU8[$buf + ($idx + 1) | 0] | 0)) << 8 | (HEAPU8[$buf + ($idx + 2) | 0] | 0)) << 8 | (HEAPU8[$buf + ($idx + 3) | 0] | 0) | 0; //@line 41610
}
function _psi_set_uint16_be($buf, $idx, $val) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 $val = $val | 0;
 HEAP8[$buf + $idx | 0] = $val >>> 8 & 255; //@line 41624
 HEAP8[$buf + ($idx + 1) | 0] = $val & 255; //@line 41628
 return;
}
function _psi_set_uint32_be($buf, $idx, $val) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 $val = $val | 0;
 HEAP8[$buf + $idx | 0] = $val >>> 24 & 255; //@line 41645
 HEAP8[$buf + ($idx + 1) | 0] = $val >>> 16 & 255; //@line 41650
 HEAP8[$buf + ($idx + 2) | 0] = $val >>> 8 & 255; //@line 41655
 HEAP8[$buf + ($idx + 3) | 0] = $val & 255; //@line 41659
 return;
}
function _psi_get_uint16_le($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (HEAPU8[$buf + ($idx + 1) | 0] | 0) << 8 | (HEAPU8[$buf + $idx | 0] | 0) | 0; //@line 41682
}
function _psi_get_uint32_le($buf, $idx) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 return (((HEAPU8[$buf + ($idx + 3) | 0] | 0) << 8 | (HEAPU8[$buf + ($idx + 2) | 0] | 0)) << 8 | (HEAPU8[$buf + ($idx + 1) | 0] | 0)) << 8 | (HEAPU8[$buf + $idx | 0] | 0) | 0; //@line 41716
}
function _psi_set_uint16_le($buf, $idx, $val) {
 $buf = $buf | 0;
 $idx = $idx | 0;
 $val = $val | 0;
 HEAP8[$buf + $idx | 0] = $val & 255; //@line 41729
 HEAP8[$buf + ($idx + 1) | 0] = $val >>> 8 & 255; //@line 41734
 return;
}
function _snd_iir2_filter($iir, $dst, $src, $cnt, $ofs, $sign) {
 $iir = $iir | 0;
 $dst = $dst | 0;
 $src = $src | 0;
 $cnt = $cnt | 0;
 $ofs = $ofs | 0;
 $sign = $sign | 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $_047 = 0, $_04146 = 0, $_04245 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $31 = 0, $33 = 0, $37 = 0, $38 = 0, $v_0_off0 = 0, $47 = 0;
 if (($cnt | 0) == 0) {
  return;
 }
 $3 = ($sign | 0) != 0 ? 32768 : 0; //@line 41763
 $4 = $iir + 28 | 0; //@line 41764
 $5 = $iir + 32 | 0; //@line 41765
 $6 = $iir + 24 | 0; //@line 41766
 $7 = $iir + 40 | 0; //@line 41767
 $8 = $iir + 44 | 0; //@line 41768
 $9 = $iir + 36 | 0; //@line 41769
 $10 = $iir | 0; //@line 41770
 $11 = $iir + 4 | 0; //@line 41771
 $12 = $iir + 8 | 0; //@line 41772
 $13 = $iir + 16 | 0; //@line 41773
 $14 = $iir + 20 | 0; //@line 41774
 $_04245 = $cnt;
 $_04146 = $src;
 $_047 = $dst;
 while (1) {
  $19 = ((HEAPU16[$_04146 >> 1] | 0) ^ $3) - 32768 | 0; //@line 41784
  $20 = HEAP32[$4 >> 2] | 0; //@line 41785
  HEAP32[$5 >> 2] = $20; //@line 41786
  $21 = HEAP32[$6 >> 2] | 0; //@line 41787
  HEAP32[$4 >> 2] = $21; //@line 41788
  HEAP32[$6 >> 2] = $19; //@line 41789
  $22 = HEAP32[$7 >> 2] | 0; //@line 41790
  HEAP32[$8 >> 2] = $22; //@line 41791
  $23 = HEAP32[$9 >> 2] | 0; //@line 41792
  HEAP32[$7 >> 2] = $23; //@line 41793
  $25 = Math_imul($19, HEAP32[$10 >> 2] | 0) | 0; //@line 41795
  $27 = Math_imul($21, HEAP32[$11 >> 2] | 0) | 0; //@line 41797
  $31 = $27 + $25 + (Math_imul($20, HEAP32[$12 >> 2] | 0) | 0) | 0; //@line 41801
  $33 = Math_imul($23, HEAP32[$13 >> 2] | 0) | 0; //@line 41803
  $37 = ($31 - $33 - (Math_imul($22, HEAP32[$14 >> 2] | 0) | 0) | 0) / 8192 | 0; //@line 41808
  HEAP32[$9 >> 2] = $37; //@line 41809
  $38 = $37 + 32768 | 0; //@line 41810
  if (($38 | 0) < 0) {
   $v_0_off0 = 0; //@line 41814
  } else {
   $v_0_off0 = ($38 | 0) > 65535 ? 65535 : $38 & 65535; //@line 41820
  }
  HEAP16[$_047 >> 1] = ($v_0_off0 ^ $3) & 65535; //@line 41825
  $47 = $_04245 - 1 | 0; //@line 41828
  if (($47 | 0) == 0) {
   break;
  } else {
   $_04245 = $47;
   $_04146 = $_04146 + ($ofs << 1) | 0;
   $_047 = $_047 + ($ofs << 1) | 0;
  }
 }
 return;
}
function _snd_set_buf($dst, $src, $cnt, $sign, $be) {
 $dst = $dst | 0;
 $src = $src | 0;
 $cnt = $cnt | 0;
 $sign = $sign | 0;
 $be = $be | 0;
 var $2 = 0, $4 = 0, $_030 = 0, $i_029 = 0, $_02128 = 0, $6 = 0, $13 = 0, $_125 = 0, $i_124 = 0, $_12223 = 0, $16 = 0, $23 = 0;
 $2 = ($sign | 0) != 0 ? -32768 : 0; //@line 41855
 $4 = ($cnt | 0) == 0; //@line 41857
 if (($be | 0) == 0) {
  if ($4) {
   return;
  } else {
   $_12223 = $src;
   $i_124 = 0;
   $_125 = $dst;
  }
  while (1) {
   $16 = HEAP16[$_12223 >> 1] ^ $2; //@line 41872
   HEAP8[$_125] = $16 & 255; //@line 41874
   HEAP8[$_125 + 1 | 0] = ($16 & 65535) >>> 8 & 255; //@line 41878
   $23 = $i_124 + 1 | 0; //@line 41881
   if ($23 >>> 0 < $cnt >>> 0) {
    $_12223 = $_12223 + 2 | 0;
    $i_124 = $23;
    $_125 = $_125 + 2 | 0;
   } else {
    break;
   }
  }
  return;
 } else {
  if ($4) {
   return;
  } else {
   $_02128 = $src;
   $i_029 = 0;
   $_030 = $dst;
  }
  while (1) {
   $6 = HEAP16[$_02128 >> 1] ^ $2; //@line 41905
   HEAP8[$_030] = ($6 & 65535) >>> 8 & 255; //@line 41908
   HEAP8[$_030 + 1 | 0] = $6 & 255; //@line 41911
   $13 = $i_029 + 1 | 0; //@line 41914
   if ($13 >>> 0 < $cnt >>> 0) {
    $_02128 = $_02128 + 2 | 0;
    $i_029 = $13;
    $_030 = $_030 + 2 | 0;
   } else {
    break;
   }
  }
  return;
 }
}
function _psi_probe_td0_fp($fp) {
 $fp = $fp | 0;
 var $buf = 0, $4 = 0, $8 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 41935
 STACKTOP = STACKTOP + 16 | 0; //@line 41935
 $buf = sp | 0; //@line 41936
 do {
  if ((_fseek($fp | 0, 0, 0) | 0) == 0) {
   $4 = $buf | 0; //@line 41942
   if ((_psi_read($fp, $4, 16) | 0) != 0) {
    $_0 = 0; //@line 41947
    break;
   }
   $8 = HEAP8[$4] | 0; //@line 41950
   if (($8 << 24 >> 24 | 0) == 84) {
    if ((HEAP8[$buf + 1 | 0] | 0) != 68) {
     $_0 = 0; //@line 41957
     break;
    }
   } else if (($8 << 24 >> 24 | 0) == 116) {
    if ((HEAP8[$buf + 1 | 0] | 0) != 100) {
     $_0 = 0; //@line 41966
     break;
    }
   } else {
    $_0 = 0; //@line 41970
    break;
   }
   $_0 = (HEAP8[$buf + 2 | 0] | 0) == 0 | 0; //@line 41978
  } else {
   $_0 = 0; //@line 41980
  }
 } while (0);
 STACKTOP = sp; //@line 41984
 return $_0 | 0; //@line 41985
}
function _psi_load_xdf($fp) {
 $fp = $fp | 0;
 var $1 = 0, $i_0_i = 0, $6 = 0, $10 = 0, $11 = 0, $17 = 0, $ofs_07_i = 0, $j_06_i = 0, $i_1_i = 0, $38 = 0, $42 = 0, $43 = 0, $49 = 0, $66 = 0, $_0 = 0, label = 0;
 $1 = _psi_img_new() | 0; //@line 42002
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 42006
  return $_0 | 0; //@line 42009
 } else {
  $i_0_i = 0; //@line 42011
 }
 while (1) {
  if ($i_0_i >>> 0 >= (HEAP32[96] | 0) >>> 0) {
   label = 14291; //@line 42019
   break;
  }
  $6 = HEAP32[97] | 0; //@line 42022
  $10 = 128 << (HEAPU8[$6 + ($i_0_i << 3) + 2 | 0] | 0); //@line 42026
  $11 = $6 + ($i_0_i << 3) | 0; //@line 42027
  $17 = _psi_sct_new(0, HEAPU8[$11] | 0, HEAPU8[$6 + ($i_0_i << 3) + 1 | 0] | 0, $10) | 0; //@line 42033
  if (($17 | 0) == 0) {
   break;
  }
  _psi_sct_set_encoding($17, 32770); //@line 42039
  if ((_psi_img_add_sector($1, $17, 0, HEAPU8[$11] | 0) | 0) != 0) {
   break;
  }
  if ((_psi_read_ofs($fp, HEAP32[$6 + ($i_0_i << 3) + 4 >> 2] | 0, HEAP32[$17 + 24 >> 2] | 0, $10) | 0) == 0) {
   $i_0_i = $i_0_i + 1 | 0; //@line 42057
  } else {
   break;
  }
 }
 L18187 : do {
  if ((label | 0) == 14291) {
   if ((HEAP32[94] | 0) >>> 0 <= 1) {
    $_0 = $1; //@line 42068
    return $_0 | 0; //@line 42071
   }
   $j_06_i = 1;
   $ofs_07_i = HEAP32[95] | 0;
   while (1) {
    $i_1_i = 0; //@line 42080
    while (1) {
     if ($i_1_i >>> 0 >= (HEAP32[98] | 0) >>> 0) {
      break;
     }
     $38 = HEAP32[99] | 0; //@line 42089
     $42 = 128 << (HEAPU8[$38 + ($i_1_i << 3) + 2 | 0] | 0); //@line 42093
     $43 = $38 + ($i_1_i << 3) | 0; //@line 42094
     $49 = _psi_sct_new($j_06_i, HEAPU8[$43] | 0, HEAPU8[$38 + ($i_1_i << 3) + 1 | 0] | 0, $42) | 0; //@line 42100
     if (($49 | 0) == 0) {
      break L18187;
     }
     _psi_sct_set_encoding($49, 32770); //@line 42106
     if ((_psi_img_add_sector($1, $49, $j_06_i, HEAPU8[$43] | 0) | 0) != 0) {
      break L18187;
     }
     if ((_psi_read_ofs($fp, (HEAP32[$38 + ($i_1_i << 3) + 4 >> 2] | 0) + $ofs_07_i | 0, HEAP32[$49 + 24 >> 2] | 0, $42) | 0) != 0) {
      break L18187;
     }
     $i_1_i = $i_1_i + 1 | 0; //@line 42128
    }
    $66 = $j_06_i + 1 | 0; //@line 42132
    if ($66 >>> 0 < (HEAP32[94] | 0) >>> 0) {
     $j_06_i = $66;
     $ofs_07_i = (HEAP32[95] | 0) + $ofs_07_i | 0;
    } else {
     $_0 = $1; //@line 42139
     break;
    }
   }
   return $_0 | 0; //@line 42145
  }
 } while (0);
 _psi_img_del($1); //@line 42148
 $_0 = 0; //@line 42150
 return $_0 | 0; //@line 42153
}
function _psi_save_xdf($fp, $img) {
 $fp = $fp | 0;
 $img = $img | 0;
 var $i_0_i = 0, $5 = 0, $9 = 0, $16 = 0, $ofs_07_i = 0, $j_06_i = 0, $i_1_i = 0, $37 = 0, $41 = 0, $48 = 0, $65 = 0, $_0_i = 0, label = 0;
 $i_0_i = 0; //@line 42172
 while (1) {
  if ($i_0_i >>> 0 >= (HEAP32[96] | 0) >>> 0) {
   label = 14311; //@line 42179
   break;
  }
  $5 = HEAP32[97] | 0; //@line 42182
  $9 = 128 << (HEAPU8[$5 + ($i_0_i << 3) + 2 | 0] | 0); //@line 42186
  $16 = _psi_img_get_sector($img, 0, HEAPU8[$5 + ($i_0_i << 3) | 0] | 0, HEAPU8[$5 + ($i_0_i << 3) + 1 | 0] | 0, 0) | 0; //@line 42193
  if (($16 | 0) == 0) {
   $_0_i = 1; //@line 42197
   label = 14327; //@line 42198
   break;
  }
  if ((HEAPU16[$16 + 10 >> 1] | 0 | 0) != ($9 | 0)) {
   $_0_i = 1; //@line 42207
   label = 14325; //@line 42208
   break;
  }
  if ((_psi_write_ofs($fp, HEAP32[$5 + ($i_0_i << 3) + 4 >> 2] | 0, HEAP32[$16 + 24 >> 2] | 0, $9) | 0) == 0) {
   $i_0_i = $i_0_i + 1 | 0; //@line 42220
  } else {
   $_0_i = 1; //@line 42222
   label = 14322; //@line 42223
   break;
  }
 }
 if ((label | 0) == 14322) {
  return $_0_i | 0; //@line 42230
 } else if ((label | 0) == 14325) {
  return $_0_i | 0; //@line 42235
 } else if ((label | 0) == 14311) {
  if ((HEAP32[94] | 0) >>> 0 <= 1) {
   $_0_i = 0; //@line 42242
   return $_0_i | 0; //@line 42245
  }
  $j_06_i = 1;
  $ofs_07_i = HEAP32[95] | 0;
  L18217 : while (1) {
   $i_1_i = 0; //@line 42254
   while (1) {
    if ($i_1_i >>> 0 >= (HEAP32[98] | 0) >>> 0) {
     break;
    }
    $37 = HEAP32[99] | 0; //@line 42263
    $41 = 128 << (HEAPU8[$37 + ($i_1_i << 3) + 2 | 0] | 0); //@line 42267
    $48 = _psi_img_get_sector($img, $j_06_i, HEAPU8[$37 + ($i_1_i << 3) | 0] | 0, HEAPU8[$37 + ($i_1_i << 3) + 1 | 0] | 0, 0) | 0; //@line 42274
    if (($48 | 0) == 0) {
     $_0_i = 1; //@line 42278
     label = 14326; //@line 42279
     break L18217;
    }
    if ((HEAPU16[$48 + 10 >> 1] | 0 | 0) != ($41 | 0)) {
     $_0_i = 1; //@line 42288
     label = 14324; //@line 42289
     break L18217;
    }
    if ((_psi_write_ofs($fp, (HEAP32[$37 + ($i_1_i << 3) + 4 >> 2] | 0) + $ofs_07_i | 0, HEAP32[$48 + 24 >> 2] | 0, $41) | 0) != 0) {
     $_0_i = 1; //@line 42301
     label = 14321; //@line 42302
     break L18217;
    }
    $i_1_i = $i_1_i + 1 | 0; //@line 42307
   }
   $65 = $j_06_i + 1 | 0; //@line 42311
   if ($65 >>> 0 < (HEAP32[94] | 0) >>> 0) {
    $j_06_i = $65;
    $ofs_07_i = (HEAP32[95] | 0) + $ofs_07_i | 0;
   } else {
    $_0_i = 0; //@line 42318
    label = 14328; //@line 42319
    break;
   }
  }
  if ((label | 0) == 14326) {
   return $_0_i | 0; //@line 42326
  } else if ((label | 0) == 14324) {
   return $_0_i | 0; //@line 42331
  } else if ((label | 0) == 14321) {
   return $_0_i | 0; //@line 42336
  } else if ((label | 0) == 14328) {
   return $_0_i | 0; //@line 42341
  }
 } else if ((label | 0) == 14327) {
  return $_0_i | 0; //@line 42347
 }
 return 0;
}
function _psi_read($fp, $buf, $cnt) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return (_fread($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 42363
}
function _psi_read_ofs($fp, $ofs, $buf, $cnt) {
 $fp = $fp | 0;
 $ofs = $ofs | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $_0 = 0;
 if ((_fseek($fp | 0, $ofs | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 42379
  return $_0 | 0; //@line 42382
 }
 $_0 = (_fread($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 42388
 return $_0 | 0; //@line 42391
}
function _psi_write($fp, $buf, $cnt) {
 $fp = $fp | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return (_fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 42406
}
function _psi_write_ofs($fp, $ofs, $buf, $cnt) {
 $fp = $fp | 0;
 $ofs = $ofs | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $_0 = 0;
 if ((_fseek($fp | 0, $ofs | 0, 0) | 0) != 0) {
  $_0 = 1; //@line 42422
  return $_0 | 0; //@line 42425
 }
 $_0 = (_fwrite($buf | 0, 1, $cnt | 0, $fp | 0) | 0) != ($cnt | 0) | 0; //@line 42431
 return $_0 | 0; //@line 42434
}
function _psi_skip($fp, $cnt) {
 $fp = $fp | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $_07 = 0, $6 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 42444
 STACKTOP = STACKTOP + 256 | 0; //@line 42444
 $1 = sp | 0; //@line 42446
 $_07 = $cnt; //@line 42448
 while (1) {
  if (($_07 | 0) == 0) {
   $_0 = 0; //@line 42454
   label = 14345; //@line 42455
   break;
  }
  $6 = $_07 >>> 0 < 256 ? $_07 : 256; //@line 42459
  if ((_fread($1 | 0, 1, $6 | 0, $fp | 0) | 0) == ($6 | 0)) {
   $_07 = $_07 - $6 | 0; //@line 42465
  } else {
   $_0 = 1; //@line 42467
   label = 14346; //@line 42468
   break;
  }
 }
 if ((label | 0) == 14346) {
  STACKTOP = sp; //@line 42474
  return $_0 | 0; //@line 42475
 } else if ((label | 0) == 14345) {
  STACKTOP = sp; //@line 42479
  return $_0 | 0; //@line 42480
 }
 return 0;
}
function _snd_iir2_init($iir) {
 $iir = $iir | 0;
 _memset($iir | 0, 0, 48); //@line 42492
 HEAP32[$iir >> 2] = 8192; //@line 42493
 return;
}
function _snd_iir2_reset($iir) {
 $iir = $iir | 0;
 _memset($iir + 24 | 0, 0, 24); //@line 42506
 return;
}
function _snd_iir2_set_lowpass($iir, $freq, $srate) {
 $iir = $iir | 0;
 $freq = $freq | 0;
 $srate = $srate | 0;
 var $1 = 0, $_0 = 0, $17 = 0.0, $20 = 0.0, $22 = 0;
 $1 = $iir | 0; //@line 42523
 _memset($iir | 0, 0, 48); //@line 42525
 HEAP32[$1 >> 2] = 8192; //@line 42526
 if (($freq | 0) == 0 | ($srate | 0) == 0) {
  return;
 }
 if ($freq << 1 >>> 0 < $srate >>> 0) {
  $_0 = $freq; //@line 42539
 } else {
  $_0 = ($srate >>> 1) - 1 | 0; //@line 42544
 }
 $17 = 1.0 / +Math_tan(+(+($_0 >>> 0 >>> 0) * 3.141592653589793 / +($srate >>> 0 >>> 0))); //@line 42552
 $20 = $17 * ($17 + 1.4142135623730951) + 1.0; //@line 42555
 $22 = ~~(8192.0 / $20); //@line 42557
 HEAP32[$1 >> 2] = $22; //@line 42558
 HEAP32[$iir + 4 >> 2] = ~~(16384.0 / $20); //@line 42562
 HEAP32[$iir + 8 >> 2] = $22; //@line 42564
 HEAP32[$iir + 12 >> 2] = 8192; //@line 42566
 HEAP32[$iir + 16 >> 2] = ~~((1.0 - $17 * $17) * 16384.0 / $20); //@line 42573
 HEAP32[$iir + 20 >> 2] = ~~(($17 * ($17 - 1.4142135623730951) + 1.0) * 8192.0 / $20); //@line 42581
 return;
}
function _snd_get_bbuf($sdrv, $cnt) {
 $sdrv = $sdrv | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $4 = 0, $5 = 0, $7 = 0, $_0 = 0;
 $1 = $sdrv + 788 | 0; //@line 42594
 $4 = $sdrv + 792 | 0; //@line 42597
 $5 = HEAP32[$4 >> 2] | 0; //@line 42598
 if ((HEAP32[$1 >> 2] | 0) >>> 0 >= $cnt >>> 0) {
  $_0 = $5; //@line 42601
  return $_0 | 0; //@line 42604
 }
 $7 = _realloc($5, $cnt) | 0; //@line 42606
 if (($7 | 0) == 0) {
  $_0 = 0; //@line 42610
  return $_0 | 0; //@line 42613
 }
 HEAP32[$4 >> 2] = $7; //@line 42615
 HEAP32[$1 >> 2] = $cnt; //@line 42616
 $_0 = $7; //@line 42618
 return $_0 | 0; //@line 42621
}
function _snd_init($sdrv, $ext) {
 $sdrv = $sdrv | 0;
 $ext = $ext | 0;
 HEAP32[$sdrv >> 2] = $ext; //@line 42633
 _memset($sdrv + 4 | 0, 0, 16); //@line 42638
 _memset($sdrv + 788 | 0, 0, 24); //@line 42640
 HEAP8[$sdrv + 812 | 0] = 1; //@line 42641
 HEAP32[$sdrv + 816 >> 2] = 0; //@line 42643
 HEAP32[$sdrv + 820 >> 2] = 0; //@line 42645
 HEAP32[$sdrv + 824 >> 2] = 0; //@line 42647
 return;
}
function _snd_close($sdrv) {
 $sdrv = $sdrv | 0;
 var $4 = 0, $9 = 0, $15 = 0;
 if (($sdrv | 0) == 0) {
  return;
 }
 _snd_wav_close($sdrv); //@line 42665
 $4 = HEAP32[$sdrv + 816 >> 2] | 0; //@line 42667
 if (($4 | 0) != 0) {
  FUNCTION_TABLE_vi[$4 & 1023]($sdrv); //@line 42671
 }
 $9 = HEAP32[$sdrv + 800 >> 2] | 0; //@line 42675
 if (($9 | 0) != 0) {
  _free($9); //@line 42680
 }
 $15 = HEAP32[$sdrv + 792 >> 2] | 0; //@line 42684
 if (($15 | 0) == 0) {
  return;
 }
 _free($15); //@line 42691
 return;
}
function _snd_write($sdrv, $buf, $cnt) {
 $sdrv = $sdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $3 = 0, $11 = 0, $13 = 0, $14 = 0, $17 = 0, $18 = 0, $22 = 0, $25 = 0, $_0_i_i = 0, $27 = 0, $29 = 0, $31 = 0, $i_018_i = 0, $36 = 0, $37 = 0, $_0_i = 0, $40 = 0, $_0 = 0;
 if (($sdrv | 0) == 0) {
  $_0 = 1; //@line 42713
  return $_0 | 0; //@line 42716
 }
 $3 = $sdrv + 820 | 0; //@line 42718
 if ((HEAP32[$3 >> 2] | 0) == 0) {
  $_0 = 1; //@line 42723
  return $_0 | 0; //@line 42726
 }
 do {
  if ((HEAP32[$sdrv + 16 >> 2] | 0) == 0) {
   $_0_i = $buf; //@line 42734
  } else {
   $11 = $sdrv + 4 | 0; //@line 42736
   $13 = Math_imul(HEAP32[$11 >> 2] | 0, $cnt) | 0; //@line 42738
   $14 = $sdrv + 796 | 0; //@line 42739
   $17 = $sdrv + 800 | 0; //@line 42742
   $18 = HEAP32[$17 >> 2] | 0; //@line 42743
   if ((HEAP32[$14 >> 2] | 0) >>> 0 < $13 >>> 0) {
    $22 = _realloc($18, $13 << 1) | 0; //@line 42748
    if (($22 | 0) == 0) {
     $_0_i = 0; //@line 42752
     break;
    }
    $25 = $22; //@line 42755
    HEAP32[$17 >> 2] = $25; //@line 42756
    HEAP32[$14 >> 2] = $13; //@line 42757
    $_0_i_i = $25; //@line 42759
   } else {
    $_0_i_i = $18; //@line 42761
   }
   if (($_0_i_i | 0) == 0) {
    $_0_i = 0; //@line 42767
    break;
   }
   $27 = HEAP32[$11 >> 2] | 0; //@line 42770
   if (($27 | 0) == 0) {
    $_0_i = $_0_i_i; //@line 42774
    break;
   }
   $29 = $sdrv + 12 | 0; //@line 42777
   $i_018_i = 0;
   $31 = $27;
   while (1) {
    _snd_iir2_filter($sdrv + 20 + ($i_018_i * 48 | 0) | 0, $_0_i_i + ($i_018_i << 1) | 0, $buf + ($i_018_i << 1) | 0, $cnt, $31, HEAP32[$29 >> 2] | 0); //@line 42787
    $36 = $i_018_i + 1 | 0; //@line 42788
    $37 = HEAP32[$11 >> 2] | 0; //@line 42789
    if ($36 >>> 0 < $37 >>> 0) {
     $i_018_i = $36;
     $31 = $37;
    } else {
     $_0_i = $_0_i_i; //@line 42795
     break;
    }
   }
  }
 } while (0);
 $40 = FUNCTION_TABLE_iiii[HEAP32[$3 >> 2] & 127]($sdrv, $_0_i, $cnt) | 0; //@line 42803
 _snd_wav_write($sdrv, (HEAP8[$sdrv + 812 | 0] | 0) != 0 ? $_0_i : $buf, $cnt) | 0; //@line 42808
 $_0 = $40; //@line 42810
 return $_0 | 0; //@line 42813
}
function _snd_null_write($sdrv, $buf, $cnt) {
 $sdrv = $sdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 return 0; //@line 42824
}
function _snd_null_set_params($sdrv, $chn, $srate, $sign) {
 $sdrv = $sdrv | 0;
 $chn = $chn | 0;
 $srate = $srate | 0;
 $sign = $sign | 0;
 return 0; //@line 42836
}
function _snd_set_params($sdrv, $chn, $srate, $sign) {
 $sdrv = $sdrv | 0;
 $chn = $chn | 0;
 $srate = $srate | 0;
 $sign = $sign | 0;
 var $4 = 0, $8 = 0, $11 = 0, $24 = 0, $31 = 0, $i_08_i = 0, $33 = 0, $36 = 0, $_0 = 0;
 if (($sdrv | 0) == 0) {
  $_0 = 1; //@line 42855
  return $_0 | 0; //@line 42858
 }
 $4 = HEAP32[$sdrv + 824 >> 2] | 0; //@line 42861
 if (($4 | 0) == 0) {
  $_0 = 1; //@line 42865
  return $_0 | 0; //@line 42868
 }
 $8 = ($sign | 0) != 0 | 0; //@line 42871
 if ($chn >>> 0 > 16) {
  $_0 = 1; //@line 42875
  return $_0 | 0; //@line 42878
 }
 $11 = $sdrv + 4 | 0; //@line 42880
 do {
  if ((HEAP32[$11 >> 2] | 0) == ($chn | 0)) {
   if ((HEAP32[$sdrv + 8 >> 2] | 0) != ($srate | 0)) {
    break;
   }
   if ((HEAP32[$sdrv + 12 >> 2] | 0) == ($8 | 0)) {
    $_0 = 0; //@line 42898
   } else {
    break;
   }
   return $_0 | 0; //@line 42904
  }
 } while (0);
 if ((FUNCTION_TABLE_iiiii[$4 & 127]($sdrv, $chn, $srate, $8) | 0) != 0) {
  $_0 = 1; //@line 42911
  return $_0 | 0; //@line 42914
 }
 HEAP32[$11 >> 2] = $chn; //@line 42916
 $24 = $sdrv + 8 | 0; //@line 42917
 HEAP32[$24 >> 2] = $srate; //@line 42918
 HEAP32[$sdrv + 12 >> 2] = $8; //@line 42920
 if ((_snd_wav_set_params($sdrv, $chn, $srate, $8) | 0) != 0) {
  $_0 = 1; //@line 42925
  return $_0 | 0; //@line 42928
 }
 if ((HEAP32[$11 >> 2] | 0) == 0) {
  $_0 = 0; //@line 42934
  return $_0 | 0; //@line 42937
 }
 $31 = $sdrv + 16 | 0; //@line 42939
 $i_08_i = 0; //@line 42941
 while (1) {
  $33 = $sdrv + 20 + ($i_08_i * 48 | 0) | 0; //@line 42944
  _snd_iir2_set_lowpass($33, HEAP32[$31 >> 2] | 0, HEAP32[$24 >> 2] | 0); //@line 42947
  _snd_iir2_reset($33); //@line 42948
  $36 = $i_08_i + 1 | 0; //@line 42949
  if ($36 >>> 0 < (HEAP32[$11 >> 2] | 0) >>> 0) {
   $i_08_i = $36; //@line 42954
  } else {
   $_0 = 0; //@line 42956
   break;
  }
 }
 return $_0 | 0; //@line 42962
}
function _snd_open($name) {
 $name = $name | 0;
 var $1 = 0, $d_016 = 0, $s_015 = 0, $5 = 0, $6 = 0, $7 = 0, $s_013 = 0, $10 = 0, $i_019_lcssa = 0, $14 = 0, $21 = 0, $26 = 0, $32 = 0, $39 = 0, $40 = 0, $41 = 0, $44 = 0, $45 = 0, $49 = 0, $50 = 0, $52 = 0, $_0 = 0, $55 = 0, $d_016_1 = 0, $s_015_1 = 0, $60 = 0, $61 = 0, $62 = 0, $s_013_1 = 0, $64 = 0, $65 = 0, $d_016_2 = 0, $s_015_2 = 0, $70 = 0, $71 = 0, $72 = 0, $s_013_2 = 0, $74 = 0, label = 0;
 $s_015 = $name;
 $d_016 = 49864;
 $1 = 110;
 while (1) {
  if ($1 << 24 >> 24 != (HEAP8[$s_015] | 0)) {
   label = 14415; //@line 42989
   break;
  }
  $5 = $d_016 + 1 | 0; //@line 42992
  $6 = $s_015 + 1 | 0; //@line 42993
  $7 = HEAP8[$5] | 0; //@line 42994
  if ($7 << 24 >> 24 == 0) {
   $s_013 = $6; //@line 42998
   label = 14416; //@line 42999
   break;
  } else {
   $s_015 = $6;
   $d_016 = $5;
   $1 = $7;
  }
 }
 if ((label | 0) == 14415) {
  if ((HEAP8[$d_016] | 0) == 0) {
   $s_013 = $s_015; //@line 43010
   label = 14416; //@line 43011
  } else {
   $s_015_1 = $name;
   $d_016_1 = 46040;
   $55 = 119;
   label = 14429; //@line 43014
  }
 }
 if ((label | 0) == 14416) {
  $10 = HEAP8[$s_013] | 0; //@line 43019
  if (($10 << 24 >> 24 | 0) == 58 | ($10 << 24 >> 24 | 0) == 0) {
   $i_019_lcssa = 0;
  } else {
   $s_015_1 = $name;
   $d_016_1 = 46040;
   $55 = 119;
   label = 14429; //@line 43024
  }
 }
 do {
  if ((label | 0) == 14429) {
   while (1) {
    label = 0; //@line 43030
    if ($55 << 24 >> 24 != (HEAP8[$s_015_1] | 0)) {
     label = 14430; //@line 43037
     break;
    }
    $60 = $d_016_1 + 1 | 0; //@line 43040
    $61 = $s_015_1 + 1 | 0; //@line 43041
    $62 = HEAP8[$60] | 0; //@line 43042
    if ($62 << 24 >> 24 == 0) {
     $s_013_1 = $61; //@line 43046
     label = 14432; //@line 43047
     break;
    } else {
     $s_015_1 = $61;
     $d_016_1 = $60;
     $55 = $62;
     label = 14429; //@line 43051
    }
   }
   if ((label | 0) == 14430) {
    if ((HEAP8[$d_016_1] | 0) == 0) {
     $s_013_1 = $s_015_1; //@line 43059
     label = 14432; //@line 43060
    } else {
     $s_015_2 = $name;
     $d_016_2 = 42592;
     $65 = 115;
    }
   }
   if ((label | 0) == 14432) {
    $64 = HEAP8[$s_013_1] | 0; //@line 43067
    if (($64 << 24 >> 24 | 0) == 58 | ($64 << 24 >> 24 | 0) == 0) {
     $i_019_lcssa = 1;
     break;
    } else {
     $s_015_2 = $name;
     $d_016_2 = 42592;
     $65 = 115;
    }
   }
   while (1) {
    if ($65 << 24 >> 24 != (HEAP8[$s_015_2] | 0)) {
     label = 14434; //@line 43082
     break;
    }
    $70 = $d_016_2 + 1 | 0; //@line 43085
    $71 = $s_015_2 + 1 | 0; //@line 43086
    $72 = HEAP8[$70] | 0; //@line 43087
    if ($72 << 24 >> 24 == 0) {
     $s_013_2 = $71; //@line 43091
     break;
    } else {
     $s_015_2 = $71;
     $d_016_2 = $70;
     $65 = $72;
    }
   }
   do {
    if ((label | 0) == 14434) {
     if ((HEAP8[$d_016_2] | 0) == 0) {
      $s_013_2 = $s_015_2; //@line 43103
      break;
     } else {
      $_0 = 0; //@line 43106
     }
     return $_0 | 0; //@line 43110
    }
   } while (0);
   $74 = HEAP8[$s_013_2] | 0; //@line 43114
   if (($74 << 24 >> 24 | 0) == 58 | ($74 << 24 >> 24 | 0) == 0) {
    $i_019_lcssa = 2;
    break;
   } else {
    $_0 = 0; //@line 43119
   }
   return $_0 | 0; //@line 43123
  }
 } while (0);
 $14 = FUNCTION_TABLE_ii[HEAP32[29020 + ($i_019_lcssa << 3) >> 2] & 31]($name) | 0; //@line 43129
 if (($14 | 0) == 0) {
  $_0 = 0; //@line 43133
  return $_0 | 0; //@line 43136
 }
 if ((_snd_wav_init($14, $name) | 0) == 0) {
  HEAP8[$14 + 812 | 0] = (_drv_get_option_bool($name, 52128, 1) | 0) & 255; //@line 43145
  $39 = _drv_get_option_uint($name, 56336, 0) | 0; //@line 43146
  $40 = $14 + 16 | 0; //@line 43147
  HEAP32[$40 >> 2] = $39; //@line 43148
  $41 = $14 + 4 | 0; //@line 43149
  if ((HEAP32[$41 >> 2] | 0) == 0) {
   $_0 = $14; //@line 43154
   return $_0 | 0; //@line 43157
  }
  $44 = $14 + 8 | 0; //@line 43159
  $45 = $14 + 20 | 0; //@line 43160
  _snd_iir2_set_lowpass($45, $39, HEAP32[$44 >> 2] | 0); //@line 43162
  _snd_iir2_reset($45); //@line 43163
  if ((HEAP32[$41 >> 2] | 0) >>> 0 > 1) {
   $49 = 1; //@line 43168
  } else {
   $_0 = $14; //@line 43170
   return $_0 | 0; //@line 43173
  }
  while (1) {
   $50 = $14 + 20 + ($49 * 48 | 0) | 0; //@line 43178
   _snd_iir2_set_lowpass($50, HEAP32[$40 >> 2] | 0, HEAP32[$44 >> 2] | 0); //@line 43180
   _snd_iir2_reset($50); //@line 43181
   $52 = $49 + 1 | 0; //@line 43182
   if ($52 >>> 0 < (HEAP32[$41 >> 2] | 0) >>> 0) {
    $49 = $52; //@line 43187
   } else {
    $_0 = $14; //@line 43189
    break;
   }
  }
  return $_0 | 0; //@line 43195
 }
 _snd_wav_close($14); //@line 43197
 $21 = HEAP32[$14 + 816 >> 2] | 0; //@line 43199
 if (($21 | 0) != 0) {
  FUNCTION_TABLE_vi[$21 & 1023]($14); //@line 43203
 }
 $26 = HEAP32[$14 + 800 >> 2] | 0; //@line 43207
 if (($26 | 0) != 0) {
  _free($26); //@line 43212
 }
 $32 = HEAP32[$14 + 792 >> 2] | 0; //@line 43216
 if (($32 | 0) == 0) {
  $_0 = 0; //@line 43220
  return $_0 | 0; //@line 43223
 }
 _free($32); //@line 43225
 $_0 = 0; //@line 43227
 return $_0 | 0; //@line 43230
}
function _snd_null_open($name) {
 $name = $name | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _malloc(828) | 0; //@line 43240
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 43244
  return $_0 | 0; //@line 43247
 }
 $4 = $1; //@line 43249
 _snd_init($4, $1); //@line 43250
 HEAP32[$1 + 816 >> 2] = 464; //@line 43253
 HEAP32[$1 + 820 >> 2] = 26; //@line 43256
 HEAP32[$1 + 824 >> 2] = 40; //@line 43259
 $_0 = $4; //@line 43261
 return $_0 | 0; //@line 43264
}
function _snd_null_close($sdrv) {
 $sdrv = $sdrv | 0;
 _free(HEAP32[$sdrv >> 2] | 0); //@line 43275
 return;
}
function _snd_sdl_open($name) {
 $name = $name | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _malloc(856) | 0; //@line 43287
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 43291
  return $_0 | 0; //@line 43294
 }
 $4 = $1; //@line 43296
 _snd_init($4, $1); //@line 43297
 HEAP32[$1 + 816 >> 2] = 6; //@line 43300
 HEAP32[$1 + 820 >> 2] = 82; //@line 43303
 HEAP32[$1 + 824 >> 2] = 4; //@line 43306
 HEAP8[$1 + 828 | 0] = 0; //@line 43308
 HEAP8[$1 + 829 | 0] = 1; //@line 43310
 _memset($1 + 840 | 0, 0, 16); //@line 43312
 $_0 = $4; //@line 43314
 return $_0 | 0; //@line 43317
}
function _snd_sdl_close($sdrv) {
 $sdrv = $sdrv | 0;
 var $2 = 0, $10 = 0, $_04_i = 0, $13 = 0, $20 = 0, $_04_i4 = 0, $23 = 0;
 $2 = HEAP32[$sdrv >> 2] | 0; //@line 43330
 if ((HEAP8[$2 + 828 | 0] | 0) != 0) {
  _SDL_CloseAudio(); //@line 43336
 }
 $10 = HEAP32[$2 + 844 >> 2] | 0; //@line 43341
 if (($10 | 0) != 0) {
  $_04_i = $10; //@line 43345
  while (1) {
   $13 = HEAP32[$_04_i >> 2] | 0; //@line 43349
   _free(HEAP32[$_04_i + 16 >> 2] | 0); //@line 43352
   _free($_04_i); //@line 43354
   if (($13 | 0) == 0) {
    break;
   } else {
    $_04_i = $13; //@line 43360
   }
  }
 }
 $20 = HEAP32[$2 + 852 >> 2] | 0; //@line 43366
 if (($20 | 0) == 0) {
  _free($2); //@line 43370
  return;
 } else {
  $_04_i4 = $20; //@line 43374
 }
 while (1) {
  $23 = HEAP32[$_04_i4 >> 2] | 0; //@line 43379
  _free(HEAP32[$_04_i4 + 16 >> 2] | 0); //@line 43382
  _free($_04_i4); //@line 43384
  if (($23 | 0) == 0) {
   break;
  } else {
   $_04_i4 = $23; //@line 43390
  }
 }
 _free($2); //@line 43393
 return;
}
function _snd_sdl_write($sdrv, $buf, $cnt) {
 $sdrv = $sdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $2 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $16 = 0, $17 = 0, $20 = 0, $buf_0_i = 0, $31 = 0, $32 = 0, $33 = 0, $37 = 0, $39 = 0, $45 = 0, $64 = 0, $65 = 0, $73 = 0, $_0 = 0, label = 0;
 $2 = HEAP32[$sdrv >> 2] | 0; //@line 43415
 $5 = Math_imul(HEAP32[$sdrv + 4 >> 2] | 0, $cnt) | 0; //@line 43418
 $6 = $5 << 1; //@line 43419
 $8 = $2 + 852 | 0; //@line 43422
 $9 = HEAP32[$8 >> 2] | 0; //@line 43423
 do {
  if (($9 | 0) == 0) {
   $16 = $2 + 840 | 0; //@line 43429
   $17 = HEAP32[$16 >> 2] | 0; //@line 43430
   if ($17 >>> 0 > 32) {
    break;
   }
   $20 = _malloc(20) | 0; //@line 43436
   if (($20 | 0) == 0) {
    break;
   }
   HEAP32[$20 + 12 >> 2] = 0; //@line 43445
   HEAP32[$20 + 16 >> 2] = 0; //@line 43448
   HEAP32[$16 >> 2] = $17 + 1; //@line 43450
   $buf_0_i = $20; //@line 43451
   label = 14470; //@line 43452
  } else {
   HEAP32[$8 >> 2] = HEAP32[$9 >> 2]; //@line 43456
   $buf_0_i = $9; //@line 43458
   label = 14470; //@line 43459
  }
 } while (0);
 L18411 : do {
  if ((label | 0) == 14470) {
   HEAP32[$buf_0_i >> 2] = 0; //@line 43466
   $31 = $buf_0_i + 4 | 0; //@line 43467
   HEAP32[$31 >> 2] = 0; //@line 43468
   $32 = $buf_0_i + 8 | 0; //@line 43469
   HEAP32[$32 >> 2] = 0; //@line 43470
   $33 = $buf_0_i + 12 | 0; //@line 43471
   do {
    if ((HEAP32[$33 >> 2] | 0) >>> 0 < $6 >>> 0) {
     $37 = $buf_0_i + 16 | 0; //@line 43477
     $39 = _realloc(HEAP32[$37 >> 2] | 0, $6) | 0; //@line 43479
     if (($39 | 0) == 0) {
      _free(HEAP32[$37 >> 2] | 0); //@line 43484
      _free($buf_0_i); //@line 43486
      $45 = $2 + 840 | 0; //@line 43488
      HEAP32[$45 >> 2] = (HEAP32[$45 >> 2] | 0) - 1; //@line 43491
      break L18411;
     } else {
      HEAP32[$33 >> 2] = $6; //@line 43495
      HEAP32[$37 >> 2] = $39; //@line 43496
      break;
     }
    }
   } while (0);
   if (($buf_0_i | 0) == 0) {
    $_0 = 1; //@line 43506
    return $_0 | 0; //@line 43509
   }
   _snd_set_buf(HEAP32[$buf_0_i + 16 >> 2] | 0, $buf, $5, (HEAP32[$sdrv + 12 >> 2] | 0) != (HEAP32[$2 + 832 >> 2] | 0) | 0, HEAP32[$2 + 836 >> 2] | 0); //@line 43523
   HEAP32[$31 >> 2] = 0; //@line 43524
   HEAP32[$32 >> 2] = $6; //@line 43525
   $64 = $2 + 848 | 0; //@line 43528
   $65 = HEAP32[$64 >> 2] | 0; //@line 43529
   if (($65 | 0) == 0) {
    HEAP32[$2 + 844 >> 2] = $buf_0_i; //@line 43535
   } else {
    HEAP32[$65 >> 2] = $buf_0_i; //@line 43539
   }
   HEAP32[$64 >> 2] = $buf_0_i; //@line 43541
   $73 = $2 + 829 | 0; //@line 43543
   if ((HEAP8[$73] | 0) == 0) {
    $_0 = 0; //@line 43548
    return $_0 | 0; //@line 43551
   }
   _SDL_PauseAudio(0); //@line 43553
   HEAP8[$73] = 0; //@line 43554
   $_0 = 0; //@line 43556
   return $_0 | 0; //@line 43559
  }
 } while (0);
 $_0 = 1; //@line 43564
 return $_0 | 0; //@line 43567
}
function _snd_sdl_set_params($sdrv, $chn, $srate, $sign) {
 $sdrv = $sdrv | 0;
 $chn = $chn | 0;
 $srate = $srate | 0;
 $sign = $sign | 0;
 var $req = 0, $2 = 0, $9 = 0, $10 = 0, $13 = 0, $28 = 0, $29 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 43581
 STACKTOP = STACKTOP + 24 | 0; //@line 43581
 $req = sp | 0; //@line 43582
 $2 = HEAP32[$sdrv >> 2] | 0; //@line 43584
 do {
  if ((_SDL_WasInit(16) | 0) == 0) {
   if ((_SDL_InitSubSystem(16) | 0) >= 0) {
    break;
   }
   $9 = HEAP32[_stderr >> 2] | 0; //@line 43596
   $10 = _SDL_GetError() | 0; //@line 43597
   _fprintf($9 | 0, 52048, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $10, tempInt) | 0) | 0; //@line 43598
   $_0 = 1; //@line 43600
   STACKTOP = sp; //@line 43602
   return $_0 | 0; //@line 43603
  }
 } while (0);
 $13 = $2 + 828 | 0; //@line 43606
 if ((HEAP8[$13] | 0) != 0) {
  _SDL_CloseAudio(); //@line 43611
  HEAP8[$13] = 0; //@line 43612
 }
 HEAP32[$req >> 2] = $srate; //@line 43616
 HEAP16[$req + 4 >> 1] = -32752; //@line 43618
 HEAP8[$req + 6 | 0] = $chn & 255; //@line 43621
 HEAP16[$req + 8 >> 1] = 1024; //@line 43623
 HEAP32[$req + 16 >> 2] = 8; //@line 43625
 HEAP32[$req + 20 >> 2] = $2; //@line 43627
 if ((_SDL_OpenAudio($req | 0, 0) | 0) < 0) {
  $28 = HEAP32[_stderr >> 2] | 0; //@line 43632
  $29 = _SDL_GetError() | 0; //@line 43633
  _fprintf($28 | 0, 56296, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $29, tempInt) | 0) | 0; //@line 43634
  $_0 = 1; //@line 43636
  STACKTOP = sp; //@line 43638
  return $_0 | 0; //@line 43639
 } else {
  _SDL_PauseAudio(1); //@line 43641
  HEAP8[$13] = 1; //@line 43642
  HEAP8[$2 + 829 | 0] = 1; //@line 43644
  HEAP32[$2 + 832 >> 2] = 1; //@line 43647
  HEAP32[$2 + 836 >> 2] = 0; //@line 43650
  $_0 = 0; //@line 43652
  STACKTOP = sp; //@line 43654
  return $_0 | 0; //@line 43655
 }
 return 0;
}
function _snd_sdl_callback($user, $buf, $cnt) {
 $user = $user | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $2 = 0, $3 = 0, $7 = 0, $9 = 0, $16 = 0, $17 = 0, $18 = 0, $22 = 0, $25 = 0, $26 = 0, $27 = 0, $32 = 0, $_0_ph37 = 0, $_028_ph36 = 0, label = 0;
 $2 = $user + 844 | 0; //@line 43672
 $3 = HEAP32[$2 >> 2] | 0; //@line 43673
 if (($3 | 0) == 0) {
  _SDL_PauseAudio(1); //@line 43677
  HEAP8[$user + 829 | 0] = 1; //@line 43679
  return;
 }
 if (($cnt | 0) <= 0) {
  return;
 }
 $7 = $user + 848 | 0; //@line 43691
 $9 = $user + 852 | 0; //@line 43693
 $_028_ph36 = $cnt;
 $_0_ph37 = $buf;
 $32 = $3;
 while (1) {
  if (($32 | 0) == 0) {
   label = 14502; //@line 43703
   break;
  }
  $16 = $32 + 4 | 0; //@line 43708
  $17 = HEAP32[$16 >> 2] | 0; //@line 43709
  $18 = (HEAP32[$32 + 8 >> 2] | 0) - $17 | 0; //@line 43710
  $22 = (HEAP32[$32 + 16 >> 2] | 0) + $17 | 0; //@line 43714
  if (($18 | 0) > ($_028_ph36 | 0)) {
   label = 14509; //@line 43717
   break;
  }
  _memcpy($_0_ph37 | 0, $22 | 0, $18) | 0; //@line 43720
  $25 = $_028_ph36 - $18 | 0; //@line 43722
  $26 = $32 | 0; //@line 43723
  $27 = HEAP32[$26 >> 2] | 0; //@line 43724
  HEAP32[$2 >> 2] = $27; //@line 43725
  if (($27 | 0) == 0) {
   HEAP32[$7 >> 2] = 0; //@line 43729
  }
  HEAP32[$26 >> 2] = HEAP32[$9 >> 2]; //@line 43733
  HEAP32[$9 >> 2] = $32; //@line 43734
  if (($25 | 0) <= 0) {
   label = 14514; //@line 43738
   break;
  }
  $_028_ph36 = $25;
  $_0_ph37 = $_0_ph37 + $18 | 0;
  $32 = HEAP32[$2 >> 2] | 0;
 }
 if ((label | 0) == 14509) {
  _memcpy($_0_ph37 | 0, $22 | 0, $_028_ph36) | 0; //@line 43746
  HEAP32[$16 >> 2] = (HEAP32[$16 >> 2] | 0) + $_028_ph36; //@line 43749
  return;
 } else if ((label | 0) == 14502) {
  _memset($_0_ph37 | 0, 0, $_028_ph36 | 0); //@line 43755
  return;
 } else if ((label | 0) == 14514) {
  return;
 }
}
function _snd_wav_close($sdrv) {
 $sdrv = $sdrv | 0;
 if ((HEAP32[$sdrv + 804 >> 2] | 0) == 0) {
  return;
 }
 _snd_wav_write_header($sdrv) | 0; //@line 43780
 return;
}
function _snd_wav_write_header($sdrv) {
 $sdrv = $sdrv | 0;
 var $buf = 0, $1 = 0, $6 = 0, $10 = 0, $11 = 0, $12 = 0, $39 = 0, $46 = 0, $58 = 0, $59 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 43803
 STACKTOP = STACKTOP + 64 | 0; //@line 43803
 $buf = sp | 0; //@line 43804
 $1 = $sdrv + 804 | 0; //@line 43805
 if ((_fseek(HEAP32[$1 >> 2] | 0, 0, 0) | 0) != 0) {
  $_0 = 1; //@line 43811
  STACKTOP = sp; //@line 43813
  return $_0 | 0; //@line 43814
 }
 $6 = $buf | 0; //@line 43816
 HEAP8[$6] = 82; //@line 43817
 HEAP8[$buf + 1 | 0] = 73; //@line 43819
 HEAP8[$buf + 2 | 0] = 70; //@line 43821
 HEAP8[$buf + 3 | 0] = 70; //@line 43823
 $10 = $sdrv + 808 | 0; //@line 43824
 $11 = HEAP32[$10 >> 2] | 0; //@line 43825
 $12 = $11 + 36 | 0; //@line 43826
 HEAP8[$buf + 4 | 0] = $12 & 255; //@line 43829
 HEAP8[$buf + 5 | 0] = $12 >>> 8 & 255; //@line 43833
 HEAP8[$buf + 6 | 0] = $12 >>> 16 & 255; //@line 43837
 HEAP8[$buf + 7 | 0] = $12 >>> 24 & 255; //@line 43841
 HEAP8[$buf + 8 | 0] = 87; //@line 43843
 HEAP8[$buf + 9 | 0] = 65; //@line 43845
 HEAP8[$buf + 10 | 0] = 86; //@line 43847
 HEAP8[$buf + 11 | 0] = 69; //@line 43849
 HEAP8[$buf + 12 | 0] = 102; //@line 43851
 HEAP8[$buf + 13 | 0] = 109; //@line 43853
 HEAP8[$buf + 14 | 0] = 116; //@line 43855
 HEAP8[$buf + 15 | 0] = 32; //@line 43857
 HEAP8[$buf + 16 | 0] = 16; //@line 43859
 HEAP8[$buf + 17 | 0] = 0; //@line 43861
 HEAP8[$buf + 18 | 0] = 0; //@line 43863
 HEAP8[$buf + 19 | 0] = 0; //@line 43865
 HEAP8[$buf + 20 | 0] = 1; //@line 43867
 HEAP8[$buf + 21 | 0] = 0; //@line 43869
 $39 = HEAP32[$sdrv + 4 >> 2] | 0; //@line 43871
 HEAP8[$buf + 22 | 0] = $39 & 255; //@line 43874
 HEAP8[$buf + 23 | 0] = $39 >>> 8 & 255; //@line 43878
 $46 = HEAP32[$sdrv + 8 >> 2] | 0; //@line 43880
 HEAP8[$buf + 24 | 0] = $46 & 255; //@line 43883
 HEAP8[$buf + 25 | 0] = $46 >>> 8 & 255; //@line 43887
 HEAP8[$buf + 26 | 0] = $46 >>> 16 & 255; //@line 43891
 HEAP8[$buf + 27 | 0] = $46 >>> 24 & 255; //@line 43895
 $58 = $39 << 1; //@line 43896
 $59 = Math_imul($58, $46) | 0; //@line 43897
 HEAP8[$buf + 28 | 0] = $59 & 255; //@line 43900
 HEAP8[$buf + 29 | 0] = $59 >>> 8 & 255; //@line 43904
 HEAP8[$buf + 30 | 0] = $59 >>> 16 & 255; //@line 43908
 HEAP8[$buf + 31 | 0] = $59 >>> 24 & 255; //@line 43912
 HEAP8[$buf + 32 | 0] = $58 & 255; //@line 43915
 HEAP8[$buf + 33 | 0] = $39 >>> 7 & 255; //@line 43919
 HEAP8[$buf + 34 | 0] = 16; //@line 43921
 HEAP8[$buf + 35 | 0] = 0; //@line 43923
 HEAP8[$buf + 36 | 0] = 100; //@line 43925
 HEAP8[$buf + 37 | 0] = 97; //@line 43927
 HEAP8[$buf + 38 | 0] = 116; //@line 43929
 HEAP8[$buf + 39 | 0] = 97; //@line 43931
 HEAP8[$buf + 40 | 0] = $11 & 255; //@line 43934
 HEAP8[$buf + 41 | 0] = $11 >>> 8 & 255; //@line 43938
 HEAP8[$buf + 42 | 0] = $11 >>> 16 & 255; //@line 43942
 HEAP8[$buf + 43 | 0] = $11 >>> 24 & 255; //@line 43946
 if ((_fwrite($6 | 0, 1, 44, HEAP32[$1 >> 2] | 0) | 0) != 44) {
  $_0 = 1; //@line 43952
  STACKTOP = sp; //@line 43954
  return $_0 | 0; //@line 43955
 }
 $_0 = (_fseek(HEAP32[$1 >> 2] | 0, (HEAP32[$10 >> 2] | 0) + 44 | 0, 0) | 0) != 0 | 0; //@line 43964
 STACKTOP = sp; //@line 43966
 return $_0 | 0; //@line 43967
}
function _snd_wav_write($sdrv, $buf, $cnt) {
 $sdrv = $sdrv | 0;
 $buf = $buf | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $7 = 0, $8 = 0, $9 = 0, $20 = 0, $_0 = 0;
 $1 = $sdrv + 804 | 0; //@line 43980
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  $_0 = 0; //@line 43985
  return $_0 | 0; //@line 43988
 }
 $7 = Math_imul(HEAP32[$sdrv + 4 >> 2] | 0, $cnt) | 0; //@line 43992
 $8 = $7 << 1; //@line 43993
 $9 = _snd_get_bbuf($sdrv, $8) | 0; //@line 43994
 if (($buf | 0) == 0) {
  $_0 = 1; //@line 43998
  return $_0 | 0; //@line 44001
 }
 _snd_set_buf($9, $buf, $7, (HEAP32[$sdrv + 12 >> 2] | 0) == 0 | 0, 0); //@line 44007
 if ((_fwrite($9 | 0, 1, $8 | 0, HEAP32[$1 >> 2] | 0) | 0) != ($8 | 0)) {
  $_0 = 1; //@line 44013
  return $_0 | 0; //@line 44016
 }
 $20 = $sdrv + 808 | 0; //@line 44018
 HEAP32[$20 >> 2] = (HEAP32[$20 >> 2] | 0) + $8; //@line 44021
 $_0 = 0; //@line 44023
 return $_0 | 0; //@line 44026
}
function _bp_addr_match($bp, $seg, $addr) {
 $bp = $bp | 0;
 $seg = $seg | 0;
 $addr = $addr | 0;
 return (HEAP32[$bp + 28 >> 2] | 0) == (($seg << 4) + $addr | 0) | 0; //@line 44044
}
function _bp_segofs_match($bp, $seg, $addr) {
 $bp = $bp | 0;
 $seg = $seg | 0;
 $addr = $addr | 0;
 var $_0 = 0;
 do {
  if ((HEAP32[$bp + 24 >> 2] | 0) == ($seg | 0)) {
   if ((HEAP32[$bp + 28 >> 2] | 0) == ($addr | 0)) {
    $_0 = 1; //@line 44066
   } else {
    break;
   }
   return $_0 | 0; //@line 44072
  }
 } while (0);
 $_0 = 0; //@line 44076
 return $_0 | 0; //@line 44079
}
function _bps_init($bps) {
 $bps = $bps | 0;
 HEAP32[$bps >> 2] = 0; //@line 44089
 HEAP32[$bps + 4 >> 2] = 0; //@line 44091
 return;
}
function _snd_wav_set_params($sdrv, $chn, $srate, $sign) {
 $sdrv = $sdrv | 0;
 $chn = $chn | 0;
 $srate = $srate | 0;
 $sign = $sign | 0;
 var $_0 = 0;
 if ((HEAP32[$sdrv + 804 >> 2] | 0) == 0) {
  $_0 = 0; //@line 44110
  return $_0 | 0; //@line 44113
 }
 $_0 = (_snd_wav_write_header($sdrv) | 0) != 0 | 0; //@line 44119
 return $_0 | 0; //@line 44122
}
function _snd_wav_init($sdrv, $name) {
 $sdrv = $sdrv | 0;
 $name = $name | 0;
 var $1 = 0, $3 = 0, $_0 = 0;
 $1 = $sdrv + 804 | 0; //@line 44133
 HEAP32[$1 >> 2] = 0; //@line 44134
 HEAP32[$sdrv + 808 >> 2] = 0; //@line 44136
 $3 = _drv_get_option($name, 52016) | 0; //@line 44137
 if (($3 | 0) == 0) {
  $_0 = 0; //@line 44141
  return $_0 | 0; //@line 44144
 }
 if ((HEAP8[$3] | 0) == 0) {
  $_0 = 0; //@line 44150
  return $_0 | 0; //@line 44153
 }
 HEAP32[$1 >> 2] = _fopen($3 | 0, 56288) | 0; //@line 44156
 _free($3); //@line 44157
 $_0 = (HEAP32[$1 >> 2] | 0) == 0 | 0; //@line 44162
 return $_0 | 0; //@line 44165
}
function _drv_get_option($str, $name) {
 $str = $str | 0;
 $name = $name | 0;
 var $2 = 0, $_0627_us = 0, $_0_i_i_us = 0, $5 = 0, $6 = 0, $_0_i16_i_us = 0, $_0_i16_sink_i_us = 0, $7 = 0, $8 = 0, $_0_be_i17_i_us = 0, $10 = 0, $12 = 0, $_06_i_us = 0, $14 = 0, $_0_be_i_us = 0, $20 = 0, $_0627 = 0, $_0_i_i = 0, $24 = 0, $_01024_i21 = 0, $_025_i20 = 0, $28 = 0, $_0_i16_i = 0, $31 = 0, $_0_i16_sink_i = 0, $32 = 0, $33 = 0, $35 = 0, $_0_i16_sink_i_lcssa_lcssa = 0, $n_0_lcssa_i = 0, $38 = 0, $n_040_i = 0, $40 = 0, $_sum17 = 0, $n_0_be_i = 0, $46 = 0, $n_134_i = 0, $48 = 0, $50 = 0, $n_1_lcssa_i = 0, $53 = 0, $56 = 0, $j_031_i = 0, $i_030_i = 0, $58 = 0, $_sum16 = 0, $i_1_i = 0, $67 = 0, $j_0_lcssa_i = 0, $70 = 0, $73 = 0, $_06_i = 0, $75 = 0, $_0_be_i = 0, $81 = 0, $_0 = 0, label = 0;
 if (($str | 0) == 0) {
  $_0 = 0; //@line 44191
  return $_0 | 0; //@line 44194
 }
 $2 = HEAP8[$name] | 0; //@line 44196
 L18517 : do {
  if ($2 << 24 >> 24 == 0) {
   $_0627_us = $str; //@line 44200
   L18546 : while (1) {
    $_0_i_i_us = $_0627_us; //@line 44204
    while (1) {
     $5 = HEAP8[$_0_i_i_us] | 0; //@line 44207
     if (!(($5 << 24 >> 24 | 0) == 32 | ($5 << 24 >> 24 | 0) == 9)) {
      $_0_i16_i_us = $_0_i_i_us;
      $6 = $5;
      break;
     }
     $_0_i_i_us = $_0_i_i_us + 1 | 0; //@line 44213
    }
    while (1) {
     if (($6 << 24 >> 24 | 0) == 61) {
      $_0_i16_sink_i_us = $_0_i16_i_us; //@line 44219
      label = 14563; //@line 44220
      break;
     } else if (!(($6 << 24 >> 24 | 0) == 32 | ($6 << 24 >> 24 | 0) == 9)) {
      break;
     }
     $_0_be_i17_i_us = $_0_i16_i_us + 1 | 0; //@line 44225
     $_0_i16_i_us = $_0_be_i17_i_us;
     $6 = HEAP8[$_0_be_i17_i_us] | 0;
    }
    if ((label | 0) == 14563) {
     while (1) {
      label = 0; //@line 44231
      $7 = $_0_i16_sink_i_us + 1 | 0; //@line 44233
      $8 = HEAP8[$7] | 0; //@line 44234
      if (($8 << 24 >> 24 | 0) == 32 | ($8 << 24 >> 24 | 0) == 9) {
       $_0_i16_sink_i_us = $7;
       label = 14563; //@line 44237
      } else {
       break;
      }
     }
     if (($7 | 0) != 0) {
      $_0_i16_sink_i_lcssa_lcssa = $_0_i16_sink_i_us;
      $35 = $8;
      break L18517;
     }
    }
    $10 = HEAP8[$_0627_us] | 0; //@line 44249
    if ($10 << 24 >> 24 == 0) {
     $_0 = 0; //@line 44253
     label = 14611; //@line 44254
     break;
    } else {
     $_06_i_us = $_0627_us;
     $12 = $10;
    }
    while (1) {
     $14 = $_06_i_us + 1 | 0; //@line 44263
     if ($12 << 24 >> 24 == 58) {
      if ((HEAP8[$14] | 0) != 58) {
       break;
      }
      $_0_be_i_us = $_06_i_us + 2 | 0; //@line 44274
     } else {
      $_0_be_i_us = $14; //@line 44276
     }
     $20 = HEAP8[$_0_be_i_us] | 0; //@line 44279
     if ($20 << 24 >> 24 == 0) {
      $_0 = 0; //@line 44283
      label = 14605; //@line 44284
      break L18546;
     } else {
      $_06_i_us = $_0_be_i_us;
      $12 = $20;
     }
    }
    if (($14 | 0) == 0) {
     $_0 = 0; //@line 44293
     label = 14607; //@line 44294
     break;
    } else {
     $_0627_us = $14; //@line 44297
    }
   }
   if ((label | 0) == 14605) {
    return $_0 | 0; //@line 44303
   } else if ((label | 0) == 14611) {
    return $_0 | 0; //@line 44308
   } else if ((label | 0) == 14607) {
    return $_0 | 0; //@line 44313
   }
  } else {
   $_0627 = $str; //@line 44316
   L18518 : while (1) {
    $_0_i_i = $_0627; //@line 44320
    while (1) {
     $24 = HEAP8[$_0_i_i] | 0; //@line 44323
     if (!(($24 << 24 >> 24 | 0) == 32 | ($24 << 24 >> 24 | 0) == 9)) {
      break;
     }
     $_0_i_i = $_0_i_i + 1 | 0; //@line 44328
    }
    L18524 : do {
     if ($24 << 24 >> 24 == $2 << 24 >> 24) {
      $_025_i20 = $name;
      $_01024_i21 = $_0_i_i;
      while (1) {
       $_01024_i21 = $_01024_i21 + 1 | 0; //@line 44338
       $_025_i20 = $_025_i20 + 1 | 0; //@line 44339
       $28 = HEAP8[$_025_i20] | 0; //@line 44340
       if ($28 << 24 >> 24 == 0) {
        $_0_i16_i = $_01024_i21; //@line 44344
        break;
       }
       if ((HEAP8[$_01024_i21] | 0) != $28 << 24 >> 24) {
        break L18524;
       }
      }
      while (1) {
       $31 = HEAP8[$_0_i16_i] | 0; //@line 44358
       if (($31 << 24 >> 24 | 0) == 61) {
        $_0_i16_sink_i = $_0_i16_i; //@line 44360
        break;
       } else if (!(($31 << 24 >> 24 | 0) == 32 | ($31 << 24 >> 24 | 0) == 9)) {
        break L18524;
       }
       $_0_i16_i = $_0_i16_i + 1 | 0; //@line 44366
      }
      while (1) {
       $32 = $_0_i16_sink_i + 1 | 0; //@line 44370
       $33 = HEAP8[$32] | 0; //@line 44371
       if (($33 << 24 >> 24 | 0) == 32 | ($33 << 24 >> 24 | 0) == 9) {
        $_0_i16_sink_i = $32;
       } else {
        break;
       }
      }
      if (($32 | 0) != 0) {
       $_0_i16_sink_i_lcssa_lcssa = $_0_i16_sink_i;
       $35 = $33;
       break L18517;
      }
     }
    } while (0);
    $70 = HEAP8[$_0627] | 0; //@line 44386
    if ($70 << 24 >> 24 == 0) {
     $_0 = 0; //@line 44390
     label = 14608; //@line 44391
     break;
    } else {
     $_06_i = $_0627;
     $73 = $70;
    }
    while (1) {
     $75 = $_06_i + 1 | 0; //@line 44400
     if ($73 << 24 >> 24 == 58) {
      if ((HEAP8[$75] | 0) != 58) {
       break;
      }
      $_0_be_i = $_06_i + 2 | 0; //@line 44411
     } else {
      $_0_be_i = $75; //@line 44413
     }
     $81 = HEAP8[$_0_be_i] | 0; //@line 44416
     if ($81 << 24 >> 24 == 0) {
      $_0 = 0; //@line 44420
      label = 14610; //@line 44421
      break L18518;
     } else {
      $_06_i = $_0_be_i;
      $73 = $81;
     }
    }
    if (($75 | 0) == 0) {
     $_0 = 0; //@line 44430
     label = 14606; //@line 44431
     break;
    } else {
     $_0627 = $75; //@line 44434
    }
   }
   if ((label | 0) == 14606) {
    return $_0 | 0; //@line 44440
   } else if ((label | 0) == 14608) {
    return $_0 | 0; //@line 44445
   } else if ((label | 0) == 14610) {
    return $_0 | 0; //@line 44450
   }
  }
 } while (0);
 L18571 : do {
  if ($35 << 24 >> 24 == 0) {
   $n_1_lcssa_i = 0; //@line 44460
  } else {
   $n_040_i = 0;
   $38 = $35;
   while (1) {
    $40 = $n_040_i + 1 | 0; //@line 44467
    if ($38 << 24 >> 24 == 58) {
     $_sum17 = $n_040_i + 2 | 0; //@line 44470
     if ((HEAP8[$_0_i16_sink_i_lcssa_lcssa + $_sum17 | 0] | 0) == 58) {
      $n_0_be_i = $_sum17; //@line 44476
     } else {
      $n_0_lcssa_i = $n_040_i; //@line 44478
      break;
     }
    } else {
     $n_0_be_i = $40; //@line 44482
    }
    $46 = HEAP8[$_0_i16_sink_i_lcssa_lcssa + ($n_0_be_i + 1) | 0] | 0; //@line 44487
    if ($46 << 24 >> 24 == 0) {
     $n_0_lcssa_i = $n_0_be_i; //@line 44491
     break;
    } else {
     $n_040_i = $n_0_be_i;
     $38 = $46;
    }
   }
   if (($n_0_lcssa_i | 0) == 0) {
    $n_1_lcssa_i = 0; //@line 44501
    break;
   } else {
    $n_134_i = $n_0_lcssa_i; //@line 44504
   }
   while (1) {
    $48 = $n_134_i - 1 | 0; //@line 44508
    $50 = HEAP8[$_0_i16_sink_i_lcssa_lcssa + $n_134_i | 0] | 0; //@line 44510
    if (!(($50 << 24 >> 24 | 0) == 32 | ($50 << 24 >> 24 | 0) == 9)) {
     $n_1_lcssa_i = $n_134_i; //@line 44512
     break L18571;
    }
    if (($48 | 0) == 0) {
     $n_1_lcssa_i = 0; //@line 44518
     break;
    } else {
     $n_134_i = $48; //@line 44521
    }
   }
  }
 } while (0);
 $53 = _malloc($n_1_lcssa_i + 1 | 0) | 0; //@line 44528
 if (($53 | 0) == 0) {
  $_0 = 0; //@line 44532
  return $_0 | 0; //@line 44535
 }
 L18585 : do {
  if (($n_1_lcssa_i | 0) == 0) {
   $j_0_lcssa_i = 0; //@line 44541
  } else {
   $i_030_i = 0;
   $j_031_i = 0;
   $56 = $35;
   while (1) {
    $58 = $i_030_i + 1 | 0; //@line 44549
    do {
     if ($56 << 24 >> 24 == 58) {
      $_sum16 = $i_030_i + 2 | 0; //@line 44553
      if ((HEAP8[$_0_i16_sink_i_lcssa_lcssa + $_sum16 | 0] | 0) != 58) {
       label = 14594; //@line 44559
       break;
      }
      HEAP8[$53 + $j_031_i | 0] = 58; //@line 44563
      $i_1_i = $_sum16; //@line 44565
     } else {
      label = 14594; //@line 44567
     }
    } while (0);
    if ((label | 0) == 14594) {
     label = 0; //@line 44571
     HEAP8[$53 + $j_031_i | 0] = $56; //@line 44573
     $i_1_i = $58; //@line 44574
    }
    $67 = $j_031_i + 1 | 0; //@line 44577
    if ($i_1_i >>> 0 >= $n_1_lcssa_i >>> 0) {
     $j_0_lcssa_i = $67; //@line 44581
     break L18585;
    }
    $i_030_i = $i_1_i;
    $j_031_i = $67;
    $56 = HEAP8[$_0_i16_sink_i_lcssa_lcssa + ($i_1_i + 1) | 0] | 0;
   }
  }
 } while (0);
 HEAP8[$53 + $j_0_lcssa_i | 0] = 0; //@line 44594
 $_0 = $53; //@line 44596
 return $_0 | 0; //@line 44599
}
function _drv_get_option_bool($str, $name, $def) {
 $str = $str | 0;
 $name = $name | 0;
 $def = $def | 0;
 var $1 = 0, $r_0 = 0, $_0 = 0;
 $1 = _drv_get_option($str, $name) | 0; //@line 44612
 if (($1 | 0) == 0) {
  $_0 = $def; //@line 44616
  return $_0 | 0; //@line 44619
 }
 do {
  if ((_strcmp($1 | 0, 51984) | 0) == 0) {
   $r_0 = 1; //@line 44626
  } else {
   if ((_strcmp($1 | 0, 56280) | 0) == 0) {
    $r_0 = 1; //@line 44632
    break;
   }
   if ((_strcmp($1 | 0, 49840) | 0) == 0) {
    $r_0 = 1; //@line 44639
    break;
   }
   if ((_strcmp($1 | 0, 46e3) | 0) == 0) {
    $r_0 = 0; //@line 44646
    break;
   }
   if ((_strcmp($1 | 0, 42568) | 0) == 0) {
    $r_0 = 0; //@line 44653
    break;
   }
   $r_0 = (_strcmp($1 | 0, 39488) | 0) == 0 ? 0 : $def; //@line 44660
  }
 } while (0);
 _free($1); //@line 44664
 $_0 = $r_0; //@line 44666
 return $_0 | 0; //@line 44669
}
function _drv_get_option_uint($str, $name, $def) {
 $str = $str | 0;
 $name = $name | 0;
 $def = $def | 0;
 var $end = 0, $1 = 0, $4 = 0, $5 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 44680
 STACKTOP = STACKTOP + 8 | 0; //@line 44680
 $end = sp | 0; //@line 44681
 $1 = _drv_get_option($str, $name) | 0; //@line 44682
 if (($1 | 0) == 0) {
  $_0 = $def; //@line 44686
  STACKTOP = sp; //@line 44688
  return $_0 | 0; //@line 44689
 }
 $4 = _strtoul($1 | 0, $end | 0, 0) | 0; //@line 44691
 $5 = HEAP32[$end >> 2] | 0; //@line 44692
 do {
  if (($5 | 0) != 0) {
   if ((HEAP8[$5] | 0) == 0) {
    break;
   }
   _free($1); //@line 44703
   $_0 = $def; //@line 44705
   STACKTOP = sp; //@line 44707
   return $_0 | 0; //@line 44708
  }
 } while (0);
 _free($1); //@line 44711
 $_0 = $4; //@line 44713
 STACKTOP = sp; //@line 44715
 return $_0 | 0; //@line 44716
}
function _drv_get_option_sint($str, $name, $def) {
 $str = $str | 0;
 $name = $name | 0;
 $def = $def | 0;
 var $end = 0, $1 = 0, $4 = 0, $5 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 44727
 STACKTOP = STACKTOP + 8 | 0; //@line 44727
 $end = sp | 0; //@line 44728
 $1 = _drv_get_option($str, $name) | 0; //@line 44729
 if (($1 | 0) == 0) {
  $_0 = $def; //@line 44733
  STACKTOP = sp; //@line 44735
  return $_0 | 0; //@line 44736
 }
 $4 = _strtol($1 | 0, $end | 0, 0) | 0; //@line 44738
 $5 = HEAP32[$end >> 2] | 0; //@line 44739
 do {
  if (($5 | 0) != 0) {
   if ((HEAP8[$5] | 0) == 0) {
    break;
   }
   _free($1); //@line 44750
   $_0 = $def; //@line 44752
   STACKTOP = sp; //@line 44754
   return $_0 | 0; //@line 44755
  }
 } while (0);
 _free($1); //@line 44758
 $_0 = $4; //@line 44760
 STACKTOP = sp; //@line 44762
 return $_0 | 0; //@line 44763
}
function _bp_addr_new($addr) {
 $addr = $addr | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _malloc(36) | 0; //@line 44773
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 44777
  return $_0 | 0; //@line 44780
 }
 HEAP32[$1 >> 2] = 1; //@line 44783
 $4 = $1 + 4 | 0; //@line 44784
 _memset($4 | 0, 0, 20); //@line 44785
 HEAP32[$4 >> 2] = 294; //@line 44788
 HEAP32[$1 + 8 >> 2] = 86; //@line 44791
 HEAP32[$1 + 12 >> 2] = 160; //@line 44794
 HEAP32[$1 + 24 >> 2] = 0; //@line 44797
 HEAP32[$1 + 28 >> 2] = $addr; //@line 44800
 $_0 = $1; //@line 44802
 return $_0 | 0; //@line 44805
}
function _bp_addr_del($bp) {
 $bp = $bp | 0;
 _free($bp); //@line 44815
 return;
}
function _bp_addr_print($bp, $fp) {
 $bp = $bp | 0;
 $fp = $fp | 0;
 var $4 = 0, $6 = 0, sp = 0;
 sp = STACKTOP; //@line 44826
 $4 = HEAP32[$bp + 16 >> 2] | 0; //@line 44830
 $6 = HEAP32[$bp + 20 >> 2] | 0; //@line 44832
 _printf(55968, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$bp + 28 >> 2], HEAP32[tempInt + 8 >> 2] = $4, HEAP32[tempInt + 16 >> 2] = $6, tempInt) | 0) | 0; //@line 44833
 STACKTOP = sp; //@line 44834
 return;
}
function _bp_segofs_del($bp) {
 $bp = $bp | 0;
 _free($bp); //@line 44845
 return;
}
function _bp_segofs_print($bp, $fp) {
 $bp = $bp | 0;
 $fp = $fp | 0;
 var $4 = 0, $6 = 0, $8 = 0, sp = 0;
 sp = STACKTOP; //@line 44857
 $4 = HEAP32[$bp + 28 >> 2] | 0; //@line 44861
 $6 = HEAP32[$bp + 16 >> 2] | 0; //@line 44863
 $8 = HEAP32[$bp + 20 >> 2] | 0; //@line 44865
 _printf(57160, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = HEAP32[$bp + 24 >> 2], HEAP32[tempInt + 8 >> 2] = $4, HEAP32[tempInt + 16 >> 2] = $6, HEAP32[tempInt + 24 >> 2] = $8, tempInt) | 0) | 0; //@line 44866
 STACKTOP = sp; //@line 44867
 return;
}
function _bp_expr_del($bp) {
 $bp = $bp | 0;
 _free(HEAP32[$bp + 32 >> 2] | 0); //@line 44879
 _free($bp); //@line 44881
 return;
}
function _bp_expr_match($bp, $seg, $addr) {
 $bp = $bp | 0;
 $seg = $seg | 0;
 $addr = $addr | 0;
 var $val = 0, $cmd = 0, $4 = 0, sp = 0;
 sp = STACKTOP; //@line 44894
 STACKTOP = STACKTOP + 272 | 0; //@line 44894
 $val = sp | 0; //@line 44895
 $cmd = sp + 8 | 0; //@line 44896
 _cmd_set_str($cmd, HEAP32[$bp + 32 >> 2] | 0); //@line 44899
 $4 = (_cmd_match_uint32($cmd, $val) | 0) != 0; //@line 44901
 STACKTOP = sp; //@line 44906
 return $4 & (HEAP32[$val >> 2] | 0) != 0 & 1 | 0; //@line 44907
}
function _bp_expr_print($bp, $fp) {
 $bp = $bp | 0;
 $fp = $fp | 0;
 var sp = 0;
 sp = STACKTOP; //@line 44916
 _printf(57960, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$bp + 32 >> 2], tempInt) | 0) | 0; //@line 44919
 STACKTOP = sp; //@line 44920
 return;
}
function _bps_bp_add($bps, $bp) {
 $bps = $bps | 0;
 $bp = $bp | 0;
 var $1 = 0, $4 = 0, $8 = 0, $9 = 0, $12 = 0, $_0 = 0;
 $1 = $bps + 4 | 0; //@line 44932
 $4 = $bps | 0; //@line 44935
 $8 = _realloc(HEAP32[$1 >> 2] | 0, (HEAP32[$4 >> 2] << 2) + 4 | 0) | 0; //@line 44939
 $9 = $8; //@line 44940
 if (($8 | 0) == 0) {
  $_0 = 1; //@line 44944
  return $_0 | 0; //@line 44947
 }
 HEAP32[$1 >> 2] = $9; //@line 44949
 $12 = HEAP32[$4 >> 2] | 0; //@line 44950
 HEAP32[$9 + ($12 << 2) >> 2] = $bp; //@line 44952
 HEAP32[$4 >> 2] = $12 + 1; //@line 44954
 $_0 = 0; //@line 44956
 return $_0 | 0; //@line 44959
}
function _bps_check($bps, $seg, $addr, $fp) {
 $bps = $bps | 0;
 $seg = $seg | 0;
 $addr = $addr | 0;
 $fp = $fp | 0;
 var $1 = 0, $4 = 0, $i_013_i = 0, $7 = 0, $9 = 0, $14 = 0, $15 = 0, $18 = 0, $21 = 0, $24 = 0, $29 = 0, $33 = 0, $40 = 0, $i_0_i = 0, $48 = 0, $51 = 0, $56 = 0, $_015_i_i = 0, $_0_in14_i_i = 0, $58 = 0, $_0_i_i = 0, $62 = 0, $_lcssa_i_i = 0, $_0 = 0, label = 0;
 $1 = $bps | 0; //@line 44978
 if ((HEAP32[$1 >> 2] | 0) == 0) {
  $_0 = 0; //@line 44983
  return $_0 | 0; //@line 44986
 }
 $4 = $bps + 4 | 0; //@line 44988
 $i_013_i = 0; //@line 44990
 L18650 : while (1) {
  $7 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($i_013_i << 2) >> 2] | 0; //@line 44995
  $9 = HEAP32[$7 + 8 >> 2] | 0; //@line 44997
  do {
   if (($9 | 0) != 0) {
    if ((FUNCTION_TABLE_iiii[$9 & 127]($7, $seg, $addr) | 0) == 0) {
     break;
    }
    $14 = $7 + 16 | 0; //@line 45008
    $15 = HEAP32[$14 >> 2] | 0; //@line 45009
    if (($15 | 0) == 0) {
     break L18650;
    }
    $18 = $15 - 1 | 0; //@line 45015
    HEAP32[$14 >> 2] = $18; //@line 45016
    if (($18 | 0) == 0) {
     break L18650;
    }
   }
  } while (0);
  $24 = $i_013_i + 1 | 0; //@line 45024
  if ($24 >>> 0 < (HEAP32[$1 >> 2] | 0) >>> 0) {
   $i_013_i = $24; //@line 45029
  } else {
   $_0 = 0; //@line 45031
   label = 14683; //@line 45032
   break;
  }
 }
 if ((label | 0) == 14683) {
  return $_0 | 0; //@line 45039
 }
 $21 = HEAP32[$7 + 20 >> 2] | 0; //@line 45042
 if (($21 | 0) != 0) {
  HEAP32[$14 >> 2] = $21; //@line 45046
 }
 $29 = HEAP32[(HEAP32[$4 >> 2] | 0) + ($i_013_i << 2) >> 2] | 0; //@line 45051
 if (($29 | 0) == 0) {
  $_0 = 0; //@line 45055
  return $_0 | 0; //@line 45058
 }
 $33 = HEAP32[$29 + 12 >> 2] | 0; //@line 45061
 if (($33 | 0) != 0) {
  FUNCTION_TABLE_vii[$33 & 511]($29, $fp); //@line 45065
 }
 if ((HEAP32[$29 + 16 >> 2] | 0) != 0) {
  $_0 = 1; //@line 45073
  return $_0 | 0; //@line 45076
 }
 $40 = HEAP32[$1 >> 2] | 0; //@line 45078
 $i_0_i = 0; //@line 45080
 while (1) {
  if ($i_0_i >>> 0 >= $40 >>> 0) {
   $_0 = 1; //@line 45086
   label = 14687; //@line 45087
   break;
  }
  $48 = $i_0_i + 1 | 0; //@line 45094
  if ((HEAP32[(HEAP32[$4 >> 2] | 0) + ($i_0_i << 2) >> 2] | 0) == ($29 | 0)) {
   break;
  } else {
   $i_0_i = $48; //@line 45099
  }
 }
 if ((label | 0) == 14687) {
  return $_0 | 0; //@line 45105
 }
 $51 = HEAP32[$29 + 4 >> 2] | 0; //@line 45108
 if (($51 | 0) == 0) {
  _free($29); //@line 45113
 } else {
  FUNCTION_TABLE_vi[$51 & 1023]($29); //@line 45115
 }
 $56 = HEAP32[$1 >> 2] | 0; //@line 45118
 if ($48 >>> 0 < $56 >>> 0) {
  $_0_in14_i_i = $i_0_i;
  $_015_i_i = $48;
  while (1) {
   $58 = HEAP32[$4 >> 2] | 0; //@line 45126
   HEAP32[$58 + ($_0_in14_i_i << 2) >> 2] = HEAP32[$58 + ($_015_i_i << 2) >> 2]; //@line 45130
   $_0_i_i = $_015_i_i + 1 | 0; //@line 45131
   $62 = HEAP32[$1 >> 2] | 0; //@line 45132
   if ($_0_i_i >>> 0 < $62 >>> 0) {
    $_0_in14_i_i = $_015_i_i;
    $_015_i_i = $_0_i_i;
   } else {
    $_lcssa_i_i = $62; //@line 45138
    break;
   }
  }
 } else {
  $_lcssa_i_i = $56; //@line 45143
 }
 HEAP32[$1 >> 2] = $_lcssa_i_i - 1; //@line 45147
 $_0 = 1; //@line 45149
 return $_0 | 0; //@line 45152
}
function _cmd_set_str($cmd, $str) {
 $cmd = $cmd | 0;
 $str = $str | 0;
 var $i_0 = 0, $5 = 0, label = 0;
 HEAP32[$cmd >> 2] = 0; //@line 45164
 $i_0 = 0; //@line 45166
 while (1) {
  if ($i_0 >>> 0 >= 256) {
   break;
  }
  $5 = $str + $i_0 | 0; //@line 45174
  HEAP8[$cmd + 4 + $i_0 | 0] = HEAP8[$5] | 0; //@line 45177
  if ((HEAP8[$5] | 0) == 0) {
   label = 14695; //@line 45183
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 45186
  }
 }
 if ((label | 0) == 14695) {
  return;
 }
 HEAP8[$cmd + 259 | 0] = 0; //@line 45194
 return;
}
function _cmd_get_str($cmd) {
 $cmd = $cmd | 0;
 return (HEAP32[$cmd >> 2] | 0) + ($cmd + 4) | 0; //@line 45210
}
function _cmd_do_b($cmd, $bps) {
 $cmd = $cmd | 0;
 $bps = $bps | 0;
 var $idx_i = 0, $addr_i_i = 0, $pass_i3_i = 0, $reset_i4_i = 0, $pass_i_i = 0, $reset_i_i = 0, $expr_i_i = 0, $7 = 0, $8 = 0, $11 = 0, $i_07_i_i = 0, $16 = 0, $18 = 0, $34 = 0, $44 = 0, $47 = 0, $50 = 0, $60 = 0, $_0_i_i_i = 0, $63 = 0, $67 = 0, $71 = 0, $74 = 0, $78 = 0, $79 = 0, $82 = 0, $96 = 0, $isseg_0_i_i = 0, $seg_0_off0_i_i = 0, $107 = 0, $111 = 0, $112 = 0, $113 = 0, $116 = 0, $130 = 0, $bp_0_i_i = 0, $143 = 0, $147 = 0, $151 = 0, $154 = 0, $158 = 0, $159 = 0, $162 = 0, $174 = 0, $175 = 0, $177 = 0, $180 = 0, $181 = 0, $182 = 0, $i_09_i_i = 0, $184 = 0, $186 = 0, $191 = 0, $194 = 0, $_lcssa8_i_i = 0, $198 = 0, $206 = 0, $208 = 0, $_013_i_i = 0, $213 = 0, $_015_i_i = 0, $_0_in14_i_i = 0, $215 = 0, $_0_i_i = 0, $219 = 0, $_lcssa_i_i = 0, sp = 0;
 sp = STACKTOP; //@line 45244
 STACKTOP = STACKTOP + 304 | 0; //@line 45244
 $idx_i = sp | 0; //@line 45245
 $addr_i_i = sp + 8 | 0; //@line 45246
 $pass_i3_i = sp + 16 | 0; //@line 45247
 $reset_i4_i = sp + 24 | 0; //@line 45248
 $pass_i_i = sp + 32 | 0; //@line 45249
 $reset_i_i = sp + 40 | 0; //@line 45250
 $expr_i_i = sp + 48 | 0; //@line 45251
 if ((_cmd_match($cmd, 56264) | 0) != 0) {
  if ((_cmd_match_end($cmd) | 0) == 0) {
   STACKTOP = sp; //@line 45260
   return;
  }
  $7 = HEAP32[_stdout >> 2] | 0; //@line 45263
  $8 = $bps | 0; //@line 45264
  if ((HEAP32[$8 >> 2] | 0) != 0) {
   $11 = $bps + 4 | 0; //@line 45269
   $i_07_i_i = 0; //@line 45271
   do {
    _fprintf($7 | 0, 51936, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $i_07_i_i, tempInt) | 0) | 0; //@line 45274
    $16 = HEAP32[(HEAP32[$11 >> 2] | 0) + ($i_07_i_i << 2) >> 2] | 0; //@line 45277
    $18 = HEAP32[$16 + 12 >> 2] | 0; //@line 45279
    if (($18 | 0) != 0) {
     FUNCTION_TABLE_vii[$18 & 511]($16, $7); //@line 45283
    }
    $i_07_i_i = $i_07_i_i + 1 | 0; //@line 45286
   } while ($i_07_i_i >>> 0 < (HEAP32[$8 >> 2] | 0) >>> 0);
  }
  _fflush($7 | 0) | 0; //@line 45297
  STACKTOP = sp; //@line 45299
  return;
 }
 if ((_cmd_match($cmd, 49824) | 0) == 0) {
  if ((_cmd_match($cmd, 45992) | 0) == 0) {
   _cmd_error($cmd, 42544); //@line 45310
   STACKTOP = sp; //@line 45311
   return;
  }
  if ((_cmd_match_eol($cmd) | 0) != 0) {
   $177 = $bps | 0; //@line 45319
   $180 = $bps + 4 | 0; //@line 45322
   $181 = HEAP32[$180 >> 2] | 0; //@line 45323
   if ((HEAP32[$177 >> 2] | 0) == 0) {
    $_lcssa8_i_i = $181; //@line 45326
   } else {
    $i_09_i_i = 0;
    $182 = $181;
    while (1) {
     $184 = HEAP32[$182 + ($i_09_i_i << 2) >> 2] | 0; //@line 45333
     $186 = HEAP32[$184 + 4 >> 2] | 0; //@line 45335
     if (($186 | 0) == 0) {
      _free($184); //@line 45340
     } else {
      FUNCTION_TABLE_vi[$186 & 1023]($184); //@line 45342
     }
     $191 = $i_09_i_i + 1 | 0; //@line 45345
     $194 = HEAP32[$180 >> 2] | 0; //@line 45348
     if ($191 >>> 0 < (HEAP32[$177 >> 2] | 0) >>> 0) {
      $i_09_i_i = $191;
      $182 = $194;
     } else {
      $_lcssa8_i_i = $194; //@line 45353
      break;
     }
    }
   }
   _free($_lcssa8_i_i); //@line 45360
   HEAP32[$177 >> 2] = 0; //@line 45361
   HEAP32[$180 >> 2] = 0; //@line 45362
   STACKTOP = sp; //@line 45363
   return;
  }
  if ((_cmd_match_uint16($cmd, $idx_i) | 0) != 0) {
   $174 = $bps | 0; //@line 45370
   $175 = $bps + 4 | 0; //@line 45371
   do {
    $198 = HEAPU16[$idx_i >> 1] | 0; //@line 45375
    if ((HEAP32[$174 >> 2] | 0) >>> 0 > $198 >>> 0) {
     $206 = HEAP32[(HEAP32[$175 >> 2] | 0) + ($198 << 2) >> 2] | 0; //@line 45382
     $208 = HEAP32[$206 + 4 >> 2] | 0; //@line 45384
     if (($208 | 0) == 0) {
      _free($206); //@line 45389
     } else {
      FUNCTION_TABLE_vi[$208 & 1023]($206); //@line 45391
     }
     $_013_i_i = $198 + 1 | 0; //@line 45394
     $213 = HEAP32[$174 >> 2] | 0; //@line 45395
     if ($_013_i_i >>> 0 < $213 >>> 0) {
      $_0_in14_i_i = $198;
      $_015_i_i = $_013_i_i;
      while (1) {
       $215 = HEAP32[$175 >> 2] | 0; //@line 45403
       HEAP32[$215 + ($_0_in14_i_i << 2) >> 2] = HEAP32[$215 + ($_015_i_i << 2) >> 2]; //@line 45407
       $_0_i_i = $_015_i_i + 1 | 0; //@line 45408
       $219 = HEAP32[$174 >> 2] | 0; //@line 45409
       if ($_0_i_i >>> 0 < $219 >>> 0) {
        $_0_in14_i_i = $_015_i_i;
        $_015_i_i = $_0_i_i;
       } else {
        $_lcssa_i_i = $219; //@line 45415
        break;
       }
      }
     } else {
      $_lcssa_i_i = $213; //@line 45420
     }
     HEAP32[$174 >> 2] = $_lcssa_i_i - 1; //@line 45424
    }
   } while ((_cmd_match_uint16($cmd, $idx_i) | 0) != 0);
  }
  _cmd_match_end($cmd) | 0; //@line 45435
  STACKTOP = sp; //@line 45436
  return;
 }
 if ((_cmd_match($cmd, 39456) | 0) != 0) {
  $34 = $expr_i_i | 0; //@line 45445
  HEAP16[$pass_i_i >> 1] = 1; //@line 45446
  HEAP16[$reset_i_i >> 1] = 0; //@line 45447
  if ((_cmd_match_str($cmd, $34, 256) | 0) == 0) {
   _cmd_error($cmd, 30784); //@line 45452
   STACKTOP = sp; //@line 45454
   return;
  }
  _cmd_match_uint16($cmd, $pass_i_i) | 0; //@line 45457
  _cmd_match_uint16($cmd, $reset_i_i) | 0; //@line 45458
  if ((_cmd_match_end($cmd) | 0) == 0) {
   STACKTOP = sp; //@line 45463
   return;
  }
  $44 = HEAP16[$pass_i_i >> 1] | 0; //@line 45466
  if ($44 << 16 >> 16 == 0) {
   STACKTOP = sp; //@line 45470
   return;
  }
  $47 = _malloc(36) | 0; //@line 45473
  if (($47 | 0) == 0) {
   $_0_i_i_i = 0;
   $60 = $44;
  } else {
   HEAP32[$47 >> 2] = 3; //@line 45480
   $50 = $47 + 4 | 0; //@line 45481
   _memset($50 | 0, 0, 20); //@line 45482
   HEAP32[$50 >> 2] = 352; //@line 45485
   HEAP32[$47 + 8 >> 2] = 58; //@line 45488
   HEAP32[$47 + 12 >> 2] = 206; //@line 45491
   HEAP32[$47 + 32 >> 2] = _strdup($34 | 0) | 0; //@line 45495
   $_0_i_i_i = $47;
   $60 = HEAP16[$pass_i_i >> 1] | 0;
  }
  $63 = HEAPU16[$reset_i_i >> 1] | 0; //@line 45504
  HEAP32[$_0_i_i_i + 16 >> 2] = $60 & 65535; //@line 45506
  HEAP32[$_0_i_i_i + 20 >> 2] = $63; //@line 45508
  $67 = HEAP32[$_0_i_i_i + 12 >> 2] | 0; //@line 45510
  if (($67 | 0) != 0) {
   FUNCTION_TABLE_vii[$67 & 511]($_0_i_i_i, HEAP32[_stdout >> 2] | 0); //@line 45515
  }
  $71 = $bps + 4 | 0; //@line 45518
  $74 = $bps | 0; //@line 45521
  $78 = _realloc(HEAP32[$71 >> 2] | 0, (HEAP32[$74 >> 2] << 2) + 4 | 0) | 0; //@line 45525
  $79 = $78; //@line 45526
  if (($78 | 0) == 0) {
   STACKTOP = sp; //@line 45530
   return;
  }
  HEAP32[$71 >> 2] = $79; //@line 45533
  $82 = HEAP32[$74 >> 2] | 0; //@line 45534
  HEAP32[$79 + ($82 << 2) >> 2] = $_0_i_i_i; //@line 45536
  HEAP32[$74 >> 2] = $82 + 1; //@line 45538
  STACKTOP = sp; //@line 45540
  return;
 }
 HEAP16[$pass_i3_i >> 1] = 1; //@line 45546
 HEAP16[$reset_i4_i >> 1] = 0; //@line 45547
 HEAP32[$addr_i_i >> 2] = 0; //@line 45548
 if ((_cmd_match_uint32($cmd, $addr_i_i) | 0) == 0) {
  _cmd_error($cmd, 36496); //@line 45553
  STACKTOP = sp; //@line 45555
  return;
 }
 do {
  if ((_cmd_match($cmd, 33544) | 0) == 0) {
   $seg_0_off0_i_i = 0;
   $isseg_0_i_i = 0;
  } else {
   $96 = HEAP32[$addr_i_i >> 2] | 0; //@line 45565
   if ((_cmd_match_uint32($cmd, $addr_i_i) | 0) != 0) {
    $seg_0_off0_i_i = $96 & 65535;
    $isseg_0_i_i = 1;
    break;
   }
   _cmd_error($cmd, 31728); //@line 45575
   STACKTOP = sp; //@line 45577
   return;
  }
 } while (0);
 _cmd_match_uint16($cmd, $pass_i3_i) | 0; //@line 45583
 _cmd_match_uint16($cmd, $reset_i4_i) | 0; //@line 45584
 if ((_cmd_match_end($cmd) | 0) == 0) {
  STACKTOP = sp; //@line 45589
  return;
 }
 $107 = HEAP16[$pass_i3_i >> 1] | 0; //@line 45592
 if ($107 << 16 >> 16 == 0) {
  STACKTOP = sp; //@line 45596
  return;
 }
 $111 = HEAP32[$addr_i_i >> 2] | 0; //@line 45600
 $112 = _malloc(36) | 0; //@line 45601
 $113 = ($112 | 0) == 0; //@line 45602
 do {
  if (($isseg_0_i_i | 0) == 0) {
   if ($113) {
    $bp_0_i_i = 0; //@line 45608
    break;
   }
   HEAP32[$112 >> 2] = 1; //@line 45612
   $130 = $112 + 4 | 0; //@line 45613
   _memset($130 | 0, 0, 20); //@line 45614
   HEAP32[$130 >> 2] = 294; //@line 45617
   HEAP32[$112 + 8 >> 2] = 86; //@line 45620
   HEAP32[$112 + 12 >> 2] = 160; //@line 45623
   HEAP32[$112 + 24 >> 2] = 0; //@line 45626
   HEAP32[$112 + 28 >> 2] = $111; //@line 45629
   $bp_0_i_i = $112; //@line 45631
  } else {
   if ($113) {
    $bp_0_i_i = 0; //@line 45635
    break;
   }
   HEAP32[$112 >> 2] = 2; //@line 45639
   $116 = $112 + 4 | 0; //@line 45640
   _memset($116 | 0, 0, 20); //@line 45641
   HEAP32[$116 >> 2] = 108; //@line 45644
   HEAP32[$112 + 8 >> 2] = 40; //@line 45647
   HEAP32[$112 + 12 >> 2] = 294; //@line 45650
   HEAP32[$112 + 24 >> 2] = $seg_0_off0_i_i; //@line 45653
   HEAP32[$112 + 28 >> 2] = $111 & 65535; //@line 45657
   $bp_0_i_i = $112; //@line 45659
  }
 } while (0);
 $143 = HEAPU16[$reset_i4_i >> 1] | 0; //@line 45665
 HEAP32[$bp_0_i_i + 16 >> 2] = $107 & 65535; //@line 45667
 HEAP32[$bp_0_i_i + 20 >> 2] = $143; //@line 45669
 $147 = HEAP32[$bp_0_i_i + 12 >> 2] | 0; //@line 45671
 if (($147 | 0) != 0) {
  FUNCTION_TABLE_vii[$147 & 511]($bp_0_i_i, HEAP32[_stdout >> 2] | 0); //@line 45676
 }
 $151 = $bps + 4 | 0; //@line 45679
 $154 = $bps | 0; //@line 45682
 $158 = _realloc(HEAP32[$151 >> 2] | 0, (HEAP32[$154 >> 2] << 2) + 4 | 0) | 0; //@line 45686
 $159 = $158; //@line 45687
 if (($158 | 0) == 0) {
  STACKTOP = sp; //@line 45691
  return;
 }
 HEAP32[$151 >> 2] = $159; //@line 45694
 $162 = HEAP32[$154 >> 2] | 0; //@line 45695
 HEAP32[$159 + ($162 << 2) >> 2] = $bp_0_i_i; //@line 45697
 HEAP32[$154 >> 2] = $162 + 1; //@line 45699
 STACKTOP = sp; //@line 45701
 return;
}
function _cmd_set_sym($cmd, $sym, $val) {
 $cmd = $cmd | 0;
 $sym = $sym | 0;
 $val = $val | 0;
 var $1 = 0, $_sym = 0, $5 = 0, $12 = 0, $14 = 0, $15 = 0, $i_0 = 0, $30 = 0, $31 = 0, $34 = 0, $i_129 = 0, $36 = 0, $37 = 0, $44 = 0, $45 = 0, $46$1 = 0, $i_1_lcssa = 0, $_0 = 0, label = 0;
 $1 = HEAP8[$sym] | 0; //@line 45719
 $_sym = ($1 - 36 & 255) < 2 ? $sym + 1 | 0 : $sym; //@line 45723
 do {
  if ($1 << 24 >> 24 != 36) {
   $5 = HEAP32[15700] | 0; //@line 45728
   do {
    if (($5 | 0) == 0) {
     $12 = $1; //@line 45733
    } else {
     if ((FUNCTION_TABLE_iiii[$5 & 127](HEAP32[15702] | 0, $_sym, $val) | 0) == 0) {
      $_0 = 0; //@line 45740
      return $_0 | 0; //@line 45743
     } else {
      $12 = HEAP8[$sym] | 0; //@line 45747
      break;
     }
    }
   } while (0);
   if ($12 << 24 >> 24 == 37) {
    $_0 = 1; //@line 45756
   } else {
    break;
   }
   return $_0 | 0; //@line 45762
  }
 } while (0);
 $14 = HEAP32[15696] | 0; //@line 45765
 $15 = HEAP32[15698] | 0; //@line 45766
 $i_0 = 0; //@line 45768
 while (1) {
  if ($i_0 >>> 0 >= $14 >>> 0) {
   break;
  }
  if ((_strcmp(HEAP32[$15 + ($i_0 << 3) >> 2] | 0, $_sym | 0) | 0) == 0) {
   label = 14779; //@line 45783
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 45786
  }
 }
 if ((label | 0) == 14779) {
  HEAP32[$15 + ($i_0 << 3) + 4 >> 2] = $val; //@line 45791
  $_0 = 0; //@line 45793
  return $_0 | 0; //@line 45796
 }
 $30 = _realloc($15, ($14 << 3) + 8 | 0) | 0; //@line 45801
 $31 = $30; //@line 45802
 if (($30 | 0) == 0) {
  $_0 = 1; //@line 45806
  return $_0 | 0; //@line 45809
 }
 $34 = HEAP32[15696] | 0; //@line 45811
 L18822 : do {
  if (($34 | 0) == 0) {
   $i_1_lcssa = 0; //@line 45816
  } else {
   $i_129 = $34; //@line 45818
   while (1) {
    $36 = $i_129 - 1 | 0; //@line 45821
    $37 = $31 + ($36 << 3) | 0; //@line 45822
    if ((_strcmp(HEAP32[$37 >> 2] | 0, $_sym | 0) | 0) < 0) {
     $i_1_lcssa = $i_129; //@line 45829
     break L18822;
    }
    $44 = $37; //@line 45833
    $45 = $31 + ($i_129 << 3) | 0; //@line 45834
    $46$1 = HEAP32[$44 + 4 >> 2] | 0; //@line 45838
    HEAP32[$45 >> 2] = HEAP32[$44 >> 2]; //@line 45840
    HEAP32[$45 + 4 >> 2] = $46$1; //@line 45842
    if (($36 | 0) == 0) {
     $i_1_lcssa = 0; //@line 45846
     break;
    } else {
     $i_129 = $36; //@line 45849
    }
   }
  }
 } while (0);
 HEAP32[$31 + ($i_1_lcssa << 3) >> 2] = _strdup($_sym | 0) | 0; //@line 45857
 HEAP32[$31 + ($i_1_lcssa << 3) + 4 >> 2] = $val; //@line 45859
 HEAP32[15698] = $31; //@line 45860
 HEAP32[15696] = (HEAP32[15696] | 0) + 1; //@line 45863
 $_0 = 0; //@line 45865
 return $_0 | 0; //@line 45868
}
function _cmd_error($cmd, $str) {
 $cmd = $cmd | 0;
 $str = $str | 0;
 var $3 = 0, sp = 0;
 sp = STACKTOP; //@line 45877
 $3 = (HEAP32[$cmd >> 2] | 0) + ($cmd + 4) | 0; //@line 45880
 _pce_printf(42512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $str, HEAP32[tempInt + 8 >> 2] = $3, tempInt) | 0); //@line 45881
 STACKTOP = sp; //@line 45882
 return;
}
function _cmd_match_ident($cmd, $str, $max) {
 $cmd = $cmd | 0;
 $str = $str | 0;
 $max = $max | 0;
 var $1 = 0, $i_0_i = 0, $4 = 0, $5 = 0, $8 = 0, $_024 = 0, $i_0 = 0, $n_0 = 0, $14 = 0, $23 = 0, $27 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 45897
 $1 = $cmd | 0; //@line 45898
 $i_0_i = HEAP32[$1 >> 2] | 0; //@line 45901
 while (1) {
  $4 = $cmd + 4 + $i_0_i | 0; //@line 45904
  $5 = HEAP8[$4] | 0; //@line 45905
  if (!(($5 << 24 >> 24 | 0) == 13 | ($5 << 24 >> 24 | 0) == 32 | ($5 << 24 >> 24 | 0) == 9 | ($5 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i = $i_0_i + 1 | 0; //@line 45911
 }
 HEAP32[$1 >> 2] = $i_0_i; //@line 45913
 $8 = HEAP8[$4] | 0; //@line 45914
 if ((($8 << 24 >> 24) - 36 | 0) >>> 0 < 2) {
  HEAP8[$str] = $8; //@line 45921
  $n_0 = 1;
  $i_0 = $i_0_i + 1 | 0;
  $_024 = $str + 1 | 0;
 } else {
  $n_0 = 0;
  $i_0 = $i_0_i;
  $_024 = $str;
 }
 while (1) {
  $14 = HEAP8[$cmd + 4 + $i_0 | 0] | 0; //@line 45933
  if ($14 << 24 >> 24 == 0) {
   label = 14801; //@line 45937
   break;
  }
  if (!(($14 - 48 & 255) < 10 | ($14 - 97 & 255) < 26 | ($14 - 65 & 255) < 26 | $14 << 24 >> 24 == 95)) {
   label = 14801; //@line 45952
   break;
  }
  HEAP8[$_024] = $14; //@line 45956
  $23 = $n_0 + 1 | 0; //@line 45958
  if ($23 >>> 0 < $max >>> 0) {
   $n_0 = $23;
   $i_0 = $i_0 + 1 | 0;
   $_024 = $_024 + 1 | 0;
  } else {
   label = 14800; //@line 45964
   break;
  }
 }
 if ((label | 0) == 14800) {
  $27 = (HEAP32[$1 >> 2] | 0) + ($cmd + 4) | 0; //@line 45970
  _pce_printf(42512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 39432, HEAP32[tempInt + 8 >> 2] = $27, tempInt) | 0); //@line 45971
  $_0 = 0; //@line 45973
  STACKTOP = sp; //@line 45975
  return $_0 | 0; //@line 45976
 } else if ((label | 0) == 14801) {
  HEAP8[$_024] = 0; //@line 45979
  HEAP32[$1 >> 2] = $i_0; //@line 45980
  $_0 = ($n_0 | 0) != 0 | 0; //@line 45984
  STACKTOP = sp; //@line 45986
  return $_0 | 0; //@line 45987
 }
 return 0;
}
function _cmd_match_eol($cmd) {
 $cmd = $cmd | 0;
 var $1 = 0, $i_0_i = 0, $4 = 0, $5 = 0;
 $1 = $cmd | 0; //@line 45998
 $i_0_i = HEAP32[$1 >> 2] | 0; //@line 46001
 while (1) {
  $4 = $cmd + 4 + $i_0_i | 0; //@line 46004
  $5 = HEAP8[$4] | 0; //@line 46005
  if (!(($5 << 24 >> 24 | 0) == 13 | ($5 << 24 >> 24 | 0) == 32 | ($5 << 24 >> 24 | 0) == 9 | ($5 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i = $i_0_i + 1 | 0; //@line 46011
 }
 HEAP32[$1 >> 2] = $i_0_i; //@line 46013
 return (HEAP8[$4] | 0) == 0 | 0; //@line 46018
}
function _cmd_match($cmd, $str) {
 $cmd = $cmd | 0;
 $str = $str | 0;
 var $1 = 0, $i_0_i = 0, $5 = 0, $8 = 0, $_pr = 0, $i_016 = 0, $_015 = 0, $14 = 0, $15 = 0, $16 = 0, $i_014 = 0, $_011 = 0;
 $1 = $cmd | 0; //@line 46030
 $i_0_i = HEAP32[$1 >> 2] | 0; //@line 46033
 while (1) {
  $5 = HEAP8[$cmd + 4 + $i_0_i | 0] | 0; //@line 46037
  if (!(($5 << 24 >> 24 | 0) == 13 | ($5 << 24 >> 24 | 0) == 32 | ($5 << 24 >> 24 | 0) == 9 | ($5 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i = $i_0_i + 1 | 0; //@line 46043
 }
 HEAP32[$1 >> 2] = $i_0_i; //@line 46045
 $8 = HEAP8[$str] | 0; //@line 46046
 L18855 : do {
  if ($8 << 24 >> 24 == 0) {
   $i_014 = $i_0_i; //@line 46051
  } else {
   $_015 = $str;
   $i_016 = $i_0_i;
   $_pr = $8;
   while (1) {
    if ((HEAP8[$cmd + 4 + $i_016 | 0] | 0) != $_pr << 24 >> 24) {
     $_011 = 0; //@line 46062
     break;
    }
    $14 = $i_016 + 1 | 0; //@line 46065
    $15 = $_015 + 1 | 0; //@line 46066
    $16 = HEAP8[$15] | 0; //@line 46067
    if ($16 << 24 >> 24 == 0) {
     $i_014 = $14; //@line 46071
     break L18855;
    } else {
     $_015 = $15;
     $i_016 = $14;
     $_pr = $16;
    }
   }
   return $_011 | 0; //@line 46079
  }
 } while (0);
 HEAP32[$1 >> 2] = $i_014; //@line 46083
 $_011 = 1; //@line 46085
 return $_011 | 0; //@line 46088
}
function _cmd_match_str($cmd, $str, $max) {
 $cmd = $cmd | 0;
 $str = $str | 0;
 $max = $max | 0;
 var $1 = 0, $i_0_i = 0, $4 = 0, $5 = 0, $9 = 0, $_i_0_i = 0, $_021_us = 0, $i_0_us = 0, $n_0_us = 0, $12 = 0, $15 = 0, $_021 = 0, $i_0 = 0, $n_0 = 0, $18 = 0, $22 = 0, $25 = 0, $n_030 = 0, $_02125 = 0, $i_1 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 46102
 $1 = $cmd | 0; //@line 46103
 $i_0_i = HEAP32[$1 >> 2] | 0; //@line 46106
 while (1) {
  $4 = $cmd + 4 + $i_0_i | 0; //@line 46109
  $5 = HEAP8[$4] | 0; //@line 46110
  if (!(($5 << 24 >> 24 | 0) == 13 | ($5 << 24 >> 24 | 0) == 32 | ($5 << 24 >> 24 | 0) == 9 | ($5 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i = $i_0_i + 1 | 0; //@line 46116
 }
 HEAP32[$1 >> 2] = $i_0_i; //@line 46118
 $9 = (HEAP8[$4] | 0) == 34; //@line 46120
 $_i_0_i = ($9 & 1) + $i_0_i | 0; //@line 46122
 L18867 : do {
  if ($9) {
   $n_0_us = 0;
   $i_0_us = $_i_0_i;
   $_021_us = $str;
   while (1) {
    $12 = HEAP8[$cmd + 4 + $i_0_us | 0] | 0; //@line 46131
    if (($12 << 24 >> 24 | 0) == 0) {
     $i_1 = $i_0_us;
     $_02125 = $_021_us;
     $n_030 = $n_0_us;
     label = 14829; //@line 46134
     break L18867;
    } else if (($12 << 24 >> 24 | 0) == 34) {
     break;
    }
    HEAP8[$_021_us] = $12; //@line 46140
    $15 = $n_0_us + 1 | 0; //@line 46142
    if ($15 >>> 0 < $max >>> 0) {
     $n_0_us = $15;
     $i_0_us = $i_0_us + 1 | 0;
     $_021_us = $_021_us + 1 | 0;
    } else {
     label = 14828; //@line 46148
     break L18867;
    }
   }
   $i_1 = $i_0_us + 1 | 0;
   $_02125 = $_021_us;
   $n_030 = $n_0_us;
   label = 14829; //@line 46155
  } else {
   $n_0 = 0;
   $i_0 = $_i_0_i;
   $_021 = $str;
   while (1) {
    $18 = HEAP8[$cmd + 4 + $i_0 | 0] | 0; //@line 46163
    if (($18 << 24 >> 24 | 0) == 0 | ($18 << 24 >> 24 | 0) == 32 | ($18 << 24 >> 24 | 0) == 9 | ($18 << 24 >> 24 | 0) == 10 | ($18 << 24 >> 24 | 0) == 13) {
     $i_1 = $i_0;
     $_02125 = $_021;
     $n_030 = $n_0;
     label = 14829; //@line 46166
     break L18867;
    }
    HEAP8[$_021] = $18; //@line 46170
    $22 = $n_0 + 1 | 0; //@line 46172
    if ($22 >>> 0 < $max >>> 0) {
     $n_0 = $22;
     $i_0 = $i_0 + 1 | 0;
     $_021 = $_021 + 1 | 0;
    } else {
     label = 14828; //@line 46178
     break;
    }
   }
  }
 } while (0);
 if ((label | 0) == 14829) {
  HEAP8[$_02125] = 0; //@line 46188
  HEAP32[$1 >> 2] = $i_1; //@line 46189
  $_0 = ($n_030 | 0) != 0 | 0; //@line 46193
  STACKTOP = sp; //@line 46195
  return $_0 | 0; //@line 46196
 } else if ((label | 0) == 14828) {
  $25 = (HEAP32[$1 >> 2] | 0) + ($cmd + 4) | 0; //@line 46200
  _pce_printf(42512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 36480, HEAP32[tempInt + 8 >> 2] = $25, tempInt) | 0); //@line 46201
  $_0 = 0; //@line 46203
  STACKTOP = sp; //@line 46205
  return $_0 | 0; //@line 46206
 }
 return 0;
}
function _cmd_match_end($cmd) {
 $cmd = $cmd | 0;
 var $1 = 0, $i_0_i_i = 0, $4 = 0, $5 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 46216
 $1 = $cmd | 0; //@line 46217
 $i_0_i_i = HEAP32[$1 >> 2] | 0; //@line 46220
 while (1) {
  $4 = $cmd + 4 + $i_0_i_i | 0; //@line 46223
  $5 = HEAP8[$4] | 0; //@line 46224
  if (!(($5 << 24 >> 24 | 0) == 13 | ($5 << 24 >> 24 | 0) == 32 | ($5 << 24 >> 24 | 0) == 9 | ($5 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i_i = $i_0_i_i + 1 | 0; //@line 46230
 }
 HEAP32[$1 >> 2] = $i_0_i_i; //@line 46232
 if ((HEAP8[$4] | 0) == 0) {
  $_0 = 1; //@line 46237
  STACKTOP = sp; //@line 46239
  return $_0 | 0; //@line 46240
 }
 _pce_printf(42512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 33520, HEAP32[tempInt + 8 >> 2] = $4, tempInt) | 0); //@line 46242
 $_0 = 0; //@line 46244
 STACKTOP = sp; //@line 46246
 return $_0 | 0; //@line 46247
}
function _cmd_init($ext, $getsym, $setsym) {
 $ext = $ext | 0;
 $getsym = $getsym | 0;
 $setsym = $setsym | 0;
 HEAP32[15706] = $ext; //@line 46258
 HEAP32[15704] = $getsym; //@line 46260
 HEAP32[15702] = $ext; //@line 46261
 HEAP32[15700] = $setsym; //@line 46263
 return;
}
function _cmd_match_expr($cmd, $val, $base) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 $base = $base | 0;
 var $str_i = 0, $tmp_i = 0, $1 = 0, $3 = 0, $4 = 0, $i_0_i144_i = 0, $7 = 0, $i_0_i_i137_i = 0, $11 = 0, $12 = 0, $15 = 0, $_024_i_i = 0, $19 = 0, $n_0_i_i = 0, $21 = 0, $30 = 0, $33 = 0, $j_0_i = 0, $35 = 0, $36 = 0, $38 = 0, $40 = 0, $41 = 0, $42 = 0, $45 = 0, $47 = 0, $49 = 0, $50 = 0, $52 = 0, $54 = 0, $61 = 0, $62 = 0, $63 = 0, $65 = 0, $72 = 0, $73 = 0, $74 = 0, $76 = 0, $83 = 0, $84 = 0, $85 = 0, $87 = 0, $94 = 0, $95 = 0, $96 = 0, $98 = 0, $105 = 0, $106 = 0, $107 = 0, $109 = 0, $116 = 0, $117 = 0, $118 = 0, $120 = 0, $127 = 0, $128 = 0, $129 = 0, $131 = 0, $138 = 0, $i_0_i_i47_i = 0, $139 = 0, $147 = 0, $op_0_i7 = 0, $i_0_i_i_i = 0, $149 = 0, $150 = 0, $_0_i43_i = 0, $160 = 0, $162 = 0, $j_014_i_i = 0, $i_013_i_i = 0, $163 = 0, $177 = 0, $178 = 0, $179$1 = 0, $182 = 0, $j_1_i_i = 0, $183 = 0, $j_0_lcssa_i_i = 0, $_sym_i_i = 0, $189 = 0, $196 = 0, $198 = 0, $199 = 0, $i_0_i_i6 = 0, $215 = 0, $219 = 0, $223 = 0, $227 = 0, $229 = 0, $233 = 0, $238 = 0, $242 = 0, $246 = 0, $250 = 0, $254 = 0, $256 = 0, $258 = 0, $i_0_i_i = 0, $264 = 0, $265 = 0, $270 = 0, $_0 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $279 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 46311
 STACKTOP = STACKTOP + 264 | 0; //@line 46311
 $str_i = sp | 0; //@line 46312
 $tmp_i = sp + 256 | 0; //@line 46313
 $1 = $str_i | 0; //@line 46314
 $3 = $cmd | 0; //@line 46316
 $4 = $str_i + 1 | 0; //@line 46317
 $i_0_i144_i = HEAP32[$3 >> 2] | 0; //@line 46320
 while (1) {
  $7 = HEAP8[$cmd + 4 + $i_0_i144_i | 0] | 0; //@line 46324
  if (($7 << 24 >> 24 | 0) == 13 | ($7 << 24 >> 24 | 0) == 32 | ($7 << 24 >> 24 | 0) == 9 | ($7 << 24 >> 24 | 0) == 10) {
   $i_0_i144_i = $i_0_i144_i + 1 | 0; //@line 46328
   continue;
  }
  HEAP32[$3 >> 2] = $i_0_i144_i; //@line 46331
  $i_0_i_i137_i = $i_0_i144_i; //@line 46333
  while (1) {
   $11 = $cmd + 4 + $i_0_i_i137_i | 0; //@line 46336
   $12 = HEAP8[$11] | 0; //@line 46337
   if (!(($12 << 24 >> 24 | 0) == 13 | ($12 << 24 >> 24 | 0) == 32 | ($12 << 24 >> 24 | 0) == 9 | ($12 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $i_0_i_i137_i = $i_0_i_i137_i + 1 | 0; //@line 46343
  }
  HEAP32[$3 >> 2] = $i_0_i_i137_i; //@line 46345
  $15 = HEAP8[$11] | 0; //@line 46346
  if ((($15 << 24 >> 24) - 36 | 0) >>> 0 < 2) {
   HEAP8[$1] = $15; //@line 46352
   $n_0_i_i = 1;
   $19 = $i_0_i_i137_i + 1 | 0;
   $_024_i_i = $4;
  } else {
   $n_0_i_i = 0;
   $19 = $i_0_i_i137_i;
   $_024_i_i = $1;
  }
  while (1) {
   $21 = HEAP8[$cmd + 4 + $19 | 0] | 0; //@line 46364
   if ($21 << 24 >> 24 == 0) {
    label = 14854; //@line 46368
    break;
   }
   if (!(($21 - 48 & 255) < 10 | ($21 - 97 & 255) < 26 | ($21 - 65 & 255) < 26 | $21 << 24 >> 24 == 95)) {
    label = 14854; //@line 46383
    break;
   }
   HEAP8[$_024_i_i] = $21; //@line 46387
   $30 = $n_0_i_i + 1 | 0; //@line 46389
   if ($30 >>> 0 < 256) {
    $n_0_i_i = $30;
    $19 = $19 + 1 | 0;
    $_024_i_i = $_024_i_i + 1 | 0;
   } else {
    label = 14853; //@line 46395
    break;
   }
  }
  L18906 : do {
   if ((label | 0) == 14854) {
    label = 0; //@line 46401
    HEAP8[$_024_i_i] = 0; //@line 46402
    HEAP32[$3 >> 2] = $19; //@line 46403
    if (($n_0_i_i | 0) == 0) {
     label = 14934; //@line 46407
     break;
    } else {
     $j_0_i = 0; //@line 46410
    }
    while (1) {
     $35 = $str_i + $j_0_i | 0; //@line 46414
     $36 = HEAP8[$35] | 0; //@line 46415
     $38 = $j_0_i + 1 | 0; //@line 46417
     if ($36 << 24 >> 24 == 37) {
      $j_0_i = $38; //@line 46420
     } else {
      $40 = $19; //@line 46422
      break;
     }
    }
    while (1) {
     $41 = $cmd + 4 + $40 | 0; //@line 46428
     $42 = HEAP8[$41] | 0; //@line 46429
     if (!(($42 << 24 >> 24 | 0) == 13 | ($42 << 24 >> 24 | 0) == 32 | ($42 << 24 >> 24 | 0) == 9 | ($42 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $40 = $40 + 1 | 0; //@line 46435
    }
    HEAP32[$3 >> 2] = $40; //@line 46437
    $45 = HEAP8[$41] | 0; //@line 46438
    L18914 : do {
     if ($45 << 24 >> 24 == 61) {
      $47 = $40 + 1 | 0; //@line 46442
      HEAP32[$3 >> 2] = $47; //@line 46443
      $op_0_i7 = 1;
      $147 = $47;
     } else {
      $50 = $40;
      $49 = $45;
      while (1) {
       if (!(($49 << 24 >> 24 | 0) == 13 | ($49 << 24 >> 24 | 0) == 32 | ($49 << 24 >> 24 | 0) == 9 | ($49 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $52 = $50 + 1 | 0; //@line 46454
       $50 = $52;
       $49 = HEAP8[$cmd + 4 + $52 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $50; //@line 46461
      $54 = HEAP8[$cmd + 4 + $50 | 0] | 0; //@line 46462
      do {
       if ($54 << 24 >> 24 == 43) {
        if ((HEAP8[$50 + 1 + ($cmd + 4) | 0] | 0) != 61) {
         $62 = $50;
         $61 = 43;
         break;
        }
        $271 = $50 + 2 | 0; //@line 46474
        HEAP32[$3 >> 2] = $271; //@line 46475
        $op_0_i7 = 2;
        $147 = $271;
        break L18914;
       } else {
        $62 = $50;
        $61 = $54;
       }
      } while (0);
      while (1) {
       if (!(($61 << 24 >> 24 | 0) == 13 | ($61 << 24 >> 24 | 0) == 32 | ($61 << 24 >> 24 | 0) == 9 | ($61 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $63 = $62 + 1 | 0; //@line 46489
       $62 = $63;
       $61 = HEAP8[$cmd + 4 + $63 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $62; //@line 46496
      $65 = HEAP8[$cmd + 4 + $62 | 0] | 0; //@line 46497
      do {
       if ($65 << 24 >> 24 == 45) {
        if ((HEAP8[$62 + 1 + ($cmd + 4) | 0] | 0) != 61) {
         $73 = $62;
         $72 = 45;
         break;
        }
        $272 = $62 + 2 | 0; //@line 46509
        HEAP32[$3 >> 2] = $272; //@line 46510
        $op_0_i7 = 3;
        $147 = $272;
        break L18914;
       } else {
        $73 = $62;
        $72 = $65;
       }
      } while (0);
      while (1) {
       if (!(($72 << 24 >> 24 | 0) == 13 | ($72 << 24 >> 24 | 0) == 32 | ($72 << 24 >> 24 | 0) == 9 | ($72 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $74 = $73 + 1 | 0; //@line 46524
       $73 = $74;
       $72 = HEAP8[$cmd + 4 + $74 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $73; //@line 46531
      $76 = HEAP8[$cmd + 4 + $73 | 0] | 0; //@line 46532
      do {
       if ($76 << 24 >> 24 == 42) {
        if ((HEAP8[$73 + 1 + ($cmd + 4) | 0] | 0) != 61) {
         $84 = $73;
         $83 = 42;
         break;
        }
        $273 = $73 + 2 | 0; //@line 46544
        HEAP32[$3 >> 2] = $273; //@line 46545
        $op_0_i7 = 4;
        $147 = $273;
        break L18914;
       } else {
        $84 = $73;
        $83 = $76;
       }
      } while (0);
      while (1) {
       if (!(($83 << 24 >> 24 | 0) == 13 | ($83 << 24 >> 24 | 0) == 32 | ($83 << 24 >> 24 | 0) == 9 | ($83 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $85 = $84 + 1 | 0; //@line 46559
       $84 = $85;
       $83 = HEAP8[$cmd + 4 + $85 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $84; //@line 46566
      $87 = HEAP8[$cmd + 4 + $84 | 0] | 0; //@line 46567
      do {
       if ($87 << 24 >> 24 == 47) {
        if ((HEAP8[$84 + 1 + ($cmd + 4) | 0] | 0) != 61) {
         $95 = $84;
         $94 = 47;
         break;
        }
        $274 = $84 + 2 | 0; //@line 46579
        HEAP32[$3 >> 2] = $274; //@line 46580
        $op_0_i7 = 5;
        $147 = $274;
        break L18914;
       } else {
        $95 = $84;
        $94 = $87;
       }
      } while (0);
      while (1) {
       if (!(($94 << 24 >> 24 | 0) == 13 | ($94 << 24 >> 24 | 0) == 32 | ($94 << 24 >> 24 | 0) == 9 | ($94 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $96 = $95 + 1 | 0; //@line 46594
       $95 = $96;
       $94 = HEAP8[$cmd + 4 + $96 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $95; //@line 46601
      $98 = HEAP8[$cmd + 4 + $95 | 0] | 0; //@line 46602
      do {
       if ($98 << 24 >> 24 == 60) {
        if ((HEAP8[$95 + 1 + ($cmd + 4) | 0] | 0) != 60) {
         $106 = $95;
         $105 = 60;
         break;
        }
        if ((HEAP8[$95 + 2 + ($cmd + 4) | 0] | 0) != 61) {
         $106 = $95;
         $105 = $98;
         break;
        }
        $279 = $95 + 3 | 0; //@line 46622
        HEAP32[$3 >> 2] = $279; //@line 46623
        $op_0_i7 = 6;
        $147 = $279;
        break L18914;
       } else {
        $106 = $95;
        $105 = $98;
       }
      } while (0);
      while (1) {
       if (!(($105 << 24 >> 24 | 0) == 13 | ($105 << 24 >> 24 | 0) == 32 | ($105 << 24 >> 24 | 0) == 9 | ($105 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $107 = $106 + 1 | 0; //@line 46637
       $106 = $107;
       $105 = HEAP8[$cmd + 4 + $107 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $106; //@line 46644
      $109 = HEAP8[$cmd + 4 + $106 | 0] | 0; //@line 46645
      do {
       if ($109 << 24 >> 24 == 62) {
        if ((HEAP8[$106 + 1 + ($cmd + 4) | 0] | 0) != 62) {
         $117 = $106;
         $116 = 62;
         break;
        }
        if ((HEAP8[$106 + 2 + ($cmd + 4) | 0] | 0) != 61) {
         $117 = $106;
         $116 = $109;
         break;
        }
        $284 = $106 + 3 | 0; //@line 46665
        HEAP32[$3 >> 2] = $284; //@line 46666
        $op_0_i7 = 7;
        $147 = $284;
        break L18914;
       } else {
        $117 = $106;
        $116 = $109;
       }
      } while (0);
      while (1) {
       if (!(($116 << 24 >> 24 | 0) == 13 | ($116 << 24 >> 24 | 0) == 32 | ($116 << 24 >> 24 | 0) == 9 | ($116 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $118 = $117 + 1 | 0; //@line 46680
       $117 = $118;
       $116 = HEAP8[$cmd + 4 + $118 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $117; //@line 46687
      $120 = HEAP8[$cmd + 4 + $117 | 0] | 0; //@line 46688
      do {
       if ($120 << 24 >> 24 == 124) {
        if ((HEAP8[$117 + 1 + ($cmd + 4) | 0] | 0) != 61) {
         $128 = $117;
         $127 = 124;
         break;
        }
        $285 = $117 + 2 | 0; //@line 46700
        HEAP32[$3 >> 2] = $285; //@line 46701
        $op_0_i7 = 8;
        $147 = $285;
        break L18914;
       } else {
        $128 = $117;
        $127 = $120;
       }
      } while (0);
      while (1) {
       if (!(($127 << 24 >> 24 | 0) == 13 | ($127 << 24 >> 24 | 0) == 32 | ($127 << 24 >> 24 | 0) == 9 | ($127 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $129 = $128 + 1 | 0; //@line 46715
       $128 = $129;
       $127 = HEAP8[$cmd + 4 + $129 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $128; //@line 46722
      $131 = HEAP8[$cmd + 4 + $128 | 0] | 0; //@line 46723
      do {
       if ($131 << 24 >> 24 == 38) {
        if ((HEAP8[$128 + 1 + ($cmd + 4) | 0] | 0) != 61) {
         $i_0_i_i47_i = $128;
         $138 = 38;
         break;
        }
        $286 = $128 + 2 | 0; //@line 46735
        HEAP32[$3 >> 2] = $286; //@line 46736
        $op_0_i7 = 9;
        $147 = $286;
        break L18914;
       } else {
        $i_0_i_i47_i = $128;
        $138 = $131;
       }
      } while (0);
      while (1) {
       if (!(($138 << 24 >> 24 | 0) == 13 | ($138 << 24 >> 24 | 0) == 32 | ($138 << 24 >> 24 | 0) == 9 | ($138 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $139 = $i_0_i_i47_i + 1 | 0; //@line 46750
       $i_0_i_i47_i = $139;
       $138 = HEAP8[$cmd + 4 + $139 | 0] | 0;
      }
      HEAP32[$3 >> 2] = $i_0_i_i47_i; //@line 46757
      if ((HEAP8[$cmd + 4 + $i_0_i_i47_i | 0] | 0) != 94) {
       label = 14934; //@line 46761
       break L18906;
      }
      if ((HEAP8[$i_0_i_i47_i + 1 + ($cmd + 4) | 0] | 0) != 61) {
       label = 14934; //@line 46769
       break L18906;
      }
      $287 = $i_0_i_i47_i + 2 | 0; //@line 46772
      HEAP32[$3 >> 2] = $287; //@line 46773
      $op_0_i7 = 10;
      $147 = $287;
     }
    } while (0);
    $i_0_i_i_i = $147; //@line 46781
    while (1) {
     $149 = $cmd + 4 + $i_0_i_i_i | 0; //@line 46784
     $150 = HEAP8[$149] | 0; //@line 46785
     if (!(($150 << 24 >> 24 | 0) == 13 | ($150 << 24 >> 24 | 0) == 32 | ($150 << 24 >> 24 | 0) == 9 | ($150 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $i_0_i_i_i = $i_0_i_i_i + 1 | 0; //@line 46791
    }
    HEAP32[$3 >> 2] = $i_0_i_i_i; //@line 46793
    if ((HEAP8[$149] | 0) == 59) {
     HEAP32[$3 >> 2] = $i_0_i_i_i + 1; //@line 46798
     if (($36 << 24 >> 24 | 0) == 36) {
      $_0_i43_i = $str_i + $38 | 0; //@line 46802
     } else if (($36 << 24 >> 24 | 0) == 37) {
      break;
     } else {
      $_0_i43_i = $35; //@line 46806
     }
     HEAP32[$val >> 2] = 0; //@line 46809
     $160 = HEAP32[15696] | 0; //@line 46810
     if (($160 | 0) == 0) {
      $j_0_lcssa_i_i = 0; //@line 46814
     } else {
      $i_013_i_i = 0;
      $j_014_i_i = 0;
      $162 = $160;
      while (1) {
       $163 = HEAP32[15698] | 0; //@line 46821
       if ((_strcmp(HEAP32[$163 + ($i_013_i_i << 3) >> 2] | 0, $_0_i43_i | 0) | 0) == 0) {
        HEAP32[$val >> 2] = HEAP32[$163 + ($i_013_i_i << 3) + 4 >> 2]; //@line 46830
        _free(HEAP32[(HEAP32[15698] | 0) + ($i_013_i_i << 3) >> 2] | 0); //@line 46834
        $j_1_i_i = $j_014_i_i;
        $182 = HEAP32[15696] | 0;
       } else {
        $177 = $163 + ($i_013_i_i << 3) | 0; //@line 46841
        $178 = $163 + ($j_014_i_i << 3) | 0; //@line 46842
        $179$1 = HEAP32[$177 + 4 >> 2] | 0; //@line 46846
        HEAP32[$178 >> 2] = HEAP32[$177 >> 2]; //@line 46848
        HEAP32[$178 + 4 >> 2] = $179$1; //@line 46850
        $j_1_i_i = $j_014_i_i + 1 | 0;
        $182 = $162;
       }
       $183 = $i_013_i_i + 1 | 0; //@line 46856
       if ($183 >>> 0 < $182 >>> 0) {
        $i_013_i_i = $183;
        $j_014_i_i = $j_1_i_i;
        $162 = $182;
       } else {
        $j_0_lcssa_i_i = $j_1_i_i; //@line 46862
        break;
       }
      }
     }
     HEAP32[15696] = $j_0_lcssa_i_i; //@line 46868
     break;
    }
    $_sym_i_i = ($36 - 36 & 255) < 2 ? $str_i + $38 | 0 : $35; //@line 46875
    do {
     if ($36 << 24 >> 24 == 36) {
      label = 14913; //@line 46880
     } else {
      $189 = HEAP32[15704] | 0; //@line 46882
      if (($189 | 0) == 0) {
       $196 = $36; //@line 46886
      } else {
       if ((FUNCTION_TABLE_iiii[$189 & 127](HEAP32[15706] | 0, $_sym_i_i, $val) | 0) == 0) {
        break;
       }
       $196 = HEAP8[$35] | 0; //@line 46897
      }
      if ($196 << 24 >> 24 == 37) {
       label = 14917; //@line 46903
      } else {
       label = 14913; //@line 46905
      }
     }
    } while (0);
    L19005 : do {
     if ((label | 0) == 14913) {
      label = 0; //@line 46911
      $198 = HEAP32[15696] | 0; //@line 46912
      $199 = HEAP32[15698] | 0; //@line 46913
      $i_0_i_i6 = 0; //@line 46915
      while (1) {
       if ($i_0_i_i6 >>> 0 >= $198 >>> 0) {
        label = 14917; //@line 46921
        break L19005;
       }
       if ((_strcmp(HEAP32[$199 + ($i_0_i_i6 << 3) >> 2] | 0, $_sym_i_i | 0) | 0) == 0) {
        break;
       } else {
        $i_0_i_i6 = $i_0_i_i6 + 1 | 0; //@line 46933
       }
      }
      HEAP32[$val >> 2] = HEAP32[$199 + ($i_0_i_i6 << 3) + 4 >> 2]; //@line 46938
     }
    } while (0);
    if ((label | 0) == 14917) {
     label = 0; //@line 46943
     HEAP32[$val >> 2] = 0; //@line 46944
    }
    if ((_cmd_match_expr_cond($cmd, $tmp_i, $base) | 0) == 0) {
     label = 14934; //@line 46951
     break;
    }
    do {
     if (($op_0_i7 | 0) == 10) {
      $254 = HEAP32[$val >> 2] ^ HEAP32[$tmp_i >> 2]; //@line 46958
      HEAP32[$val >> 2] = $254; //@line 46959
      $258 = $254; //@line 46961
     } else if (($op_0_i7 | 0) == 9) {
      $250 = HEAP32[$val >> 2] & HEAP32[$tmp_i >> 2]; //@line 46965
      HEAP32[$val >> 2] = $250; //@line 46966
      $258 = $250; //@line 46968
     } else if (($op_0_i7 | 0) == 1) {
      $215 = HEAP32[$tmp_i >> 2] | 0; //@line 46970
      HEAP32[$val >> 2] = $215; //@line 46971
      $258 = $215; //@line 46973
     } else if (($op_0_i7 | 0) == 3) {
      $223 = (HEAP32[$val >> 2] | 0) - (HEAP32[$tmp_i >> 2] | 0) | 0; //@line 46977
      HEAP32[$val >> 2] = $223; //@line 46978
      $258 = $223; //@line 46980
     } else if (($op_0_i7 | 0) == 4) {
      $227 = Math_imul(HEAP32[$val >> 2] | 0, HEAP32[$tmp_i >> 2] | 0) | 0; //@line 46984
      HEAP32[$val >> 2] = $227; //@line 46985
      $258 = $227; //@line 46987
     } else if (($op_0_i7 | 0) == 5) {
      $229 = HEAP32[$tmp_i >> 2] | 0; //@line 46989
      if (($229 | 0) == 0) {
       HEAP32[$val >> 2] = -1; //@line 46993
       $258 = -1; //@line 46994
       break;
      } else {
       $233 = ((HEAP32[$val >> 2] | 0) >>> 0) / ($229 >>> 0) | 0; //@line 46998
       HEAP32[$val >> 2] = $233; //@line 46999
       $258 = $233; //@line 47001
       break;
      }
     } else if (($op_0_i7 | 0) == 2) {
      $219 = (HEAP32[$val >> 2] | 0) + (HEAP32[$tmp_i >> 2] | 0) | 0; //@line 47007
      HEAP32[$val >> 2] = $219; //@line 47008
      $258 = $219; //@line 47010
     } else if (($op_0_i7 | 0) == 6) {
      $238 = HEAP32[$val >> 2] << HEAP32[$tmp_i >> 2]; //@line 47014
      HEAP32[$val >> 2] = $238; //@line 47015
      $258 = $238; //@line 47017
     } else if (($op_0_i7 | 0) == 7) {
      $242 = (HEAP32[$val >> 2] | 0) >>> ((HEAP32[$tmp_i >> 2] | 0) >>> 0); //@line 47021
      HEAP32[$val >> 2] = $242; //@line 47022
      $258 = $242; //@line 47024
     } else if (($op_0_i7 | 0) == 8) {
      $246 = HEAP32[$val >> 2] | HEAP32[$tmp_i >> 2]; //@line 47028
      HEAP32[$val >> 2] = $246; //@line 47029
      $258 = $246; //@line 47031
     } else {
      $256 = HEAP32[$tmp_i >> 2] | 0; //@line 47033
      HEAP32[$val >> 2] = $256; //@line 47034
      $258 = $256; //@line 47036
     }
    } while (0);
    _cmd_set_sym(0, $35, $258) | 0; //@line 47040
   } else if ((label | 0) == 14853) {
    label = 0; //@line 47044
    $33 = (HEAP32[$3 >> 2] | 0) + ($cmd + 4) | 0; //@line 47046
    _pce_printf(42512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 39432, HEAP32[tempInt + 8 >> 2] = $33, tempInt) | 0); //@line 47047
    label = 14934; //@line 47049
   }
  } while (0);
  if ((label | 0) == 14934) {
   label = 0; //@line 47053
   HEAP32[$3 >> 2] = $i_0_i144_i; //@line 47054
   if ((_cmd_match_expr_cond($cmd, $val, $base) | 0) == 0) {
    $_0 = 0; //@line 47059
    label = 14953; //@line 47060
    break;
   }
  }
  $i_0_i_i = HEAP32[$3 >> 2] | 0; //@line 47066
  while (1) {
   $264 = $cmd + 4 + $i_0_i_i | 0; //@line 47069
   $265 = HEAP8[$264] | 0; //@line 47070
   if (!(($265 << 24 >> 24 | 0) == 13 | ($265 << 24 >> 24 | 0) == 32 | ($265 << 24 >> 24 | 0) == 9 | ($265 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $i_0_i_i = $i_0_i_i + 1 | 0; //@line 47076
  }
  HEAP32[$3 >> 2] = $i_0_i_i; //@line 47078
  if ((HEAP8[$264] | 0) != 44) {
   $_0 = 1; //@line 47082
   label = 14952; //@line 47083
   break;
  }
  $270 = $i_0_i_i + 1 | 0; //@line 47086
  HEAP32[$3 >> 2] = $270; //@line 47087
  $i_0_i144_i = $270; //@line 47089
 }
 if ((label | 0) == 14952) {
  STACKTOP = sp; //@line 47093
  return $_0 | 0; //@line 47094
 } else if ((label | 0) == 14953) {
  STACKTOP = sp; //@line 47098
  return $_0 | 0; //@line 47099
 }
 return 0;
}
function _cmd_match_uint16($cmd, $val) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 var $tmp_i = 0, $_0_i = 0, sp = 0;
 sp = STACKTOP; //@line 47109
 STACKTOP = STACKTOP + 8 | 0; //@line 47109
 $tmp_i = sp | 0; //@line 47110
 if ((_cmd_match_expr($cmd, $tmp_i, 16) | 0) == 0) {
  $_0_i = 0; //@line 47116
  STACKTOP = sp; //@line 47118
  return $_0_i | 0; //@line 47119
 }
 HEAP16[$val >> 1] = HEAP32[$tmp_i >> 2] & 65535; //@line 47123
 $_0_i = 1; //@line 47125
 STACKTOP = sp; //@line 47127
 return $_0_i | 0; //@line 47128
}
function _cmd_match_uint32($cmd, $val) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 return _cmd_match_expr($cmd, $val, 16) | 0; //@line 47140
}
function _cmd_match_expr_cond($cmd, $val, $base) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 $base = $base | 0;
 var $val2_i2110 = 0, $val2_i2087 = 0, $val2_i2083 = 0, $val2_i2060 = 0, $val2_i2056 = 0, $val2_i2033 = 0, $val2_i2029 = 0, $val2_i2006 = 0, $val2_i2002 = 0, $val2_i1979 = 0, $val2_i1975 = 0, $val2_i1952 = 0, $val2_i1948 = 0, $val2_i1925 = 0, $val2_i1921 = 0, $val2_i1898 = 0, $val2_i1894 = 0, $val2_i1871 = 0, $val2_i1867 = 0, $val2_i1844 = 0, $val2_i1840 = 0, $val2_i1817 = 0, $val2_i1813 = 0, $val2_i1790 = 0, $val2_i1786 = 0, $val2_i1763 = 0, $val2_i1759 = 0, $val2_i1736 = 0, $val2_i1732 = 0, $val2_i1709 = 0, $val2_i1705 = 0, $val2_i1682 = 0, $val2_i1678 = 0, $val2_i1655 = 0, $val2_i1651 = 0, $val2_i1628 = 0, $val2_i1624 = 0, $val2_i1601 = 0, $val2_i1597 = 0, $val2_i1574 = 0, $val2_i1570 = 0, $val2_i1547 = 0, $val2_i1543 = 0, $val2_i1520 = 0, $val2_i1516 = 0, $val2_i1493 = 0, $val2_i1489 = 0, $val2_i1466 = 0, $val2_i1462 = 0, $val2_i1439 = 0, $val2_i1435 = 0, $val2_i1412 = 0, $val2_i1408 = 0, $val2_i1385 = 0, $val2_i1381 = 0, $val2_i1358 = 0, $val2_i1354 = 0, $val2_i1331 = 0, $val2_i1327 = 0, $val2_i1304 = 0, $val2_i1300 = 0, $val2_i1277 = 0, $val2_i1273 = 0, $val2_i1250 = 0, $val2_i1246 = 0, $val2_i1223 = 0, $val2_i1219 = 0, $val2_i1196 = 0, $val2_i1192 = 0, $val2_i1169 = 0, $val2_i1165 = 0, $val2_i1142 = 0, $val2_i1138 = 0, $val2_i1115 = 0, $val2_i1111 = 0, $val2_i1088 = 0, $val2_i1084 = 0, $val2_i1061 = 0, $val2_i1057 = 0, $val2_i1034 = 0, $val2_i1030 = 0, $val2_i1007 = 0, $val2_i1003 = 0, $val2_i980 = 0, $val2_i976 = 0, $val2_i953 = 0, $val2_i949 = 0, $val2_i926 = 0, $val2_i922 = 0, $val2_i899 = 0, $val2_i895 = 0, $val2_i872 = 0, $val2_i868 = 0, $val2_i845 = 0, $val2_i841 = 0, $val2_i820 = 0, $val2_i817 = 0, $val2_i814 = 0, $val2_i811 = 0, $val2_i808 = 0, $val2_i805 = 0, $val2_i802 = 0, $val2_i799 = 0, $val2_i796 = 0, $val2_i793 = 0, $val2_i790 = 0, $val2_i787 = 0, $val2_i784 = 0, $val2_i781 = 0, $val2_i778 = 0, $val2_i775 = 0, $val2_i772 = 0, $val2_i769 = 0, $val2_i766 = 0, $val2_i763 = 0, $val2_i760 = 0, $val2_i757 = 0, $val2_i754 = 0, $val2_i751 = 0, $val2_i748 = 0, $val2_i745 = 0, $val2_i742 = 0, $val2_i739 = 0, $val2_i736 = 0, $val2_i733 = 0, $val2_i730 = 0, $val2_i727 = 0, $val2_i724 = 0, $val2_i721 = 0, $val2_i718 = 0, $val2_i715 = 0, $val2_i712 = 0, $val2_i709 = 0, $val2_i706 = 0, $val2_i703 = 0, $val2_i700 = 0, $val2_i697 = 0, $val2_i694 = 0, $val2_i691 = 0, $val2_i688 = 0, $val2_i685 = 0, $val2_i682 = 0, $val2_i679 = 0, $val2_i677 = 0, $val2_i665 = 0, $val2_i634 = 0, $val2_i622 = 0, $val2_i591 = 0, $val2_i579 = 0, $val2_i548 = 0, $val2_i536 = 0, $val2_i505 = 0, $val2_i493 = 0, $val2_i462 = 0, $val2_i450 = 0, $val2_i419 = 0, $val2_i407 = 0, $val2_i376 = 0, $val2_i364 = 0, $val2_i333 = 0, $val2_i321 = 0, $val2_i290 = 0, $val2_i278 = 0, $val2_i247 = 0, $val2_i235 = 0, $val2_i204 = 0, $val2_i192 = 0, $val2_i165 = 0, $val2_i162 = 0, $val2_i159 = 0, $val2_i156 = 0, $val2_i153 = 0, $val2_i150 = 0, $val2_i147 = 0, $val2_i144 = 0, $val2_i141 = 0, $val2_i138 = 0, $val2_i135 = 0, $val2_i132 = 0, $val2_i130 = 0, $val2_i117 = 0, $val2_i104 = 0, $val2_i91 = 0, $val2_i78 = 0, $val2_i65 = 0, $val2_i53 = 0, $val2_i40 = 0, $val2_i27 = 0, $val2_i = 0, $val2 = 0, $val3 = 0, $1 = 0, $2 = 0, $13 = 0, $14 = 0, $15 = 0, $18 = 0, $25 = 0, $i_0_i_i2124 = 0, $26 = 0, $storemerge4248_in = 0, $op_0_i = 0, $49 = 0, $51 = 0, $52 = 0, $53 = 0, $56 = 0, $63 = 0, $i_0_i_i831 = 0, $64 = 0, $68 = 0, $73 = 0, $78 = 0, $79 = 0, $80 = 0, $83 = 0, $90 = 0, $i_0_i_i2144 = 0, $91 = 0, $storemerge4247_in = 0, $op_0_i842 = 0, $i_0_i_i_i166 = 0, $116 = 0, $117 = 0, $130 = 0, $135 = 0, $136 = 0, $137 = 0, $140 = 0, $147 = 0, $i_0_i_i2164 = 0, $148 = 0, $storemerge4246_in = 0, $op_0_i846 = 0, $170 = 0, $172 = 0, $173 = 0, $174 = 0, $177 = 0, $184 = 0, $i_0_i_i858 = 0, $185 = 0, $190 = 0, $195 = 0, $196 = 0, $197 = 0, $200 = 0, $207 = 0, $i_0_i_i2184 = 0, $208 = 0, $storemerge4245_in = 0, $op_0_i869 = 0, $236 = 0, $238 = 0, $239 = 0, $240 = 0, $243 = 0, $250 = 0, $i_0_i_i182 = 0, $251 = 0, $255 = 0, $272 = 0, $277 = 0, $278 = 0, $279 = 0, $282 = 0, $289 = 0, $i_0_i_i2204 = 0, $290 = 0, $storemerge4244_in = 0, $op_0_i873 = 0, $312 = 0, $314 = 0, $315 = 0, $316 = 0, $319 = 0, $326 = 0, $i_0_i_i885 = 0, $327 = 0, $332 = 0, $337 = 0, $338 = 0, $339 = 0, $342 = 0, $349 = 0, $i_0_i_i2224 = 0, $350 = 0, $storemerge4243_in = 0, $op_0_i896 = 0, $i_0_i_i_i193 = 0, $375 = 0, $376 = 0, $382 = 0, $387 = 0, $388 = 0, $389 = 0, $392 = 0, $399 = 0, $i_0_i_i2244 = 0, $400 = 0, $storemerge4242_in = 0, $op_0_i900 = 0, $422 = 0, $424 = 0, $425 = 0, $426 = 0, $429 = 0, $436 = 0, $i_0_i_i912 = 0, $437 = 0, $442 = 0, $447 = 0, $448 = 0, $449 = 0, $452 = 0, $459 = 0, $i_0_i_i2264 = 0, $460 = 0, $storemerge4241_in = 0, $op_0_i923 = 0, $485 = 0, $i_0_i_i_i54 = 0, $493 = 0, $494 = 0, $536 = 0, $537 = 0, $538 = 0, $541 = 0, $548 = 0, $i_0_i_i2284 = 0, $549 = 0, $storemerge4240_in = 0, $op_0_i927 = 0, $571 = 0, $573 = 0, $574 = 0, $575 = 0, $578 = 0, $585 = 0, $i_0_i_i939 = 0, $586 = 0, $591 = 0, $596 = 0, $597 = 0, $598 = 0, $601 = 0, $608 = 0, $i_0_i_i2304 = 0, $609 = 0, $storemerge4239_in = 0, $op_0_i950 = 0, $i_0_i_i_i205 = 0, $634 = 0, $635 = 0, $641 = 0, $646 = 0, $647 = 0, $648 = 0, $651 = 0, $658 = 0, $i_0_i_i2324 = 0, $659 = 0, $storemerge4238_in = 0, $op_0_i954 = 0, $681 = 0, $683 = 0, $684 = 0, $685 = 0, $688 = 0, $695 = 0, $i_0_i_i966 = 0, $696 = 0, $701 = 0, $706 = 0, $707 = 0, $708 = 0, $711 = 0, $718 = 0, $i_0_i_i2344 = 0, $719 = 0, $storemerge4237_in = 0, $op_0_i977 = 0, $744 = 0, $748 = 0, $750 = 0, $751 = 0, $752 = 0, $755 = 0, $762 = 0, $i_0_i_i225 = 0, $763 = 0, $768 = 0, $773 = 0, $774 = 0, $775 = 0, $778 = 0, $785 = 0, $i_0_i_i2364 = 0, $786 = 0, $storemerge4236_in = 0, $op_0_i981 = 0, $808 = 0, $810 = 0, $811 = 0, $812 = 0, $815 = 0, $822 = 0, $i_0_i_i993 = 0, $823 = 0, $828 = 0, $833 = 0, $834 = 0, $835 = 0, $838 = 0, $845 = 0, $i_0_i_i2384 = 0, $846 = 0, $storemerge4235_in = 0, $op_0_i1004 = 0, $i_0_i_i_i236 = 0, $871 = 0, $872 = 0, $878 = 0, $883 = 0, $884 = 0, $885 = 0, $888 = 0, $895 = 0, $i_0_i_i2404 = 0, $896 = 0, $storemerge4234_in = 0, $op_0_i1008 = 0, $918 = 0, $920 = 0, $921 = 0, $922 = 0, $925 = 0, $932 = 0, $i_0_i_i1020 = 0, $933 = 0, $938 = 0, $943 = 0, $944 = 0, $945 = 0, $948 = 0, $955 = 0, $i_0_i_i2424 = 0, $956 = 0, $storemerge4233_in = 0, $op_0_i1031 = 0, $981 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $1001 = 0, $1009 = 0, $1010 = 0, $1011 = 0, $1014 = 0, $1021 = 0, $i_0_i_i2444 = 0, $1022 = 0, $storemerge4232_in = 0, $op_0_i1035 = 0, $1044 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1051 = 0, $1058 = 0, $i_0_i_i1047 = 0, $1059 = 0, $1064 = 0, $1069 = 0, $1070 = 0, $1071 = 0, $1074 = 0, $1081 = 0, $i_0_i_i2464 = 0, $1082 = 0, $storemerge4231_in = 0, $op_0_i1058 = 0, $i_0_i_i_i248 = 0, $1107 = 0, $1108 = 0, $1114 = 0, $1119 = 0, $1120 = 0, $1121 = 0, $1124 = 0, $1131 = 0, $i_0_i_i2484 = 0, $1132 = 0, $storemerge4230_in = 0, $op_0_i1062 = 0, $1154 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1161 = 0, $1168 = 0, $i_0_i_i1074 = 0, $1169 = 0, $1174 = 0, $1179 = 0, $1180 = 0, $1181 = 0, $1184 = 0, $1191 = 0, $i_0_i_i2504 = 0, $1192 = 0, $storemerge4229_in = 0, $op_0_i1085 = 0, $1217 = 0, $1221 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1228 = 0, $1235 = 0, $i_0_i_i268 = 0, $1236 = 0, $1241 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1251 = 0, $1258 = 0, $i_0_i_i2524 = 0, $1259 = 0, $storemerge4228_in = 0, $op_0_i1089 = 0, $1281 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1288 = 0, $1295 = 0, $i_0_i_i1101 = 0, $1296 = 0, $1301 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1311 = 0, $1318 = 0, $i_0_i_i2544 = 0, $1319 = 0, $storemerge4227_in = 0, $op_0_i1112 = 0, $i_0_i_i_i279 = 0, $1344 = 0, $1345 = 0, $1351 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1361 = 0, $1368 = 0, $i_0_i_i2564 = 0, $1369 = 0, $storemerge4226_in = 0, $op_0_i1116 = 0, $1391 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1398 = 0, $1405 = 0, $i_0_i_i1128 = 0, $1406 = 0, $1411 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1421 = 0, $1428 = 0, $i_0_i_i2584 = 0, $1429 = 0, $storemerge4225_in = 0, $op_0_i1139 = 0, $1454 = 0, $i_0_i_i_i66 = 0, $1462 = 0, $1463 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1479 = 0, $1486 = 0, $i_0_i_i2604 = 0, $1487 = 0, $storemerge4224_in = 0, $op_0_i1143 = 0, $1509 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1516 = 0, $1523 = 0, $i_0_i_i1155 = 0, $1524 = 0, $1529 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1539 = 0, $1546 = 0, $i_0_i_i2624 = 0, $1547 = 0, $storemerge4223_in = 0, $op_0_i1166 = 0, $i_0_i_i_i291 = 0, $1572 = 0, $1573 = 0, $1579 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1589 = 0, $1596 = 0, $i_0_i_i2644 = 0, $1597 = 0, $storemerge4222_in = 0, $op_0_i1170 = 0, $1619 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1626 = 0, $1633 = 0, $i_0_i_i1182 = 0, $1634 = 0, $1639 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1649 = 0, $1656 = 0, $i_0_i_i2664 = 0, $1657 = 0, $storemerge4221_in = 0, $op_0_i1193 = 0, $1682 = 0, $1686 = 0, $1688 = 0, $1689 = 0, $1690 = 0, $1693 = 0, $1700 = 0, $i_0_i_i311 = 0, $1701 = 0, $1706 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1716 = 0, $1723 = 0, $i_0_i_i2684 = 0, $1724 = 0, $storemerge4220_in = 0, $op_0_i1197 = 0, $1746 = 0, $1748 = 0, $1749 = 0, $1750 = 0, $1753 = 0, $1760 = 0, $i_0_i_i1209 = 0, $1761 = 0, $1766 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1776 = 0, $1783 = 0, $i_0_i_i2704 = 0, $1784 = 0, $storemerge4219_in = 0, $op_0_i1220 = 0, $i_0_i_i_i322 = 0, $1809 = 0, $1810 = 0, $1816 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1826 = 0, $1833 = 0, $i_0_i_i2724 = 0, $1834 = 0, $storemerge4218_in = 0, $op_0_i1224 = 0, $1856 = 0, $1858 = 0, $1859 = 0, $1860 = 0, $1863 = 0, $1870 = 0, $i_0_i_i1236 = 0, $1871 = 0, $1876 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1886 = 0, $1893 = 0, $i_0_i_i2744 = 0, $1894 = 0, $storemerge4217_in = 0, $op_0_i1247 = 0, $1919 = 0, $1927 = 0, $1934 = 0, $1942 = 0, $1944 = 0, $i_0_i_i18 = 0, $1945 = 0, $1950 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1966 = 0, $1973 = 0, $i_0_i_i2764 = 0, $1974 = 0, $storemerge4216_in = 0, $op_0_i1251 = 0, $1997 = 0, $1999 = 0, $2000 = 0, $2001 = 0, $2004 = 0, $2011 = 0, $i_0_i_i1263 = 0, $2012 = 0, $2016 = 0, $2021 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2031 = 0, $2038 = 0, $i_0_i_i2784 = 0, $2039 = 0, $storemerge4215_in = 0, $op_0_i1274 = 0, $i_0_i_i_i334 = 0, $2064 = 0, $2065 = 0, $2078 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2088 = 0, $2095 = 0, $i_0_i_i2804 = 0, $2096 = 0, $storemerge4214_in = 0, $op_0_i1278 = 0, $2118 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2125 = 0, $2132 = 0, $i_0_i_i1290 = 0, $2133 = 0, $2138 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2148 = 0, $2155 = 0, $i_0_i_i2824 = 0, $2156 = 0, $storemerge4213_in = 0, $op_0_i1301 = 0, $2181 = 0, $2185 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $2192 = 0, $2199 = 0, $i_0_i_i354 = 0, $2200 = 0, $2204 = 0, $2221 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2231 = 0, $2238 = 0, $i_0_i_i2844 = 0, $2239 = 0, $storemerge4212_in = 0, $op_0_i1305 = 0, $2261 = 0, $2263 = 0, $2264 = 0, $2265 = 0, $2268 = 0, $2275 = 0, $i_0_i_i1317 = 0, $2276 = 0, $2281 = 0, $2286 = 0, $2287 = 0, $2288 = 0, $2291 = 0, $2298 = 0, $i_0_i_i2864 = 0, $2299 = 0, $storemerge4211_in = 0, $op_0_i1328 = 0, $i_0_i_i_i365 = 0, $2324 = 0, $2325 = 0, $2331 = 0, $2336 = 0, $2337 = 0, $2338 = 0, $2341 = 0, $2348 = 0, $i_0_i_i2884 = 0, $2349 = 0, $storemerge4210_in = 0, $op_0_i1332 = 0, $2371 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2378 = 0, $2385 = 0, $i_0_i_i1344 = 0, $2386 = 0, $2391 = 0, $2396 = 0, $2397 = 0, $2398 = 0, $2401 = 0, $2408 = 0, $i_0_i_i2904 = 0, $2409 = 0, $storemerge4209_in = 0, $op_0_i1355 = 0, $2434 = 0, $i_0_i_i_i79 = 0, $2442 = 0, $2443 = 0, $2485 = 0, $2486 = 0, $2487 = 0, $2490 = 0, $2497 = 0, $i_0_i_i2924 = 0, $2498 = 0, $storemerge4208_in = 0, $op_0_i1359 = 0, $2520 = 0, $2522 = 0, $2523 = 0, $2524 = 0, $2527 = 0, $2534 = 0, $i_0_i_i1371 = 0, $2535 = 0, $2540 = 0, $2545 = 0, $2546 = 0, $2547 = 0, $2550 = 0, $2557 = 0, $i_0_i_i2944 = 0, $2558 = 0, $storemerge4207_in = 0, $op_0_i1382 = 0, $i_0_i_i_i377 = 0, $2583 = 0, $2584 = 0, $2590 = 0, $2595 = 0, $2596 = 0, $2597 = 0, $2600 = 0, $2607 = 0, $i_0_i_i2964 = 0, $2608 = 0, $storemerge4206_in = 0, $op_0_i1386 = 0, $2630 = 0, $2632 = 0, $2633 = 0, $2634 = 0, $2637 = 0, $2644 = 0, $i_0_i_i1398 = 0, $2645 = 0, $2650 = 0, $2655 = 0, $2656 = 0, $2657 = 0, $2660 = 0, $2667 = 0, $i_0_i_i2984 = 0, $2668 = 0, $storemerge4205_in = 0, $op_0_i1409 = 0, $2693 = 0, $2697 = 0, $2699 = 0, $2700 = 0, $2701 = 0, $2704 = 0, $2711 = 0, $i_0_i_i397 = 0, $2712 = 0, $2717 = 0, $2722 = 0, $2723 = 0, $2724 = 0, $2727 = 0, $2734 = 0, $i_0_i_i3004 = 0, $2735 = 0, $storemerge4204_in = 0, $op_0_i1413 = 0, $2757 = 0, $2759 = 0, $2760 = 0, $2761 = 0, $2764 = 0, $2771 = 0, $i_0_i_i1425 = 0, $2772 = 0, $2777 = 0, $2782 = 0, $2783 = 0, $2784 = 0, $2787 = 0, $2794 = 0, $i_0_i_i3024 = 0, $2795 = 0, $storemerge4203_in = 0, $op_0_i1436 = 0, $i_0_i_i_i408 = 0, $2820 = 0, $2821 = 0, $2827 = 0, $2832 = 0, $2833 = 0, $2834 = 0, $2837 = 0, $2844 = 0, $i_0_i_i3044 = 0, $2845 = 0, $storemerge4202_in = 0, $op_0_i1440 = 0, $2867 = 0, $2869 = 0, $2870 = 0, $2871 = 0, $2874 = 0, $2881 = 0, $i_0_i_i1452 = 0, $2882 = 0, $2887 = 0, $2892 = 0, $2893 = 0, $2894 = 0, $2897 = 0, $2904 = 0, $i_0_i_i3064 = 0, $2905 = 0, $storemerge4201_in = 0, $op_0_i1463 = 0, $2930 = 0, $2938 = 0, $2945 = 0, $2946 = 0, $2947 = 0, $2948 = 0, $2951 = 0, $2959 = 0, $2960 = 0, $2961 = 0, $2964 = 0, $2971 = 0, $i_0_i_i3084 = 0, $2972 = 0, $storemerge4200_in = 0, $op_0_i1467 = 0, $2994 = 0, $2996 = 0, $2997 = 0, $2998 = 0, $3001 = 0, $3008 = 0, $i_0_i_i1479 = 0, $3009 = 0, $3014 = 0, $3019 = 0, $3020 = 0, $3021 = 0, $3024 = 0, $3031 = 0, $i_0_i_i3104 = 0, $3032 = 0, $storemerge4199_in = 0, $op_0_i1490 = 0, $i_0_i_i_i420 = 0, $3057 = 0, $3058 = 0, $3064 = 0, $3069 = 0, $3070 = 0, $3071 = 0, $3074 = 0, $3081 = 0, $i_0_i_i3124 = 0, $3082 = 0, $storemerge4198_in = 0, $op_0_i1494 = 0, $3104 = 0, $3106 = 0, $3107 = 0, $3108 = 0, $3111 = 0, $3118 = 0, $i_0_i_i1506 = 0, $3119 = 0, $3124 = 0, $3129 = 0, $3130 = 0, $3131 = 0, $3134 = 0, $3141 = 0, $i_0_i_i3144 = 0, $3142 = 0, $storemerge4197_in = 0, $op_0_i1517 = 0, $3167 = 0, $3171 = 0, $3173 = 0, $3174 = 0, $3175 = 0, $3178 = 0, $3185 = 0, $i_0_i_i440 = 0, $3186 = 0, $3191 = 0, $3196 = 0, $3197 = 0, $3198 = 0, $3201 = 0, $3208 = 0, $i_0_i_i3164 = 0, $3209 = 0, $storemerge4196_in = 0, $op_0_i1521 = 0, $3231 = 0, $3233 = 0, $3234 = 0, $3235 = 0, $3238 = 0, $3245 = 0, $i_0_i_i1533 = 0, $3246 = 0, $3251 = 0, $3256 = 0, $3257 = 0, $3258 = 0, $3261 = 0, $3268 = 0, $i_0_i_i3184 = 0, $3269 = 0, $storemerge4195_in = 0, $op_0_i1544 = 0, $i_0_i_i_i451 = 0, $3294 = 0, $3295 = 0, $3301 = 0, $3306 = 0, $3307 = 0, $3308 = 0, $3311 = 0, $3318 = 0, $i_0_i_i3204 = 0, $3319 = 0, $storemerge4194_in = 0, $op_0_i1548 = 0, $3341 = 0, $3343 = 0, $3344 = 0, $3345 = 0, $3348 = 0, $3355 = 0, $i_0_i_i1560 = 0, $3356 = 0, $3361 = 0, $3366 = 0, $3367 = 0, $3368 = 0, $3371 = 0, $3378 = 0, $i_0_i_i3224 = 0, $3379 = 0, $storemerge4193_in = 0, $op_0_i1571 = 0, $3404 = 0, $i_0_i_i_i92 = 0, $3412 = 0, $3413 = 0, $3424 = 0, $3425 = 0, $3426 = 0, $3429 = 0, $3436 = 0, $i_0_i_i3244 = 0, $3437 = 0, $storemerge4192_in = 0, $op_0_i1575 = 0, $3459 = 0, $3461 = 0, $3462 = 0, $3463 = 0, $3466 = 0, $3473 = 0, $i_0_i_i1587 = 0, $3474 = 0, $3479 = 0, $3484 = 0, $3485 = 0, $3486 = 0, $3489 = 0, $3496 = 0, $i_0_i_i3264 = 0, $3497 = 0, $storemerge4191_in = 0, $op_0_i1598 = 0, $i_0_i_i_i463 = 0, $3522 = 0, $3523 = 0, $3529 = 0, $3534 = 0, $3535 = 0, $3536 = 0, $3539 = 0, $3546 = 0, $i_0_i_i3284 = 0, $3547 = 0, $storemerge4190_in = 0, $op_0_i1602 = 0, $3569 = 0, $3571 = 0, $3572 = 0, $3573 = 0, $3576 = 0, $3583 = 0, $i_0_i_i1614 = 0, $3584 = 0, $3589 = 0, $3594 = 0, $3595 = 0, $3596 = 0, $3599 = 0, $3606 = 0, $i_0_i_i3304 = 0, $3607 = 0, $storemerge4189_in = 0, $op_0_i1625 = 0, $3632 = 0, $3636 = 0, $3638 = 0, $3639 = 0, $3640 = 0, $3643 = 0, $3650 = 0, $i_0_i_i483 = 0, $3651 = 0, $3656 = 0, $3661 = 0, $3662 = 0, $3663 = 0, $3666 = 0, $3673 = 0, $i_0_i_i3324 = 0, $3674 = 0, $storemerge4188_in = 0, $op_0_i1629 = 0, $3696 = 0, $3698 = 0, $3699 = 0, $3700 = 0, $3703 = 0, $3710 = 0, $i_0_i_i1641 = 0, $3711 = 0, $3716 = 0, $3721 = 0, $3722 = 0, $3723 = 0, $3726 = 0, $3733 = 0, $i_0_i_i3344 = 0, $3734 = 0, $storemerge4187_in = 0, $op_0_i1652 = 0, $i_0_i_i_i494 = 0, $3759 = 0, $3760 = 0, $3766 = 0, $3771 = 0, $3772 = 0, $3773 = 0, $3776 = 0, $3783 = 0, $i_0_i_i3364 = 0, $3784 = 0, $storemerge4186_in = 0, $op_0_i1656 = 0, $3806 = 0, $3808 = 0, $3809 = 0, $3810 = 0, $3813 = 0, $3820 = 0, $i_0_i_i1668 = 0, $3821 = 0, $3826 = 0, $3831 = 0, $3832 = 0, $3833 = 0, $3836 = 0, $3843 = 0, $i_0_i_i3384 = 0, $3844 = 0, $storemerge4185_in = 0, $op_0_i1679 = 0, $3869 = 0, $3877 = 0, $3884 = 0, $3892 = 0, $3894 = 0, $i_0_i_i = 0, $3895 = 0, $3900 = 0, $3912 = 0, $3913 = 0, $3914 = 0, $3917 = 0, $3924 = 0, $i_0_i_i3404 = 0, $3925 = 0, $storemerge4184_in = 0, $op_0_i1683 = 0, $3948 = 0, $3950 = 0, $3951 = 0, $3952 = 0, $3955 = 0, $3962 = 0, $i_0_i_i1695 = 0, $3963 = 0, $3967 = 0, $3972 = 0, $3977 = 0, $3978 = 0, $3979 = 0, $3982 = 0, $3989 = 0, $i_0_i_i3424 = 0, $3990 = 0, $storemerge4183_in = 0, $op_0_i1706 = 0, $i_0_i_i_i506 = 0, $4015 = 0, $4016 = 0, $4029 = 0, $4034 = 0, $4035 = 0, $4036 = 0, $4039 = 0, $4046 = 0, $i_0_i_i3444 = 0, $4047 = 0, $storemerge4182_in = 0, $op_0_i1710 = 0, $4069 = 0, $4071 = 0, $4072 = 0, $4073 = 0, $4076 = 0, $4083 = 0, $i_0_i_i1722 = 0, $4084 = 0, $4089 = 0, $4094 = 0, $4095 = 0, $4096 = 0, $4099 = 0, $4106 = 0, $i_0_i_i3464 = 0, $4107 = 0, $storemerge4181_in = 0, $op_0_i1733 = 0, $4132 = 0, $4136 = 0, $4138 = 0, $4139 = 0, $4140 = 0, $4143 = 0, $4150 = 0, $i_0_i_i526 = 0, $4151 = 0, $4155 = 0, $4172 = 0, $4177 = 0, $4178 = 0, $4179 = 0, $4182 = 0, $4189 = 0, $i_0_i_i3484 = 0, $4190 = 0, $storemerge4180_in = 0, $op_0_i1737 = 0, $4212 = 0, $4214 = 0, $4215 = 0, $4216 = 0, $4219 = 0, $4226 = 0, $i_0_i_i1749 = 0, $4227 = 0, $4232 = 0, $4237 = 0, $4238 = 0, $4239 = 0, $4242 = 0, $4249 = 0, $i_0_i_i3504 = 0, $4250 = 0, $storemerge4179_in = 0, $op_0_i1760 = 0, $i_0_i_i_i537 = 0, $4275 = 0, $4276 = 0, $4282 = 0, $4287 = 0, $4288 = 0, $4289 = 0, $4292 = 0, $4299 = 0, $i_0_i_i3524 = 0, $4300 = 0, $storemerge4178_in = 0, $op_0_i1764 = 0, $4322 = 0, $4324 = 0, $4325 = 0, $4326 = 0, $4329 = 0, $4336 = 0, $i_0_i_i1776 = 0, $4337 = 0, $4342 = 0, $4347 = 0, $4348 = 0, $4349 = 0, $4352 = 0, $4359 = 0, $i_0_i_i3544 = 0, $4360 = 0, $storemerge4177_in = 0, $op_0_i1787 = 0, $4385 = 0, $i_0_i_i_i105 = 0, $4393 = 0, $4394 = 0, $4436 = 0, $4437 = 0, $4438 = 0, $4441 = 0, $4448 = 0, $i_0_i_i3564 = 0, $4449 = 0, $storemerge4176_in = 0, $op_0_i1791 = 0, $4471 = 0, $4473 = 0, $4474 = 0, $4475 = 0, $4478 = 0, $4485 = 0, $i_0_i_i1803 = 0, $4486 = 0, $4491 = 0, $4496 = 0, $4497 = 0, $4498 = 0, $4501 = 0, $4508 = 0, $i_0_i_i3584 = 0, $4509 = 0, $storemerge4175_in = 0, $op_0_i1814 = 0, $i_0_i_i_i549 = 0, $4534 = 0, $4535 = 0, $4541 = 0, $4546 = 0, $4547 = 0, $4548 = 0, $4551 = 0, $4558 = 0, $i_0_i_i3604 = 0, $4559 = 0, $storemerge4174_in = 0, $op_0_i1818 = 0, $4581 = 0, $4583 = 0, $4584 = 0, $4585 = 0, $4588 = 0, $4595 = 0, $i_0_i_i1830 = 0, $4596 = 0, $4601 = 0, $4606 = 0, $4607 = 0, $4608 = 0, $4611 = 0, $4618 = 0, $i_0_i_i3624 = 0, $4619 = 0, $storemerge4173_in = 0, $op_0_i1841 = 0, $4644 = 0, $4648 = 0, $4650 = 0, $4651 = 0, $4652 = 0, $4655 = 0, $4662 = 0, $i_0_i_i569 = 0, $4663 = 0, $4668 = 0, $4673 = 0, $4674 = 0, $4675 = 0, $4678 = 0, $4685 = 0, $i_0_i_i3644 = 0, $4686 = 0, $storemerge4172_in = 0, $op_0_i1845 = 0, $4708 = 0, $4710 = 0, $4711 = 0, $4712 = 0, $4715 = 0, $4722 = 0, $i_0_i_i1857 = 0, $4723 = 0, $4728 = 0, $4733 = 0, $4734 = 0, $4735 = 0, $4738 = 0, $4745 = 0, $i_0_i_i3664 = 0, $4746 = 0, $storemerge4171_in = 0, $op_0_i1868 = 0, $i_0_i_i_i580 = 0, $4771 = 0, $4772 = 0, $4778 = 0, $4783 = 0, $4784 = 0, $4785 = 0, $4788 = 0, $4795 = 0, $i_0_i_i3684 = 0, $4796 = 0, $storemerge4170_in = 0, $op_0_i1872 = 0, $4818 = 0, $4820 = 0, $4821 = 0, $4822 = 0, $4825 = 0, $4832 = 0, $i_0_i_i1884 = 0, $4833 = 0, $4838 = 0, $4843 = 0, $4844 = 0, $4845 = 0, $4848 = 0, $4855 = 0, $i_0_i_i3704 = 0, $4856 = 0, $storemerge4169_in = 0, $op_0_i1895 = 0, $4881 = 0, $4889 = 0, $4896 = 0, $i_0_i_i_i41 = 0, $4897 = 0, $4898 = 0, $4909 = 0, $4910 = 0, $4911 = 0, $4914 = 0, $4921 = 0, $i_0_i_i3724 = 0, $4922 = 0, $storemerge4168_in = 0, $op_0_i1899 = 0, $4944 = 0, $4946 = 0, $4947 = 0, $4948 = 0, $4951 = 0, $4958 = 0, $i_0_i_i1911 = 0, $4959 = 0, $4964 = 0, $4969 = 0, $4970 = 0, $4971 = 0, $4974 = 0, $4981 = 0, $i_0_i_i3744 = 0, $4982 = 0, $storemerge4167_in = 0, $op_0_i1922 = 0, $i_0_i_i_i592 = 0, $5007 = 0, $5008 = 0, $5014 = 0, $5019 = 0, $5020 = 0, $5021 = 0, $5024 = 0, $5031 = 0, $i_0_i_i3764 = 0, $5032 = 0, $storemerge4166_in = 0, $op_0_i1926 = 0, $5054 = 0, $5056 = 0, $5057 = 0, $5058 = 0, $5061 = 0, $5068 = 0, $i_0_i_i1938 = 0, $5069 = 0, $5074 = 0, $5079 = 0, $5080 = 0, $5081 = 0, $5084 = 0, $5091 = 0, $i_0_i_i3784 = 0, $5092 = 0, $storemerge4165_in = 0, $op_0_i1949 = 0, $5117 = 0, $5121 = 0, $5123 = 0, $5124 = 0, $5125 = 0, $5128 = 0, $5135 = 0, $i_0_i_i612 = 0, $5136 = 0, $5141 = 0, $5146 = 0, $5147 = 0, $5148 = 0, $5151 = 0, $5158 = 0, $i_0_i_i3804 = 0, $5159 = 0, $storemerge4164_in = 0, $op_0_i1953 = 0, $5181 = 0, $5183 = 0, $5184 = 0, $5185 = 0, $5188 = 0, $5195 = 0, $i_0_i_i1965 = 0, $5196 = 0, $5201 = 0, $5206 = 0, $5207 = 0, $5208 = 0, $5211 = 0, $5218 = 0, $i_0_i_i3824 = 0, $5219 = 0, $storemerge4163_in = 0, $op_0_i1976 = 0, $i_0_i_i_i623 = 0, $5244 = 0, $5245 = 0, $5251 = 0, $5256 = 0, $5257 = 0, $5258 = 0, $5261 = 0, $5268 = 0, $i_0_i_i3844 = 0, $5269 = 0, $storemerge4162_in = 0, $op_0_i1980 = 0, $5291 = 0, $5293 = 0, $5294 = 0, $5295 = 0, $5298 = 0, $5305 = 0, $i_0_i_i1992 = 0, $5306 = 0, $5311 = 0, $5316 = 0, $5317 = 0, $5318 = 0, $5321 = 0, $5328 = 0, $i_0_i_i3864 = 0, $5329 = 0, $storemerge4161_in = 0, $op_0_i2003 = 0, $5354 = 0, $i_0_i_i_i118 = 0, $5362 = 0, $5363 = 0, $5374 = 0, $5375 = 0, $5376 = 0, $5379 = 0, $5386 = 0, $i_0_i_i3884 = 0, $5387 = 0, $storemerge4160_in = 0, $op_0_i2007 = 0, $5409 = 0, $5411 = 0, $5412 = 0, $5413 = 0, $5416 = 0, $5423 = 0, $i_0_i_i2019 = 0, $5424 = 0, $5429 = 0, $5434 = 0, $5435 = 0, $5436 = 0, $5439 = 0, $5446 = 0, $i_0_i_i3904 = 0, $5447 = 0, $storemerge4159_in = 0, $op_0_i2030 = 0, $i_0_i_i_i635 = 0, $5472 = 0, $5473 = 0, $5479 = 0, $5484 = 0, $5485 = 0, $5486 = 0, $5489 = 0, $5496 = 0, $i_0_i_i3924 = 0, $5497 = 0, $storemerge4158_in = 0, $op_0_i2034 = 0, $5519 = 0, $5521 = 0, $5522 = 0, $5523 = 0, $5526 = 0, $5533 = 0, $i_0_i_i2046 = 0, $5534 = 0, $5539 = 0, $5544 = 0, $5545 = 0, $5546 = 0, $5549 = 0, $5556 = 0, $i_0_i_i3944 = 0, $5557 = 0, $storemerge4157_in = 0, $op_0_i2057 = 0, $5582 = 0, $5586 = 0, $5588 = 0, $5589 = 0, $5590 = 0, $5593 = 0, $5600 = 0, $i_0_i_i655 = 0, $5601 = 0, $5606 = 0, $5611 = 0, $5612 = 0, $5613 = 0, $5616 = 0, $5623 = 0, $i_0_i_i3964 = 0, $5624 = 0, $storemerge4156_in = 0, $op_0_i2061 = 0, $5646 = 0, $5648 = 0, $5649 = 0, $5650 = 0, $5653 = 0, $5660 = 0, $i_0_i_i2073 = 0, $5661 = 0, $5666 = 0, $5671 = 0, $5672 = 0, $5673 = 0, $5676 = 0, $5683 = 0, $i_0_i_i3984 = 0, $5684 = 0, $storemerge4155_in = 0, $op_0_i2084 = 0, $i_0_i_i_i666 = 0, $5709 = 0, $5710 = 0, $5716 = 0, $5721 = 0, $5722 = 0, $5723 = 0, $5726 = 0, $5733 = 0, $i_0_i_i4004 = 0, $5734 = 0, $storemerge4154_in = 0, $op_0_i2088 = 0, $5756 = 0, $5758 = 0, $5759 = 0, $5760 = 0, $5763 = 0, $5770 = 0, $i_0_i_i2100 = 0, $5771 = 0, $5776 = 0, $5781 = 0, $5782 = 0, $5783 = 0, $5786 = 0, $5793 = 0, $i_0_i_i4024 = 0, $5794 = 0, $storemerge_in = 0, $op_0_i2111 = 0, $5819 = 0, $5827 = 0, $5834 = 0, $5842 = 0, $_0 = 0, $5849 = 0, $5853 = 0, $5857 = 0, $5861 = 0, $5865 = 0, $5869 = 0, $5873 = 0, $5877 = 0, $5881 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 47883
 STACKTOP = STACKTOP + 1528 | 0; //@line 47883
 $val2_i2110 = sp | 0; //@line 47884
 $val2_i2087 = sp + 8 | 0; //@line 47885
 $val2_i2083 = sp + 16 | 0; //@line 47886
 $val2_i2060 = sp + 24 | 0; //@line 47887
 $val2_i2056 = sp + 32 | 0; //@line 47888
 $val2_i2033 = sp + 40 | 0; //@line 47889
 $val2_i2029 = sp + 48 | 0; //@line 47890
 $val2_i2006 = sp + 56 | 0; //@line 47891
 $val2_i2002 = sp + 64 | 0; //@line 47892
 $val2_i1979 = sp + 72 | 0; //@line 47893
 $val2_i1975 = sp + 80 | 0; //@line 47894
 $val2_i1952 = sp + 88 | 0; //@line 47895
 $val2_i1948 = sp + 96 | 0; //@line 47896
 $val2_i1925 = sp + 104 | 0; //@line 47897
 $val2_i1921 = sp + 112 | 0; //@line 47898
 $val2_i1898 = sp + 120 | 0; //@line 47899
 $val2_i1894 = sp + 128 | 0; //@line 47900
 $val2_i1871 = sp + 136 | 0; //@line 47901
 $val2_i1867 = sp + 144 | 0; //@line 47902
 $val2_i1844 = sp + 152 | 0; //@line 47903
 $val2_i1840 = sp + 160 | 0; //@line 47904
 $val2_i1817 = sp + 168 | 0; //@line 47905
 $val2_i1813 = sp + 176 | 0; //@line 47906
 $val2_i1790 = sp + 184 | 0; //@line 47907
 $val2_i1786 = sp + 192 | 0; //@line 47908
 $val2_i1763 = sp + 200 | 0; //@line 47909
 $val2_i1759 = sp + 208 | 0; //@line 47910
 $val2_i1736 = sp + 216 | 0; //@line 47911
 $val2_i1732 = sp + 224 | 0; //@line 47912
 $val2_i1709 = sp + 232 | 0; //@line 47913
 $val2_i1705 = sp + 240 | 0; //@line 47914
 $val2_i1682 = sp + 248 | 0; //@line 47915
 $val2_i1678 = sp + 256 | 0; //@line 47916
 $val2_i1655 = sp + 264 | 0; //@line 47917
 $val2_i1651 = sp + 272 | 0; //@line 47918
 $val2_i1628 = sp + 280 | 0; //@line 47919
 $val2_i1624 = sp + 288 | 0; //@line 47920
 $val2_i1601 = sp + 296 | 0; //@line 47921
 $val2_i1597 = sp + 304 | 0; //@line 47922
 $val2_i1574 = sp + 312 | 0; //@line 47923
 $val2_i1570 = sp + 320 | 0; //@line 47924
 $val2_i1547 = sp + 328 | 0; //@line 47925
 $val2_i1543 = sp + 336 | 0; //@line 47926
 $val2_i1520 = sp + 344 | 0; //@line 47927
 $val2_i1516 = sp + 352 | 0; //@line 47928
 $val2_i1493 = sp + 360 | 0; //@line 47929
 $val2_i1489 = sp + 368 | 0; //@line 47930
 $val2_i1466 = sp + 376 | 0; //@line 47931
 $val2_i1462 = sp + 384 | 0; //@line 47932
 $val2_i1439 = sp + 392 | 0; //@line 47933
 $val2_i1435 = sp + 400 | 0; //@line 47934
 $val2_i1412 = sp + 408 | 0; //@line 47935
 $val2_i1408 = sp + 416 | 0; //@line 47936
 $val2_i1385 = sp + 424 | 0; //@line 47937
 $val2_i1381 = sp + 432 | 0; //@line 47938
 $val2_i1358 = sp + 440 | 0; //@line 47939
 $val2_i1354 = sp + 448 | 0; //@line 47940
 $val2_i1331 = sp + 456 | 0; //@line 47941
 $val2_i1327 = sp + 464 | 0; //@line 47942
 $val2_i1304 = sp + 472 | 0; //@line 47943
 $val2_i1300 = sp + 480 | 0; //@line 47944
 $val2_i1277 = sp + 488 | 0; //@line 47945
 $val2_i1273 = sp + 496 | 0; //@line 47946
 $val2_i1250 = sp + 504 | 0; //@line 47947
 $val2_i1246 = sp + 512 | 0; //@line 47948
 $val2_i1223 = sp + 520 | 0; //@line 47949
 $val2_i1219 = sp + 528 | 0; //@line 47950
 $val2_i1196 = sp + 536 | 0; //@line 47951
 $val2_i1192 = sp + 544 | 0; //@line 47952
 $val2_i1169 = sp + 552 | 0; //@line 47953
 $val2_i1165 = sp + 560 | 0; //@line 47954
 $val2_i1142 = sp + 568 | 0; //@line 47955
 $val2_i1138 = sp + 576 | 0; //@line 47956
 $val2_i1115 = sp + 584 | 0; //@line 47957
 $val2_i1111 = sp + 592 | 0; //@line 47958
 $val2_i1088 = sp + 600 | 0; //@line 47959
 $val2_i1084 = sp + 608 | 0; //@line 47960
 $val2_i1061 = sp + 616 | 0; //@line 47961
 $val2_i1057 = sp + 624 | 0; //@line 47962
 $val2_i1034 = sp + 632 | 0; //@line 47963
 $val2_i1030 = sp + 640 | 0; //@line 47964
 $val2_i1007 = sp + 648 | 0; //@line 47965
 $val2_i1003 = sp + 656 | 0; //@line 47966
 $val2_i980 = sp + 664 | 0; //@line 47967
 $val2_i976 = sp + 672 | 0; //@line 47968
 $val2_i953 = sp + 680 | 0; //@line 47969
 $val2_i949 = sp + 688 | 0; //@line 47970
 $val2_i926 = sp + 696 | 0; //@line 47971
 $val2_i922 = sp + 704 | 0; //@line 47972
 $val2_i899 = sp + 712 | 0; //@line 47973
 $val2_i895 = sp + 720 | 0; //@line 47974
 $val2_i872 = sp + 728 | 0; //@line 47975
 $val2_i868 = sp + 736 | 0; //@line 47976
 $val2_i845 = sp + 744 | 0; //@line 47977
 $val2_i841 = sp + 752 | 0; //@line 47978
 $val2_i820 = sp + 760 | 0; //@line 47979
 $val2_i817 = sp + 768 | 0; //@line 47980
 $val2_i814 = sp + 776 | 0; //@line 47981
 $val2_i811 = sp + 784 | 0; //@line 47982
 $val2_i808 = sp + 792 | 0; //@line 47983
 $val2_i805 = sp + 800 | 0; //@line 47984
 $val2_i802 = sp + 808 | 0; //@line 47985
 $val2_i799 = sp + 816 | 0; //@line 47986
 $val2_i796 = sp + 824 | 0; //@line 47987
 $val2_i793 = sp + 832 | 0; //@line 47988
 $val2_i790 = sp + 840 | 0; //@line 47989
 $val2_i787 = sp + 848 | 0; //@line 47990
 $val2_i784 = sp + 856 | 0; //@line 47991
 $val2_i781 = sp + 864 | 0; //@line 47992
 $val2_i778 = sp + 872 | 0; //@line 47993
 $val2_i775 = sp + 880 | 0; //@line 47994
 $val2_i772 = sp + 888 | 0; //@line 47995
 $val2_i769 = sp + 896 | 0; //@line 47996
 $val2_i766 = sp + 904 | 0; //@line 47997
 $val2_i763 = sp + 912 | 0; //@line 47998
 $val2_i760 = sp + 920 | 0; //@line 47999
 $val2_i757 = sp + 928 | 0; //@line 48000
 $val2_i754 = sp + 936 | 0; //@line 48001
 $val2_i751 = sp + 944 | 0; //@line 48002
 $val2_i748 = sp + 952 | 0; //@line 48003
 $val2_i745 = sp + 960 | 0; //@line 48004
 $val2_i742 = sp + 968 | 0; //@line 48005
 $val2_i739 = sp + 976 | 0; //@line 48006
 $val2_i736 = sp + 984 | 0; //@line 48007
 $val2_i733 = sp + 992 | 0; //@line 48008
 $val2_i730 = sp + 1e3 | 0; //@line 48009
 $val2_i727 = sp + 1008 | 0; //@line 48010
 $val2_i724 = sp + 1016 | 0; //@line 48011
 $val2_i721 = sp + 1024 | 0; //@line 48012
 $val2_i718 = sp + 1032 | 0; //@line 48013
 $val2_i715 = sp + 1040 | 0; //@line 48014
 $val2_i712 = sp + 1048 | 0; //@line 48015
 $val2_i709 = sp + 1056 | 0; //@line 48016
 $val2_i706 = sp + 1064 | 0; //@line 48017
 $val2_i703 = sp + 1072 | 0; //@line 48018
 $val2_i700 = sp + 1080 | 0; //@line 48019
 $val2_i697 = sp + 1088 | 0; //@line 48020
 $val2_i694 = sp + 1096 | 0; //@line 48021
 $val2_i691 = sp + 1104 | 0; //@line 48022
 $val2_i688 = sp + 1112 | 0; //@line 48023
 $val2_i685 = sp + 1120 | 0; //@line 48024
 $val2_i682 = sp + 1128 | 0; //@line 48025
 $val2_i679 = sp + 1136 | 0; //@line 48026
 $val2_i677 = sp + 1144 | 0; //@line 48027
 $val2_i665 = sp + 1152 | 0; //@line 48028
 $val2_i634 = sp + 1160 | 0; //@line 48029
 $val2_i622 = sp + 1168 | 0; //@line 48030
 $val2_i591 = sp + 1176 | 0; //@line 48031
 $val2_i579 = sp + 1184 | 0; //@line 48032
 $val2_i548 = sp + 1192 | 0; //@line 48033
 $val2_i536 = sp + 1200 | 0; //@line 48034
 $val2_i505 = sp + 1208 | 0; //@line 48035
 $val2_i493 = sp + 1216 | 0; //@line 48036
 $val2_i462 = sp + 1224 | 0; //@line 48037
 $val2_i450 = sp + 1232 | 0; //@line 48038
 $val2_i419 = sp + 1240 | 0; //@line 48039
 $val2_i407 = sp + 1248 | 0; //@line 48040
 $val2_i376 = sp + 1256 | 0; //@line 48041
 $val2_i364 = sp + 1264 | 0; //@line 48042
 $val2_i333 = sp + 1272 | 0; //@line 48043
 $val2_i321 = sp + 1280 | 0; //@line 48044
 $val2_i290 = sp + 1288 | 0; //@line 48045
 $val2_i278 = sp + 1296 | 0; //@line 48046
 $val2_i247 = sp + 1304 | 0; //@line 48047
 $val2_i235 = sp + 1312 | 0; //@line 48048
 $val2_i204 = sp + 1320 | 0; //@line 48049
 $val2_i192 = sp + 1328 | 0; //@line 48050
 $val2_i165 = sp + 1336 | 0; //@line 48051
 $val2_i162 = sp + 1344 | 0; //@line 48052
 $val2_i159 = sp + 1352 | 0; //@line 48053
 $val2_i156 = sp + 1360 | 0; //@line 48054
 $val2_i153 = sp + 1368 | 0; //@line 48055
 $val2_i150 = sp + 1376 | 0; //@line 48056
 $val2_i147 = sp + 1384 | 0; //@line 48057
 $val2_i144 = sp + 1392 | 0; //@line 48058
 $val2_i141 = sp + 1400 | 0; //@line 48059
 $val2_i138 = sp + 1408 | 0; //@line 48060
 $val2_i135 = sp + 1416 | 0; //@line 48061
 $val2_i132 = sp + 1424 | 0; //@line 48062
 $val2_i130 = sp + 1432 | 0; //@line 48063
 $val2_i117 = sp + 1440 | 0; //@line 48064
 $val2_i104 = sp + 1448 | 0; //@line 48065
 $val2_i91 = sp + 1456 | 0; //@line 48066
 $val2_i78 = sp + 1464 | 0; //@line 48067
 $val2_i65 = sp + 1472 | 0; //@line 48068
 $val2_i53 = sp + 1480 | 0; //@line 48069
 $val2_i40 = sp + 1488 | 0; //@line 48070
 $val2_i27 = sp + 1496 | 0; //@line 48071
 $val2_i = sp + 1504 | 0; //@line 48072
 $val2 = sp + 1512 | 0; //@line 48073
 $val3 = sp + 1520 | 0; //@line 48074
 $1 = $cmd | 0; //@line 48075
 $2 = HEAP32[$1 >> 2] | 0; //@line 48076
 if ((_cmd_match_expr_cmp($cmd, $val, $base) | 0) == 0) {
  $_0 = 0; //@line 48087
  STACKTOP = sp; //@line 48089
  return $_0 | 0; //@line 48090
 }
 while (1) {
  $13 = HEAP32[$1 >> 2] | 0; //@line 48095
  while (1) {
   $14 = $cmd + 4 + $13 | 0; //@line 48098
   $15 = HEAP8[$14] | 0; //@line 48099
   if (!(($15 << 24 >> 24 | 0) == 13 | ($15 << 24 >> 24 | 0) == 32 | ($15 << 24 >> 24 | 0) == 9 | ($15 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $13 = $13 + 1 | 0; //@line 48105
  }
  HEAP32[$1 >> 2] = $13; //@line 48107
  $18 = HEAP8[$14] | 0; //@line 48108
  if ($18 << 24 >> 24 == 61) {
   if ((HEAP8[$13 + 1 + ($cmd + 4) | 0] | 0) == 61) {
    $op_0_i = 1;
    $storemerge4248_in = $13;
   } else {
    $i_0_i_i2124 = $13;
    $25 = 61;
    label = 14966; //@line 48119
   }
  } else {
   $i_0_i_i2124 = $13;
   $25 = $18;
   label = 14966; //@line 48123
  }
  if ((label | 0) == 14966) {
   while (1) {
    label = 0; //@line 48127
    if (!(($25 << 24 >> 24 | 0) == 13 | ($25 << 24 >> 24 | 0) == 32 | ($25 << 24 >> 24 | 0) == 9 | ($25 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $26 = $i_0_i_i2124 + 1 | 0; //@line 48133
    $i_0_i_i2124 = $26;
    $25 = HEAP8[$cmd + 4 + $26 | 0] | 0;
    label = 14966; //@line 48138
   }
   HEAP32[$1 >> 2] = $i_0_i_i2124; //@line 48141
   if ((HEAP8[$cmd + 4 + $i_0_i_i2124 | 0] | 0) != 33) {
    break;
   }
   if ((HEAP8[$i_0_i_i2124 + 1 + ($cmd + 4) | 0] | 0) == 61) {
    $op_0_i = 2;
    $storemerge4248_in = $i_0_i_i2124;
   } else {
    break;
   }
  }
  HEAP32[$1 >> 2] = $storemerge4248_in + 2; //@line 48160
  if ((_cmd_match_expr_cmp($cmd, $val2_i820, $base) | 0) == 0) {
   label = 14972; //@line 48165
   break;
  }
  if (($op_0_i | 0) == 1) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) == (HEAP32[$val2_i820 >> 2] | 0); //@line 48173
   continue;
  } else if (($op_0_i | 0) == 2) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) != (HEAP32[$val2_i820 >> 2] | 0); //@line 48181
   continue;
  } else {
   continue;
  }
 }
 if ((label | 0) == 14972) {
  HEAP32[$1 >> 2] = $2; //@line 48189
  $_0 = 0; //@line 48191
  STACKTOP = sp; //@line 48193
  return $_0 | 0; //@line 48194
 }
 $49 = $i_0_i_i2124; //@line 48198
 L19075 : while (1) {
  $51 = $49; //@line 48202
  while (1) {
   $52 = $cmd + 4 + $51 | 0; //@line 48205
   $53 = HEAP8[$52] | 0; //@line 48206
   if (!(($53 << 24 >> 24 | 0) == 13 | ($53 << 24 >> 24 | 0) == 32 | ($53 << 24 >> 24 | 0) == 9 | ($53 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $51 = $51 + 1 | 0; //@line 48212
  }
  HEAP32[$1 >> 2] = $51; //@line 48214
  $56 = HEAP8[$52] | 0; //@line 48215
  if ($56 << 24 >> 24 == 38) {
   if ((HEAP8[$51 + 1 + ($cmd + 4) | 0] | 0) == 38) {
    label = 17277; //@line 48223
    break;
   } else {
    $i_0_i_i831 = $51;
    $63 = 38;
   }
  } else {
   $i_0_i_i831 = $51;
   $63 = $56;
  }
  while (1) {
   if (!(($63 << 24 >> 24 | 0) == 13 | ($63 << 24 >> 24 | 0) == 32 | ($63 << 24 >> 24 | 0) == 9 | ($63 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $64 = $i_0_i_i831 + 1 | 0; //@line 48237
   $i_0_i_i831 = $64;
   $63 = HEAP8[$cmd + 4 + $64 | 0] | 0;
  }
  HEAP32[$1 >> 2] = $i_0_i_i831; //@line 48244
  if ((HEAP8[$cmd + 4 + $i_0_i_i831 | 0] | 0) != 38) {
   $68 = $i_0_i_i831; //@line 48248
   break;
  }
  $73 = $i_0_i_i831 + 1 | 0; //@line 48251
  HEAP32[$1 >> 2] = $73; //@line 48252
  if ((_cmd_match_expr_cmp($cmd, $val2_i677, $base) | 0) == 0) {
   label = 15e3; //@line 48257
   break;
  }
  while (1) {
   $78 = HEAP32[$1 >> 2] | 0; //@line 48263
   while (1) {
    $79 = $cmd + 4 + $78 | 0; //@line 48266
    $80 = HEAP8[$79] | 0; //@line 48267
    if (!(($80 << 24 >> 24 | 0) == 13 | ($80 << 24 >> 24 | 0) == 32 | ($80 << 24 >> 24 | 0) == 9 | ($80 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $78 = $78 + 1 | 0; //@line 48273
   }
   HEAP32[$1 >> 2] = $78; //@line 48275
   $83 = HEAP8[$79] | 0; //@line 48276
   if ($83 << 24 >> 24 == 61) {
    if ((HEAP8[$78 + 1 + ($cmd + 4) | 0] | 0) == 61) {
     $op_0_i842 = 1;
     $storemerge4247_in = $78;
    } else {
     $i_0_i_i2144 = $78;
     $90 = 61;
     label = 14991; //@line 48287
    }
   } else {
    $i_0_i_i2144 = $78;
    $90 = $83;
    label = 14991; //@line 48291
   }
   if ((label | 0) == 14991) {
    while (1) {
     label = 0; //@line 48295
     if (!(($90 << 24 >> 24 | 0) == 13 | ($90 << 24 >> 24 | 0) == 32 | ($90 << 24 >> 24 | 0) == 9 | ($90 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $91 = $i_0_i_i2144 + 1 | 0; //@line 48301
     $i_0_i_i2144 = $91;
     $90 = HEAP8[$cmd + 4 + $91 | 0] | 0;
     label = 14991; //@line 48306
    }
    HEAP32[$1 >> 2] = $i_0_i_i2144; //@line 48309
    if ((HEAP8[$cmd + 4 + $i_0_i_i2144 | 0] | 0) != 33) {
     break;
    }
    if ((HEAP8[$i_0_i_i2144 + 1 + ($cmd + 4) | 0] | 0) == 61) {
     $op_0_i842 = 2;
     $storemerge4247_in = $i_0_i_i2144;
    } else {
     break;
    }
   }
   HEAP32[$1 >> 2] = $storemerge4247_in + 2; //@line 48328
   if ((_cmd_match_expr_cmp($cmd, $val2_i841, $base) | 0) == 0) {
    label = 14996; //@line 48333
    break L19075;
   }
   if (($op_0_i842 | 0) == 1) {
    HEAP32[$val2_i677 >> 2] = (HEAP32[$val2_i677 >> 2] | 0) == (HEAP32[$val2_i841 >> 2] | 0); //@line 48341
    continue;
   } else if (($op_0_i842 | 0) == 2) {
    HEAP32[$val2_i677 >> 2] = (HEAP32[$val2_i677 >> 2] | 0) != (HEAP32[$val2_i841 >> 2] | 0); //@line 48349
    continue;
   } else {
    continue;
   }
  }
  HEAP32[$val >> 2] = HEAP32[$val2_i677 >> 2] & HEAP32[$val >> 2]; //@line 48359
  $49 = HEAP32[$1 >> 2] | 0; //@line 48362
 }
 if ((label | 0) == 14996) {
  HEAP32[$1 >> 2] = $73; //@line 48365
  label = 15e3; //@line 48367
 } else if ((label | 0) == 17277) {
  HEAP32[$1 >> 2] = $49; //@line 48370
  $68 = $49; //@line 48372
 }
 if ((label | 0) == 15e3) {
  HEAP32[$1 >> 2] = $2; //@line 48375
  $_0 = 0; //@line 48377
  STACKTOP = sp; //@line 48379
  return $_0 | 0; //@line 48380
 }
 $i_0_i_i_i166 = $68; //@line 48387
 L19115 : while (1) {
  $116 = $cmd + 4 + $i_0_i_i_i166 | 0; //@line 48390
  $117 = HEAP8[$116] | 0; //@line 48391
  if (($117 << 24 >> 24 | 0) == 13 | ($117 << 24 >> 24 | 0) == 32 | ($117 << 24 >> 24 | 0) == 9 | ($117 << 24 >> 24 | 0) == 10) {
   $i_0_i_i_i166 = $i_0_i_i_i166 + 1 | 0; //@line 48395
   continue;
  }
  HEAP32[$1 >> 2] = $i_0_i_i_i166; //@line 48398
  if ((HEAP8[$116] | 0) != 94) {
   label = 15005; //@line 48402
   break;
  }
  $130 = $i_0_i_i_i166 + 1 | 0; //@line 48405
  HEAP32[$1 >> 2] = $130; //@line 48406
  if ((_cmd_match_expr_cmp($cmd, $val2_i165, $base) | 0) == 0) {
   break;
  }
  while (1) {
   $135 = HEAP32[$1 >> 2] | 0; //@line 48416
   while (1) {
    $136 = $cmd + 4 + $135 | 0; //@line 48419
    $137 = HEAP8[$136] | 0; //@line 48420
    if (!(($137 << 24 >> 24 | 0) == 13 | ($137 << 24 >> 24 | 0) == 32 | ($137 << 24 >> 24 | 0) == 9 | ($137 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $135 = $135 + 1 | 0; //@line 48426
   }
   HEAP32[$1 >> 2] = $135; //@line 48428
   $140 = HEAP8[$136] | 0; //@line 48429
   if ($140 << 24 >> 24 == 61) {
    if ((HEAP8[$135 + 1 + ($cmd + 4) | 0] | 0) == 61) {
     $op_0_i846 = 1;
     $storemerge4246_in = $135;
    } else {
     $i_0_i_i2164 = $135;
     $147 = 61;
     label = 15012; //@line 48440
    }
   } else {
    $i_0_i_i2164 = $135;
    $147 = $140;
    label = 15012; //@line 48444
   }
   if ((label | 0) == 15012) {
    while (1) {
     label = 0; //@line 48448
     if (!(($147 << 24 >> 24 | 0) == 13 | ($147 << 24 >> 24 | 0) == 32 | ($147 << 24 >> 24 | 0) == 9 | ($147 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $148 = $i_0_i_i2164 + 1 | 0; //@line 48454
     $i_0_i_i2164 = $148;
     $147 = HEAP8[$cmd + 4 + $148 | 0] | 0;
     label = 15012; //@line 48459
    }
    HEAP32[$1 >> 2] = $i_0_i_i2164; //@line 48462
    if ((HEAP8[$cmd + 4 + $i_0_i_i2164 | 0] | 0) != 33) {
     $170 = $i_0_i_i2164; //@line 48466
     break;
    }
    if ((HEAP8[$i_0_i_i2164 + 1 + ($cmd + 4) | 0] | 0) == 61) {
     $op_0_i846 = 2;
     $storemerge4246_in = $i_0_i_i2164;
    } else {
     $170 = $i_0_i_i2164; //@line 48476
     break;
    }
   }
   HEAP32[$1 >> 2] = $storemerge4246_in + 2; //@line 48483
   if ((_cmd_match_expr_cmp($cmd, $val2_i845, $base) | 0) == 0) {
    label = 15017; //@line 48488
    break L19115;
   }
   if (($op_0_i846 | 0) == 1) {
    HEAP32[$val2_i165 >> 2] = (HEAP32[$val2_i165 >> 2] | 0) == (HEAP32[$val2_i845 >> 2] | 0); //@line 48496
    continue;
   } else if (($op_0_i846 | 0) == 2) {
    HEAP32[$val2_i165 >> 2] = (HEAP32[$val2_i165 >> 2] | 0) != (HEAP32[$val2_i845 >> 2] | 0); //@line 48504
    continue;
   } else {
    continue;
   }
  }
  while (1) {
   $172 = $170; //@line 48514
   while (1) {
    $173 = $cmd + 4 + $172 | 0; //@line 48517
    $174 = HEAP8[$173] | 0; //@line 48518
    if (!(($174 << 24 >> 24 | 0) == 13 | ($174 << 24 >> 24 | 0) == 32 | ($174 << 24 >> 24 | 0) == 9 | ($174 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $172 = $172 + 1 | 0; //@line 48524
   }
   HEAP32[$1 >> 2] = $172; //@line 48526
   $177 = HEAP8[$173] | 0; //@line 48527
   if ($177 << 24 >> 24 == 38) {
    if ((HEAP8[$172 + 1 + ($cmd + 4) | 0] | 0) == 38) {
     label = 17276; //@line 48535
     break;
    } else {
     $i_0_i_i858 = $172;
     $184 = 38;
    }
   } else {
    $i_0_i_i858 = $172;
    $184 = $177;
   }
   while (1) {
    if (!(($184 << 24 >> 24 | 0) == 13 | ($184 << 24 >> 24 | 0) == 32 | ($184 << 24 >> 24 | 0) == 9 | ($184 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $185 = $i_0_i_i858 + 1 | 0; //@line 48549
    $i_0_i_i858 = $185;
    $184 = HEAP8[$cmd + 4 + $185 | 0] | 0;
   }
   HEAP32[$1 >> 2] = $i_0_i_i858; //@line 48556
   if ((HEAP8[$cmd + 4 + $i_0_i_i858 | 0] | 0) != 38) {
    break;
   }
   $190 = $i_0_i_i858 + 1 | 0; //@line 48562
   HEAP32[$1 >> 2] = $190; //@line 48563
   if ((_cmd_match_expr_cmp($cmd, $val2_i679, $base) | 0) == 0) {
    label = 15044; //@line 48568
    break L19115;
   }
   while (1) {
    $195 = HEAP32[$1 >> 2] | 0; //@line 48574
    while (1) {
     $196 = $cmd + 4 + $195 | 0; //@line 48577
     $197 = HEAP8[$196] | 0; //@line 48578
     if (!(($197 << 24 >> 24 | 0) == 13 | ($197 << 24 >> 24 | 0) == 32 | ($197 << 24 >> 24 | 0) == 9 | ($197 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $195 = $195 + 1 | 0; //@line 48584
    }
    HEAP32[$1 >> 2] = $195; //@line 48586
    $200 = HEAP8[$196] | 0; //@line 48587
    if ($200 << 24 >> 24 == 61) {
     if ((HEAP8[$195 + 1 + ($cmd + 4) | 0] | 0) == 61) {
      $op_0_i869 = 1;
      $storemerge4245_in = $195;
     } else {
      $i_0_i_i2184 = $195;
      $207 = 61;
      label = 15035; //@line 48598
     }
    } else {
     $i_0_i_i2184 = $195;
     $207 = $200;
     label = 15035; //@line 48602
    }
    if ((label | 0) == 15035) {
     while (1) {
      label = 0; //@line 48606
      if (!(($207 << 24 >> 24 | 0) == 13 | ($207 << 24 >> 24 | 0) == 32 | ($207 << 24 >> 24 | 0) == 9 | ($207 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $208 = $i_0_i_i2184 + 1 | 0; //@line 48612
      $i_0_i_i2184 = $208;
      $207 = HEAP8[$cmd + 4 + $208 | 0] | 0;
      label = 15035; //@line 48617
     }
     HEAP32[$1 >> 2] = $i_0_i_i2184; //@line 48620
     if ((HEAP8[$cmd + 4 + $i_0_i_i2184 | 0] | 0) != 33) {
      break;
     }
     if ((HEAP8[$i_0_i_i2184 + 1 + ($cmd + 4) | 0] | 0) == 61) {
      $op_0_i869 = 2;
      $storemerge4245_in = $i_0_i_i2184;
     } else {
      break;
     }
    }
    HEAP32[$1 >> 2] = $storemerge4245_in + 2; //@line 48639
    if ((_cmd_match_expr_cmp($cmd, $val2_i868, $base) | 0) == 0) {
     label = 15040; //@line 48644
     break L19115;
    }
    if (($op_0_i869 | 0) == 1) {
     HEAP32[$val2_i679 >> 2] = (HEAP32[$val2_i679 >> 2] | 0) == (HEAP32[$val2_i868 >> 2] | 0); //@line 48652
     continue;
    } else if (($op_0_i869 | 0) == 2) {
     HEAP32[$val2_i679 >> 2] = (HEAP32[$val2_i679 >> 2] | 0) != (HEAP32[$val2_i868 >> 2] | 0); //@line 48660
     continue;
    } else {
     continue;
    }
   }
   HEAP32[$val2_i165 >> 2] = HEAP32[$val2_i679 >> 2] & HEAP32[$val2_i165 >> 2]; //@line 48670
   $170 = $i_0_i_i2184; //@line 48672
  }
  if ((label | 0) == 17276) {
   label = 0; //@line 48675
   HEAP32[$1 >> 2] = $170; //@line 48676
  }
  HEAP32[$val >> 2] = HEAP32[$val2_i165 >> 2] ^ HEAP32[$val >> 2]; //@line 48682
  $i_0_i_i_i166 = HEAP32[$1 >> 2] | 0; //@line 48685
 }
 if ((label | 0) == 15005) {
  $236 = $i_0_i_i_i166; //@line 48696
  L19178 : while (1) {
   $238 = $236; //@line 48700
   while (1) {
    $239 = $cmd + 4 + $238 | 0; //@line 48703
    $240 = HEAP8[$239] | 0; //@line 48704
    if (!(($240 << 24 >> 24 | 0) == 13 | ($240 << 24 >> 24 | 0) == 32 | ($240 << 24 >> 24 | 0) == 9 | ($240 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $238 = $238 + 1 | 0; //@line 48710
   }
   HEAP32[$1 >> 2] = $238; //@line 48712
   $243 = HEAP8[$239] | 0; //@line 48713
   if ($243 << 24 >> 24 == 124) {
    if ((HEAP8[$238 + 1 + ($cmd + 4) | 0] | 0) == 124) {
     label = 17273; //@line 48721
     break;
    } else {
     $i_0_i_i182 = $238;
     $250 = 124;
    }
   } else {
    $i_0_i_i182 = $238;
    $250 = $243;
   }
   while (1) {
    if (!(($250 << 24 >> 24 | 0) == 13 | ($250 << 24 >> 24 | 0) == 32 | ($250 << 24 >> 24 | 0) == 9 | ($250 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $251 = $i_0_i_i182 + 1 | 0; //@line 48735
    $i_0_i_i182 = $251;
    $250 = HEAP8[$cmd + 4 + $251 | 0] | 0;
   }
   HEAP32[$1 >> 2] = $i_0_i_i182; //@line 48742
   if ((HEAP8[$cmd + 4 + $i_0_i_i182 | 0] | 0) != 124) {
    $255 = $i_0_i_i182; //@line 48746
    label = 15056; //@line 48747
    break;
   }
   $272 = $i_0_i_i182 + 1 | 0; //@line 48750
   HEAP32[$1 >> 2] = $272; //@line 48751
   if ((_cmd_match_expr_cmp($cmd, $val2_i130, $base) | 0) == 0) {
    break;
   }
   while (1) {
    $277 = HEAP32[$1 >> 2] | 0; //@line 48761
    while (1) {
     $278 = $cmd + 4 + $277 | 0; //@line 48764
     $279 = HEAP8[$278] | 0; //@line 48765
     if (!(($279 << 24 >> 24 | 0) == 13 | ($279 << 24 >> 24 | 0) == 32 | ($279 << 24 >> 24 | 0) == 9 | ($279 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $277 = $277 + 1 | 0; //@line 48771
    }
    HEAP32[$1 >> 2] = $277; //@line 48773
    $282 = HEAP8[$278] | 0; //@line 48774
    if ($282 << 24 >> 24 == 61) {
     if ((HEAP8[$277 + 1 + ($cmd + 4) | 0] | 0) == 61) {
      $op_0_i873 = 1;
      $storemerge4244_in = $277;
     } else {
      $i_0_i_i2204 = $277;
      $289 = 61;
      label = 15063; //@line 48785
     }
    } else {
     $i_0_i_i2204 = $277;
     $289 = $282;
     label = 15063; //@line 48789
    }
    if ((label | 0) == 15063) {
     while (1) {
      label = 0; //@line 48793
      if (!(($289 << 24 >> 24 | 0) == 13 | ($289 << 24 >> 24 | 0) == 32 | ($289 << 24 >> 24 | 0) == 9 | ($289 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $290 = $i_0_i_i2204 + 1 | 0; //@line 48799
      $i_0_i_i2204 = $290;
      $289 = HEAP8[$cmd + 4 + $290 | 0] | 0;
      label = 15063; //@line 48804
     }
     HEAP32[$1 >> 2] = $i_0_i_i2204; //@line 48807
     if ((HEAP8[$cmd + 4 + $i_0_i_i2204 | 0] | 0) != 33) {
      $312 = $i_0_i_i2204; //@line 48811
      break;
     }
     if ((HEAP8[$i_0_i_i2204 + 1 + ($cmd + 4) | 0] | 0) == 61) {
      $op_0_i873 = 2;
      $storemerge4244_in = $i_0_i_i2204;
     } else {
      $312 = $i_0_i_i2204; //@line 48821
      break;
     }
    }
    HEAP32[$1 >> 2] = $storemerge4244_in + 2; //@line 48828
    if ((_cmd_match_expr_cmp($cmd, $val2_i872, $base) | 0) == 0) {
     label = 15068; //@line 48833
     break L19178;
    }
    if (($op_0_i873 | 0) == 1) {
     HEAP32[$val2_i130 >> 2] = (HEAP32[$val2_i130 >> 2] | 0) == (HEAP32[$val2_i872 >> 2] | 0); //@line 48841
     continue;
    } else if (($op_0_i873 | 0) == 2) {
     HEAP32[$val2_i130 >> 2] = (HEAP32[$val2_i130 >> 2] | 0) != (HEAP32[$val2_i872 >> 2] | 0); //@line 48849
     continue;
    } else {
     continue;
    }
   }
   while (1) {
    $314 = $312; //@line 48859
    while (1) {
     $315 = $cmd + 4 + $314 | 0; //@line 48862
     $316 = HEAP8[$315] | 0; //@line 48863
     if (!(($316 << 24 >> 24 | 0) == 13 | ($316 << 24 >> 24 | 0) == 32 | ($316 << 24 >> 24 | 0) == 9 | ($316 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $314 = $314 + 1 | 0; //@line 48869
    }
    HEAP32[$1 >> 2] = $314; //@line 48871
    $319 = HEAP8[$315] | 0; //@line 48872
    if ($319 << 24 >> 24 == 38) {
     if ((HEAP8[$314 + 1 + ($cmd + 4) | 0] | 0) == 38) {
      label = 17274; //@line 48880
      break;
     } else {
      $i_0_i_i885 = $314;
      $326 = 38;
     }
    } else {
     $i_0_i_i885 = $314;
     $326 = $319;
    }
    while (1) {
     if (!(($326 << 24 >> 24 | 0) == 13 | ($326 << 24 >> 24 | 0) == 32 | ($326 << 24 >> 24 | 0) == 9 | ($326 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $327 = $i_0_i_i885 + 1 | 0; //@line 48894
     $i_0_i_i885 = $327;
     $326 = HEAP8[$cmd + 4 + $327 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $i_0_i_i885; //@line 48901
    if ((HEAP8[$cmd + 4 + $i_0_i_i885 | 0] | 0) != 38) {
     $i_0_i_i_i193 = $i_0_i_i885; //@line 48905
     break;
    }
    $332 = $i_0_i_i885 + 1 | 0; //@line 48908
    HEAP32[$1 >> 2] = $332; //@line 48909
    if ((_cmd_match_expr_cmp($cmd, $val2_i682, $base) | 0) == 0) {
     label = 15095; //@line 48914
     break L19178;
    }
    while (1) {
     $337 = HEAP32[$1 >> 2] | 0; //@line 48920
     while (1) {
      $338 = $cmd + 4 + $337 | 0; //@line 48923
      $339 = HEAP8[$338] | 0; //@line 48924
      if (!(($339 << 24 >> 24 | 0) == 13 | ($339 << 24 >> 24 | 0) == 32 | ($339 << 24 >> 24 | 0) == 9 | ($339 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $337 = $337 + 1 | 0; //@line 48930
     }
     HEAP32[$1 >> 2] = $337; //@line 48932
     $342 = HEAP8[$338] | 0; //@line 48933
     if ($342 << 24 >> 24 == 61) {
      if ((HEAP8[$337 + 1 + ($cmd + 4) | 0] | 0) == 61) {
       $op_0_i896 = 1;
       $storemerge4243_in = $337;
      } else {
       $i_0_i_i2224 = $337;
       $349 = 61;
       label = 15086; //@line 48944
      }
     } else {
      $i_0_i_i2224 = $337;
      $349 = $342;
      label = 15086; //@line 48948
     }
     if ((label | 0) == 15086) {
      while (1) {
       label = 0; //@line 48952
       if (!(($349 << 24 >> 24 | 0) == 13 | ($349 << 24 >> 24 | 0) == 32 | ($349 << 24 >> 24 | 0) == 9 | ($349 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $350 = $i_0_i_i2224 + 1 | 0; //@line 48958
       $i_0_i_i2224 = $350;
       $349 = HEAP8[$cmd + 4 + $350 | 0] | 0;
       label = 15086; //@line 48963
      }
      HEAP32[$1 >> 2] = $i_0_i_i2224; //@line 48966
      if ((HEAP8[$cmd + 4 + $i_0_i_i2224 | 0] | 0) != 33) {
       break;
      }
      if ((HEAP8[$i_0_i_i2224 + 1 + ($cmd + 4) | 0] | 0) == 61) {
       $op_0_i896 = 2;
       $storemerge4243_in = $i_0_i_i2224;
      } else {
       break;
      }
     }
     HEAP32[$1 >> 2] = $storemerge4243_in + 2; //@line 48985
     if ((_cmd_match_expr_cmp($cmd, $val2_i895, $base) | 0) == 0) {
      label = 15091; //@line 48990
      break L19178;
     }
     if (($op_0_i896 | 0) == 1) {
      HEAP32[$val2_i682 >> 2] = (HEAP32[$val2_i682 >> 2] | 0) == (HEAP32[$val2_i895 >> 2] | 0); //@line 48998
      continue;
     } else if (($op_0_i896 | 0) == 2) {
      HEAP32[$val2_i682 >> 2] = (HEAP32[$val2_i682 >> 2] | 0) != (HEAP32[$val2_i895 >> 2] | 0); //@line 49006
      continue;
     } else {
      continue;
     }
    }
    HEAP32[$val2_i130 >> 2] = HEAP32[$val2_i682 >> 2] & HEAP32[$val2_i130 >> 2]; //@line 49016
    $312 = $i_0_i_i2224; //@line 49018
   }
   if ((label | 0) == 17274) {
    label = 0; //@line 49021
    HEAP32[$1 >> 2] = $312; //@line 49022
    $i_0_i_i_i193 = $312; //@line 49024
   }
   while (1) {
    $375 = $cmd + 4 + $i_0_i_i_i193 | 0; //@line 49028
    $376 = HEAP8[$375] | 0; //@line 49029
    if (($376 << 24 >> 24 | 0) == 13 | ($376 << 24 >> 24 | 0) == 32 | ($376 << 24 >> 24 | 0) == 9 | ($376 << 24 >> 24 | 0) == 10) {
     $i_0_i_i_i193 = $i_0_i_i_i193 + 1 | 0; //@line 49033
     continue;
    }
    HEAP32[$1 >> 2] = $i_0_i_i_i193; //@line 49036
    if ((HEAP8[$375] | 0) != 94) {
     break;
    }
    $382 = $i_0_i_i_i193 + 1 | 0; //@line 49042
    HEAP32[$1 >> 2] = $382; //@line 49043
    if ((_cmd_match_expr_cmp($cmd, $val2_i192, $base) | 0) == 0) {
     label = 15140; //@line 49048
     break L19178;
    }
    while (1) {
     $387 = HEAP32[$1 >> 2] | 0; //@line 49054
     while (1) {
      $388 = $cmd + 4 + $387 | 0; //@line 49057
      $389 = HEAP8[$388] | 0; //@line 49058
      if (!(($389 << 24 >> 24 | 0) == 13 | ($389 << 24 >> 24 | 0) == 32 | ($389 << 24 >> 24 | 0) == 9 | ($389 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $387 = $387 + 1 | 0; //@line 49064
     }
     HEAP32[$1 >> 2] = $387; //@line 49066
     $392 = HEAP8[$388] | 0; //@line 49067
     if ($392 << 24 >> 24 == 61) {
      if ((HEAP8[$387 + 1 + ($cmd + 4) | 0] | 0) == 61) {
       $op_0_i900 = 1;
       $storemerge4242_in = $387;
      } else {
       $i_0_i_i2244 = $387;
       $399 = 61;
       label = 15106; //@line 49078
      }
     } else {
      $i_0_i_i2244 = $387;
      $399 = $392;
      label = 15106; //@line 49082
     }
     if ((label | 0) == 15106) {
      while (1) {
       label = 0; //@line 49086
       if (!(($399 << 24 >> 24 | 0) == 13 | ($399 << 24 >> 24 | 0) == 32 | ($399 << 24 >> 24 | 0) == 9 | ($399 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $400 = $i_0_i_i2244 + 1 | 0; //@line 49092
       $i_0_i_i2244 = $400;
       $399 = HEAP8[$cmd + 4 + $400 | 0] | 0;
       label = 15106; //@line 49097
      }
      HEAP32[$1 >> 2] = $i_0_i_i2244; //@line 49100
      if ((HEAP8[$cmd + 4 + $i_0_i_i2244 | 0] | 0) != 33) {
       $422 = $i_0_i_i2244; //@line 49104
       break;
      }
      if ((HEAP8[$i_0_i_i2244 + 1 + ($cmd + 4) | 0] | 0) == 61) {
       $op_0_i900 = 2;
       $storemerge4242_in = $i_0_i_i2244;
      } else {
       $422 = $i_0_i_i2244; //@line 49114
       break;
      }
     }
     HEAP32[$1 >> 2] = $storemerge4242_in + 2; //@line 49121
     if ((_cmd_match_expr_cmp($cmd, $val2_i899, $base) | 0) == 0) {
      label = 15111; //@line 49126
      break L19178;
     }
     if (($op_0_i900 | 0) == 2) {
      HEAP32[$val2_i192 >> 2] = (HEAP32[$val2_i192 >> 2] | 0) != (HEAP32[$val2_i899 >> 2] | 0); //@line 49134
      continue;
     } else if (($op_0_i900 | 0) == 1) {
      HEAP32[$val2_i192 >> 2] = (HEAP32[$val2_i192 >> 2] | 0) == (HEAP32[$val2_i899 >> 2] | 0); //@line 49142
      continue;
     } else {
      continue;
     }
    }
    while (1) {
     $424 = $422; //@line 49152
     while (1) {
      $425 = $cmd + 4 + $424 | 0; //@line 49155
      $426 = HEAP8[$425] | 0; //@line 49156
      if (!(($426 << 24 >> 24 | 0) == 13 | ($426 << 24 >> 24 | 0) == 32 | ($426 << 24 >> 24 | 0) == 9 | ($426 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $424 = $424 + 1 | 0; //@line 49162
     }
     HEAP32[$1 >> 2] = $424; //@line 49164
     $429 = HEAP8[$425] | 0; //@line 49165
     if ($429 << 24 >> 24 == 38) {
      if ((HEAP8[$424 + 1 + ($cmd + 4) | 0] | 0) == 38) {
       label = 17275; //@line 49173
       break;
      } else {
       $i_0_i_i912 = $424;
       $436 = 38;
      }
     } else {
      $i_0_i_i912 = $424;
      $436 = $429;
     }
     while (1) {
      if (!(($436 << 24 >> 24 | 0) == 13 | ($436 << 24 >> 24 | 0) == 32 | ($436 << 24 >> 24 | 0) == 9 | ($436 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $437 = $i_0_i_i912 + 1 | 0; //@line 49187
      $i_0_i_i912 = $437;
      $436 = HEAP8[$cmd + 4 + $437 | 0] | 0;
     }
     HEAP32[$1 >> 2] = $i_0_i_i912; //@line 49194
     if ((HEAP8[$cmd + 4 + $i_0_i_i912 | 0] | 0) != 38) {
      $485 = $i_0_i_i912; //@line 49198
      break;
     }
     $442 = $i_0_i_i912 + 1 | 0; //@line 49201
     HEAP32[$1 >> 2] = $442; //@line 49202
     if ((_cmd_match_expr_cmp($cmd, $val2_i685, $base) | 0) == 0) {
      label = 15138; //@line 49207
      break L19178;
     }
     while (1) {
      $447 = HEAP32[$1 >> 2] | 0; //@line 49213
      while (1) {
       $448 = $cmd + 4 + $447 | 0; //@line 49216
       $449 = HEAP8[$448] | 0; //@line 49217
       if (!(($449 << 24 >> 24 | 0) == 13 | ($449 << 24 >> 24 | 0) == 32 | ($449 << 24 >> 24 | 0) == 9 | ($449 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $447 = $447 + 1 | 0; //@line 49223
      }
      HEAP32[$1 >> 2] = $447; //@line 49225
      $452 = HEAP8[$448] | 0; //@line 49226
      if ($452 << 24 >> 24 == 61) {
       if ((HEAP8[$447 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i923 = 1;
        $storemerge4241_in = $447;
       } else {
        $i_0_i_i2264 = $447;
        $459 = 61;
        label = 15129; //@line 49237
       }
      } else {
       $i_0_i_i2264 = $447;
       $459 = $452;
       label = 15129; //@line 49241
      }
      if ((label | 0) == 15129) {
       while (1) {
        label = 0; //@line 49245
        if (!(($459 << 24 >> 24 | 0) == 13 | ($459 << 24 >> 24 | 0) == 32 | ($459 << 24 >> 24 | 0) == 9 | ($459 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $460 = $i_0_i_i2264 + 1 | 0; //@line 49251
        $i_0_i_i2264 = $460;
        $459 = HEAP8[$cmd + 4 + $460 | 0] | 0;
        label = 15129; //@line 49256
       }
       HEAP32[$1 >> 2] = $i_0_i_i2264; //@line 49259
       if ((HEAP8[$cmd + 4 + $i_0_i_i2264 | 0] | 0) != 33) {
        break;
       }
       if ((HEAP8[$i_0_i_i2264 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i923 = 2;
        $storemerge4241_in = $i_0_i_i2264;
       } else {
        break;
       }
      }
      HEAP32[$1 >> 2] = $storemerge4241_in + 2; //@line 49278
      if ((_cmd_match_expr_cmp($cmd, $val2_i922, $base) | 0) == 0) {
       label = 15134; //@line 49283
       break L19178;
      }
      if (($op_0_i923 | 0) == 1) {
       HEAP32[$val2_i685 >> 2] = (HEAP32[$val2_i685 >> 2] | 0) == (HEAP32[$val2_i922 >> 2] | 0); //@line 49291
       continue;
      } else if (($op_0_i923 | 0) == 2) {
       HEAP32[$val2_i685 >> 2] = (HEAP32[$val2_i685 >> 2] | 0) != (HEAP32[$val2_i922 >> 2] | 0); //@line 49299
       continue;
      } else {
       continue;
      }
     }
     HEAP32[$val2_i192 >> 2] = HEAP32[$val2_i685 >> 2] & HEAP32[$val2_i192 >> 2]; //@line 49309
     $422 = $i_0_i_i2264; //@line 49311
    }
    if ((label | 0) == 17275) {
     label = 0; //@line 49314
     HEAP32[$1 >> 2] = $422; //@line 49315
     $485 = $422; //@line 49317
    }
    HEAP32[$val2_i130 >> 2] = HEAP32[$val2_i192 >> 2] ^ HEAP32[$val2_i130 >> 2]; //@line 49323
    $i_0_i_i_i193 = $485; //@line 49325
   }
   HEAP32[$val >> 2] = HEAP32[$val2_i130 >> 2] | HEAP32[$val >> 2]; //@line 49330
   $236 = HEAP32[$1 >> 2] | 0; //@line 49333
  }
  if ((label | 0) == 15111) {
   HEAP32[$1 >> 2] = $382; //@line 49336
   label = 15140; //@line 49338
  } else if ((label | 0) == 15068) {
   HEAP32[$1 >> 2] = $272; //@line 49341
  } else if ((label | 0) == 15134) {
   HEAP32[$1 >> 2] = $442; //@line 49345
   label = 15138; //@line 49347
  } else if ((label | 0) == 15091) {
   HEAP32[$1 >> 2] = $332; //@line 49350
   label = 15095; //@line 49352
  } else if ((label | 0) == 17273) {
   HEAP32[$1 >> 2] = $236; //@line 49355
   $255 = $236; //@line 49357
   label = 15056; //@line 49358
  }
  if ((label | 0) == 15138) {
   HEAP32[$1 >> 2] = $382; //@line 49361
   label = 15140; //@line 49363
  } else if ((label | 0) == 15056) {
   $i_0_i_i_i54 = $255; //@line 49383
   L19316 : while (1) {
    $493 = $cmd + 4 + $i_0_i_i_i54 | 0; //@line 49386
    $494 = HEAP8[$493] | 0; //@line 49387
    if (($494 << 24 >> 24 | 0) == 13 | ($494 << 24 >> 24 | 0) == 32 | ($494 << 24 >> 24 | 0) == 9 | ($494 << 24 >> 24 | 0) == 10) {
     $i_0_i_i_i54 = $i_0_i_i_i54 + 1 | 0; //@line 49391
     continue;
    }
    HEAP32[$1 >> 2] = $i_0_i_i_i54; //@line 49394
    if ((HEAP8[$493] | 0) != 38) {
     label = 15147; //@line 49398
     break;
    }
    if ((HEAP8[$i_0_i_i_i54 + 1 + ($cmd + 4) | 0] | 0) != 38) {
     label = 15147; //@line 49406
     break;
    }
    $5881 = $i_0_i_i_i54 + 2 | 0; //@line 49409
    HEAP32[$1 >> 2] = $5881; //@line 49410
    if ((_cmd_match_expr_cmp($cmd, $val2_i53, $base) | 0) == 0) {
     break;
    }
    while (1) {
     $536 = HEAP32[$1 >> 2] | 0; //@line 49420
     while (1) {
      $537 = $cmd + 4 + $536 | 0; //@line 49423
      $538 = HEAP8[$537] | 0; //@line 49424
      if (!(($538 << 24 >> 24 | 0) == 13 | ($538 << 24 >> 24 | 0) == 32 | ($538 << 24 >> 24 | 0) == 9 | ($538 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $536 = $536 + 1 | 0; //@line 49430
     }
     HEAP32[$1 >> 2] = $536; //@line 49432
     $541 = HEAP8[$537] | 0; //@line 49433
     if ($541 << 24 >> 24 == 61) {
      if ((HEAP8[$536 + 1 + ($cmd + 4) | 0] | 0) == 61) {
       $op_0_i927 = 1;
       $storemerge4240_in = $536;
      } else {
       $i_0_i_i2284 = $536;
       $548 = 61;
       label = 15154; //@line 49444
      }
     } else {
      $i_0_i_i2284 = $536;
      $548 = $541;
      label = 15154; //@line 49448
     }
     if ((label | 0) == 15154) {
      while (1) {
       label = 0; //@line 49452
       if (!(($548 << 24 >> 24 | 0) == 13 | ($548 << 24 >> 24 | 0) == 32 | ($548 << 24 >> 24 | 0) == 9 | ($548 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $549 = $i_0_i_i2284 + 1 | 0; //@line 49458
       $i_0_i_i2284 = $549;
       $548 = HEAP8[$cmd + 4 + $549 | 0] | 0;
       label = 15154; //@line 49463
      }
      HEAP32[$1 >> 2] = $i_0_i_i2284; //@line 49466
      if ((HEAP8[$cmd + 4 + $i_0_i_i2284 | 0] | 0) != 33) {
       $571 = $i_0_i_i2284; //@line 49470
       break;
      }
      if ((HEAP8[$i_0_i_i2284 + 1 + ($cmd + 4) | 0] | 0) == 61) {
       $op_0_i927 = 2;
       $storemerge4240_in = $i_0_i_i2284;
      } else {
       $571 = $i_0_i_i2284; //@line 49480
       break;
      }
     }
     HEAP32[$1 >> 2] = $storemerge4240_in + 2; //@line 49487
     if ((_cmd_match_expr_cmp($cmd, $val2_i926, $base) | 0) == 0) {
      label = 15159; //@line 49492
      break L19316;
     }
     if (($op_0_i927 | 0) == 1) {
      HEAP32[$val2_i53 >> 2] = (HEAP32[$val2_i53 >> 2] | 0) == (HEAP32[$val2_i926 >> 2] | 0); //@line 49500
      continue;
     } else if (($op_0_i927 | 0) == 2) {
      HEAP32[$val2_i53 >> 2] = (HEAP32[$val2_i53 >> 2] | 0) != (HEAP32[$val2_i926 >> 2] | 0); //@line 49508
      continue;
     } else {
      continue;
     }
    }
    while (1) {
     $573 = $571; //@line 49518
     while (1) {
      $574 = $cmd + 4 + $573 | 0; //@line 49521
      $575 = HEAP8[$574] | 0; //@line 49522
      if (!(($575 << 24 >> 24 | 0) == 13 | ($575 << 24 >> 24 | 0) == 32 | ($575 << 24 >> 24 | 0) == 9 | ($575 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $573 = $573 + 1 | 0; //@line 49528
     }
     HEAP32[$1 >> 2] = $573; //@line 49530
     $578 = HEAP8[$574] | 0; //@line 49531
     if ($578 << 24 >> 24 == 38) {
      if ((HEAP8[$573 + 1 + ($cmd + 4) | 0] | 0) == 38) {
       label = 17268; //@line 49539
       break;
      } else {
       $i_0_i_i939 = $573;
       $585 = 38;
      }
     } else {
      $i_0_i_i939 = $573;
      $585 = $578;
     }
     while (1) {
      if (!(($585 << 24 >> 24 | 0) == 13 | ($585 << 24 >> 24 | 0) == 32 | ($585 << 24 >> 24 | 0) == 9 | ($585 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $586 = $i_0_i_i939 + 1 | 0; //@line 49553
      $i_0_i_i939 = $586;
      $585 = HEAP8[$cmd + 4 + $586 | 0] | 0;
     }
     HEAP32[$1 >> 2] = $i_0_i_i939; //@line 49560
     if ((HEAP8[$cmd + 4 + $i_0_i_i939 | 0] | 0) != 38) {
      $i_0_i_i_i205 = $i_0_i_i939; //@line 49564
      break;
     }
     $591 = $i_0_i_i939 + 1 | 0; //@line 49567
     HEAP32[$1 >> 2] = $591; //@line 49568
     if ((_cmd_match_expr_cmp($cmd, $val2_i688, $base) | 0) == 0) {
      label = 15186; //@line 49573
      break L19316;
     }
     while (1) {
      $596 = HEAP32[$1 >> 2] | 0; //@line 49579
      while (1) {
       $597 = $cmd + 4 + $596 | 0; //@line 49582
       $598 = HEAP8[$597] | 0; //@line 49583
       if (!(($598 << 24 >> 24 | 0) == 13 | ($598 << 24 >> 24 | 0) == 32 | ($598 << 24 >> 24 | 0) == 9 | ($598 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $596 = $596 + 1 | 0; //@line 49589
      }
      HEAP32[$1 >> 2] = $596; //@line 49591
      $601 = HEAP8[$597] | 0; //@line 49592
      if ($601 << 24 >> 24 == 61) {
       if ((HEAP8[$596 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i950 = 1;
        $storemerge4239_in = $596;
       } else {
        $i_0_i_i2304 = $596;
        $608 = 61;
        label = 15177; //@line 49603
       }
      } else {
       $i_0_i_i2304 = $596;
       $608 = $601;
       label = 15177; //@line 49607
      }
      if ((label | 0) == 15177) {
       while (1) {
        label = 0; //@line 49611
        if (!(($608 << 24 >> 24 | 0) == 13 | ($608 << 24 >> 24 | 0) == 32 | ($608 << 24 >> 24 | 0) == 9 | ($608 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $609 = $i_0_i_i2304 + 1 | 0; //@line 49617
        $i_0_i_i2304 = $609;
        $608 = HEAP8[$cmd + 4 + $609 | 0] | 0;
        label = 15177; //@line 49622
       }
       HEAP32[$1 >> 2] = $i_0_i_i2304; //@line 49625
       if ((HEAP8[$cmd + 4 + $i_0_i_i2304 | 0] | 0) != 33) {
        break;
       }
       if ((HEAP8[$i_0_i_i2304 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i950 = 2;
        $storemerge4239_in = $i_0_i_i2304;
       } else {
        break;
       }
      }
      HEAP32[$1 >> 2] = $storemerge4239_in + 2; //@line 49644
      if ((_cmd_match_expr_cmp($cmd, $val2_i949, $base) | 0) == 0) {
       label = 15182; //@line 49649
       break L19316;
      }
      if (($op_0_i950 | 0) == 1) {
       HEAP32[$val2_i688 >> 2] = (HEAP32[$val2_i688 >> 2] | 0) == (HEAP32[$val2_i949 >> 2] | 0); //@line 49657
       continue;
      } else if (($op_0_i950 | 0) == 2) {
       HEAP32[$val2_i688 >> 2] = (HEAP32[$val2_i688 >> 2] | 0) != (HEAP32[$val2_i949 >> 2] | 0); //@line 49665
       continue;
      } else {
       continue;
      }
     }
     HEAP32[$val2_i53 >> 2] = HEAP32[$val2_i688 >> 2] & HEAP32[$val2_i53 >> 2]; //@line 49675
     $571 = $i_0_i_i2304; //@line 49677
    }
    if ((label | 0) == 17268) {
     label = 0; //@line 49680
     HEAP32[$1 >> 2] = $571; //@line 49681
     $i_0_i_i_i205 = $571; //@line 49683
    }
    while (1) {
     $634 = $cmd + 4 + $i_0_i_i_i205 | 0; //@line 49687
     $635 = HEAP8[$634] | 0; //@line 49688
     if (($635 << 24 >> 24 | 0) == 13 | ($635 << 24 >> 24 | 0) == 32 | ($635 << 24 >> 24 | 0) == 9 | ($635 << 24 >> 24 | 0) == 10) {
      $i_0_i_i_i205 = $i_0_i_i_i205 + 1 | 0; //@line 49692
      continue;
     }
     HEAP32[$1 >> 2] = $i_0_i_i_i205; //@line 49695
     if ((HEAP8[$634] | 0) != 94) {
      $748 = $i_0_i_i_i205; //@line 49699
      break;
     }
     $641 = $i_0_i_i_i205 + 1 | 0; //@line 49702
     HEAP32[$1 >> 2] = $641; //@line 49703
     if ((_cmd_match_expr_cmp($cmd, $val2_i204, $base) | 0) == 0) {
      label = 15231; //@line 49708
      break L19316;
     }
     while (1) {
      $646 = HEAP32[$1 >> 2] | 0; //@line 49714
      while (1) {
       $647 = $cmd + 4 + $646 | 0; //@line 49717
       $648 = HEAP8[$647] | 0; //@line 49718
       if (!(($648 << 24 >> 24 | 0) == 13 | ($648 << 24 >> 24 | 0) == 32 | ($648 << 24 >> 24 | 0) == 9 | ($648 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $646 = $646 + 1 | 0; //@line 49724
      }
      HEAP32[$1 >> 2] = $646; //@line 49726
      $651 = HEAP8[$647] | 0; //@line 49727
      if ($651 << 24 >> 24 == 61) {
       if ((HEAP8[$646 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i954 = 1;
        $storemerge4238_in = $646;
       } else {
        $i_0_i_i2324 = $646;
        $658 = 61;
        label = 15197; //@line 49738
       }
      } else {
       $i_0_i_i2324 = $646;
       $658 = $651;
       label = 15197; //@line 49742
      }
      if ((label | 0) == 15197) {
       while (1) {
        label = 0; //@line 49746
        if (!(($658 << 24 >> 24 | 0) == 13 | ($658 << 24 >> 24 | 0) == 32 | ($658 << 24 >> 24 | 0) == 9 | ($658 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $659 = $i_0_i_i2324 + 1 | 0; //@line 49752
        $i_0_i_i2324 = $659;
        $658 = HEAP8[$cmd + 4 + $659 | 0] | 0;
        label = 15197; //@line 49757
       }
       HEAP32[$1 >> 2] = $i_0_i_i2324; //@line 49760
       if ((HEAP8[$cmd + 4 + $i_0_i_i2324 | 0] | 0) != 33) {
        $681 = $i_0_i_i2324; //@line 49764
        break;
       }
       if ((HEAP8[$i_0_i_i2324 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i954 = 2;
        $storemerge4238_in = $i_0_i_i2324;
       } else {
        $681 = $i_0_i_i2324; //@line 49774
        break;
       }
      }
      HEAP32[$1 >> 2] = $storemerge4238_in + 2; //@line 49781
      if ((_cmd_match_expr_cmp($cmd, $val2_i953, $base) | 0) == 0) {
       label = 15202; //@line 49786
       break L19316;
      }
      if (($op_0_i954 | 0) == 1) {
       HEAP32[$val2_i204 >> 2] = (HEAP32[$val2_i204 >> 2] | 0) == (HEAP32[$val2_i953 >> 2] | 0); //@line 49794
       continue;
      } else if (($op_0_i954 | 0) == 2) {
       HEAP32[$val2_i204 >> 2] = (HEAP32[$val2_i204 >> 2] | 0) != (HEAP32[$val2_i953 >> 2] | 0); //@line 49802
       continue;
      } else {
       continue;
      }
     }
     while (1) {
      $683 = $681; //@line 49812
      while (1) {
       $684 = $cmd + 4 + $683 | 0; //@line 49815
       $685 = HEAP8[$684] | 0; //@line 49816
       if (!(($685 << 24 >> 24 | 0) == 13 | ($685 << 24 >> 24 | 0) == 32 | ($685 << 24 >> 24 | 0) == 9 | ($685 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $683 = $683 + 1 | 0; //@line 49822
      }
      HEAP32[$1 >> 2] = $683; //@line 49824
      $688 = HEAP8[$684] | 0; //@line 49825
      if ($688 << 24 >> 24 == 38) {
       if ((HEAP8[$683 + 1 + ($cmd + 4) | 0] | 0) == 38) {
        label = 17269; //@line 49833
        break;
       } else {
        $i_0_i_i966 = $683;
        $695 = 38;
       }
      } else {
       $i_0_i_i966 = $683;
       $695 = $688;
      }
      while (1) {
       if (!(($695 << 24 >> 24 | 0) == 13 | ($695 << 24 >> 24 | 0) == 32 | ($695 << 24 >> 24 | 0) == 9 | ($695 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $696 = $i_0_i_i966 + 1 | 0; //@line 49847
       $i_0_i_i966 = $696;
       $695 = HEAP8[$cmd + 4 + $696 | 0] | 0;
      }
      HEAP32[$1 >> 2] = $i_0_i_i966; //@line 49854
      if ((HEAP8[$cmd + 4 + $i_0_i_i966 | 0] | 0) != 38) {
       $744 = $i_0_i_i966; //@line 49858
       break;
      }
      $701 = $i_0_i_i966 + 1 | 0; //@line 49861
      HEAP32[$1 >> 2] = $701; //@line 49862
      if ((_cmd_match_expr_cmp($cmd, $val2_i691, $base) | 0) == 0) {
       label = 15229; //@line 49867
       break L19316;
      }
      while (1) {
       $706 = HEAP32[$1 >> 2] | 0; //@line 49873
       while (1) {
        $707 = $cmd + 4 + $706 | 0; //@line 49876
        $708 = HEAP8[$707] | 0; //@line 49877
        if (!(($708 << 24 >> 24 | 0) == 13 | ($708 << 24 >> 24 | 0) == 32 | ($708 << 24 >> 24 | 0) == 9 | ($708 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $706 = $706 + 1 | 0; //@line 49883
       }
       HEAP32[$1 >> 2] = $706; //@line 49885
       $711 = HEAP8[$707] | 0; //@line 49886
       if ($711 << 24 >> 24 == 61) {
        if ((HEAP8[$706 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i977 = 1;
         $storemerge4237_in = $706;
        } else {
         $i_0_i_i2344 = $706;
         $718 = 61;
         label = 15220; //@line 49897
        }
       } else {
        $i_0_i_i2344 = $706;
        $718 = $711;
        label = 15220; //@line 49901
       }
       if ((label | 0) == 15220) {
        while (1) {
         label = 0; //@line 49905
         if (!(($718 << 24 >> 24 | 0) == 13 | ($718 << 24 >> 24 | 0) == 32 | ($718 << 24 >> 24 | 0) == 9 | ($718 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $719 = $i_0_i_i2344 + 1 | 0; //@line 49911
         $i_0_i_i2344 = $719;
         $718 = HEAP8[$cmd + 4 + $719 | 0] | 0;
         label = 15220; //@line 49916
        }
        HEAP32[$1 >> 2] = $i_0_i_i2344; //@line 49919
        if ((HEAP8[$cmd + 4 + $i_0_i_i2344 | 0] | 0) != 33) {
         break;
        }
        if ((HEAP8[$i_0_i_i2344 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i977 = 2;
         $storemerge4237_in = $i_0_i_i2344;
        } else {
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4237_in + 2; //@line 49938
       if ((_cmd_match_expr_cmp($cmd, $val2_i976, $base) | 0) == 0) {
        label = 15225; //@line 49943
        break L19316;
       }
       if (($op_0_i977 | 0) == 1) {
        HEAP32[$val2_i691 >> 2] = (HEAP32[$val2_i691 >> 2] | 0) == (HEAP32[$val2_i976 >> 2] | 0); //@line 49951
        continue;
       } else if (($op_0_i977 | 0) == 2) {
        HEAP32[$val2_i691 >> 2] = (HEAP32[$val2_i691 >> 2] | 0) != (HEAP32[$val2_i976 >> 2] | 0); //@line 49959
        continue;
       } else {
        continue;
       }
      }
      HEAP32[$val2_i204 >> 2] = HEAP32[$val2_i691 >> 2] & HEAP32[$val2_i204 >> 2]; //@line 49969
      $681 = $i_0_i_i2344; //@line 49971
     }
     if ((label | 0) == 17269) {
      label = 0; //@line 49974
      HEAP32[$1 >> 2] = $681; //@line 49975
      $744 = $681; //@line 49977
     }
     HEAP32[$val2_i53 >> 2] = HEAP32[$val2_i204 >> 2] ^ HEAP32[$val2_i53 >> 2]; //@line 49983
     $i_0_i_i_i205 = $744; //@line 49985
    }
    while (1) {
     $750 = $748; //@line 49990
     while (1) {
      $751 = $cmd + 4 + $750 | 0; //@line 49993
      $752 = HEAP8[$751] | 0; //@line 49994
      if (!(($752 << 24 >> 24 | 0) == 13 | ($752 << 24 >> 24 | 0) == 32 | ($752 << 24 >> 24 | 0) == 9 | ($752 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $750 = $750 + 1 | 0; //@line 50000
     }
     HEAP32[$1 >> 2] = $750; //@line 50002
     $755 = HEAP8[$751] | 0; //@line 50003
     if ($755 << 24 >> 24 == 124) {
      if ((HEAP8[$750 + 1 + ($cmd + 4) | 0] | 0) == 124) {
       label = 17270; //@line 50011
       break;
      } else {
       $i_0_i_i225 = $750;
       $762 = 124;
      }
     } else {
      $i_0_i_i225 = $750;
      $762 = $755;
     }
     while (1) {
      if (!(($762 << 24 >> 24 | 0) == 13 | ($762 << 24 >> 24 | 0) == 32 | ($762 << 24 >> 24 | 0) == 9 | ($762 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $763 = $i_0_i_i225 + 1 | 0; //@line 50025
      $i_0_i_i225 = $763;
      $762 = HEAP8[$cmd + 4 + $763 | 0] | 0;
     }
     HEAP32[$1 >> 2] = $i_0_i_i225; //@line 50032
     if ((HEAP8[$cmd + 4 + $i_0_i_i225 | 0] | 0) != 124) {
      break;
     }
     $768 = $i_0_i_i225 + 1 | 0; //@line 50038
     HEAP32[$1 >> 2] = $768; //@line 50039
     if ((_cmd_match_expr_cmp($cmd, $val2_i132, $base) | 0) == 0) {
      label = 15326; //@line 50044
      break L19316;
     }
     while (1) {
      $773 = HEAP32[$1 >> 2] | 0; //@line 50050
      while (1) {
       $774 = $cmd + 4 + $773 | 0; //@line 50053
       $775 = HEAP8[$774] | 0; //@line 50054
       if (!(($775 << 24 >> 24 | 0) == 13 | ($775 << 24 >> 24 | 0) == 32 | ($775 << 24 >> 24 | 0) == 9 | ($775 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $773 = $773 + 1 | 0; //@line 50060
      }
      HEAP32[$1 >> 2] = $773; //@line 50062
      $778 = HEAP8[$774] | 0; //@line 50063
      if ($778 << 24 >> 24 == 61) {
       if ((HEAP8[$773 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i981 = 1;
        $storemerge4236_in = $773;
       } else {
        $i_0_i_i2364 = $773;
        $785 = 61;
        label = 15247; //@line 50074
       }
      } else {
       $i_0_i_i2364 = $773;
       $785 = $778;
       label = 15247; //@line 50078
      }
      if ((label | 0) == 15247) {
       while (1) {
        label = 0; //@line 50082
        if (!(($785 << 24 >> 24 | 0) == 13 | ($785 << 24 >> 24 | 0) == 32 | ($785 << 24 >> 24 | 0) == 9 | ($785 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $786 = $i_0_i_i2364 + 1 | 0; //@line 50088
        $i_0_i_i2364 = $786;
        $785 = HEAP8[$cmd + 4 + $786 | 0] | 0;
        label = 15247; //@line 50093
       }
       HEAP32[$1 >> 2] = $i_0_i_i2364; //@line 50096
       if ((HEAP8[$cmd + 4 + $i_0_i_i2364 | 0] | 0) != 33) {
        $808 = $i_0_i_i2364; //@line 50100
        break;
       }
       if ((HEAP8[$i_0_i_i2364 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i981 = 2;
        $storemerge4236_in = $i_0_i_i2364;
       } else {
        $808 = $i_0_i_i2364; //@line 50110
        break;
       }
      }
      HEAP32[$1 >> 2] = $storemerge4236_in + 2; //@line 50117
      if ((_cmd_match_expr_cmp($cmd, $val2_i980, $base) | 0) == 0) {
       label = 15252; //@line 50122
       break L19316;
      }
      if (($op_0_i981 | 0) == 1) {
       HEAP32[$val2_i132 >> 2] = (HEAP32[$val2_i132 >> 2] | 0) == (HEAP32[$val2_i980 >> 2] | 0); //@line 50130
       continue;
      } else if (($op_0_i981 | 0) == 2) {
       HEAP32[$val2_i132 >> 2] = (HEAP32[$val2_i132 >> 2] | 0) != (HEAP32[$val2_i980 >> 2] | 0); //@line 50138
       continue;
      } else {
       continue;
      }
     }
     while (1) {
      $810 = $808; //@line 50148
      while (1) {
       $811 = $cmd + 4 + $810 | 0; //@line 50151
       $812 = HEAP8[$811] | 0; //@line 50152
       if (!(($812 << 24 >> 24 | 0) == 13 | ($812 << 24 >> 24 | 0) == 32 | ($812 << 24 >> 24 | 0) == 9 | ($812 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $810 = $810 + 1 | 0; //@line 50158
      }
      HEAP32[$1 >> 2] = $810; //@line 50160
      $815 = HEAP8[$811] | 0; //@line 50161
      if ($815 << 24 >> 24 == 38) {
       if ((HEAP8[$810 + 1 + ($cmd + 4) | 0] | 0) == 38) {
        label = 17271; //@line 50169
        break;
       } else {
        $i_0_i_i993 = $810;
        $822 = 38;
       }
      } else {
       $i_0_i_i993 = $810;
       $822 = $815;
      }
      while (1) {
       if (!(($822 << 24 >> 24 | 0) == 13 | ($822 << 24 >> 24 | 0) == 32 | ($822 << 24 >> 24 | 0) == 9 | ($822 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $823 = $i_0_i_i993 + 1 | 0; //@line 50183
       $i_0_i_i993 = $823;
       $822 = HEAP8[$cmd + 4 + $823 | 0] | 0;
      }
      HEAP32[$1 >> 2] = $i_0_i_i993; //@line 50190
      if ((HEAP8[$cmd + 4 + $i_0_i_i993 | 0] | 0) != 38) {
       $i_0_i_i_i236 = $i_0_i_i993; //@line 50194
       break;
      }
      $828 = $i_0_i_i993 + 1 | 0; //@line 50197
      HEAP32[$1 >> 2] = $828; //@line 50198
      if ((_cmd_match_expr_cmp($cmd, $val2_i694, $base) | 0) == 0) {
       label = 15279; //@line 50203
       break L19316;
      }
      while (1) {
       $833 = HEAP32[$1 >> 2] | 0; //@line 50209
       while (1) {
        $834 = $cmd + 4 + $833 | 0; //@line 50212
        $835 = HEAP8[$834] | 0; //@line 50213
        if (!(($835 << 24 >> 24 | 0) == 13 | ($835 << 24 >> 24 | 0) == 32 | ($835 << 24 >> 24 | 0) == 9 | ($835 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $833 = $833 + 1 | 0; //@line 50219
       }
       HEAP32[$1 >> 2] = $833; //@line 50221
       $838 = HEAP8[$834] | 0; //@line 50222
       if ($838 << 24 >> 24 == 61) {
        if ((HEAP8[$833 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1004 = 1;
         $storemerge4235_in = $833;
        } else {
         $i_0_i_i2384 = $833;
         $845 = 61;
         label = 15270; //@line 50233
        }
       } else {
        $i_0_i_i2384 = $833;
        $845 = $838;
        label = 15270; //@line 50237
       }
       if ((label | 0) == 15270) {
        while (1) {
         label = 0; //@line 50241
         if (!(($845 << 24 >> 24 | 0) == 13 | ($845 << 24 >> 24 | 0) == 32 | ($845 << 24 >> 24 | 0) == 9 | ($845 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $846 = $i_0_i_i2384 + 1 | 0; //@line 50247
         $i_0_i_i2384 = $846;
         $845 = HEAP8[$cmd + 4 + $846 | 0] | 0;
         label = 15270; //@line 50252
        }
        HEAP32[$1 >> 2] = $i_0_i_i2384; //@line 50255
        if ((HEAP8[$cmd + 4 + $i_0_i_i2384 | 0] | 0) != 33) {
         break;
        }
        if ((HEAP8[$i_0_i_i2384 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1004 = 2;
         $storemerge4235_in = $i_0_i_i2384;
        } else {
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4235_in + 2; //@line 50274
       if ((_cmd_match_expr_cmp($cmd, $val2_i1003, $base) | 0) == 0) {
        label = 15275; //@line 50279
        break L19316;
       }
       if (($op_0_i1004 | 0) == 1) {
        HEAP32[$val2_i694 >> 2] = (HEAP32[$val2_i694 >> 2] | 0) == (HEAP32[$val2_i1003 >> 2] | 0); //@line 50287
        continue;
       } else if (($op_0_i1004 | 0) == 2) {
        HEAP32[$val2_i694 >> 2] = (HEAP32[$val2_i694 >> 2] | 0) != (HEAP32[$val2_i1003 >> 2] | 0); //@line 50295
        continue;
       } else {
        continue;
       }
      }
      HEAP32[$val2_i132 >> 2] = HEAP32[$val2_i694 >> 2] & HEAP32[$val2_i132 >> 2]; //@line 50305
      $808 = $i_0_i_i2384; //@line 50307
     }
     if ((label | 0) == 17271) {
      label = 0; //@line 50310
      HEAP32[$1 >> 2] = $808; //@line 50311
      $i_0_i_i_i236 = $808; //@line 50313
     }
     while (1) {
      $871 = $cmd + 4 + $i_0_i_i_i236 | 0; //@line 50317
      $872 = HEAP8[$871] | 0; //@line 50318
      if (($872 << 24 >> 24 | 0) == 13 | ($872 << 24 >> 24 | 0) == 32 | ($872 << 24 >> 24 | 0) == 9 | ($872 << 24 >> 24 | 0) == 10) {
       $i_0_i_i_i236 = $i_0_i_i_i236 + 1 | 0; //@line 50322
       continue;
      }
      HEAP32[$1 >> 2] = $i_0_i_i_i236; //@line 50325
      if ((HEAP8[$871] | 0) != 94) {
       break;
      }
      $878 = $i_0_i_i_i236 + 1 | 0; //@line 50331
      HEAP32[$1 >> 2] = $878; //@line 50332
      if ((_cmd_match_expr_cmp($cmd, $val2_i235, $base) | 0) == 0) {
       label = 15324; //@line 50337
       break L19316;
      }
      while (1) {
       $883 = HEAP32[$1 >> 2] | 0; //@line 50343
       while (1) {
        $884 = $cmd + 4 + $883 | 0; //@line 50346
        $885 = HEAP8[$884] | 0; //@line 50347
        if (!(($885 << 24 >> 24 | 0) == 13 | ($885 << 24 >> 24 | 0) == 32 | ($885 << 24 >> 24 | 0) == 9 | ($885 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $883 = $883 + 1 | 0; //@line 50353
       }
       HEAP32[$1 >> 2] = $883; //@line 50355
       $888 = HEAP8[$884] | 0; //@line 50356
       if ($888 << 24 >> 24 == 61) {
        if ((HEAP8[$883 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1008 = 1;
         $storemerge4234_in = $883;
        } else {
         $i_0_i_i2404 = $883;
         $895 = 61;
         label = 15290; //@line 50367
        }
       } else {
        $i_0_i_i2404 = $883;
        $895 = $888;
        label = 15290; //@line 50371
       }
       if ((label | 0) == 15290) {
        while (1) {
         label = 0; //@line 50375
         if (!(($895 << 24 >> 24 | 0) == 13 | ($895 << 24 >> 24 | 0) == 32 | ($895 << 24 >> 24 | 0) == 9 | ($895 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $896 = $i_0_i_i2404 + 1 | 0; //@line 50381
         $i_0_i_i2404 = $896;
         $895 = HEAP8[$cmd + 4 + $896 | 0] | 0;
         label = 15290; //@line 50386
        }
        HEAP32[$1 >> 2] = $i_0_i_i2404; //@line 50389
        if ((HEAP8[$cmd + 4 + $i_0_i_i2404 | 0] | 0) != 33) {
         $918 = $i_0_i_i2404; //@line 50393
         break;
        }
        if ((HEAP8[$i_0_i_i2404 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1008 = 2;
         $storemerge4234_in = $i_0_i_i2404;
        } else {
         $918 = $i_0_i_i2404; //@line 50403
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4234_in + 2; //@line 50410
       if ((_cmd_match_expr_cmp($cmd, $val2_i1007, $base) | 0) == 0) {
        label = 15295; //@line 50415
        break L19316;
       }
       if (($op_0_i1008 | 0) == 1) {
        HEAP32[$val2_i235 >> 2] = (HEAP32[$val2_i235 >> 2] | 0) == (HEAP32[$val2_i1007 >> 2] | 0); //@line 50423
        continue;
       } else if (($op_0_i1008 | 0) == 2) {
        HEAP32[$val2_i235 >> 2] = (HEAP32[$val2_i235 >> 2] | 0) != (HEAP32[$val2_i1007 >> 2] | 0); //@line 50431
        continue;
       } else {
        continue;
       }
      }
      while (1) {
       $920 = $918; //@line 50441
       while (1) {
        $921 = $cmd + 4 + $920 | 0; //@line 50444
        $922 = HEAP8[$921] | 0; //@line 50445
        if (!(($922 << 24 >> 24 | 0) == 13 | ($922 << 24 >> 24 | 0) == 32 | ($922 << 24 >> 24 | 0) == 9 | ($922 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $920 = $920 + 1 | 0; //@line 50451
       }
       HEAP32[$1 >> 2] = $920; //@line 50453
       $925 = HEAP8[$921] | 0; //@line 50454
       if ($925 << 24 >> 24 == 38) {
        if ((HEAP8[$920 + 1 + ($cmd + 4) | 0] | 0) == 38) {
         label = 17272; //@line 50462
         break;
        } else {
         $i_0_i_i1020 = $920;
         $932 = 38;
        }
       } else {
        $i_0_i_i1020 = $920;
        $932 = $925;
       }
       while (1) {
        if (!(($932 << 24 >> 24 | 0) == 13 | ($932 << 24 >> 24 | 0) == 32 | ($932 << 24 >> 24 | 0) == 9 | ($932 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $933 = $i_0_i_i1020 + 1 | 0; //@line 50476
        $i_0_i_i1020 = $933;
        $932 = HEAP8[$cmd + 4 + $933 | 0] | 0;
       }
       HEAP32[$1 >> 2] = $i_0_i_i1020; //@line 50483
       if ((HEAP8[$cmd + 4 + $i_0_i_i1020 | 0] | 0) != 38) {
        $981 = $i_0_i_i1020; //@line 50487
        break;
       }
       $938 = $i_0_i_i1020 + 1 | 0; //@line 50490
       HEAP32[$1 >> 2] = $938; //@line 50491
       if ((_cmd_match_expr_cmp($cmd, $val2_i697, $base) | 0) == 0) {
        label = 15322; //@line 50496
        break L19316;
       }
       while (1) {
        $943 = HEAP32[$1 >> 2] | 0; //@line 50502
        while (1) {
         $944 = $cmd + 4 + $943 | 0; //@line 50505
         $945 = HEAP8[$944] | 0; //@line 50506
         if (!(($945 << 24 >> 24 | 0) == 13 | ($945 << 24 >> 24 | 0) == 32 | ($945 << 24 >> 24 | 0) == 9 | ($945 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $943 = $943 + 1 | 0; //@line 50512
        }
        HEAP32[$1 >> 2] = $943; //@line 50514
        $948 = HEAP8[$944] | 0; //@line 50515
        if ($948 << 24 >> 24 == 61) {
         if ((HEAP8[$943 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1031 = 1;
          $storemerge4233_in = $943;
         } else {
          $i_0_i_i2424 = $943;
          $955 = 61;
          label = 15313; //@line 50526
         }
        } else {
         $i_0_i_i2424 = $943;
         $955 = $948;
         label = 15313; //@line 50530
        }
        if ((label | 0) == 15313) {
         while (1) {
          label = 0; //@line 50534
          if (!(($955 << 24 >> 24 | 0) == 13 | ($955 << 24 >> 24 | 0) == 32 | ($955 << 24 >> 24 | 0) == 9 | ($955 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $956 = $i_0_i_i2424 + 1 | 0; //@line 50540
          $i_0_i_i2424 = $956;
          $955 = HEAP8[$cmd + 4 + $956 | 0] | 0;
          label = 15313; //@line 50545
         }
         HEAP32[$1 >> 2] = $i_0_i_i2424; //@line 50548
         if ((HEAP8[$cmd + 4 + $i_0_i_i2424 | 0] | 0) != 33) {
          break;
         }
         if ((HEAP8[$i_0_i_i2424 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1031 = 2;
          $storemerge4233_in = $i_0_i_i2424;
         } else {
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4233_in + 2; //@line 50567
        if ((_cmd_match_expr_cmp($cmd, $val2_i1030, $base) | 0) == 0) {
         label = 15318; //@line 50572
         break L19316;
        }
        if (($op_0_i1031 | 0) == 1) {
         HEAP32[$val2_i697 >> 2] = (HEAP32[$val2_i697 >> 2] | 0) == (HEAP32[$val2_i1030 >> 2] | 0); //@line 50580
         continue;
        } else if (($op_0_i1031 | 0) == 2) {
         HEAP32[$val2_i697 >> 2] = (HEAP32[$val2_i697 >> 2] | 0) != (HEAP32[$val2_i1030 >> 2] | 0); //@line 50588
         continue;
        } else {
         continue;
        }
       }
       HEAP32[$val2_i235 >> 2] = HEAP32[$val2_i697 >> 2] & HEAP32[$val2_i235 >> 2]; //@line 50598
       $918 = $i_0_i_i2424; //@line 50600
      }
      if ((label | 0) == 17272) {
       label = 0; //@line 50603
       HEAP32[$1 >> 2] = $918; //@line 50604
       $981 = $918; //@line 50606
      }
      HEAP32[$val2_i132 >> 2] = HEAP32[$val2_i235 >> 2] ^ HEAP32[$val2_i132 >> 2]; //@line 50612
      $i_0_i_i_i236 = $981; //@line 50614
     }
     HEAP32[$val2_i53 >> 2] = HEAP32[$val2_i132 >> 2] | HEAP32[$val2_i53 >> 2]; //@line 50619
     $748 = $i_0_i_i_i236; //@line 50621
    }
    if ((label | 0) == 17270) {
     label = 0; //@line 50624
     HEAP32[$1 >> 2] = $748; //@line 50625
    }
    if ((HEAP32[$val >> 2] | 0) == 0) {
     $995 = 0; //@line 50632
    } else {
     $995 = (HEAP32[$val2_i53 >> 2] | 0) != 0 | 0; //@line 50637
    }
    HEAP32[$val >> 2] = $995; //@line 50640
    $i_0_i_i_i54 = HEAP32[$1 >> 2] | 0; //@line 50643
   }
   if ((label | 0) == 15252) {
    HEAP32[$1 >> 2] = $768; //@line 50646
    label = 15326; //@line 50648
   } else if ((label | 0) == 15182) {
    HEAP32[$1 >> 2] = $591; //@line 50651
    label = 15186; //@line 50653
   } else if ((label | 0) == 15202) {
    HEAP32[$1 >> 2] = $641; //@line 50656
    label = 15231; //@line 50658
   } else if ((label | 0) == 15225) {
    HEAP32[$1 >> 2] = $701; //@line 50661
    label = 15229; //@line 50663
   } else if ((label | 0) == 15147) {
    $996 = $i_0_i_i_i54; //@line 50698
    L19579 : while (1) {
     $997 = $cmd + 4 + $996 | 0; //@line 50701
     $998 = HEAP8[$997] | 0; //@line 50702
     if (($998 << 24 >> 24 | 0) == 13 | ($998 << 24 >> 24 | 0) == 32 | ($998 << 24 >> 24 | 0) == 9 | ($998 << 24 >> 24 | 0) == 10) {
      $996 = $996 + 1 | 0; //@line 50706
      continue;
     }
     HEAP32[$1 >> 2] = $996; //@line 50709
     $1001 = HEAP8[$997] | 0; //@line 50710
     if ($1001 << 24 >> 24 != 124) {
      $i_0_i_i18 = $996;
      $1944 = $1001;
      label = 15706; //@line 50714
      break;
     }
     if ((HEAP8[$996 + 1 + ($cmd + 4) | 0] | 0) != 124) {
      $i_0_i_i18 = $996;
      $1944 = $1001;
      label = 15706; //@line 50723
      break;
     }
     $5873 = $996 + 2 | 0; //@line 50726
     HEAP32[$1 >> 2] = $5873; //@line 50727
     if ((_cmd_match_expr_cmp($cmd, $val2_i, $base) | 0) == 0) {
      break;
     }
     while (1) {
      $1009 = HEAP32[$1 >> 2] | 0; //@line 50737
      while (1) {
       $1010 = $cmd + 4 + $1009 | 0; //@line 50740
       $1011 = HEAP8[$1010] | 0; //@line 50741
       if (!(($1011 << 24 >> 24 | 0) == 13 | ($1011 << 24 >> 24 | 0) == 32 | ($1011 << 24 >> 24 | 0) == 9 | ($1011 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $1009 = $1009 + 1 | 0; //@line 50747
      }
      HEAP32[$1 >> 2] = $1009; //@line 50749
      $1014 = HEAP8[$1010] | 0; //@line 50750
      if ($1014 << 24 >> 24 == 61) {
       if ((HEAP8[$1009 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i1035 = 1;
        $storemerge4232_in = $1009;
       } else {
        $i_0_i_i2444 = $1009;
        $1021 = 61;
        label = 15341; //@line 50761
       }
      } else {
       $i_0_i_i2444 = $1009;
       $1021 = $1014;
       label = 15341; //@line 50765
      }
      if ((label | 0) == 15341) {
       while (1) {
        label = 0; //@line 50769
        if (!(($1021 << 24 >> 24 | 0) == 13 | ($1021 << 24 >> 24 | 0) == 32 | ($1021 << 24 >> 24 | 0) == 9 | ($1021 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1022 = $i_0_i_i2444 + 1 | 0; //@line 50775
        $i_0_i_i2444 = $1022;
        $1021 = HEAP8[$cmd + 4 + $1022 | 0] | 0;
        label = 15341; //@line 50780
       }
       HEAP32[$1 >> 2] = $i_0_i_i2444; //@line 50783
       if ((HEAP8[$cmd + 4 + $i_0_i_i2444 | 0] | 0) != 33) {
        $1044 = $i_0_i_i2444; //@line 50787
        break;
       }
       if ((HEAP8[$i_0_i_i2444 + 1 + ($cmd + 4) | 0] | 0) == 61) {
        $op_0_i1035 = 2;
        $storemerge4232_in = $i_0_i_i2444;
       } else {
        $1044 = $i_0_i_i2444; //@line 50797
        break;
       }
      }
      HEAP32[$1 >> 2] = $storemerge4232_in + 2; //@line 50804
      if ((_cmd_match_expr_cmp($cmd, $val2_i1034, $base) | 0) == 0) {
       label = 15346; //@line 50809
       break L19579;
      }
      if (($op_0_i1035 | 0) == 1) {
       HEAP32[$val2_i >> 2] = (HEAP32[$val2_i >> 2] | 0) == (HEAP32[$val2_i1034 >> 2] | 0); //@line 50817
       continue;
      } else if (($op_0_i1035 | 0) == 2) {
       HEAP32[$val2_i >> 2] = (HEAP32[$val2_i >> 2] | 0) != (HEAP32[$val2_i1034 >> 2] | 0); //@line 50825
       continue;
      } else {
       continue;
      }
     }
     while (1) {
      $1046 = $1044; //@line 50835
      while (1) {
       $1047 = $cmd + 4 + $1046 | 0; //@line 50838
       $1048 = HEAP8[$1047] | 0; //@line 50839
       if (!(($1048 << 24 >> 24 | 0) == 13 | ($1048 << 24 >> 24 | 0) == 32 | ($1048 << 24 >> 24 | 0) == 9 | ($1048 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $1046 = $1046 + 1 | 0; //@line 50845
      }
      HEAP32[$1 >> 2] = $1046; //@line 50847
      $1051 = HEAP8[$1047] | 0; //@line 50848
      if ($1051 << 24 >> 24 == 38) {
       if ((HEAP8[$1046 + 1 + ($cmd + 4) | 0] | 0) == 38) {
        label = 17256; //@line 50856
        break;
       } else {
        $i_0_i_i1047 = $1046;
        $1058 = 38;
       }
      } else {
       $i_0_i_i1047 = $1046;
       $1058 = $1051;
      }
      while (1) {
       if (!(($1058 << 24 >> 24 | 0) == 13 | ($1058 << 24 >> 24 | 0) == 32 | ($1058 << 24 >> 24 | 0) == 9 | ($1058 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $1059 = $i_0_i_i1047 + 1 | 0; //@line 50870
       $i_0_i_i1047 = $1059;
       $1058 = HEAP8[$cmd + 4 + $1059 | 0] | 0;
      }
      HEAP32[$1 >> 2] = $i_0_i_i1047; //@line 50877
      if ((HEAP8[$cmd + 4 + $i_0_i_i1047 | 0] | 0) != 38) {
       $i_0_i_i_i248 = $i_0_i_i1047; //@line 50881
       break;
      }
      $1064 = $i_0_i_i1047 + 1 | 0; //@line 50884
      HEAP32[$1 >> 2] = $1064; //@line 50885
      if ((_cmd_match_expr_cmp($cmd, $val2_i700, $base) | 0) == 0) {
       label = 15373; //@line 50890
       break L19579;
      }
      while (1) {
       $1069 = HEAP32[$1 >> 2] | 0; //@line 50896
       while (1) {
        $1070 = $cmd + 4 + $1069 | 0; //@line 50899
        $1071 = HEAP8[$1070] | 0; //@line 50900
        if (!(($1071 << 24 >> 24 | 0) == 13 | ($1071 << 24 >> 24 | 0) == 32 | ($1071 << 24 >> 24 | 0) == 9 | ($1071 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1069 = $1069 + 1 | 0; //@line 50906
       }
       HEAP32[$1 >> 2] = $1069; //@line 50908
       $1074 = HEAP8[$1070] | 0; //@line 50909
       if ($1074 << 24 >> 24 == 61) {
        if ((HEAP8[$1069 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1058 = 1;
         $storemerge4231_in = $1069;
        } else {
         $i_0_i_i2464 = $1069;
         $1081 = 61;
         label = 15364; //@line 50920
        }
       } else {
        $i_0_i_i2464 = $1069;
        $1081 = $1074;
        label = 15364; //@line 50924
       }
       if ((label | 0) == 15364) {
        while (1) {
         label = 0; //@line 50928
         if (!(($1081 << 24 >> 24 | 0) == 13 | ($1081 << 24 >> 24 | 0) == 32 | ($1081 << 24 >> 24 | 0) == 9 | ($1081 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1082 = $i_0_i_i2464 + 1 | 0; //@line 50934
         $i_0_i_i2464 = $1082;
         $1081 = HEAP8[$cmd + 4 + $1082 | 0] | 0;
         label = 15364; //@line 50939
        }
        HEAP32[$1 >> 2] = $i_0_i_i2464; //@line 50942
        if ((HEAP8[$cmd + 4 + $i_0_i_i2464 | 0] | 0) != 33) {
         break;
        }
        if ((HEAP8[$i_0_i_i2464 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1058 = 2;
         $storemerge4231_in = $i_0_i_i2464;
        } else {
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4231_in + 2; //@line 50961
       if ((_cmd_match_expr_cmp($cmd, $val2_i1057, $base) | 0) == 0) {
        label = 15369; //@line 50966
        break L19579;
       }
       if (($op_0_i1058 | 0) == 1) {
        HEAP32[$val2_i700 >> 2] = (HEAP32[$val2_i700 >> 2] | 0) == (HEAP32[$val2_i1057 >> 2] | 0); //@line 50974
        continue;
       } else if (($op_0_i1058 | 0) == 2) {
        HEAP32[$val2_i700 >> 2] = (HEAP32[$val2_i700 >> 2] | 0) != (HEAP32[$val2_i1057 >> 2] | 0); //@line 50982
        continue;
       } else {
        continue;
       }
      }
      HEAP32[$val2_i >> 2] = HEAP32[$val2_i700 >> 2] & HEAP32[$val2_i >> 2]; //@line 50992
      $1044 = $i_0_i_i2464; //@line 50994
     }
     if ((label | 0) == 17256) {
      label = 0; //@line 50997
      HEAP32[$1 >> 2] = $1044; //@line 50998
      $i_0_i_i_i248 = $1044; //@line 51000
     }
     while (1) {
      $1107 = $cmd + 4 + $i_0_i_i_i248 | 0; //@line 51004
      $1108 = HEAP8[$1107] | 0; //@line 51005
      if (($1108 << 24 >> 24 | 0) == 13 | ($1108 << 24 >> 24 | 0) == 32 | ($1108 << 24 >> 24 | 0) == 9 | ($1108 << 24 >> 24 | 0) == 10) {
       $i_0_i_i_i248 = $i_0_i_i_i248 + 1 | 0; //@line 51009
       continue;
      }
      HEAP32[$1 >> 2] = $i_0_i_i_i248; //@line 51012
      if ((HEAP8[$1107] | 0) != 94) {
       $1221 = $i_0_i_i_i248; //@line 51016
       break;
      }
      $1114 = $i_0_i_i_i248 + 1 | 0; //@line 51019
      HEAP32[$1 >> 2] = $1114; //@line 51020
      if ((_cmd_match_expr_cmp($cmd, $val2_i247, $base) | 0) == 0) {
       label = 15418; //@line 51025
       break L19579;
      }
      while (1) {
       $1119 = HEAP32[$1 >> 2] | 0; //@line 51031
       while (1) {
        $1120 = $cmd + 4 + $1119 | 0; //@line 51034
        $1121 = HEAP8[$1120] | 0; //@line 51035
        if (!(($1121 << 24 >> 24 | 0) == 13 | ($1121 << 24 >> 24 | 0) == 32 | ($1121 << 24 >> 24 | 0) == 9 | ($1121 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1119 = $1119 + 1 | 0; //@line 51041
       }
       HEAP32[$1 >> 2] = $1119; //@line 51043
       $1124 = HEAP8[$1120] | 0; //@line 51044
       if ($1124 << 24 >> 24 == 61) {
        if ((HEAP8[$1119 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1062 = 1;
         $storemerge4230_in = $1119;
        } else {
         $i_0_i_i2484 = $1119;
         $1131 = 61;
         label = 15384; //@line 51055
        }
       } else {
        $i_0_i_i2484 = $1119;
        $1131 = $1124;
        label = 15384; //@line 51059
       }
       if ((label | 0) == 15384) {
        while (1) {
         label = 0; //@line 51063
         if (!(($1131 << 24 >> 24 | 0) == 13 | ($1131 << 24 >> 24 | 0) == 32 | ($1131 << 24 >> 24 | 0) == 9 | ($1131 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1132 = $i_0_i_i2484 + 1 | 0; //@line 51069
         $i_0_i_i2484 = $1132;
         $1131 = HEAP8[$cmd + 4 + $1132 | 0] | 0;
         label = 15384; //@line 51074
        }
        HEAP32[$1 >> 2] = $i_0_i_i2484; //@line 51077
        if ((HEAP8[$cmd + 4 + $i_0_i_i2484 | 0] | 0) != 33) {
         $1154 = $i_0_i_i2484; //@line 51081
         break;
        }
        if ((HEAP8[$i_0_i_i2484 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1062 = 2;
         $storemerge4230_in = $i_0_i_i2484;
        } else {
         $1154 = $i_0_i_i2484; //@line 51091
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4230_in + 2; //@line 51098
       if ((_cmd_match_expr_cmp($cmd, $val2_i1061, $base) | 0) == 0) {
        label = 15389; //@line 51103
        break L19579;
       }
       if (($op_0_i1062 | 0) == 1) {
        HEAP32[$val2_i247 >> 2] = (HEAP32[$val2_i247 >> 2] | 0) == (HEAP32[$val2_i1061 >> 2] | 0); //@line 51111
        continue;
       } else if (($op_0_i1062 | 0) == 2) {
        HEAP32[$val2_i247 >> 2] = (HEAP32[$val2_i247 >> 2] | 0) != (HEAP32[$val2_i1061 >> 2] | 0); //@line 51119
        continue;
       } else {
        continue;
       }
      }
      while (1) {
       $1156 = $1154; //@line 51129
       while (1) {
        $1157 = $cmd + 4 + $1156 | 0; //@line 51132
        $1158 = HEAP8[$1157] | 0; //@line 51133
        if (!(($1158 << 24 >> 24 | 0) == 13 | ($1158 << 24 >> 24 | 0) == 32 | ($1158 << 24 >> 24 | 0) == 9 | ($1158 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1156 = $1156 + 1 | 0; //@line 51139
       }
       HEAP32[$1 >> 2] = $1156; //@line 51141
       $1161 = HEAP8[$1157] | 0; //@line 51142
       if ($1161 << 24 >> 24 == 38) {
        if ((HEAP8[$1156 + 1 + ($cmd + 4) | 0] | 0) == 38) {
         label = 17257; //@line 51150
         break;
        } else {
         $i_0_i_i1074 = $1156;
         $1168 = 38;
        }
       } else {
        $i_0_i_i1074 = $1156;
        $1168 = $1161;
       }
       while (1) {
        if (!(($1168 << 24 >> 24 | 0) == 13 | ($1168 << 24 >> 24 | 0) == 32 | ($1168 << 24 >> 24 | 0) == 9 | ($1168 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1169 = $i_0_i_i1074 + 1 | 0; //@line 51164
        $i_0_i_i1074 = $1169;
        $1168 = HEAP8[$cmd + 4 + $1169 | 0] | 0;
       }
       HEAP32[$1 >> 2] = $i_0_i_i1074; //@line 51171
       if ((HEAP8[$cmd + 4 + $i_0_i_i1074 | 0] | 0) != 38) {
        $1217 = $i_0_i_i1074; //@line 51175
        break;
       }
       $1174 = $i_0_i_i1074 + 1 | 0; //@line 51178
       HEAP32[$1 >> 2] = $1174; //@line 51179
       if ((_cmd_match_expr_cmp($cmd, $val2_i703, $base) | 0) == 0) {
        label = 15416; //@line 51184
        break L19579;
       }
       while (1) {
        $1179 = HEAP32[$1 >> 2] | 0; //@line 51190
        while (1) {
         $1180 = $cmd + 4 + $1179 | 0; //@line 51193
         $1181 = HEAP8[$1180] | 0; //@line 51194
         if (!(($1181 << 24 >> 24 | 0) == 13 | ($1181 << 24 >> 24 | 0) == 32 | ($1181 << 24 >> 24 | 0) == 9 | ($1181 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1179 = $1179 + 1 | 0; //@line 51200
        }
        HEAP32[$1 >> 2] = $1179; //@line 51202
        $1184 = HEAP8[$1180] | 0; //@line 51203
        if ($1184 << 24 >> 24 == 61) {
         if ((HEAP8[$1179 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1085 = 1;
          $storemerge4229_in = $1179;
         } else {
          $i_0_i_i2504 = $1179;
          $1191 = 61;
          label = 15407; //@line 51214
         }
        } else {
         $i_0_i_i2504 = $1179;
         $1191 = $1184;
         label = 15407; //@line 51218
        }
        if ((label | 0) == 15407) {
         while (1) {
          label = 0; //@line 51222
          if (!(($1191 << 24 >> 24 | 0) == 13 | ($1191 << 24 >> 24 | 0) == 32 | ($1191 << 24 >> 24 | 0) == 9 | ($1191 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1192 = $i_0_i_i2504 + 1 | 0; //@line 51228
          $i_0_i_i2504 = $1192;
          $1191 = HEAP8[$cmd + 4 + $1192 | 0] | 0;
          label = 15407; //@line 51233
         }
         HEAP32[$1 >> 2] = $i_0_i_i2504; //@line 51236
         if ((HEAP8[$cmd + 4 + $i_0_i_i2504 | 0] | 0) != 33) {
          break;
         }
         if ((HEAP8[$i_0_i_i2504 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1085 = 2;
          $storemerge4229_in = $i_0_i_i2504;
         } else {
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4229_in + 2; //@line 51255
        if ((_cmd_match_expr_cmp($cmd, $val2_i1084, $base) | 0) == 0) {
         label = 15412; //@line 51260
         break L19579;
        }
        if (($op_0_i1085 | 0) == 1) {
         HEAP32[$val2_i703 >> 2] = (HEAP32[$val2_i703 >> 2] | 0) == (HEAP32[$val2_i1084 >> 2] | 0); //@line 51268
         continue;
        } else if (($op_0_i1085 | 0) == 2) {
         HEAP32[$val2_i703 >> 2] = (HEAP32[$val2_i703 >> 2] | 0) != (HEAP32[$val2_i1084 >> 2] | 0); //@line 51276
         continue;
        } else {
         continue;
        }
       }
       HEAP32[$val2_i247 >> 2] = HEAP32[$val2_i703 >> 2] & HEAP32[$val2_i247 >> 2]; //@line 51286
       $1154 = $i_0_i_i2504; //@line 51288
      }
      if ((label | 0) == 17257) {
       label = 0; //@line 51291
       HEAP32[$1 >> 2] = $1154; //@line 51292
       $1217 = $1154; //@line 51294
      }
      HEAP32[$val2_i >> 2] = HEAP32[$val2_i247 >> 2] ^ HEAP32[$val2_i >> 2]; //@line 51300
      $i_0_i_i_i248 = $1217; //@line 51302
     }
     while (1) {
      $1223 = $1221; //@line 51307
      while (1) {
       $1224 = $cmd + 4 + $1223 | 0; //@line 51310
       $1225 = HEAP8[$1224] | 0; //@line 51311
       if (!(($1225 << 24 >> 24 | 0) == 13 | ($1225 << 24 >> 24 | 0) == 32 | ($1225 << 24 >> 24 | 0) == 9 | ($1225 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $1223 = $1223 + 1 | 0; //@line 51317
      }
      HEAP32[$1 >> 2] = $1223; //@line 51319
      $1228 = HEAP8[$1224] | 0; //@line 51320
      if ($1228 << 24 >> 24 == 124) {
       if ((HEAP8[$1223 + 1 + ($cmd + 4) | 0] | 0) == 124) {
        label = 17258; //@line 51328
        break;
       } else {
        $i_0_i_i268 = $1223;
        $1235 = 124;
       }
      } else {
       $i_0_i_i268 = $1223;
       $1235 = $1228;
      }
      while (1) {
       if (!(($1235 << 24 >> 24 | 0) == 13 | ($1235 << 24 >> 24 | 0) == 32 | ($1235 << 24 >> 24 | 0) == 9 | ($1235 << 24 >> 24 | 0) == 10)) {
        break;
       }
       $1236 = $i_0_i_i268 + 1 | 0; //@line 51342
       $i_0_i_i268 = $1236;
       $1235 = HEAP8[$cmd + 4 + $1236 | 0] | 0;
      }
      HEAP32[$1 >> 2] = $i_0_i_i268; //@line 51349
      if ((HEAP8[$cmd + 4 + $i_0_i_i268 | 0] | 0) != 124) {
       $i_0_i_i_i66 = $i_0_i_i268; //@line 51353
       break;
      }
      $1241 = $i_0_i_i268 + 1 | 0; //@line 51356
      HEAP32[$1 >> 2] = $1241; //@line 51357
      if ((_cmd_match_expr_cmp($cmd, $val2_i135, $base) | 0) == 0) {
       label = 15513; //@line 51362
       break L19579;
      }
      while (1) {
       $1246 = HEAP32[$1 >> 2] | 0; //@line 51368
       while (1) {
        $1247 = $cmd + 4 + $1246 | 0; //@line 51371
        $1248 = HEAP8[$1247] | 0; //@line 51372
        if (!(($1248 << 24 >> 24 | 0) == 13 | ($1248 << 24 >> 24 | 0) == 32 | ($1248 << 24 >> 24 | 0) == 9 | ($1248 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1246 = $1246 + 1 | 0; //@line 51378
       }
       HEAP32[$1 >> 2] = $1246; //@line 51380
       $1251 = HEAP8[$1247] | 0; //@line 51381
       if ($1251 << 24 >> 24 == 61) {
        if ((HEAP8[$1246 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1089 = 1;
         $storemerge4228_in = $1246;
        } else {
         $i_0_i_i2524 = $1246;
         $1258 = 61;
         label = 15434; //@line 51392
        }
       } else {
        $i_0_i_i2524 = $1246;
        $1258 = $1251;
        label = 15434; //@line 51396
       }
       if ((label | 0) == 15434) {
        while (1) {
         label = 0; //@line 51400
         if (!(($1258 << 24 >> 24 | 0) == 13 | ($1258 << 24 >> 24 | 0) == 32 | ($1258 << 24 >> 24 | 0) == 9 | ($1258 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1259 = $i_0_i_i2524 + 1 | 0; //@line 51406
         $i_0_i_i2524 = $1259;
         $1258 = HEAP8[$cmd + 4 + $1259 | 0] | 0;
         label = 15434; //@line 51411
        }
        HEAP32[$1 >> 2] = $i_0_i_i2524; //@line 51414
        if ((HEAP8[$cmd + 4 + $i_0_i_i2524 | 0] | 0) != 33) {
         $1281 = $i_0_i_i2524; //@line 51418
         break;
        }
        if ((HEAP8[$i_0_i_i2524 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1089 = 2;
         $storemerge4228_in = $i_0_i_i2524;
        } else {
         $1281 = $i_0_i_i2524; //@line 51428
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4228_in + 2; //@line 51435
       if ((_cmd_match_expr_cmp($cmd, $val2_i1088, $base) | 0) == 0) {
        label = 15439; //@line 51440
        break L19579;
       }
       if (($op_0_i1089 | 0) == 1) {
        HEAP32[$val2_i135 >> 2] = (HEAP32[$val2_i135 >> 2] | 0) == (HEAP32[$val2_i1088 >> 2] | 0); //@line 51448
        continue;
       } else if (($op_0_i1089 | 0) == 2) {
        HEAP32[$val2_i135 >> 2] = (HEAP32[$val2_i135 >> 2] | 0) != (HEAP32[$val2_i1088 >> 2] | 0); //@line 51456
        continue;
       } else {
        continue;
       }
      }
      while (1) {
       $1283 = $1281; //@line 51466
       while (1) {
        $1284 = $cmd + 4 + $1283 | 0; //@line 51469
        $1285 = HEAP8[$1284] | 0; //@line 51470
        if (!(($1285 << 24 >> 24 | 0) == 13 | ($1285 << 24 >> 24 | 0) == 32 | ($1285 << 24 >> 24 | 0) == 9 | ($1285 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1283 = $1283 + 1 | 0; //@line 51476
       }
       HEAP32[$1 >> 2] = $1283; //@line 51478
       $1288 = HEAP8[$1284] | 0; //@line 51479
       if ($1288 << 24 >> 24 == 38) {
        if ((HEAP8[$1283 + 1 + ($cmd + 4) | 0] | 0) == 38) {
         label = 17259; //@line 51487
         break;
        } else {
         $i_0_i_i1101 = $1283;
         $1295 = 38;
        }
       } else {
        $i_0_i_i1101 = $1283;
        $1295 = $1288;
       }
       while (1) {
        if (!(($1295 << 24 >> 24 | 0) == 13 | ($1295 << 24 >> 24 | 0) == 32 | ($1295 << 24 >> 24 | 0) == 9 | ($1295 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1296 = $i_0_i_i1101 + 1 | 0; //@line 51501
        $i_0_i_i1101 = $1296;
        $1295 = HEAP8[$cmd + 4 + $1296 | 0] | 0;
       }
       HEAP32[$1 >> 2] = $i_0_i_i1101; //@line 51508
       if ((HEAP8[$cmd + 4 + $i_0_i_i1101 | 0] | 0) != 38) {
        $i_0_i_i_i279 = $i_0_i_i1101; //@line 51512
        break;
       }
       $1301 = $i_0_i_i1101 + 1 | 0; //@line 51515
       HEAP32[$1 >> 2] = $1301; //@line 51516
       if ((_cmd_match_expr_cmp($cmd, $val2_i706, $base) | 0) == 0) {
        label = 15466; //@line 51521
        break L19579;
       }
       while (1) {
        $1306 = HEAP32[$1 >> 2] | 0; //@line 51527
        while (1) {
         $1307 = $cmd + 4 + $1306 | 0; //@line 51530
         $1308 = HEAP8[$1307] | 0; //@line 51531
         if (!(($1308 << 24 >> 24 | 0) == 13 | ($1308 << 24 >> 24 | 0) == 32 | ($1308 << 24 >> 24 | 0) == 9 | ($1308 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1306 = $1306 + 1 | 0; //@line 51537
        }
        HEAP32[$1 >> 2] = $1306; //@line 51539
        $1311 = HEAP8[$1307] | 0; //@line 51540
        if ($1311 << 24 >> 24 == 61) {
         if ((HEAP8[$1306 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1112 = 1;
          $storemerge4227_in = $1306;
         } else {
          $i_0_i_i2544 = $1306;
          $1318 = 61;
          label = 15457; //@line 51551
         }
        } else {
         $i_0_i_i2544 = $1306;
         $1318 = $1311;
         label = 15457; //@line 51555
        }
        if ((label | 0) == 15457) {
         while (1) {
          label = 0; //@line 51559
          if (!(($1318 << 24 >> 24 | 0) == 13 | ($1318 << 24 >> 24 | 0) == 32 | ($1318 << 24 >> 24 | 0) == 9 | ($1318 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1319 = $i_0_i_i2544 + 1 | 0; //@line 51565
          $i_0_i_i2544 = $1319;
          $1318 = HEAP8[$cmd + 4 + $1319 | 0] | 0;
          label = 15457; //@line 51570
         }
         HEAP32[$1 >> 2] = $i_0_i_i2544; //@line 51573
         if ((HEAP8[$cmd + 4 + $i_0_i_i2544 | 0] | 0) != 33) {
          break;
         }
         if ((HEAP8[$i_0_i_i2544 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1112 = 2;
          $storemerge4227_in = $i_0_i_i2544;
         } else {
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4227_in + 2; //@line 51592
        if ((_cmd_match_expr_cmp($cmd, $val2_i1111, $base) | 0) == 0) {
         label = 15462; //@line 51597
         break L19579;
        }
        if (($op_0_i1112 | 0) == 1) {
         HEAP32[$val2_i706 >> 2] = (HEAP32[$val2_i706 >> 2] | 0) == (HEAP32[$val2_i1111 >> 2] | 0); //@line 51605
         continue;
        } else if (($op_0_i1112 | 0) == 2) {
         HEAP32[$val2_i706 >> 2] = (HEAP32[$val2_i706 >> 2] | 0) != (HEAP32[$val2_i1111 >> 2] | 0); //@line 51613
         continue;
        } else {
         continue;
        }
       }
       HEAP32[$val2_i135 >> 2] = HEAP32[$val2_i706 >> 2] & HEAP32[$val2_i135 >> 2]; //@line 51623
       $1281 = $i_0_i_i2544; //@line 51625
      }
      if ((label | 0) == 17259) {
       label = 0; //@line 51628
       HEAP32[$1 >> 2] = $1281; //@line 51629
       $i_0_i_i_i279 = $1281; //@line 51631
      }
      while (1) {
       $1344 = $cmd + 4 + $i_0_i_i_i279 | 0; //@line 51635
       $1345 = HEAP8[$1344] | 0; //@line 51636
       if (($1345 << 24 >> 24 | 0) == 13 | ($1345 << 24 >> 24 | 0) == 32 | ($1345 << 24 >> 24 | 0) == 9 | ($1345 << 24 >> 24 | 0) == 10) {
        $i_0_i_i_i279 = $i_0_i_i_i279 + 1 | 0; //@line 51640
        continue;
       }
       HEAP32[$1 >> 2] = $i_0_i_i_i279; //@line 51643
       if ((HEAP8[$1344] | 0) != 94) {
        break;
       }
       $1351 = $i_0_i_i_i279 + 1 | 0; //@line 51649
       HEAP32[$1 >> 2] = $1351; //@line 51650
       if ((_cmd_match_expr_cmp($cmd, $val2_i278, $base) | 0) == 0) {
        label = 15511; //@line 51655
        break L19579;
       }
       while (1) {
        $1356 = HEAP32[$1 >> 2] | 0; //@line 51661
        while (1) {
         $1357 = $cmd + 4 + $1356 | 0; //@line 51664
         $1358 = HEAP8[$1357] | 0; //@line 51665
         if (!(($1358 << 24 >> 24 | 0) == 13 | ($1358 << 24 >> 24 | 0) == 32 | ($1358 << 24 >> 24 | 0) == 9 | ($1358 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1356 = $1356 + 1 | 0; //@line 51671
        }
        HEAP32[$1 >> 2] = $1356; //@line 51673
        $1361 = HEAP8[$1357] | 0; //@line 51674
        if ($1361 << 24 >> 24 == 61) {
         if ((HEAP8[$1356 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1116 = 1;
          $storemerge4226_in = $1356;
         } else {
          $i_0_i_i2564 = $1356;
          $1368 = 61;
          label = 15477; //@line 51685
         }
        } else {
         $i_0_i_i2564 = $1356;
         $1368 = $1361;
         label = 15477; //@line 51689
        }
        if ((label | 0) == 15477) {
         while (1) {
          label = 0; //@line 51693
          if (!(($1368 << 24 >> 24 | 0) == 13 | ($1368 << 24 >> 24 | 0) == 32 | ($1368 << 24 >> 24 | 0) == 9 | ($1368 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1369 = $i_0_i_i2564 + 1 | 0; //@line 51699
          $i_0_i_i2564 = $1369;
          $1368 = HEAP8[$cmd + 4 + $1369 | 0] | 0;
          label = 15477; //@line 51704
         }
         HEAP32[$1 >> 2] = $i_0_i_i2564; //@line 51707
         if ((HEAP8[$cmd + 4 + $i_0_i_i2564 | 0] | 0) != 33) {
          $1391 = $i_0_i_i2564; //@line 51711
          break;
         }
         if ((HEAP8[$i_0_i_i2564 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1116 = 2;
          $storemerge4226_in = $i_0_i_i2564;
         } else {
          $1391 = $i_0_i_i2564; //@line 51721
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4226_in + 2; //@line 51728
        if ((_cmd_match_expr_cmp($cmd, $val2_i1115, $base) | 0) == 0) {
         label = 15482; //@line 51733
         break L19579;
        }
        if (($op_0_i1116 | 0) == 1) {
         HEAP32[$val2_i278 >> 2] = (HEAP32[$val2_i278 >> 2] | 0) == (HEAP32[$val2_i1115 >> 2] | 0); //@line 51741
         continue;
        } else if (($op_0_i1116 | 0) == 2) {
         HEAP32[$val2_i278 >> 2] = (HEAP32[$val2_i278 >> 2] | 0) != (HEAP32[$val2_i1115 >> 2] | 0); //@line 51749
         continue;
        } else {
         continue;
        }
       }
       while (1) {
        $1393 = $1391; //@line 51759
        while (1) {
         $1394 = $cmd + 4 + $1393 | 0; //@line 51762
         $1395 = HEAP8[$1394] | 0; //@line 51763
         if (!(($1395 << 24 >> 24 | 0) == 13 | ($1395 << 24 >> 24 | 0) == 32 | ($1395 << 24 >> 24 | 0) == 9 | ($1395 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1393 = $1393 + 1 | 0; //@line 51769
        }
        HEAP32[$1 >> 2] = $1393; //@line 51771
        $1398 = HEAP8[$1394] | 0; //@line 51772
        if ($1398 << 24 >> 24 == 38) {
         if ((HEAP8[$1393 + 1 + ($cmd + 4) | 0] | 0) == 38) {
          label = 17260; //@line 51780
          break;
         } else {
          $i_0_i_i1128 = $1393;
          $1405 = 38;
         }
        } else {
         $i_0_i_i1128 = $1393;
         $1405 = $1398;
        }
        while (1) {
         if (!(($1405 << 24 >> 24 | 0) == 13 | ($1405 << 24 >> 24 | 0) == 32 | ($1405 << 24 >> 24 | 0) == 9 | ($1405 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1406 = $i_0_i_i1128 + 1 | 0; //@line 51794
         $i_0_i_i1128 = $1406;
         $1405 = HEAP8[$cmd + 4 + $1406 | 0] | 0;
        }
        HEAP32[$1 >> 2] = $i_0_i_i1128; //@line 51801
        if ((HEAP8[$cmd + 4 + $i_0_i_i1128 | 0] | 0) != 38) {
         $1454 = $i_0_i_i1128; //@line 51805
         break;
        }
        $1411 = $i_0_i_i1128 + 1 | 0; //@line 51808
        HEAP32[$1 >> 2] = $1411; //@line 51809
        if ((_cmd_match_expr_cmp($cmd, $val2_i709, $base) | 0) == 0) {
         label = 15509; //@line 51814
         break L19579;
        }
        while (1) {
         $1416 = HEAP32[$1 >> 2] | 0; //@line 51820
         while (1) {
          $1417 = $cmd + 4 + $1416 | 0; //@line 51823
          $1418 = HEAP8[$1417] | 0; //@line 51824
          if (!(($1418 << 24 >> 24 | 0) == 13 | ($1418 << 24 >> 24 | 0) == 32 | ($1418 << 24 >> 24 | 0) == 9 | ($1418 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1416 = $1416 + 1 | 0; //@line 51830
         }
         HEAP32[$1 >> 2] = $1416; //@line 51832
         $1421 = HEAP8[$1417] | 0; //@line 51833
         if ($1421 << 24 >> 24 == 61) {
          if ((HEAP8[$1416 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1139 = 1;
           $storemerge4225_in = $1416;
          } else {
           $i_0_i_i2584 = $1416;
           $1428 = 61;
           label = 15500; //@line 51844
          }
         } else {
          $i_0_i_i2584 = $1416;
          $1428 = $1421;
          label = 15500; //@line 51848
         }
         if ((label | 0) == 15500) {
          while (1) {
           label = 0; //@line 51852
           if (!(($1428 << 24 >> 24 | 0) == 13 | ($1428 << 24 >> 24 | 0) == 32 | ($1428 << 24 >> 24 | 0) == 9 | ($1428 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $1429 = $i_0_i_i2584 + 1 | 0; //@line 51858
           $i_0_i_i2584 = $1429;
           $1428 = HEAP8[$cmd + 4 + $1429 | 0] | 0;
           label = 15500; //@line 51863
          }
          HEAP32[$1 >> 2] = $i_0_i_i2584; //@line 51866
          if ((HEAP8[$cmd + 4 + $i_0_i_i2584 | 0] | 0) != 33) {
           break;
          }
          if ((HEAP8[$i_0_i_i2584 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1139 = 2;
           $storemerge4225_in = $i_0_i_i2584;
          } else {
           break;
          }
         }
         HEAP32[$1 >> 2] = $storemerge4225_in + 2; //@line 51885
         if ((_cmd_match_expr_cmp($cmd, $val2_i1138, $base) | 0) == 0) {
          label = 15505; //@line 51890
          break L19579;
         }
         if (($op_0_i1139 | 0) == 1) {
          HEAP32[$val2_i709 >> 2] = (HEAP32[$val2_i709 >> 2] | 0) == (HEAP32[$val2_i1138 >> 2] | 0); //@line 51898
          continue;
         } else if (($op_0_i1139 | 0) == 2) {
          HEAP32[$val2_i709 >> 2] = (HEAP32[$val2_i709 >> 2] | 0) != (HEAP32[$val2_i1138 >> 2] | 0); //@line 51906
          continue;
         } else {
          continue;
         }
        }
        HEAP32[$val2_i278 >> 2] = HEAP32[$val2_i709 >> 2] & HEAP32[$val2_i278 >> 2]; //@line 51916
        $1391 = $i_0_i_i2584; //@line 51918
       }
       if ((label | 0) == 17260) {
        label = 0; //@line 51921
        HEAP32[$1 >> 2] = $1391; //@line 51922
        $1454 = $1391; //@line 51924
       }
       HEAP32[$val2_i135 >> 2] = HEAP32[$val2_i278 >> 2] ^ HEAP32[$val2_i135 >> 2]; //@line 51930
       $i_0_i_i_i279 = $1454; //@line 51932
      }
      HEAP32[$val2_i >> 2] = HEAP32[$val2_i135 >> 2] | HEAP32[$val2_i >> 2]; //@line 51937
      $1221 = $i_0_i_i_i279; //@line 51939
     }
     if ((label | 0) == 17258) {
      label = 0; //@line 51942
      HEAP32[$1 >> 2] = $1221; //@line 51943
      $i_0_i_i_i66 = $1221; //@line 51945
     }
     while (1) {
      $1462 = $cmd + 4 + $i_0_i_i_i66 | 0; //@line 51949
      $1463 = HEAP8[$1462] | 0; //@line 51950
      if (($1463 << 24 >> 24 | 0) == 13 | ($1463 << 24 >> 24 | 0) == 32 | ($1463 << 24 >> 24 | 0) == 9 | ($1463 << 24 >> 24 | 0) == 10) {
       $i_0_i_i_i66 = $i_0_i_i_i66 + 1 | 0; //@line 51954
       continue;
      }
      HEAP32[$1 >> 2] = $i_0_i_i_i66; //@line 51957
      if ((HEAP8[$1462] | 0) != 38) {
       break;
      }
      if ((HEAP8[$i_0_i_i_i66 + 1 + ($cmd + 4) | 0] | 0) != 38) {
       break;
      }
      $5877 = $i_0_i_i_i66 + 2 | 0; //@line 51970
      HEAP32[$1 >> 2] = $5877; //@line 51971
      if ((_cmd_match_expr_cmp($cmd, $val2_i65, $base) | 0) == 0) {
       label = 15698; //@line 51976
       break L19579;
      }
      while (1) {
       $1474 = HEAP32[$1 >> 2] | 0; //@line 51982
       while (1) {
        $1475 = $cmd + 4 + $1474 | 0; //@line 51985
        $1476 = HEAP8[$1475] | 0; //@line 51986
        if (!(($1476 << 24 >> 24 | 0) == 13 | ($1476 << 24 >> 24 | 0) == 32 | ($1476 << 24 >> 24 | 0) == 9 | ($1476 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1474 = $1474 + 1 | 0; //@line 51992
       }
       HEAP32[$1 >> 2] = $1474; //@line 51994
       $1479 = HEAP8[$1475] | 0; //@line 51995
       if ($1479 << 24 >> 24 == 61) {
        if ((HEAP8[$1474 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1143 = 1;
         $storemerge4224_in = $1474;
        } else {
         $i_0_i_i2604 = $1474;
         $1486 = 61;
         label = 15524; //@line 52006
        }
       } else {
        $i_0_i_i2604 = $1474;
        $1486 = $1479;
        label = 15524; //@line 52010
       }
       if ((label | 0) == 15524) {
        while (1) {
         label = 0; //@line 52014
         if (!(($1486 << 24 >> 24 | 0) == 13 | ($1486 << 24 >> 24 | 0) == 32 | ($1486 << 24 >> 24 | 0) == 9 | ($1486 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1487 = $i_0_i_i2604 + 1 | 0; //@line 52020
         $i_0_i_i2604 = $1487;
         $1486 = HEAP8[$cmd + 4 + $1487 | 0] | 0;
         label = 15524; //@line 52025
        }
        HEAP32[$1 >> 2] = $i_0_i_i2604; //@line 52028
        if ((HEAP8[$cmd + 4 + $i_0_i_i2604 | 0] | 0) != 33) {
         $1509 = $i_0_i_i2604; //@line 52032
         break;
        }
        if ((HEAP8[$i_0_i_i2604 + 1 + ($cmd + 4) | 0] | 0) == 61) {
         $op_0_i1143 = 2;
         $storemerge4224_in = $i_0_i_i2604;
        } else {
         $1509 = $i_0_i_i2604; //@line 52042
         break;
        }
       }
       HEAP32[$1 >> 2] = $storemerge4224_in + 2; //@line 52049
       if ((_cmd_match_expr_cmp($cmd, $val2_i1142, $base) | 0) == 0) {
        label = 15529; //@line 52054
        break L19579;
       }
       if (($op_0_i1143 | 0) == 1) {
        HEAP32[$val2_i65 >> 2] = (HEAP32[$val2_i65 >> 2] | 0) == (HEAP32[$val2_i1142 >> 2] | 0); //@line 52062
        continue;
       } else if (($op_0_i1143 | 0) == 2) {
        HEAP32[$val2_i65 >> 2] = (HEAP32[$val2_i65 >> 2] | 0) != (HEAP32[$val2_i1142 >> 2] | 0); //@line 52070
        continue;
       } else {
        continue;
       }
      }
      while (1) {
       $1511 = $1509; //@line 52080
       while (1) {
        $1512 = $cmd + 4 + $1511 | 0; //@line 52083
        $1513 = HEAP8[$1512] | 0; //@line 52084
        if (!(($1513 << 24 >> 24 | 0) == 13 | ($1513 << 24 >> 24 | 0) == 32 | ($1513 << 24 >> 24 | 0) == 9 | ($1513 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1511 = $1511 + 1 | 0; //@line 52090
       }
       HEAP32[$1 >> 2] = $1511; //@line 52092
       $1516 = HEAP8[$1512] | 0; //@line 52093
       if ($1516 << 24 >> 24 == 38) {
        if ((HEAP8[$1511 + 1 + ($cmd + 4) | 0] | 0) == 38) {
         label = 17262; //@line 52101
         break;
        } else {
         $i_0_i_i1155 = $1511;
         $1523 = 38;
        }
       } else {
        $i_0_i_i1155 = $1511;
        $1523 = $1516;
       }
       while (1) {
        if (!(($1523 << 24 >> 24 | 0) == 13 | ($1523 << 24 >> 24 | 0) == 32 | ($1523 << 24 >> 24 | 0) == 9 | ($1523 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1524 = $i_0_i_i1155 + 1 | 0; //@line 52115
        $i_0_i_i1155 = $1524;
        $1523 = HEAP8[$cmd + 4 + $1524 | 0] | 0;
       }
       HEAP32[$1 >> 2] = $i_0_i_i1155; //@line 52122
       if ((HEAP8[$cmd + 4 + $i_0_i_i1155 | 0] | 0) != 38) {
        $i_0_i_i_i291 = $i_0_i_i1155; //@line 52126
        break;
       }
       $1529 = $i_0_i_i1155 + 1 | 0; //@line 52129
       HEAP32[$1 >> 2] = $1529; //@line 52130
       if ((_cmd_match_expr_cmp($cmd, $val2_i712, $base) | 0) == 0) {
        label = 15556; //@line 52135
        break L19579;
       }
       while (1) {
        $1534 = HEAP32[$1 >> 2] | 0; //@line 52141
        while (1) {
         $1535 = $cmd + 4 + $1534 | 0; //@line 52144
         $1536 = HEAP8[$1535] | 0; //@line 52145
         if (!(($1536 << 24 >> 24 | 0) == 13 | ($1536 << 24 >> 24 | 0) == 32 | ($1536 << 24 >> 24 | 0) == 9 | ($1536 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1534 = $1534 + 1 | 0; //@line 52151
        }
        HEAP32[$1 >> 2] = $1534; //@line 52153
        $1539 = HEAP8[$1535] | 0; //@line 52154
        if ($1539 << 24 >> 24 == 61) {
         if ((HEAP8[$1534 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1166 = 1;
          $storemerge4223_in = $1534;
         } else {
          $i_0_i_i2624 = $1534;
          $1546 = 61;
          label = 15547; //@line 52165
         }
        } else {
         $i_0_i_i2624 = $1534;
         $1546 = $1539;
         label = 15547; //@line 52169
        }
        if ((label | 0) == 15547) {
         while (1) {
          label = 0; //@line 52173
          if (!(($1546 << 24 >> 24 | 0) == 13 | ($1546 << 24 >> 24 | 0) == 32 | ($1546 << 24 >> 24 | 0) == 9 | ($1546 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1547 = $i_0_i_i2624 + 1 | 0; //@line 52179
          $i_0_i_i2624 = $1547;
          $1546 = HEAP8[$cmd + 4 + $1547 | 0] | 0;
          label = 15547; //@line 52184
         }
         HEAP32[$1 >> 2] = $i_0_i_i2624; //@line 52187
         if ((HEAP8[$cmd + 4 + $i_0_i_i2624 | 0] | 0) != 33) {
          break;
         }
         if ((HEAP8[$i_0_i_i2624 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1166 = 2;
          $storemerge4223_in = $i_0_i_i2624;
         } else {
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4223_in + 2; //@line 52206
        if ((_cmd_match_expr_cmp($cmd, $val2_i1165, $base) | 0) == 0) {
         label = 15552; //@line 52211
         break L19579;
        }
        if (($op_0_i1166 | 0) == 1) {
         HEAP32[$val2_i712 >> 2] = (HEAP32[$val2_i712 >> 2] | 0) == (HEAP32[$val2_i1165 >> 2] | 0); //@line 52219
         continue;
        } else if (($op_0_i1166 | 0) == 2) {
         HEAP32[$val2_i712 >> 2] = (HEAP32[$val2_i712 >> 2] | 0) != (HEAP32[$val2_i1165 >> 2] | 0); //@line 52227
         continue;
        } else {
         continue;
        }
       }
       HEAP32[$val2_i65 >> 2] = HEAP32[$val2_i712 >> 2] & HEAP32[$val2_i65 >> 2]; //@line 52237
       $1509 = $i_0_i_i2624; //@line 52239
      }
      if ((label | 0) == 17262) {
       label = 0; //@line 52242
       HEAP32[$1 >> 2] = $1509; //@line 52243
       $i_0_i_i_i291 = $1509; //@line 52245
      }
      while (1) {
       $1572 = $cmd + 4 + $i_0_i_i_i291 | 0; //@line 52249
       $1573 = HEAP8[$1572] | 0; //@line 52250
       if (($1573 << 24 >> 24 | 0) == 13 | ($1573 << 24 >> 24 | 0) == 32 | ($1573 << 24 >> 24 | 0) == 9 | ($1573 << 24 >> 24 | 0) == 10) {
        $i_0_i_i_i291 = $i_0_i_i_i291 + 1 | 0; //@line 52254
        continue;
       }
       HEAP32[$1 >> 2] = $i_0_i_i_i291; //@line 52257
       if ((HEAP8[$1572] | 0) != 94) {
        $1686 = $i_0_i_i_i291; //@line 52261
        break;
       }
       $1579 = $i_0_i_i_i291 + 1 | 0; //@line 52264
       HEAP32[$1 >> 2] = $1579; //@line 52265
       if ((_cmd_match_expr_cmp($cmd, $val2_i290, $base) | 0) == 0) {
        label = 15601; //@line 52270
        break L19579;
       }
       while (1) {
        $1584 = HEAP32[$1 >> 2] | 0; //@line 52276
        while (1) {
         $1585 = $cmd + 4 + $1584 | 0; //@line 52279
         $1586 = HEAP8[$1585] | 0; //@line 52280
         if (!(($1586 << 24 >> 24 | 0) == 13 | ($1586 << 24 >> 24 | 0) == 32 | ($1586 << 24 >> 24 | 0) == 9 | ($1586 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1584 = $1584 + 1 | 0; //@line 52286
        }
        HEAP32[$1 >> 2] = $1584; //@line 52288
        $1589 = HEAP8[$1585] | 0; //@line 52289
        if ($1589 << 24 >> 24 == 61) {
         if ((HEAP8[$1584 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1170 = 1;
          $storemerge4222_in = $1584;
         } else {
          $i_0_i_i2644 = $1584;
          $1596 = 61;
          label = 15567; //@line 52300
         }
        } else {
         $i_0_i_i2644 = $1584;
         $1596 = $1589;
         label = 15567; //@line 52304
        }
        if ((label | 0) == 15567) {
         while (1) {
          label = 0; //@line 52308
          if (!(($1596 << 24 >> 24 | 0) == 13 | ($1596 << 24 >> 24 | 0) == 32 | ($1596 << 24 >> 24 | 0) == 9 | ($1596 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1597 = $i_0_i_i2644 + 1 | 0; //@line 52314
          $i_0_i_i2644 = $1597;
          $1596 = HEAP8[$cmd + 4 + $1597 | 0] | 0;
          label = 15567; //@line 52319
         }
         HEAP32[$1 >> 2] = $i_0_i_i2644; //@line 52322
         if ((HEAP8[$cmd + 4 + $i_0_i_i2644 | 0] | 0) != 33) {
          $1619 = $i_0_i_i2644; //@line 52326
          break;
         }
         if ((HEAP8[$i_0_i_i2644 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1170 = 2;
          $storemerge4222_in = $i_0_i_i2644;
         } else {
          $1619 = $i_0_i_i2644; //@line 52336
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4222_in + 2; //@line 52343
        if ((_cmd_match_expr_cmp($cmd, $val2_i1169, $base) | 0) == 0) {
         label = 15572; //@line 52348
         break L19579;
        }
        if (($op_0_i1170 | 0) == 1) {
         HEAP32[$val2_i290 >> 2] = (HEAP32[$val2_i290 >> 2] | 0) == (HEAP32[$val2_i1169 >> 2] | 0); //@line 52356
         continue;
        } else if (($op_0_i1170 | 0) == 2) {
         HEAP32[$val2_i290 >> 2] = (HEAP32[$val2_i290 >> 2] | 0) != (HEAP32[$val2_i1169 >> 2] | 0); //@line 52364
         continue;
        } else {
         continue;
        }
       }
       while (1) {
        $1621 = $1619; //@line 52374
        while (1) {
         $1622 = $cmd + 4 + $1621 | 0; //@line 52377
         $1623 = HEAP8[$1622] | 0; //@line 52378
         if (!(($1623 << 24 >> 24 | 0) == 13 | ($1623 << 24 >> 24 | 0) == 32 | ($1623 << 24 >> 24 | 0) == 9 | ($1623 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1621 = $1621 + 1 | 0; //@line 52384
        }
        HEAP32[$1 >> 2] = $1621; //@line 52386
        $1626 = HEAP8[$1622] | 0; //@line 52387
        if ($1626 << 24 >> 24 == 38) {
         if ((HEAP8[$1621 + 1 + ($cmd + 4) | 0] | 0) == 38) {
          label = 17263; //@line 52395
          break;
         } else {
          $i_0_i_i1182 = $1621;
          $1633 = 38;
         }
        } else {
         $i_0_i_i1182 = $1621;
         $1633 = $1626;
        }
        while (1) {
         if (!(($1633 << 24 >> 24 | 0) == 13 | ($1633 << 24 >> 24 | 0) == 32 | ($1633 << 24 >> 24 | 0) == 9 | ($1633 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1634 = $i_0_i_i1182 + 1 | 0; //@line 52409
         $i_0_i_i1182 = $1634;
         $1633 = HEAP8[$cmd + 4 + $1634 | 0] | 0;
        }
        HEAP32[$1 >> 2] = $i_0_i_i1182; //@line 52416
        if ((HEAP8[$cmd + 4 + $i_0_i_i1182 | 0] | 0) != 38) {
         $1682 = $i_0_i_i1182; //@line 52420
         break;
        }
        $1639 = $i_0_i_i1182 + 1 | 0; //@line 52423
        HEAP32[$1 >> 2] = $1639; //@line 52424
        if ((_cmd_match_expr_cmp($cmd, $val2_i715, $base) | 0) == 0) {
         label = 15599; //@line 52429
         break L19579;
        }
        while (1) {
         $1644 = HEAP32[$1 >> 2] | 0; //@line 52435
         while (1) {
          $1645 = $cmd + 4 + $1644 | 0; //@line 52438
          $1646 = HEAP8[$1645] | 0; //@line 52439
          if (!(($1646 << 24 >> 24 | 0) == 13 | ($1646 << 24 >> 24 | 0) == 32 | ($1646 << 24 >> 24 | 0) == 9 | ($1646 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1644 = $1644 + 1 | 0; //@line 52445
         }
         HEAP32[$1 >> 2] = $1644; //@line 52447
         $1649 = HEAP8[$1645] | 0; //@line 52448
         if ($1649 << 24 >> 24 == 61) {
          if ((HEAP8[$1644 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1193 = 1;
           $storemerge4221_in = $1644;
          } else {
           $i_0_i_i2664 = $1644;
           $1656 = 61;
           label = 15590; //@line 52459
          }
         } else {
          $i_0_i_i2664 = $1644;
          $1656 = $1649;
          label = 15590; //@line 52463
         }
         if ((label | 0) == 15590) {
          while (1) {
           label = 0; //@line 52467
           if (!(($1656 << 24 >> 24 | 0) == 13 | ($1656 << 24 >> 24 | 0) == 32 | ($1656 << 24 >> 24 | 0) == 9 | ($1656 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $1657 = $i_0_i_i2664 + 1 | 0; //@line 52473
           $i_0_i_i2664 = $1657;
           $1656 = HEAP8[$cmd + 4 + $1657 | 0] | 0;
           label = 15590; //@line 52478
          }
          HEAP32[$1 >> 2] = $i_0_i_i2664; //@line 52481
          if ((HEAP8[$cmd + 4 + $i_0_i_i2664 | 0] | 0) != 33) {
           break;
          }
          if ((HEAP8[$i_0_i_i2664 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1193 = 2;
           $storemerge4221_in = $i_0_i_i2664;
          } else {
           break;
          }
         }
         HEAP32[$1 >> 2] = $storemerge4221_in + 2; //@line 52500
         if ((_cmd_match_expr_cmp($cmd, $val2_i1192, $base) | 0) == 0) {
          label = 15595; //@line 52505
          break L19579;
         }
         if (($op_0_i1193 | 0) == 1) {
          HEAP32[$val2_i715 >> 2] = (HEAP32[$val2_i715 >> 2] | 0) == (HEAP32[$val2_i1192 >> 2] | 0); //@line 52513
          continue;
         } else if (($op_0_i1193 | 0) == 2) {
          HEAP32[$val2_i715 >> 2] = (HEAP32[$val2_i715 >> 2] | 0) != (HEAP32[$val2_i1192 >> 2] | 0); //@line 52521
          continue;
         } else {
          continue;
         }
        }
        HEAP32[$val2_i290 >> 2] = HEAP32[$val2_i715 >> 2] & HEAP32[$val2_i290 >> 2]; //@line 52531
        $1619 = $i_0_i_i2664; //@line 52533
       }
       if ((label | 0) == 17263) {
        label = 0; //@line 52536
        HEAP32[$1 >> 2] = $1619; //@line 52537
        $1682 = $1619; //@line 52539
       }
       HEAP32[$val2_i65 >> 2] = HEAP32[$val2_i290 >> 2] ^ HEAP32[$val2_i65 >> 2]; //@line 52545
       $i_0_i_i_i291 = $1682; //@line 52547
      }
      while (1) {
       $1688 = $1686; //@line 52552
       while (1) {
        $1689 = $cmd + 4 + $1688 | 0; //@line 52555
        $1690 = HEAP8[$1689] | 0; //@line 52556
        if (!(($1690 << 24 >> 24 | 0) == 13 | ($1690 << 24 >> 24 | 0) == 32 | ($1690 << 24 >> 24 | 0) == 9 | ($1690 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1688 = $1688 + 1 | 0; //@line 52562
       }
       HEAP32[$1 >> 2] = $1688; //@line 52564
       $1693 = HEAP8[$1689] | 0; //@line 52565
       if ($1693 << 24 >> 24 == 124) {
        if ((HEAP8[$1688 + 1 + ($cmd + 4) | 0] | 0) == 124) {
         label = 17264; //@line 52573
         break;
        } else {
         $i_0_i_i311 = $1688;
         $1700 = 124;
        }
       } else {
        $i_0_i_i311 = $1688;
        $1700 = $1693;
       }
       while (1) {
        if (!(($1700 << 24 >> 24 | 0) == 13 | ($1700 << 24 >> 24 | 0) == 32 | ($1700 << 24 >> 24 | 0) == 9 | ($1700 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $1701 = $i_0_i_i311 + 1 | 0; //@line 52587
        $i_0_i_i311 = $1701;
        $1700 = HEAP8[$cmd + 4 + $1701 | 0] | 0;
       }
       HEAP32[$1 >> 2] = $i_0_i_i311; //@line 52594
       if ((HEAP8[$cmd + 4 + $i_0_i_i311 | 0] | 0) != 124) {
        $1927 = $i_0_i_i311; //@line 52598
        break;
       }
       $1706 = $i_0_i_i311 + 1 | 0; //@line 52601
       HEAP32[$1 >> 2] = $1706; //@line 52602
       if ((_cmd_match_expr_cmp($cmd, $val2_i138, $base) | 0) == 0) {
        label = 15696; //@line 52607
        break L19579;
       }
       while (1) {
        $1711 = HEAP32[$1 >> 2] | 0; //@line 52613
        while (1) {
         $1712 = $cmd + 4 + $1711 | 0; //@line 52616
         $1713 = HEAP8[$1712] | 0; //@line 52617
         if (!(($1713 << 24 >> 24 | 0) == 13 | ($1713 << 24 >> 24 | 0) == 32 | ($1713 << 24 >> 24 | 0) == 9 | ($1713 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1711 = $1711 + 1 | 0; //@line 52623
        }
        HEAP32[$1 >> 2] = $1711; //@line 52625
        $1716 = HEAP8[$1712] | 0; //@line 52626
        if ($1716 << 24 >> 24 == 61) {
         if ((HEAP8[$1711 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1197 = 1;
          $storemerge4220_in = $1711;
         } else {
          $i_0_i_i2684 = $1711;
          $1723 = 61;
          label = 15617; //@line 52637
         }
        } else {
         $i_0_i_i2684 = $1711;
         $1723 = $1716;
         label = 15617; //@line 52641
        }
        if ((label | 0) == 15617) {
         while (1) {
          label = 0; //@line 52645
          if (!(($1723 << 24 >> 24 | 0) == 13 | ($1723 << 24 >> 24 | 0) == 32 | ($1723 << 24 >> 24 | 0) == 9 | ($1723 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1724 = $i_0_i_i2684 + 1 | 0; //@line 52651
          $i_0_i_i2684 = $1724;
          $1723 = HEAP8[$cmd + 4 + $1724 | 0] | 0;
          label = 15617; //@line 52656
         }
         HEAP32[$1 >> 2] = $i_0_i_i2684; //@line 52659
         if ((HEAP8[$cmd + 4 + $i_0_i_i2684 | 0] | 0) != 33) {
          $1746 = $i_0_i_i2684; //@line 52663
          break;
         }
         if ((HEAP8[$i_0_i_i2684 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1197 = 2;
          $storemerge4220_in = $i_0_i_i2684;
         } else {
          $1746 = $i_0_i_i2684; //@line 52673
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4220_in + 2; //@line 52680
        if ((_cmd_match_expr_cmp($cmd, $val2_i1196, $base) | 0) == 0) {
         label = 15622; //@line 52685
         break L19579;
        }
        if (($op_0_i1197 | 0) == 1) {
         HEAP32[$val2_i138 >> 2] = (HEAP32[$val2_i138 >> 2] | 0) == (HEAP32[$val2_i1196 >> 2] | 0); //@line 52693
         continue;
        } else if (($op_0_i1197 | 0) == 2) {
         HEAP32[$val2_i138 >> 2] = (HEAP32[$val2_i138 >> 2] | 0) != (HEAP32[$val2_i1196 >> 2] | 0); //@line 52701
         continue;
        } else {
         continue;
        }
       }
       while (1) {
        $1748 = $1746; //@line 52711
        while (1) {
         $1749 = $cmd + 4 + $1748 | 0; //@line 52714
         $1750 = HEAP8[$1749] | 0; //@line 52715
         if (!(($1750 << 24 >> 24 | 0) == 13 | ($1750 << 24 >> 24 | 0) == 32 | ($1750 << 24 >> 24 | 0) == 9 | ($1750 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1748 = $1748 + 1 | 0; //@line 52721
        }
        HEAP32[$1 >> 2] = $1748; //@line 52723
        $1753 = HEAP8[$1749] | 0; //@line 52724
        if ($1753 << 24 >> 24 == 38) {
         if ((HEAP8[$1748 + 1 + ($cmd + 4) | 0] | 0) == 38) {
          label = 17265; //@line 52732
          break;
         } else {
          $i_0_i_i1209 = $1748;
          $1760 = 38;
         }
        } else {
         $i_0_i_i1209 = $1748;
         $1760 = $1753;
        }
        while (1) {
         if (!(($1760 << 24 >> 24 | 0) == 13 | ($1760 << 24 >> 24 | 0) == 32 | ($1760 << 24 >> 24 | 0) == 9 | ($1760 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1761 = $i_0_i_i1209 + 1 | 0; //@line 52746
         $i_0_i_i1209 = $1761;
         $1760 = HEAP8[$cmd + 4 + $1761 | 0] | 0;
        }
        HEAP32[$1 >> 2] = $i_0_i_i1209; //@line 52753
        if ((HEAP8[$cmd + 4 + $i_0_i_i1209 | 0] | 0) != 38) {
         $i_0_i_i_i322 = $i_0_i_i1209; //@line 52757
         break;
        }
        $1766 = $i_0_i_i1209 + 1 | 0; //@line 52760
        HEAP32[$1 >> 2] = $1766; //@line 52761
        if ((_cmd_match_expr_cmp($cmd, $val2_i718, $base) | 0) == 0) {
         label = 15649; //@line 52766
         break L19579;
        }
        while (1) {
         $1771 = HEAP32[$1 >> 2] | 0; //@line 52772
         while (1) {
          $1772 = $cmd + 4 + $1771 | 0; //@line 52775
          $1773 = HEAP8[$1772] | 0; //@line 52776
          if (!(($1773 << 24 >> 24 | 0) == 13 | ($1773 << 24 >> 24 | 0) == 32 | ($1773 << 24 >> 24 | 0) == 9 | ($1773 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1771 = $1771 + 1 | 0; //@line 52782
         }
         HEAP32[$1 >> 2] = $1771; //@line 52784
         $1776 = HEAP8[$1772] | 0; //@line 52785
         if ($1776 << 24 >> 24 == 61) {
          if ((HEAP8[$1771 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1220 = 1;
           $storemerge4219_in = $1771;
          } else {
           $i_0_i_i2704 = $1771;
           $1783 = 61;
           label = 15640; //@line 52796
          }
         } else {
          $i_0_i_i2704 = $1771;
          $1783 = $1776;
          label = 15640; //@line 52800
         }
         if ((label | 0) == 15640) {
          while (1) {
           label = 0; //@line 52804
           if (!(($1783 << 24 >> 24 | 0) == 13 | ($1783 << 24 >> 24 | 0) == 32 | ($1783 << 24 >> 24 | 0) == 9 | ($1783 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $1784 = $i_0_i_i2704 + 1 | 0; //@line 52810
           $i_0_i_i2704 = $1784;
           $1783 = HEAP8[$cmd + 4 + $1784 | 0] | 0;
           label = 15640; //@line 52815
          }
          HEAP32[$1 >> 2] = $i_0_i_i2704; //@line 52818
          if ((HEAP8[$cmd + 4 + $i_0_i_i2704 | 0] | 0) != 33) {
           break;
          }
          if ((HEAP8[$i_0_i_i2704 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1220 = 2;
           $storemerge4219_in = $i_0_i_i2704;
          } else {
           break;
          }
         }
         HEAP32[$1 >> 2] = $storemerge4219_in + 2; //@line 52837
         if ((_cmd_match_expr_cmp($cmd, $val2_i1219, $base) | 0) == 0) {
          label = 15645; //@line 52842
          break L19579;
         }
         if (($op_0_i1220 | 0) == 1) {
          HEAP32[$val2_i718 >> 2] = (HEAP32[$val2_i718 >> 2] | 0) == (HEAP32[$val2_i1219 >> 2] | 0); //@line 52850
          continue;
         } else if (($op_0_i1220 | 0) == 2) {
          HEAP32[$val2_i718 >> 2] = (HEAP32[$val2_i718 >> 2] | 0) != (HEAP32[$val2_i1219 >> 2] | 0); //@line 52858
          continue;
         } else {
          continue;
         }
        }
        HEAP32[$val2_i138 >> 2] = HEAP32[$val2_i718 >> 2] & HEAP32[$val2_i138 >> 2]; //@line 52868
        $1746 = $i_0_i_i2704; //@line 52870
       }
       if ((label | 0) == 17265) {
        label = 0; //@line 52873
        HEAP32[$1 >> 2] = $1746; //@line 52874
        $i_0_i_i_i322 = $1746; //@line 52876
       }
       while (1) {
        $1809 = $cmd + 4 + $i_0_i_i_i322 | 0; //@line 52880
        $1810 = HEAP8[$1809] | 0; //@line 52881
        if (($1810 << 24 >> 24 | 0) == 13 | ($1810 << 24 >> 24 | 0) == 32 | ($1810 << 24 >> 24 | 0) == 9 | ($1810 << 24 >> 24 | 0) == 10) {
         $i_0_i_i_i322 = $i_0_i_i_i322 + 1 | 0; //@line 52885
         continue;
        }
        HEAP32[$1 >> 2] = $i_0_i_i_i322; //@line 52888
        if ((HEAP8[$1809] | 0) != 94) {
         break;
        }
        $1816 = $i_0_i_i_i322 + 1 | 0; //@line 52894
        HEAP32[$1 >> 2] = $1816; //@line 52895
        if ((_cmd_match_expr_cmp($cmd, $val2_i321, $base) | 0) == 0) {
         label = 15694; //@line 52900
         break L19579;
        }
        while (1) {
         $1821 = HEAP32[$1 >> 2] | 0; //@line 52906
         while (1) {
          $1822 = $cmd + 4 + $1821 | 0; //@line 52909
          $1823 = HEAP8[$1822] | 0; //@line 52910
          if (!(($1823 << 24 >> 24 | 0) == 13 | ($1823 << 24 >> 24 | 0) == 32 | ($1823 << 24 >> 24 | 0) == 9 | ($1823 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1821 = $1821 + 1 | 0; //@line 52916
         }
         HEAP32[$1 >> 2] = $1821; //@line 52918
         $1826 = HEAP8[$1822] | 0; //@line 52919
         if ($1826 << 24 >> 24 == 61) {
          if ((HEAP8[$1821 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1224 = 1;
           $storemerge4218_in = $1821;
          } else {
           $i_0_i_i2724 = $1821;
           $1833 = 61;
           label = 15660; //@line 52930
          }
         } else {
          $i_0_i_i2724 = $1821;
          $1833 = $1826;
          label = 15660; //@line 52934
         }
         if ((label | 0) == 15660) {
          while (1) {
           label = 0; //@line 52938
           if (!(($1833 << 24 >> 24 | 0) == 13 | ($1833 << 24 >> 24 | 0) == 32 | ($1833 << 24 >> 24 | 0) == 9 | ($1833 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $1834 = $i_0_i_i2724 + 1 | 0; //@line 52944
           $i_0_i_i2724 = $1834;
           $1833 = HEAP8[$cmd + 4 + $1834 | 0] | 0;
           label = 15660; //@line 52949
          }
          HEAP32[$1 >> 2] = $i_0_i_i2724; //@line 52952
          if ((HEAP8[$cmd + 4 + $i_0_i_i2724 | 0] | 0) != 33) {
           $1856 = $i_0_i_i2724; //@line 52956
           break;
          }
          if ((HEAP8[$i_0_i_i2724 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1224 = 2;
           $storemerge4218_in = $i_0_i_i2724;
          } else {
           $1856 = $i_0_i_i2724; //@line 52966
           break;
          }
         }
         HEAP32[$1 >> 2] = $storemerge4218_in + 2; //@line 52973
         if ((_cmd_match_expr_cmp($cmd, $val2_i1223, $base) | 0) == 0) {
          label = 15665; //@line 52978
          break L19579;
         }
         if (($op_0_i1224 | 0) == 1) {
          HEAP32[$val2_i321 >> 2] = (HEAP32[$val2_i321 >> 2] | 0) == (HEAP32[$val2_i1223 >> 2] | 0); //@line 52986
          continue;
         } else if (($op_0_i1224 | 0) == 2) {
          HEAP32[$val2_i321 >> 2] = (HEAP32[$val2_i321 >> 2] | 0) != (HEAP32[$val2_i1223 >> 2] | 0); //@line 52994
          continue;
         } else {
          continue;
         }
        }
        while (1) {
         $1858 = $1856; //@line 53004
         while (1) {
          $1859 = $cmd + 4 + $1858 | 0; //@line 53007
          $1860 = HEAP8[$1859] | 0; //@line 53008
          if (!(($1860 << 24 >> 24 | 0) == 13 | ($1860 << 24 >> 24 | 0) == 32 | ($1860 << 24 >> 24 | 0) == 9 | ($1860 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1858 = $1858 + 1 | 0; //@line 53014
         }
         HEAP32[$1 >> 2] = $1858; //@line 53016
         $1863 = HEAP8[$1859] | 0; //@line 53017
         if ($1863 << 24 >> 24 == 38) {
          if ((HEAP8[$1858 + 1 + ($cmd + 4) | 0] | 0) == 38) {
           label = 17266; //@line 53025
           break;
          } else {
           $i_0_i_i1236 = $1858;
           $1870 = 38;
          }
         } else {
          $i_0_i_i1236 = $1858;
          $1870 = $1863;
         }
         while (1) {
          if (!(($1870 << 24 >> 24 | 0) == 13 | ($1870 << 24 >> 24 | 0) == 32 | ($1870 << 24 >> 24 | 0) == 9 | ($1870 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1871 = $i_0_i_i1236 + 1 | 0; //@line 53039
          $i_0_i_i1236 = $1871;
          $1870 = HEAP8[$cmd + 4 + $1871 | 0] | 0;
         }
         HEAP32[$1 >> 2] = $i_0_i_i1236; //@line 53046
         if ((HEAP8[$cmd + 4 + $i_0_i_i1236 | 0] | 0) != 38) {
          $1919 = $i_0_i_i1236; //@line 53050
          break;
         }
         $1876 = $i_0_i_i1236 + 1 | 0; //@line 53053
         HEAP32[$1 >> 2] = $1876; //@line 53054
         if ((_cmd_match_expr_cmp($cmd, $val2_i721, $base) | 0) == 0) {
          label = 15692; //@line 53059
          break L19579;
         }
         while (1) {
          $1881 = HEAP32[$1 >> 2] | 0; //@line 53065
          while (1) {
           $1882 = $cmd + 4 + $1881 | 0; //@line 53068
           $1883 = HEAP8[$1882] | 0; //@line 53069
           if (!(($1883 << 24 >> 24 | 0) == 13 | ($1883 << 24 >> 24 | 0) == 32 | ($1883 << 24 >> 24 | 0) == 9 | ($1883 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $1881 = $1881 + 1 | 0; //@line 53075
          }
          HEAP32[$1 >> 2] = $1881; //@line 53077
          $1886 = HEAP8[$1882] | 0; //@line 53078
          if ($1886 << 24 >> 24 == 61) {
           if ((HEAP8[$1881 + 1 + ($cmd + 4) | 0] | 0) == 61) {
            $op_0_i1247 = 1;
            $storemerge4217_in = $1881;
           } else {
            $i_0_i_i2744 = $1881;
            $1893 = 61;
            label = 15683; //@line 53089
           }
          } else {
           $i_0_i_i2744 = $1881;
           $1893 = $1886;
           label = 15683; //@line 53093
          }
          if ((label | 0) == 15683) {
           while (1) {
            label = 0; //@line 53097
            if (!(($1893 << 24 >> 24 | 0) == 13 | ($1893 << 24 >> 24 | 0) == 32 | ($1893 << 24 >> 24 | 0) == 9 | ($1893 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $1894 = $i_0_i_i2744 + 1 | 0; //@line 53103
            $i_0_i_i2744 = $1894;
            $1893 = HEAP8[$cmd + 4 + $1894 | 0] | 0;
            label = 15683; //@line 53108
           }
           HEAP32[$1 >> 2] = $i_0_i_i2744; //@line 53111
           if ((HEAP8[$cmd + 4 + $i_0_i_i2744 | 0] | 0) != 33) {
            break;
           }
           if ((HEAP8[$i_0_i_i2744 + 1 + ($cmd + 4) | 0] | 0) == 61) {
            $op_0_i1247 = 2;
            $storemerge4217_in = $i_0_i_i2744;
           } else {
            break;
           }
          }
          HEAP32[$1 >> 2] = $storemerge4217_in + 2; //@line 53130
          if ((_cmd_match_expr_cmp($cmd, $val2_i1246, $base) | 0) == 0) {
           label = 15688; //@line 53135
           break L19579;
          }
          if (($op_0_i1247 | 0) == 1) {
           HEAP32[$val2_i721 >> 2] = (HEAP32[$val2_i721 >> 2] | 0) == (HEAP32[$val2_i1246 >> 2] | 0); //@line 53143
           continue;
          } else if (($op_0_i1247 | 0) == 2) {
           HEAP32[$val2_i721 >> 2] = (HEAP32[$val2_i721 >> 2] | 0) != (HEAP32[$val2_i1246 >> 2] | 0); //@line 53151
           continue;
          } else {
           continue;
          }
         }
         HEAP32[$val2_i321 >> 2] = HEAP32[$val2_i721 >> 2] & HEAP32[$val2_i321 >> 2]; //@line 53161
         $1856 = $i_0_i_i2744; //@line 53163
        }
        if ((label | 0) == 17266) {
         label = 0; //@line 53166
         HEAP32[$1 >> 2] = $1856; //@line 53167
         $1919 = $1856; //@line 53169
        }
        HEAP32[$val2_i138 >> 2] = HEAP32[$val2_i321 >> 2] ^ HEAP32[$val2_i138 >> 2]; //@line 53175
        $i_0_i_i_i322 = $1919; //@line 53177
       }
       HEAP32[$val2_i65 >> 2] = HEAP32[$val2_i138 >> 2] | HEAP32[$val2_i65 >> 2]; //@line 53182
       $1686 = $i_0_i_i_i322; //@line 53184
      }
      if ((label | 0) == 17264) {
       label = 0; //@line 53187
       HEAP32[$1 >> 2] = $1686; //@line 53188
       $1927 = $1686; //@line 53190
      }
      if ((HEAP32[$val2_i >> 2] | 0) == 0) {
       $1934 = 0; //@line 53197
      } else {
       $1934 = (HEAP32[$val2_i65 >> 2] | 0) != 0 | 0; //@line 53202
      }
      HEAP32[$val2_i >> 2] = $1934; //@line 53205
      $i_0_i_i_i66 = $1927; //@line 53207
     }
     if ((HEAP32[$val >> 2] | 0) == 0) {
      $1942 = (HEAP32[$val2_i >> 2] | 0) != 0 | 0; //@line 53217
     } else {
      $1942 = 1; //@line 53219
     }
     HEAP32[$val >> 2] = $1942; //@line 53222
     $996 = HEAP32[$1 >> 2] | 0; //@line 53225
    }
    if ((label | 0) == 15346) {
     HEAP32[$1 >> 2] = $5873; //@line 53228
    } else if ((label | 0) == 15369) {
     HEAP32[$1 >> 2] = $1064; //@line 53232
     label = 15373; //@line 53234
    } else if ((label | 0) == 15389) {
     HEAP32[$1 >> 2] = $1114; //@line 53237
     label = 15418; //@line 53239
    } else if ((label | 0) == 15412) {
     HEAP32[$1 >> 2] = $1174; //@line 53242
     label = 15416; //@line 53244
    } else if ((label | 0) == 15439) {
     HEAP32[$1 >> 2] = $1241; //@line 53247
     label = 15513; //@line 53249
    } else if ((label | 0) == 15462) {
     HEAP32[$1 >> 2] = $1301; //@line 53252
     label = 15466; //@line 53254
    } else if ((label | 0) == 15482) {
     HEAP32[$1 >> 2] = $1351; //@line 53257
     label = 15511; //@line 53259
    } else if ((label | 0) == 15505) {
     HEAP32[$1 >> 2] = $1411; //@line 53262
     label = 15509; //@line 53264
    } else if ((label | 0) == 15529) {
     HEAP32[$1 >> 2] = $5877; //@line 53267
     label = 15698; //@line 53269
    } else if ((label | 0) == 15552) {
     HEAP32[$1 >> 2] = $1529; //@line 53272
     label = 15556; //@line 53274
    } else if ((label | 0) == 15572) {
     HEAP32[$1 >> 2] = $1579; //@line 53277
     label = 15601; //@line 53279
    } else if ((label | 0) == 15595) {
     HEAP32[$1 >> 2] = $1639; //@line 53282
     label = 15599; //@line 53284
    } else if ((label | 0) == 15622) {
     HEAP32[$1 >> 2] = $1706; //@line 53287
     label = 15696; //@line 53289
    } else if ((label | 0) == 15645) {
     HEAP32[$1 >> 2] = $1766; //@line 53292
     label = 15649; //@line 53294
    } else if ((label | 0) == 15665) {
     HEAP32[$1 >> 2] = $1816; //@line 53297
     label = 15694; //@line 53299
    } else if ((label | 0) == 15688) {
     HEAP32[$1 >> 2] = $1876; //@line 53302
     label = 15692; //@line 53304
    } else if ((label | 0) == 15706) {
     while (1) {
      label = 0; //@line 53308
      if (!(($1944 << 24 >> 24 | 0) == 13 | ($1944 << 24 >> 24 | 0) == 32 | ($1944 << 24 >> 24 | 0) == 9 | ($1944 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $1945 = $i_0_i_i18 + 1 | 0; //@line 53314
      $i_0_i_i18 = $1945;
      $1944 = HEAP8[$cmd + 4 + $1945 | 0] | 0;
      label = 15706; //@line 53319
     }
     HEAP32[$1 >> 2] = $i_0_i_i18; //@line 53322
     if ((HEAP8[$cmd + 4 + $i_0_i_i18 | 0] | 0) != 63) {
      $_0 = 1; //@line 53326
      STACKTOP = sp; //@line 53328
      return $_0 | 0; //@line 53329
     }
     $1950 = $i_0_i_i18 + 1 | 0; //@line 53331
     HEAP32[$1 >> 2] = $1950; //@line 53332
     do {
      if ((_cmd_match_expr_cmp($cmd, $val2, $base) | 0) != 0) {
       while (1) {
        $1961 = HEAP32[$1 >> 2] | 0; //@line 53347
        while (1) {
         $1962 = $cmd + 4 + $1961 | 0; //@line 53350
         $1963 = HEAP8[$1962] | 0; //@line 53351
         if (!(($1963 << 24 >> 24 | 0) == 13 | ($1963 << 24 >> 24 | 0) == 32 | ($1963 << 24 >> 24 | 0) == 9 | ($1963 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1961 = $1961 + 1 | 0; //@line 53357
        }
        HEAP32[$1 >> 2] = $1961; //@line 53359
        $1966 = HEAP8[$1962] | 0; //@line 53360
        if ($1966 << 24 >> 24 == 61) {
         if ((HEAP8[$1961 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1251 = 1;
          $storemerge4216_in = $1961;
         } else {
          $i_0_i_i2764 = $1961;
          $1973 = 61;
          label = 15715; //@line 53371
         }
        } else {
         $i_0_i_i2764 = $1961;
         $1973 = $1966;
         label = 15715; //@line 53375
        }
        if ((label | 0) == 15715) {
         while (1) {
          label = 0; //@line 53379
          if (!(($1973 << 24 >> 24 | 0) == 13 | ($1973 << 24 >> 24 | 0) == 32 | ($1973 << 24 >> 24 | 0) == 9 | ($1973 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $1974 = $i_0_i_i2764 + 1 | 0; //@line 53385
          $i_0_i_i2764 = $1974;
          $1973 = HEAP8[$cmd + 4 + $1974 | 0] | 0;
          label = 15715; //@line 53390
         }
         HEAP32[$1 >> 2] = $i_0_i_i2764; //@line 53393
         if ((HEAP8[$cmd + 4 + $i_0_i_i2764 | 0] | 0) != 33) {
          break;
         }
         if ((HEAP8[$i_0_i_i2764 + 1 + ($cmd + 4) | 0] | 0) == 61) {
          $op_0_i1251 = 2;
          $storemerge4216_in = $i_0_i_i2764;
         } else {
          break;
         }
        }
        HEAP32[$1 >> 2] = $storemerge4216_in + 2; //@line 53412
        if ((_cmd_match_expr_cmp($cmd, $val2_i1250, $base) | 0) == 0) {
         label = 15721; //@line 53417
         break;
        }
        if (($op_0_i1251 | 0) == 1) {
         HEAP32[$val2 >> 2] = (HEAP32[$val2 >> 2] | 0) == (HEAP32[$val2_i1250 >> 2] | 0); //@line 53425
         continue;
        } else if (($op_0_i1251 | 0) == 2) {
         HEAP32[$val2 >> 2] = (HEAP32[$val2 >> 2] | 0) != (HEAP32[$val2_i1250 >> 2] | 0); //@line 53433
         continue;
        } else {
         continue;
        }
       }
       if ((label | 0) == 15721) {
        HEAP32[$1 >> 2] = $1950; //@line 53441
        break;
       }
       $1997 = $i_0_i_i2764; //@line 53447
       L20140 : while (1) {
        $1999 = $1997; //@line 53451
        while (1) {
         $2000 = $cmd + 4 + $1999 | 0; //@line 53454
         $2001 = HEAP8[$2000] | 0; //@line 53455
         if (!(($2001 << 24 >> 24 | 0) == 13 | ($2001 << 24 >> 24 | 0) == 32 | ($2001 << 24 >> 24 | 0) == 9 | ($2001 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $1999 = $1999 + 1 | 0; //@line 53461
        }
        HEAP32[$1 >> 2] = $1999; //@line 53463
        $2004 = HEAP8[$2000] | 0; //@line 53464
        if ($2004 << 24 >> 24 == 38) {
         if ((HEAP8[$1999 + 1 + ($cmd + 4) | 0] | 0) == 38) {
          label = 17254; //@line 53472
          break;
         } else {
          $i_0_i_i1263 = $1999;
          $2011 = 38;
         }
        } else {
         $i_0_i_i1263 = $1999;
         $2011 = $2004;
        }
        while (1) {
         if (!(($2011 << 24 >> 24 | 0) == 13 | ($2011 << 24 >> 24 | 0) == 32 | ($2011 << 24 >> 24 | 0) == 9 | ($2011 << 24 >> 24 | 0) == 10)) {
          break;
         }
         $2012 = $i_0_i_i1263 + 1 | 0; //@line 53486
         $i_0_i_i1263 = $2012;
         $2011 = HEAP8[$cmd + 4 + $2012 | 0] | 0;
        }
        HEAP32[$1 >> 2] = $i_0_i_i1263; //@line 53493
        if ((HEAP8[$cmd + 4 + $i_0_i_i1263 | 0] | 0) != 38) {
         $2016 = $i_0_i_i1263; //@line 53497
         break;
        }
        $2021 = $i_0_i_i1263 + 1 | 0; //@line 53500
        HEAP32[$1 >> 2] = $2021; //@line 53501
        if ((_cmd_match_expr_cmp($cmd, $val2_i724, $base) | 0) == 0) {
         label = 15749; //@line 53506
         break;
        }
        while (1) {
         $2026 = HEAP32[$1 >> 2] | 0; //@line 53512
         while (1) {
          $2027 = $cmd + 4 + $2026 | 0; //@line 53515
          $2028 = HEAP8[$2027] | 0; //@line 53516
          if (!(($2028 << 24 >> 24 | 0) == 13 | ($2028 << 24 >> 24 | 0) == 32 | ($2028 << 24 >> 24 | 0) == 9 | ($2028 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $2026 = $2026 + 1 | 0; //@line 53522
         }
         HEAP32[$1 >> 2] = $2026; //@line 53524
         $2031 = HEAP8[$2027] | 0; //@line 53525
         if ($2031 << 24 >> 24 == 61) {
          if ((HEAP8[$2026 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1274 = 1;
           $storemerge4215_in = $2026;
          } else {
           $i_0_i_i2784 = $2026;
           $2038 = 61;
           label = 15740; //@line 53536
          }
         } else {
          $i_0_i_i2784 = $2026;
          $2038 = $2031;
          label = 15740; //@line 53540
         }
         if ((label | 0) == 15740) {
          while (1) {
           label = 0; //@line 53544
           if (!(($2038 << 24 >> 24 | 0) == 13 | ($2038 << 24 >> 24 | 0) == 32 | ($2038 << 24 >> 24 | 0) == 9 | ($2038 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $2039 = $i_0_i_i2784 + 1 | 0; //@line 53550
           $i_0_i_i2784 = $2039;
           $2038 = HEAP8[$cmd + 4 + $2039 | 0] | 0;
           label = 15740; //@line 53555
          }
          HEAP32[$1 >> 2] = $i_0_i_i2784; //@line 53558
          if ((HEAP8[$cmd + 4 + $i_0_i_i2784 | 0] | 0) != 33) {
           break;
          }
          if ((HEAP8[$i_0_i_i2784 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1274 = 2;
           $storemerge4215_in = $i_0_i_i2784;
          } else {
           break;
          }
         }
         HEAP32[$1 >> 2] = $storemerge4215_in + 2; //@line 53577
         if ((_cmd_match_expr_cmp($cmd, $val2_i1273, $base) | 0) == 0) {
          label = 15745; //@line 53582
          break L20140;
         }
         if (($op_0_i1274 | 0) == 1) {
          HEAP32[$val2_i724 >> 2] = (HEAP32[$val2_i724 >> 2] | 0) == (HEAP32[$val2_i1273 >> 2] | 0); //@line 53590
          continue;
         } else if (($op_0_i1274 | 0) == 2) {
          HEAP32[$val2_i724 >> 2] = (HEAP32[$val2_i724 >> 2] | 0) != (HEAP32[$val2_i1273 >> 2] | 0); //@line 53598
          continue;
         } else {
          continue;
         }
        }
        HEAP32[$val2 >> 2] = HEAP32[$val2_i724 >> 2] & HEAP32[$val2 >> 2]; //@line 53608
        $1997 = $i_0_i_i2784; //@line 53610
       }
       if ((label | 0) == 15745) {
        HEAP32[$1 >> 2] = $2021; //@line 53613
        label = 15749; //@line 53615
       } else if ((label | 0) == 17254) {
        HEAP32[$1 >> 2] = $1997; //@line 53618
        $2016 = $1997; //@line 53620
       }
       if ((label | 0) == 15749) {
        HEAP32[$1 >> 2] = $1950; //@line 53623
        break;
       }
       $i_0_i_i_i334 = $2016; //@line 53632
       L20179 : while (1) {
        $2064 = $cmd + 4 + $i_0_i_i_i334 | 0; //@line 53635
        $2065 = HEAP8[$2064] | 0; //@line 53636
        if (($2065 << 24 >> 24 | 0) == 13 | ($2065 << 24 >> 24 | 0) == 32 | ($2065 << 24 >> 24 | 0) == 9 | ($2065 << 24 >> 24 | 0) == 10) {
         $i_0_i_i_i334 = $i_0_i_i_i334 + 1 | 0; //@line 53640
         continue;
        }
        HEAP32[$1 >> 2] = $i_0_i_i_i334; //@line 53643
        if ((HEAP8[$2064] | 0) != 94) {
         label = 15754; //@line 53647
         break;
        }
        $2078 = $i_0_i_i_i334 + 1 | 0; //@line 53650
        HEAP32[$1 >> 2] = $2078; //@line 53651
        if ((_cmd_match_expr_cmp($cmd, $val2_i333, $base) | 0) == 0) {
         break;
        }
        while (1) {
         $2083 = HEAP32[$1 >> 2] | 0; //@line 53661
         while (1) {
          $2084 = $cmd + 4 + $2083 | 0; //@line 53664
          $2085 = HEAP8[$2084] | 0; //@line 53665
          if (!(($2085 << 24 >> 24 | 0) == 13 | ($2085 << 24 >> 24 | 0) == 32 | ($2085 << 24 >> 24 | 0) == 9 | ($2085 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $2083 = $2083 + 1 | 0; //@line 53671
         }
         HEAP32[$1 >> 2] = $2083; //@line 53673
         $2088 = HEAP8[$2084] | 0; //@line 53674
         if ($2088 << 24 >> 24 == 61) {
          if ((HEAP8[$2083 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1278 = 1;
           $storemerge4214_in = $2083;
          } else {
           $i_0_i_i2804 = $2083;
           $2095 = 61;
           label = 15761; //@line 53685
          }
         } else {
          $i_0_i_i2804 = $2083;
          $2095 = $2088;
          label = 15761; //@line 53689
         }
         if ((label | 0) == 15761) {
          while (1) {
           label = 0; //@line 53693
           if (!(($2095 << 24 >> 24 | 0) == 13 | ($2095 << 24 >> 24 | 0) == 32 | ($2095 << 24 >> 24 | 0) == 9 | ($2095 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $2096 = $i_0_i_i2804 + 1 | 0; //@line 53699
           $i_0_i_i2804 = $2096;
           $2095 = HEAP8[$cmd + 4 + $2096 | 0] | 0;
           label = 15761; //@line 53704
          }
          HEAP32[$1 >> 2] = $i_0_i_i2804; //@line 53707
          if ((HEAP8[$cmd + 4 + $i_0_i_i2804 | 0] | 0) != 33) {
           $2118 = $i_0_i_i2804; //@line 53711
           break;
          }
          if ((HEAP8[$i_0_i_i2804 + 1 + ($cmd + 4) | 0] | 0) == 61) {
           $op_0_i1278 = 2;
           $storemerge4214_in = $i_0_i_i2804;
          } else {
           $2118 = $i_0_i_i2804; //@line 53721
           break;
          }
         }
         HEAP32[$1 >> 2] = $storemerge4214_in + 2; //@line 53728
         if ((_cmd_match_expr_cmp($cmd, $val2_i1277, $base) | 0) == 0) {
          label = 15766; //@line 53733
          break L20179;
         }
         if (($op_0_i1278 | 0) == 1) {
          HEAP32[$val2_i333 >> 2] = (HEAP32[$val2_i333 >> 2] | 0) == (HEAP32[$val2_i1277 >> 2] | 0); //@line 53741
          continue;
         } else if (($op_0_i1278 | 0) == 2) {
          HEAP32[$val2_i333 >> 2] = (HEAP32[$val2_i333 >> 2] | 0) != (HEAP32[$val2_i1277 >> 2] | 0); //@line 53749
          continue;
         } else {
          continue;
         }
        }
        while (1) {
         $2120 = $2118; //@line 53759
         while (1) {
          $2121 = $cmd + 4 + $2120 | 0; //@line 53762
          $2122 = HEAP8[$2121] | 0; //@line 53763
          if (!(($2122 << 24 >> 24 | 0) == 13 | ($2122 << 24 >> 24 | 0) == 32 | ($2122 << 24 >> 24 | 0) == 9 | ($2122 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $2120 = $2120 + 1 | 0; //@line 53769
         }
         HEAP32[$1 >> 2] = $2120; //@line 53771
         $2125 = HEAP8[$2121] | 0; //@line 53772
         if ($2125 << 24 >> 24 == 38) {
          if ((HEAP8[$2120 + 1 + ($cmd + 4) | 0] | 0) == 38) {
           label = 17253; //@line 53780
           break;
          } else {
           $i_0_i_i1290 = $2120;
           $2132 = 38;
          }
         } else {
          $i_0_i_i1290 = $2120;
          $2132 = $2125;
         }
         while (1) {
          if (!(($2132 << 24 >> 24 | 0) == 13 | ($2132 << 24 >> 24 | 0) == 32 | ($2132 << 24 >> 24 | 0) == 9 | ($2132 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $2133 = $i_0_i_i1290 + 1 | 0; //@line 53794
          $i_0_i_i1290 = $2133;
          $2132 = HEAP8[$cmd + 4 + $2133 | 0] | 0;
         }
         HEAP32[$1 >> 2] = $i_0_i_i1290; //@line 53801
         if ((HEAP8[$cmd + 4 + $i_0_i_i1290 | 0] | 0) != 38) {
          $2181 = $i_0_i_i1290; //@line 53805
          break;
         }
         $2138 = $i_0_i_i1290 + 1 | 0; //@line 53808
         HEAP32[$1 >> 2] = $2138; //@line 53809
         if ((_cmd_match_expr_cmp($cmd, $val2_i727, $base) | 0) == 0) {
          label = 15793; //@line 53814
          break L20179;
         }
         while (1) {
          $2143 = HEAP32[$1 >> 2] | 0; //@line 53820
          while (1) {
           $2144 = $cmd + 4 + $2143 | 0; //@line 53823
           $2145 = HEAP8[$2144] | 0; //@line 53824
           if (!(($2145 << 24 >> 24 | 0) == 13 | ($2145 << 24 >> 24 | 0) == 32 | ($2145 << 24 >> 24 | 0) == 9 | ($2145 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $2143 = $2143 + 1 | 0; //@line 53830
          }
          HEAP32[$1 >> 2] = $2143; //@line 53832
          $2148 = HEAP8[$2144] | 0; //@line 53833
          if ($2148 << 24 >> 24 == 61) {
           if ((HEAP8[$2143 + 1 + ($cmd + 4) | 0] | 0) == 61) {
            $op_0_i1301 = 1;
            $storemerge4213_in = $2143;
           } else {
            $i_0_i_i2824 = $2143;
            $2155 = 61;
            label = 15784; //@line 53844
           }
          } else {
           $i_0_i_i2824 = $2143;
           $2155 = $2148;
           label = 15784; //@line 53848
          }
          if ((label | 0) == 15784) {
           while (1) {
            label = 0; //@line 53852
            if (!(($2155 << 24 >> 24 | 0) == 13 | ($2155 << 24 >> 24 | 0) == 32 | ($2155 << 24 >> 24 | 0) == 9 | ($2155 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2156 = $i_0_i_i2824 + 1 | 0; //@line 53858
            $i_0_i_i2824 = $2156;
            $2155 = HEAP8[$cmd + 4 + $2156 | 0] | 0;
            label = 15784; //@line 53863
           }
           HEAP32[$1 >> 2] = $i_0_i_i2824; //@line 53866
           if ((HEAP8[$cmd + 4 + $i_0_i_i2824 | 0] | 0) != 33) {
            break;
           }
           if ((HEAP8[$i_0_i_i2824 + 1 + ($cmd + 4) | 0] | 0) == 61) {
            $op_0_i1301 = 2;
            $storemerge4213_in = $i_0_i_i2824;
           } else {
            break;
           }
          }
          HEAP32[$1 >> 2] = $storemerge4213_in + 2; //@line 53885
          if ((_cmd_match_expr_cmp($cmd, $val2_i1300, $base) | 0) == 0) {
           label = 15789; //@line 53890
           break L20179;
          }
          if (($op_0_i1301 | 0) == 1) {
           HEAP32[$val2_i727 >> 2] = (HEAP32[$val2_i727 >> 2] | 0) == (HEAP32[$val2_i1300 >> 2] | 0); //@line 53898
           continue;
          } else if (($op_0_i1301 | 0) == 2) {
           HEAP32[$val2_i727 >> 2] = (HEAP32[$val2_i727 >> 2] | 0) != (HEAP32[$val2_i1300 >> 2] | 0); //@line 53906
           continue;
          } else {
           continue;
          }
         }
         HEAP32[$val2_i333 >> 2] = HEAP32[$val2_i727 >> 2] & HEAP32[$val2_i333 >> 2]; //@line 53916
         $2118 = $i_0_i_i2824; //@line 53918
        }
        if ((label | 0) == 17253) {
         label = 0; //@line 53921
         HEAP32[$1 >> 2] = $2118; //@line 53922
         $2181 = $2118; //@line 53924
        }
        HEAP32[$val2 >> 2] = HEAP32[$val2_i333 >> 2] ^ HEAP32[$val2 >> 2]; //@line 53930
        $i_0_i_i_i334 = $2181; //@line 53932
       }
       if ((label | 0) == 15754) {
        $2185 = $i_0_i_i_i334; //@line 53943
        L20242 : while (1) {
         $2187 = $2185; //@line 53947
         while (1) {
          $2188 = $cmd + 4 + $2187 | 0; //@line 53950
          $2189 = HEAP8[$2188] | 0; //@line 53951
          if (!(($2189 << 24 >> 24 | 0) == 13 | ($2189 << 24 >> 24 | 0) == 32 | ($2189 << 24 >> 24 | 0) == 9 | ($2189 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $2187 = $2187 + 1 | 0; //@line 53957
         }
         HEAP32[$1 >> 2] = $2187; //@line 53959
         $2192 = HEAP8[$2188] | 0; //@line 53960
         if ($2192 << 24 >> 24 == 124) {
          if ((HEAP8[$2187 + 1 + ($cmd + 4) | 0] | 0) == 124) {
           label = 17250; //@line 53968
           break;
          } else {
           $i_0_i_i354 = $2187;
           $2199 = 124;
          }
         } else {
          $i_0_i_i354 = $2187;
          $2199 = $2192;
         }
         while (1) {
          if (!(($2199 << 24 >> 24 | 0) == 13 | ($2199 << 24 >> 24 | 0) == 32 | ($2199 << 24 >> 24 | 0) == 9 | ($2199 << 24 >> 24 | 0) == 10)) {
           break;
          }
          $2200 = $i_0_i_i354 + 1 | 0; //@line 53982
          $i_0_i_i354 = $2200;
          $2199 = HEAP8[$cmd + 4 + $2200 | 0] | 0;
         }
         HEAP32[$1 >> 2] = $i_0_i_i354; //@line 53989
         if ((HEAP8[$cmd + 4 + $i_0_i_i354 | 0] | 0) != 124) {
          $2204 = $i_0_i_i354; //@line 53993
          label = 15805; //@line 53994
          break;
         }
         $2221 = $i_0_i_i354 + 1 | 0; //@line 53997
         HEAP32[$1 >> 2] = $2221; //@line 53998
         if ((_cmd_match_expr_cmp($cmd, $val2_i141, $base) | 0) == 0) {
          break;
         }
         while (1) {
          $2226 = HEAP32[$1 >> 2] | 0; //@line 54008
          while (1) {
           $2227 = $cmd + 4 + $2226 | 0; //@line 54011
           $2228 = HEAP8[$2227] | 0; //@line 54012
           if (!(($2228 << 24 >> 24 | 0) == 13 | ($2228 << 24 >> 24 | 0) == 32 | ($2228 << 24 >> 24 | 0) == 9 | ($2228 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $2226 = $2226 + 1 | 0; //@line 54018
          }
          HEAP32[$1 >> 2] = $2226; //@line 54020
          $2231 = HEAP8[$2227] | 0; //@line 54021
          if ($2231 << 24 >> 24 == 61) {
           if ((HEAP8[$2226 + 1 + ($cmd + 4) | 0] | 0) == 61) {
            $op_0_i1305 = 1;
            $storemerge4212_in = $2226;
           } else {
            $i_0_i_i2844 = $2226;
            $2238 = 61;
            label = 15812; //@line 54032
           }
          } else {
           $i_0_i_i2844 = $2226;
           $2238 = $2231;
           label = 15812; //@line 54036
          }
          if ((label | 0) == 15812) {
           while (1) {
            label = 0; //@line 54040
            if (!(($2238 << 24 >> 24 | 0) == 13 | ($2238 << 24 >> 24 | 0) == 32 | ($2238 << 24 >> 24 | 0) == 9 | ($2238 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2239 = $i_0_i_i2844 + 1 | 0; //@line 54046
            $i_0_i_i2844 = $2239;
            $2238 = HEAP8[$cmd + 4 + $2239 | 0] | 0;
            label = 15812; //@line 54051
           }
           HEAP32[$1 >> 2] = $i_0_i_i2844; //@line 54054
           if ((HEAP8[$cmd + 4 + $i_0_i_i2844 | 0] | 0) != 33) {
            $2261 = $i_0_i_i2844; //@line 54058
            break;
           }
           if ((HEAP8[$i_0_i_i2844 + 1 + ($cmd + 4) | 0] | 0) == 61) {
            $op_0_i1305 = 2;
            $storemerge4212_in = $i_0_i_i2844;
           } else {
            $2261 = $i_0_i_i2844; //@line 54068
            break;
           }
          }
          HEAP32[$1 >> 2] = $storemerge4212_in + 2; //@line 54075
          if ((_cmd_match_expr_cmp($cmd, $val2_i1304, $base) | 0) == 0) {
           label = 15817; //@line 54080
           break L20242;
          }
          if (($op_0_i1305 | 0) == 1) {
           HEAP32[$val2_i141 >> 2] = (HEAP32[$val2_i141 >> 2] | 0) == (HEAP32[$val2_i1304 >> 2] | 0); //@line 54088
           continue;
          } else if (($op_0_i1305 | 0) == 2) {
           HEAP32[$val2_i141 >> 2] = (HEAP32[$val2_i141 >> 2] | 0) != (HEAP32[$val2_i1304 >> 2] | 0); //@line 54096
           continue;
          } else {
           continue;
          }
         }
         while (1) {
          $2263 = $2261; //@line 54106
          while (1) {
           $2264 = $cmd + 4 + $2263 | 0; //@line 54109
           $2265 = HEAP8[$2264] | 0; //@line 54110
           if (!(($2265 << 24 >> 24 | 0) == 13 | ($2265 << 24 >> 24 | 0) == 32 | ($2265 << 24 >> 24 | 0) == 9 | ($2265 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $2263 = $2263 + 1 | 0; //@line 54116
          }
          HEAP32[$1 >> 2] = $2263; //@line 54118
          $2268 = HEAP8[$2264] | 0; //@line 54119
          if ($2268 << 24 >> 24 == 38) {
           if ((HEAP8[$2263 + 1 + ($cmd + 4) | 0] | 0) == 38) {
            label = 17251; //@line 54127
            break;
           } else {
            $i_0_i_i1317 = $2263;
            $2275 = 38;
           }
          } else {
           $i_0_i_i1317 = $2263;
           $2275 = $2268;
          }
          while (1) {
           if (!(($2275 << 24 >> 24 | 0) == 13 | ($2275 << 24 >> 24 | 0) == 32 | ($2275 << 24 >> 24 | 0) == 9 | ($2275 << 24 >> 24 | 0) == 10)) {
            break;
           }
           $2276 = $i_0_i_i1317 + 1 | 0; //@line 54141
           $i_0_i_i1317 = $2276;
           $2275 = HEAP8[$cmd + 4 + $2276 | 0] | 0;
          }
          HEAP32[$1 >> 2] = $i_0_i_i1317; //@line 54148
          if ((HEAP8[$cmd + 4 + $i_0_i_i1317 | 0] | 0) != 38) {
           $i_0_i_i_i365 = $i_0_i_i1317; //@line 54152
           break;
          }
          $2281 = $i_0_i_i1317 + 1 | 0; //@line 54155
          HEAP32[$1 >> 2] = $2281; //@line 54156
          if ((_cmd_match_expr_cmp($cmd, $val2_i730, $base) | 0) == 0) {
           label = 15844; //@line 54161
           break L20242;
          }
          while (1) {
           $2286 = HEAP32[$1 >> 2] | 0; //@line 54167
           while (1) {
            $2287 = $cmd + 4 + $2286 | 0; //@line 54170
            $2288 = HEAP8[$2287] | 0; //@line 54171
            if (!(($2288 << 24 >> 24 | 0) == 13 | ($2288 << 24 >> 24 | 0) == 32 | ($2288 << 24 >> 24 | 0) == 9 | ($2288 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2286 = $2286 + 1 | 0; //@line 54177
           }
           HEAP32[$1 >> 2] = $2286; //@line 54179
           $2291 = HEAP8[$2287] | 0; //@line 54180
           if ($2291 << 24 >> 24 == 61) {
            if ((HEAP8[$2286 + 1 + ($cmd + 4) | 0] | 0) == 61) {
             $op_0_i1328 = 1;
             $storemerge4211_in = $2286;
            } else {
             $i_0_i_i2864 = $2286;
             $2298 = 61;
             label = 15835; //@line 54191
            }
           } else {
            $i_0_i_i2864 = $2286;
            $2298 = $2291;
            label = 15835; //@line 54195
           }
           if ((label | 0) == 15835) {
            while (1) {
             label = 0; //@line 54199
             if (!(($2298 << 24 >> 24 | 0) == 13 | ($2298 << 24 >> 24 | 0) == 32 | ($2298 << 24 >> 24 | 0) == 9 | ($2298 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2299 = $i_0_i_i2864 + 1 | 0; //@line 54205
             $i_0_i_i2864 = $2299;
             $2298 = HEAP8[$cmd + 4 + $2299 | 0] | 0;
             label = 15835; //@line 54210
            }
            HEAP32[$1 >> 2] = $i_0_i_i2864; //@line 54213
            if ((HEAP8[$cmd + 4 + $i_0_i_i2864 | 0] | 0) != 33) {
             break;
            }
            if ((HEAP8[$i_0_i_i2864 + 1 + ($cmd + 4) | 0] | 0) == 61) {
             $op_0_i1328 = 2;
             $storemerge4211_in = $i_0_i_i2864;
            } else {
             break;
            }
           }
           HEAP32[$1 >> 2] = $storemerge4211_in + 2; //@line 54232
           if ((_cmd_match_expr_cmp($cmd, $val2_i1327, $base) | 0) == 0) {
            label = 15840; //@line 54237
            break L20242;
           }
           if (($op_0_i1328 | 0) == 1) {
            HEAP32[$val2_i730 >> 2] = (HEAP32[$val2_i730 >> 2] | 0) == (HEAP32[$val2_i1327 >> 2] | 0); //@line 54245
            continue;
           } else if (($op_0_i1328 | 0) == 2) {
            HEAP32[$val2_i730 >> 2] = (HEAP32[$val2_i730 >> 2] | 0) != (HEAP32[$val2_i1327 >> 2] | 0); //@line 54253
            continue;
           } else {
            continue;
           }
          }
          HEAP32[$val2_i141 >> 2] = HEAP32[$val2_i730 >> 2] & HEAP32[$val2_i141 >> 2]; //@line 54263
          $2261 = $i_0_i_i2864; //@line 54265
         }
         if ((label | 0) == 17251) {
          label = 0; //@line 54268
          HEAP32[$1 >> 2] = $2261; //@line 54269
          $i_0_i_i_i365 = $2261; //@line 54271
         }
         while (1) {
          $2324 = $cmd + 4 + $i_0_i_i_i365 | 0; //@line 54275
          $2325 = HEAP8[$2324] | 0; //@line 54276
          if (($2325 << 24 >> 24 | 0) == 13 | ($2325 << 24 >> 24 | 0) == 32 | ($2325 << 24 >> 24 | 0) == 9 | ($2325 << 24 >> 24 | 0) == 10) {
           $i_0_i_i_i365 = $i_0_i_i_i365 + 1 | 0; //@line 54280
           continue;
          }
          HEAP32[$1 >> 2] = $i_0_i_i_i365; //@line 54283
          if ((HEAP8[$2324] | 0) != 94) {
           break;
          }
          $2331 = $i_0_i_i_i365 + 1 | 0; //@line 54289
          HEAP32[$1 >> 2] = $2331; //@line 54290
          if ((_cmd_match_expr_cmp($cmd, $val2_i364, $base) | 0) == 0) {
           label = 15889; //@line 54295
           break L20242;
          }
          while (1) {
           $2336 = HEAP32[$1 >> 2] | 0; //@line 54301
           while (1) {
            $2337 = $cmd + 4 + $2336 | 0; //@line 54304
            $2338 = HEAP8[$2337] | 0; //@line 54305
            if (!(($2338 << 24 >> 24 | 0) == 13 | ($2338 << 24 >> 24 | 0) == 32 | ($2338 << 24 >> 24 | 0) == 9 | ($2338 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2336 = $2336 + 1 | 0; //@line 54311
           }
           HEAP32[$1 >> 2] = $2336; //@line 54313
           $2341 = HEAP8[$2337] | 0; //@line 54314
           if ($2341 << 24 >> 24 == 61) {
            if ((HEAP8[$2336 + 1 + ($cmd + 4) | 0] | 0) == 61) {
             $op_0_i1332 = 1;
             $storemerge4210_in = $2336;
            } else {
             $i_0_i_i2884 = $2336;
             $2348 = 61;
             label = 15855; //@line 54325
            }
           } else {
            $i_0_i_i2884 = $2336;
            $2348 = $2341;
            label = 15855; //@line 54329
           }
           if ((label | 0) == 15855) {
            while (1) {
             label = 0; //@line 54333
             if (!(($2348 << 24 >> 24 | 0) == 13 | ($2348 << 24 >> 24 | 0) == 32 | ($2348 << 24 >> 24 | 0) == 9 | ($2348 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2349 = $i_0_i_i2884 + 1 | 0; //@line 54339
             $i_0_i_i2884 = $2349;
             $2348 = HEAP8[$cmd + 4 + $2349 | 0] | 0;
             label = 15855; //@line 54344
            }
            HEAP32[$1 >> 2] = $i_0_i_i2884; //@line 54347
            if ((HEAP8[$cmd + 4 + $i_0_i_i2884 | 0] | 0) != 33) {
             $2371 = $i_0_i_i2884; //@line 54351
             break;
            }
            if ((HEAP8[$i_0_i_i2884 + 1 + ($cmd + 4) | 0] | 0) == 61) {
             $op_0_i1332 = 2;
             $storemerge4210_in = $i_0_i_i2884;
            } else {
             $2371 = $i_0_i_i2884; //@line 54361
             break;
            }
           }
           HEAP32[$1 >> 2] = $storemerge4210_in + 2; //@line 54368
           if ((_cmd_match_expr_cmp($cmd, $val2_i1331, $base) | 0) == 0) {
            label = 15860; //@line 54373
            break L20242;
           }
           if (($op_0_i1332 | 0) == 1) {
            HEAP32[$val2_i364 >> 2] = (HEAP32[$val2_i364 >> 2] | 0) == (HEAP32[$val2_i1331 >> 2] | 0); //@line 54381
            continue;
           } else if (($op_0_i1332 | 0) == 2) {
            HEAP32[$val2_i364 >> 2] = (HEAP32[$val2_i364 >> 2] | 0) != (HEAP32[$val2_i1331 >> 2] | 0); //@line 54389
            continue;
           } else {
            continue;
           }
          }
          while (1) {
           $2373 = $2371; //@line 54399
           while (1) {
            $2374 = $cmd + 4 + $2373 | 0; //@line 54402
            $2375 = HEAP8[$2374] | 0; //@line 54403
            if (!(($2375 << 24 >> 24 | 0) == 13 | ($2375 << 24 >> 24 | 0) == 32 | ($2375 << 24 >> 24 | 0) == 9 | ($2375 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2373 = $2373 + 1 | 0; //@line 54409
           }
           HEAP32[$1 >> 2] = $2373; //@line 54411
           $2378 = HEAP8[$2374] | 0; //@line 54412
           if ($2378 << 24 >> 24 == 38) {
            if ((HEAP8[$2373 + 1 + ($cmd + 4) | 0] | 0) == 38) {
             label = 17252; //@line 54420
             break;
            } else {
             $i_0_i_i1344 = $2373;
             $2385 = 38;
            }
           } else {
            $i_0_i_i1344 = $2373;
            $2385 = $2378;
           }
           while (1) {
            if (!(($2385 << 24 >> 24 | 0) == 13 | ($2385 << 24 >> 24 | 0) == 32 | ($2385 << 24 >> 24 | 0) == 9 | ($2385 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2386 = $i_0_i_i1344 + 1 | 0; //@line 54434
            $i_0_i_i1344 = $2386;
            $2385 = HEAP8[$cmd + 4 + $2386 | 0] | 0;
           }
           HEAP32[$1 >> 2] = $i_0_i_i1344; //@line 54441
           if ((HEAP8[$cmd + 4 + $i_0_i_i1344 | 0] | 0) != 38) {
            $2434 = $i_0_i_i1344; //@line 54445
            break;
           }
           $2391 = $i_0_i_i1344 + 1 | 0; //@line 54448
           HEAP32[$1 >> 2] = $2391; //@line 54449
           if ((_cmd_match_expr_cmp($cmd, $val2_i733, $base) | 0) == 0) {
            label = 15887; //@line 54454
            break L20242;
           }
           while (1) {
            $2396 = HEAP32[$1 >> 2] | 0; //@line 54460
            while (1) {
             $2397 = $cmd + 4 + $2396 | 0; //@line 54463
             $2398 = HEAP8[$2397] | 0; //@line 54464
             if (!(($2398 << 24 >> 24 | 0) == 13 | ($2398 << 24 >> 24 | 0) == 32 | ($2398 << 24 >> 24 | 0) == 9 | ($2398 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2396 = $2396 + 1 | 0; //@line 54470
            }
            HEAP32[$1 >> 2] = $2396; //@line 54472
            $2401 = HEAP8[$2397] | 0; //@line 54473
            if ($2401 << 24 >> 24 == 61) {
             if ((HEAP8[$2396 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1355 = 1;
              $storemerge4209_in = $2396;
             } else {
              $i_0_i_i2904 = $2396;
              $2408 = 61;
              label = 15878; //@line 54484
             }
            } else {
             $i_0_i_i2904 = $2396;
             $2408 = $2401;
             label = 15878; //@line 54488
            }
            if ((label | 0) == 15878) {
             while (1) {
              label = 0; //@line 54492
              if (!(($2408 << 24 >> 24 | 0) == 13 | ($2408 << 24 >> 24 | 0) == 32 | ($2408 << 24 >> 24 | 0) == 9 | ($2408 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2409 = $i_0_i_i2904 + 1 | 0; //@line 54498
              $i_0_i_i2904 = $2409;
              $2408 = HEAP8[$cmd + 4 + $2409 | 0] | 0;
              label = 15878; //@line 54503
             }
             HEAP32[$1 >> 2] = $i_0_i_i2904; //@line 54506
             if ((HEAP8[$cmd + 4 + $i_0_i_i2904 | 0] | 0) != 33) {
              break;
             }
             if ((HEAP8[$i_0_i_i2904 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1355 = 2;
              $storemerge4209_in = $i_0_i_i2904;
             } else {
              break;
             }
            }
            HEAP32[$1 >> 2] = $storemerge4209_in + 2; //@line 54525
            if ((_cmd_match_expr_cmp($cmd, $val2_i1354, $base) | 0) == 0) {
             label = 15883; //@line 54530
             break L20242;
            }
            if (($op_0_i1355 | 0) == 1) {
             HEAP32[$val2_i733 >> 2] = (HEAP32[$val2_i733 >> 2] | 0) == (HEAP32[$val2_i1354 >> 2] | 0); //@line 54538
             continue;
            } else if (($op_0_i1355 | 0) == 2) {
             HEAP32[$val2_i733 >> 2] = (HEAP32[$val2_i733 >> 2] | 0) != (HEAP32[$val2_i1354 >> 2] | 0); //@line 54546
             continue;
            } else {
             continue;
            }
           }
           HEAP32[$val2_i364 >> 2] = HEAP32[$val2_i733 >> 2] & HEAP32[$val2_i364 >> 2]; //@line 54556
           $2371 = $i_0_i_i2904; //@line 54558
          }
          if ((label | 0) == 17252) {
           label = 0; //@line 54561
           HEAP32[$1 >> 2] = $2371; //@line 54562
           $2434 = $2371; //@line 54564
          }
          HEAP32[$val2_i141 >> 2] = HEAP32[$val2_i364 >> 2] ^ HEAP32[$val2_i141 >> 2]; //@line 54570
          $i_0_i_i_i365 = $2434; //@line 54572
         }
         HEAP32[$val2 >> 2] = HEAP32[$val2_i141 >> 2] | HEAP32[$val2 >> 2]; //@line 54577
         $2185 = $i_0_i_i_i365; //@line 54579
        }
        if ((label | 0) == 15817) {
         HEAP32[$1 >> 2] = $2221; //@line 54582
        } else if ((label | 0) == 15840) {
         HEAP32[$1 >> 2] = $2281; //@line 54586
         label = 15844; //@line 54588
        } else if ((label | 0) == 15860) {
         HEAP32[$1 >> 2] = $2331; //@line 54591
         label = 15889; //@line 54593
        } else if ((label | 0) == 15883) {
         HEAP32[$1 >> 2] = $2391; //@line 54596
         label = 15887; //@line 54598
        } else if ((label | 0) == 17250) {
         HEAP32[$1 >> 2] = $2185; //@line 54601
         $2204 = $2185; //@line 54603
         label = 15805; //@line 54604
        }
        if ((label | 0) == 15805) {
         $i_0_i_i_i79 = $2204; //@line 54624
         L20379 : while (1) {
          $2442 = $cmd + 4 + $i_0_i_i_i79 | 0; //@line 54627
          $2443 = HEAP8[$2442] | 0; //@line 54628
          if (($2443 << 24 >> 24 | 0) == 13 | ($2443 << 24 >> 24 | 0) == 32 | ($2443 << 24 >> 24 | 0) == 9 | ($2443 << 24 >> 24 | 0) == 10) {
           $i_0_i_i_i79 = $i_0_i_i_i79 + 1 | 0; //@line 54632
           continue;
          }
          HEAP32[$1 >> 2] = $i_0_i_i_i79; //@line 54635
          if ((HEAP8[$2442] | 0) != 38) {
           label = 15896; //@line 54639
           break;
          }
          if ((HEAP8[$i_0_i_i_i79 + 1 + ($cmd + 4) | 0] | 0) != 38) {
           label = 15896; //@line 54647
           break;
          }
          $5869 = $i_0_i_i_i79 + 2 | 0; //@line 54650
          HEAP32[$1 >> 2] = $5869; //@line 54651
          if ((_cmd_match_expr_cmp($cmd, $val2_i78, $base) | 0) == 0) {
           break;
          }
          while (1) {
           $2485 = HEAP32[$1 >> 2] | 0; //@line 54661
           while (1) {
            $2486 = $cmd + 4 + $2485 | 0; //@line 54664
            $2487 = HEAP8[$2486] | 0; //@line 54665
            if (!(($2487 << 24 >> 24 | 0) == 13 | ($2487 << 24 >> 24 | 0) == 32 | ($2487 << 24 >> 24 | 0) == 9 | ($2487 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2485 = $2485 + 1 | 0; //@line 54671
           }
           HEAP32[$1 >> 2] = $2485; //@line 54673
           $2490 = HEAP8[$2486] | 0; //@line 54674
           if ($2490 << 24 >> 24 == 61) {
            if ((HEAP8[$2485 + 1 + ($cmd + 4) | 0] | 0) == 61) {
             $op_0_i1359 = 1;
             $storemerge4208_in = $2485;
            } else {
             $i_0_i_i2924 = $2485;
             $2497 = 61;
             label = 15903; //@line 54685
            }
           } else {
            $i_0_i_i2924 = $2485;
            $2497 = $2490;
            label = 15903; //@line 54689
           }
           if ((label | 0) == 15903) {
            while (1) {
             label = 0; //@line 54693
             if (!(($2497 << 24 >> 24 | 0) == 13 | ($2497 << 24 >> 24 | 0) == 32 | ($2497 << 24 >> 24 | 0) == 9 | ($2497 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2498 = $i_0_i_i2924 + 1 | 0; //@line 54699
             $i_0_i_i2924 = $2498;
             $2497 = HEAP8[$cmd + 4 + $2498 | 0] | 0;
             label = 15903; //@line 54704
            }
            HEAP32[$1 >> 2] = $i_0_i_i2924; //@line 54707
            if ((HEAP8[$cmd + 4 + $i_0_i_i2924 | 0] | 0) != 33) {
             $2520 = $i_0_i_i2924; //@line 54711
             break;
            }
            if ((HEAP8[$i_0_i_i2924 + 1 + ($cmd + 4) | 0] | 0) == 61) {
             $op_0_i1359 = 2;
             $storemerge4208_in = $i_0_i_i2924;
            } else {
             $2520 = $i_0_i_i2924; //@line 54721
             break;
            }
           }
           HEAP32[$1 >> 2] = $storemerge4208_in + 2; //@line 54728
           if ((_cmd_match_expr_cmp($cmd, $val2_i1358, $base) | 0) == 0) {
            label = 15908; //@line 54733
            break L20379;
           }
           if (($op_0_i1359 | 0) == 1) {
            HEAP32[$val2_i78 >> 2] = (HEAP32[$val2_i78 >> 2] | 0) == (HEAP32[$val2_i1358 >> 2] | 0); //@line 54741
            continue;
           } else if (($op_0_i1359 | 0) == 2) {
            HEAP32[$val2_i78 >> 2] = (HEAP32[$val2_i78 >> 2] | 0) != (HEAP32[$val2_i1358 >> 2] | 0); //@line 54749
            continue;
           } else {
            continue;
           }
          }
          while (1) {
           $2522 = $2520; //@line 54759
           while (1) {
            $2523 = $cmd + 4 + $2522 | 0; //@line 54762
            $2524 = HEAP8[$2523] | 0; //@line 54763
            if (!(($2524 << 24 >> 24 | 0) == 13 | ($2524 << 24 >> 24 | 0) == 32 | ($2524 << 24 >> 24 | 0) == 9 | ($2524 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2522 = $2522 + 1 | 0; //@line 54769
           }
           HEAP32[$1 >> 2] = $2522; //@line 54771
           $2527 = HEAP8[$2523] | 0; //@line 54772
           if ($2527 << 24 >> 24 == 38) {
            if ((HEAP8[$2522 + 1 + ($cmd + 4) | 0] | 0) == 38) {
             label = 17245; //@line 54780
             break;
            } else {
             $i_0_i_i1371 = $2522;
             $2534 = 38;
            }
           } else {
            $i_0_i_i1371 = $2522;
            $2534 = $2527;
           }
           while (1) {
            if (!(($2534 << 24 >> 24 | 0) == 13 | ($2534 << 24 >> 24 | 0) == 32 | ($2534 << 24 >> 24 | 0) == 9 | ($2534 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2535 = $i_0_i_i1371 + 1 | 0; //@line 54794
            $i_0_i_i1371 = $2535;
            $2534 = HEAP8[$cmd + 4 + $2535 | 0] | 0;
           }
           HEAP32[$1 >> 2] = $i_0_i_i1371; //@line 54801
           if ((HEAP8[$cmd + 4 + $i_0_i_i1371 | 0] | 0) != 38) {
            $i_0_i_i_i377 = $i_0_i_i1371; //@line 54805
            break;
           }
           $2540 = $i_0_i_i1371 + 1 | 0; //@line 54808
           HEAP32[$1 >> 2] = $2540; //@line 54809
           if ((_cmd_match_expr_cmp($cmd, $val2_i736, $base) | 0) == 0) {
            label = 15935; //@line 54814
            break L20379;
           }
           while (1) {
            $2545 = HEAP32[$1 >> 2] | 0; //@line 54820
            while (1) {
             $2546 = $cmd + 4 + $2545 | 0; //@line 54823
             $2547 = HEAP8[$2546] | 0; //@line 54824
             if (!(($2547 << 24 >> 24 | 0) == 13 | ($2547 << 24 >> 24 | 0) == 32 | ($2547 << 24 >> 24 | 0) == 9 | ($2547 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2545 = $2545 + 1 | 0; //@line 54830
            }
            HEAP32[$1 >> 2] = $2545; //@line 54832
            $2550 = HEAP8[$2546] | 0; //@line 54833
            if ($2550 << 24 >> 24 == 61) {
             if ((HEAP8[$2545 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1382 = 1;
              $storemerge4207_in = $2545;
             } else {
              $i_0_i_i2944 = $2545;
              $2557 = 61;
              label = 15926; //@line 54844
             }
            } else {
             $i_0_i_i2944 = $2545;
             $2557 = $2550;
             label = 15926; //@line 54848
            }
            if ((label | 0) == 15926) {
             while (1) {
              label = 0; //@line 54852
              if (!(($2557 << 24 >> 24 | 0) == 13 | ($2557 << 24 >> 24 | 0) == 32 | ($2557 << 24 >> 24 | 0) == 9 | ($2557 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2558 = $i_0_i_i2944 + 1 | 0; //@line 54858
              $i_0_i_i2944 = $2558;
              $2557 = HEAP8[$cmd + 4 + $2558 | 0] | 0;
              label = 15926; //@line 54863
             }
             HEAP32[$1 >> 2] = $i_0_i_i2944; //@line 54866
             if ((HEAP8[$cmd + 4 + $i_0_i_i2944 | 0] | 0) != 33) {
              break;
             }
             if ((HEAP8[$i_0_i_i2944 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1382 = 2;
              $storemerge4207_in = $i_0_i_i2944;
             } else {
              break;
             }
            }
            HEAP32[$1 >> 2] = $storemerge4207_in + 2; //@line 54885
            if ((_cmd_match_expr_cmp($cmd, $val2_i1381, $base) | 0) == 0) {
             label = 15931; //@line 54890
             break L20379;
            }
            if (($op_0_i1382 | 0) == 1) {
             HEAP32[$val2_i736 >> 2] = (HEAP32[$val2_i736 >> 2] | 0) == (HEAP32[$val2_i1381 >> 2] | 0); //@line 54898
             continue;
            } else if (($op_0_i1382 | 0) == 2) {
             HEAP32[$val2_i736 >> 2] = (HEAP32[$val2_i736 >> 2] | 0) != (HEAP32[$val2_i1381 >> 2] | 0); //@line 54906
             continue;
            } else {
             continue;
            }
           }
           HEAP32[$val2_i78 >> 2] = HEAP32[$val2_i736 >> 2] & HEAP32[$val2_i78 >> 2]; //@line 54916
           $2520 = $i_0_i_i2944; //@line 54918
          }
          if ((label | 0) == 17245) {
           label = 0; //@line 54921
           HEAP32[$1 >> 2] = $2520; //@line 54922
           $i_0_i_i_i377 = $2520; //@line 54924
          }
          while (1) {
           $2583 = $cmd + 4 + $i_0_i_i_i377 | 0; //@line 54928
           $2584 = HEAP8[$2583] | 0; //@line 54929
           if (($2584 << 24 >> 24 | 0) == 13 | ($2584 << 24 >> 24 | 0) == 32 | ($2584 << 24 >> 24 | 0) == 9 | ($2584 << 24 >> 24 | 0) == 10) {
            $i_0_i_i_i377 = $i_0_i_i_i377 + 1 | 0; //@line 54933
            continue;
           }
           HEAP32[$1 >> 2] = $i_0_i_i_i377; //@line 54936
           if ((HEAP8[$2583] | 0) != 94) {
            $2697 = $i_0_i_i_i377; //@line 54940
            break;
           }
           $2590 = $i_0_i_i_i377 + 1 | 0; //@line 54943
           HEAP32[$1 >> 2] = $2590; //@line 54944
           if ((_cmd_match_expr_cmp($cmd, $val2_i376, $base) | 0) == 0) {
            label = 15980; //@line 54949
            break L20379;
           }
           while (1) {
            $2595 = HEAP32[$1 >> 2] | 0; //@line 54955
            while (1) {
             $2596 = $cmd + 4 + $2595 | 0; //@line 54958
             $2597 = HEAP8[$2596] | 0; //@line 54959
             if (!(($2597 << 24 >> 24 | 0) == 13 | ($2597 << 24 >> 24 | 0) == 32 | ($2597 << 24 >> 24 | 0) == 9 | ($2597 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2595 = $2595 + 1 | 0; //@line 54965
            }
            HEAP32[$1 >> 2] = $2595; //@line 54967
            $2600 = HEAP8[$2596] | 0; //@line 54968
            if ($2600 << 24 >> 24 == 61) {
             if ((HEAP8[$2595 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1386 = 1;
              $storemerge4206_in = $2595;
             } else {
              $i_0_i_i2964 = $2595;
              $2607 = 61;
              label = 15946; //@line 54979
             }
            } else {
             $i_0_i_i2964 = $2595;
             $2607 = $2600;
             label = 15946; //@line 54983
            }
            if ((label | 0) == 15946) {
             while (1) {
              label = 0; //@line 54987
              if (!(($2607 << 24 >> 24 | 0) == 13 | ($2607 << 24 >> 24 | 0) == 32 | ($2607 << 24 >> 24 | 0) == 9 | ($2607 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2608 = $i_0_i_i2964 + 1 | 0; //@line 54993
              $i_0_i_i2964 = $2608;
              $2607 = HEAP8[$cmd + 4 + $2608 | 0] | 0;
              label = 15946; //@line 54998
             }
             HEAP32[$1 >> 2] = $i_0_i_i2964; //@line 55001
             if ((HEAP8[$cmd + 4 + $i_0_i_i2964 | 0] | 0) != 33) {
              $2630 = $i_0_i_i2964; //@line 55005
              break;
             }
             if ((HEAP8[$i_0_i_i2964 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1386 = 2;
              $storemerge4206_in = $i_0_i_i2964;
             } else {
              $2630 = $i_0_i_i2964; //@line 55015
              break;
             }
            }
            HEAP32[$1 >> 2] = $storemerge4206_in + 2; //@line 55022
            if ((_cmd_match_expr_cmp($cmd, $val2_i1385, $base) | 0) == 0) {
             label = 15951; //@line 55027
             break L20379;
            }
            if (($op_0_i1386 | 0) == 1) {
             HEAP32[$val2_i376 >> 2] = (HEAP32[$val2_i376 >> 2] | 0) == (HEAP32[$val2_i1385 >> 2] | 0); //@line 55035
             continue;
            } else if (($op_0_i1386 | 0) == 2) {
             HEAP32[$val2_i376 >> 2] = (HEAP32[$val2_i376 >> 2] | 0) != (HEAP32[$val2_i1385 >> 2] | 0); //@line 55043
             continue;
            } else {
             continue;
            }
           }
           while (1) {
            $2632 = $2630; //@line 55053
            while (1) {
             $2633 = $cmd + 4 + $2632 | 0; //@line 55056
             $2634 = HEAP8[$2633] | 0; //@line 55057
             if (!(($2634 << 24 >> 24 | 0) == 13 | ($2634 << 24 >> 24 | 0) == 32 | ($2634 << 24 >> 24 | 0) == 9 | ($2634 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2632 = $2632 + 1 | 0; //@line 55063
            }
            HEAP32[$1 >> 2] = $2632; //@line 55065
            $2637 = HEAP8[$2633] | 0; //@line 55066
            if ($2637 << 24 >> 24 == 38) {
             if ((HEAP8[$2632 + 1 + ($cmd + 4) | 0] | 0) == 38) {
              label = 17246; //@line 55074
              break;
             } else {
              $i_0_i_i1398 = $2632;
              $2644 = 38;
             }
            } else {
             $i_0_i_i1398 = $2632;
             $2644 = $2637;
            }
            while (1) {
             if (!(($2644 << 24 >> 24 | 0) == 13 | ($2644 << 24 >> 24 | 0) == 32 | ($2644 << 24 >> 24 | 0) == 9 | ($2644 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2645 = $i_0_i_i1398 + 1 | 0; //@line 55088
             $i_0_i_i1398 = $2645;
             $2644 = HEAP8[$cmd + 4 + $2645 | 0] | 0;
            }
            HEAP32[$1 >> 2] = $i_0_i_i1398; //@line 55095
            if ((HEAP8[$cmd + 4 + $i_0_i_i1398 | 0] | 0) != 38) {
             $2693 = $i_0_i_i1398; //@line 55099
             break;
            }
            $2650 = $i_0_i_i1398 + 1 | 0; //@line 55102
            HEAP32[$1 >> 2] = $2650; //@line 55103
            if ((_cmd_match_expr_cmp($cmd, $val2_i739, $base) | 0) == 0) {
             label = 15978; //@line 55108
             break L20379;
            }
            while (1) {
             $2655 = HEAP32[$1 >> 2] | 0; //@line 55114
             while (1) {
              $2656 = $cmd + 4 + $2655 | 0; //@line 55117
              $2657 = HEAP8[$2656] | 0; //@line 55118
              if (!(($2657 << 24 >> 24 | 0) == 13 | ($2657 << 24 >> 24 | 0) == 32 | ($2657 << 24 >> 24 | 0) == 9 | ($2657 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2655 = $2655 + 1 | 0; //@line 55124
             }
             HEAP32[$1 >> 2] = $2655; //@line 55126
             $2660 = HEAP8[$2656] | 0; //@line 55127
             if ($2660 << 24 >> 24 == 61) {
              if ((HEAP8[$2655 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1409 = 1;
               $storemerge4205_in = $2655;
              } else {
               $i_0_i_i2984 = $2655;
               $2667 = 61;
               label = 15969; //@line 55138
              }
             } else {
              $i_0_i_i2984 = $2655;
              $2667 = $2660;
              label = 15969; //@line 55142
             }
             if ((label | 0) == 15969) {
              while (1) {
               label = 0; //@line 55146
               if (!(($2667 << 24 >> 24 | 0) == 13 | ($2667 << 24 >> 24 | 0) == 32 | ($2667 << 24 >> 24 | 0) == 9 | ($2667 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $2668 = $i_0_i_i2984 + 1 | 0; //@line 55152
               $i_0_i_i2984 = $2668;
               $2667 = HEAP8[$cmd + 4 + $2668 | 0] | 0;
               label = 15969; //@line 55157
              }
              HEAP32[$1 >> 2] = $i_0_i_i2984; //@line 55160
              if ((HEAP8[$cmd + 4 + $i_0_i_i2984 | 0] | 0) != 33) {
               break;
              }
              if ((HEAP8[$i_0_i_i2984 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1409 = 2;
               $storemerge4205_in = $i_0_i_i2984;
              } else {
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4205_in + 2; //@line 55179
             if ((_cmd_match_expr_cmp($cmd, $val2_i1408, $base) | 0) == 0) {
              label = 15974; //@line 55184
              break L20379;
             }
             if (($op_0_i1409 | 0) == 1) {
              HEAP32[$val2_i739 >> 2] = (HEAP32[$val2_i739 >> 2] | 0) == (HEAP32[$val2_i1408 >> 2] | 0); //@line 55192
              continue;
             } else if (($op_0_i1409 | 0) == 2) {
              HEAP32[$val2_i739 >> 2] = (HEAP32[$val2_i739 >> 2] | 0) != (HEAP32[$val2_i1408 >> 2] | 0); //@line 55200
              continue;
             } else {
              continue;
             }
            }
            HEAP32[$val2_i376 >> 2] = HEAP32[$val2_i739 >> 2] & HEAP32[$val2_i376 >> 2]; //@line 55210
            $2630 = $i_0_i_i2984; //@line 55212
           }
           if ((label | 0) == 17246) {
            label = 0; //@line 55215
            HEAP32[$1 >> 2] = $2630; //@line 55216
            $2693 = $2630; //@line 55218
           }
           HEAP32[$val2_i78 >> 2] = HEAP32[$val2_i376 >> 2] ^ HEAP32[$val2_i78 >> 2]; //@line 55224
           $i_0_i_i_i377 = $2693; //@line 55226
          }
          while (1) {
           $2699 = $2697; //@line 55231
           while (1) {
            $2700 = $cmd + 4 + $2699 | 0; //@line 55234
            $2701 = HEAP8[$2700] | 0; //@line 55235
            if (!(($2701 << 24 >> 24 | 0) == 13 | ($2701 << 24 >> 24 | 0) == 32 | ($2701 << 24 >> 24 | 0) == 9 | ($2701 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2699 = $2699 + 1 | 0; //@line 55241
           }
           HEAP32[$1 >> 2] = $2699; //@line 55243
           $2704 = HEAP8[$2700] | 0; //@line 55244
           if ($2704 << 24 >> 24 == 124) {
            if ((HEAP8[$2699 + 1 + ($cmd + 4) | 0] | 0) == 124) {
             label = 17247; //@line 55252
             break;
            } else {
             $i_0_i_i397 = $2699;
             $2711 = 124;
            }
           } else {
            $i_0_i_i397 = $2699;
            $2711 = $2704;
           }
           while (1) {
            if (!(($2711 << 24 >> 24 | 0) == 13 | ($2711 << 24 >> 24 | 0) == 32 | ($2711 << 24 >> 24 | 0) == 9 | ($2711 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $2712 = $i_0_i_i397 + 1 | 0; //@line 55266
            $i_0_i_i397 = $2712;
            $2711 = HEAP8[$cmd + 4 + $2712 | 0] | 0;
           }
           HEAP32[$1 >> 2] = $i_0_i_i397; //@line 55273
           if ((HEAP8[$cmd + 4 + $i_0_i_i397 | 0] | 0) != 124) {
            $2938 = $i_0_i_i397; //@line 55277
            break;
           }
           $2717 = $i_0_i_i397 + 1 | 0; //@line 55280
           HEAP32[$1 >> 2] = $2717; //@line 55281
           if ((_cmd_match_expr_cmp($cmd, $val2_i144, $base) | 0) == 0) {
            label = 16075; //@line 55286
            break L20379;
           }
           while (1) {
            $2722 = HEAP32[$1 >> 2] | 0; //@line 55292
            while (1) {
             $2723 = $cmd + 4 + $2722 | 0; //@line 55295
             $2724 = HEAP8[$2723] | 0; //@line 55296
             if (!(($2724 << 24 >> 24 | 0) == 13 | ($2724 << 24 >> 24 | 0) == 32 | ($2724 << 24 >> 24 | 0) == 9 | ($2724 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2722 = $2722 + 1 | 0; //@line 55302
            }
            HEAP32[$1 >> 2] = $2722; //@line 55304
            $2727 = HEAP8[$2723] | 0; //@line 55305
            if ($2727 << 24 >> 24 == 61) {
             if ((HEAP8[$2722 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1413 = 1;
              $storemerge4204_in = $2722;
             } else {
              $i_0_i_i3004 = $2722;
              $2734 = 61;
              label = 15996; //@line 55316
             }
            } else {
             $i_0_i_i3004 = $2722;
             $2734 = $2727;
             label = 15996; //@line 55320
            }
            if ((label | 0) == 15996) {
             while (1) {
              label = 0; //@line 55324
              if (!(($2734 << 24 >> 24 | 0) == 13 | ($2734 << 24 >> 24 | 0) == 32 | ($2734 << 24 >> 24 | 0) == 9 | ($2734 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2735 = $i_0_i_i3004 + 1 | 0; //@line 55330
              $i_0_i_i3004 = $2735;
              $2734 = HEAP8[$cmd + 4 + $2735 | 0] | 0;
              label = 15996; //@line 55335
             }
             HEAP32[$1 >> 2] = $i_0_i_i3004; //@line 55338
             if ((HEAP8[$cmd + 4 + $i_0_i_i3004 | 0] | 0) != 33) {
              $2757 = $i_0_i_i3004; //@line 55342
              break;
             }
             if ((HEAP8[$i_0_i_i3004 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1413 = 2;
              $storemerge4204_in = $i_0_i_i3004;
             } else {
              $2757 = $i_0_i_i3004; //@line 55352
              break;
             }
            }
            HEAP32[$1 >> 2] = $storemerge4204_in + 2; //@line 55359
            if ((_cmd_match_expr_cmp($cmd, $val2_i1412, $base) | 0) == 0) {
             label = 16001; //@line 55364
             break L20379;
            }
            if (($op_0_i1413 | 0) == 1) {
             HEAP32[$val2_i144 >> 2] = (HEAP32[$val2_i144 >> 2] | 0) == (HEAP32[$val2_i1412 >> 2] | 0); //@line 55372
             continue;
            } else if (($op_0_i1413 | 0) == 2) {
             HEAP32[$val2_i144 >> 2] = (HEAP32[$val2_i144 >> 2] | 0) != (HEAP32[$val2_i1412 >> 2] | 0); //@line 55380
             continue;
            } else {
             continue;
            }
           }
           while (1) {
            $2759 = $2757; //@line 55390
            while (1) {
             $2760 = $cmd + 4 + $2759 | 0; //@line 55393
             $2761 = HEAP8[$2760] | 0; //@line 55394
             if (!(($2761 << 24 >> 24 | 0) == 13 | ($2761 << 24 >> 24 | 0) == 32 | ($2761 << 24 >> 24 | 0) == 9 | ($2761 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2759 = $2759 + 1 | 0; //@line 55400
            }
            HEAP32[$1 >> 2] = $2759; //@line 55402
            $2764 = HEAP8[$2760] | 0; //@line 55403
            if ($2764 << 24 >> 24 == 38) {
             if ((HEAP8[$2759 + 1 + ($cmd + 4) | 0] | 0) == 38) {
              label = 17248; //@line 55411
              break;
             } else {
              $i_0_i_i1425 = $2759;
              $2771 = 38;
             }
            } else {
             $i_0_i_i1425 = $2759;
             $2771 = $2764;
            }
            while (1) {
             if (!(($2771 << 24 >> 24 | 0) == 13 | ($2771 << 24 >> 24 | 0) == 32 | ($2771 << 24 >> 24 | 0) == 9 | ($2771 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2772 = $i_0_i_i1425 + 1 | 0; //@line 55425
             $i_0_i_i1425 = $2772;
             $2771 = HEAP8[$cmd + 4 + $2772 | 0] | 0;
            }
            HEAP32[$1 >> 2] = $i_0_i_i1425; //@line 55432
            if ((HEAP8[$cmd + 4 + $i_0_i_i1425 | 0] | 0) != 38) {
             $i_0_i_i_i408 = $i_0_i_i1425; //@line 55436
             break;
            }
            $2777 = $i_0_i_i1425 + 1 | 0; //@line 55439
            HEAP32[$1 >> 2] = $2777; //@line 55440
            if ((_cmd_match_expr_cmp($cmd, $val2_i742, $base) | 0) == 0) {
             label = 16028; //@line 55445
             break L20379;
            }
            while (1) {
             $2782 = HEAP32[$1 >> 2] | 0; //@line 55451
             while (1) {
              $2783 = $cmd + 4 + $2782 | 0; //@line 55454
              $2784 = HEAP8[$2783] | 0; //@line 55455
              if (!(($2784 << 24 >> 24 | 0) == 13 | ($2784 << 24 >> 24 | 0) == 32 | ($2784 << 24 >> 24 | 0) == 9 | ($2784 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2782 = $2782 + 1 | 0; //@line 55461
             }
             HEAP32[$1 >> 2] = $2782; //@line 55463
             $2787 = HEAP8[$2783] | 0; //@line 55464
             if ($2787 << 24 >> 24 == 61) {
              if ((HEAP8[$2782 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1436 = 1;
               $storemerge4203_in = $2782;
              } else {
               $i_0_i_i3024 = $2782;
               $2794 = 61;
               label = 16019; //@line 55475
              }
             } else {
              $i_0_i_i3024 = $2782;
              $2794 = $2787;
              label = 16019; //@line 55479
             }
             if ((label | 0) == 16019) {
              while (1) {
               label = 0; //@line 55483
               if (!(($2794 << 24 >> 24 | 0) == 13 | ($2794 << 24 >> 24 | 0) == 32 | ($2794 << 24 >> 24 | 0) == 9 | ($2794 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $2795 = $i_0_i_i3024 + 1 | 0; //@line 55489
               $i_0_i_i3024 = $2795;
               $2794 = HEAP8[$cmd + 4 + $2795 | 0] | 0;
               label = 16019; //@line 55494
              }
              HEAP32[$1 >> 2] = $i_0_i_i3024; //@line 55497
              if ((HEAP8[$cmd + 4 + $i_0_i_i3024 | 0] | 0) != 33) {
               break;
              }
              if ((HEAP8[$i_0_i_i3024 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1436 = 2;
               $storemerge4203_in = $i_0_i_i3024;
              } else {
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4203_in + 2; //@line 55516
             if ((_cmd_match_expr_cmp($cmd, $val2_i1435, $base) | 0) == 0) {
              label = 16024; //@line 55521
              break L20379;
             }
             if (($op_0_i1436 | 0) == 1) {
              HEAP32[$val2_i742 >> 2] = (HEAP32[$val2_i742 >> 2] | 0) == (HEAP32[$val2_i1435 >> 2] | 0); //@line 55529
              continue;
             } else if (($op_0_i1436 | 0) == 2) {
              HEAP32[$val2_i742 >> 2] = (HEAP32[$val2_i742 >> 2] | 0) != (HEAP32[$val2_i1435 >> 2] | 0); //@line 55537
              continue;
             } else {
              continue;
             }
            }
            HEAP32[$val2_i144 >> 2] = HEAP32[$val2_i742 >> 2] & HEAP32[$val2_i144 >> 2]; //@line 55547
            $2757 = $i_0_i_i3024; //@line 55549
           }
           if ((label | 0) == 17248) {
            label = 0; //@line 55552
            HEAP32[$1 >> 2] = $2757; //@line 55553
            $i_0_i_i_i408 = $2757; //@line 55555
           }
           while (1) {
            $2820 = $cmd + 4 + $i_0_i_i_i408 | 0; //@line 55559
            $2821 = HEAP8[$2820] | 0; //@line 55560
            if (($2821 << 24 >> 24 | 0) == 13 | ($2821 << 24 >> 24 | 0) == 32 | ($2821 << 24 >> 24 | 0) == 9 | ($2821 << 24 >> 24 | 0) == 10) {
             $i_0_i_i_i408 = $i_0_i_i_i408 + 1 | 0; //@line 55564
             continue;
            }
            HEAP32[$1 >> 2] = $i_0_i_i_i408; //@line 55567
            if ((HEAP8[$2820] | 0) != 94) {
             break;
            }
            $2827 = $i_0_i_i_i408 + 1 | 0; //@line 55573
            HEAP32[$1 >> 2] = $2827; //@line 55574
            if ((_cmd_match_expr_cmp($cmd, $val2_i407, $base) | 0) == 0) {
             label = 16073; //@line 55579
             break L20379;
            }
            while (1) {
             $2832 = HEAP32[$1 >> 2] | 0; //@line 55585
             while (1) {
              $2833 = $cmd + 4 + $2832 | 0; //@line 55588
              $2834 = HEAP8[$2833] | 0; //@line 55589
              if (!(($2834 << 24 >> 24 | 0) == 13 | ($2834 << 24 >> 24 | 0) == 32 | ($2834 << 24 >> 24 | 0) == 9 | ($2834 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2832 = $2832 + 1 | 0; //@line 55595
             }
             HEAP32[$1 >> 2] = $2832; //@line 55597
             $2837 = HEAP8[$2833] | 0; //@line 55598
             if ($2837 << 24 >> 24 == 61) {
              if ((HEAP8[$2832 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1440 = 1;
               $storemerge4202_in = $2832;
              } else {
               $i_0_i_i3044 = $2832;
               $2844 = 61;
               label = 16039; //@line 55609
              }
             } else {
              $i_0_i_i3044 = $2832;
              $2844 = $2837;
              label = 16039; //@line 55613
             }
             if ((label | 0) == 16039) {
              while (1) {
               label = 0; //@line 55617
               if (!(($2844 << 24 >> 24 | 0) == 13 | ($2844 << 24 >> 24 | 0) == 32 | ($2844 << 24 >> 24 | 0) == 9 | ($2844 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $2845 = $i_0_i_i3044 + 1 | 0; //@line 55623
               $i_0_i_i3044 = $2845;
               $2844 = HEAP8[$cmd + 4 + $2845 | 0] | 0;
               label = 16039; //@line 55628
              }
              HEAP32[$1 >> 2] = $i_0_i_i3044; //@line 55631
              if ((HEAP8[$cmd + 4 + $i_0_i_i3044 | 0] | 0) != 33) {
               $2867 = $i_0_i_i3044; //@line 55635
               break;
              }
              if ((HEAP8[$i_0_i_i3044 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1440 = 2;
               $storemerge4202_in = $i_0_i_i3044;
              } else {
               $2867 = $i_0_i_i3044; //@line 55645
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4202_in + 2; //@line 55652
             if ((_cmd_match_expr_cmp($cmd, $val2_i1439, $base) | 0) == 0) {
              label = 16044; //@line 55657
              break L20379;
             }
             if (($op_0_i1440 | 0) == 1) {
              HEAP32[$val2_i407 >> 2] = (HEAP32[$val2_i407 >> 2] | 0) == (HEAP32[$val2_i1439 >> 2] | 0); //@line 55665
              continue;
             } else if (($op_0_i1440 | 0) == 2) {
              HEAP32[$val2_i407 >> 2] = (HEAP32[$val2_i407 >> 2] | 0) != (HEAP32[$val2_i1439 >> 2] | 0); //@line 55673
              continue;
             } else {
              continue;
             }
            }
            while (1) {
             $2869 = $2867; //@line 55683
             while (1) {
              $2870 = $cmd + 4 + $2869 | 0; //@line 55686
              $2871 = HEAP8[$2870] | 0; //@line 55687
              if (!(($2871 << 24 >> 24 | 0) == 13 | ($2871 << 24 >> 24 | 0) == 32 | ($2871 << 24 >> 24 | 0) == 9 | ($2871 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2869 = $2869 + 1 | 0; //@line 55693
             }
             HEAP32[$1 >> 2] = $2869; //@line 55695
             $2874 = HEAP8[$2870] | 0; //@line 55696
             if ($2874 << 24 >> 24 == 38) {
              if ((HEAP8[$2869 + 1 + ($cmd + 4) | 0] | 0) == 38) {
               label = 17249; //@line 55704
               break;
              } else {
               $i_0_i_i1452 = $2869;
               $2881 = 38;
              }
             } else {
              $i_0_i_i1452 = $2869;
              $2881 = $2874;
             }
             while (1) {
              if (!(($2881 << 24 >> 24 | 0) == 13 | ($2881 << 24 >> 24 | 0) == 32 | ($2881 << 24 >> 24 | 0) == 9 | ($2881 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2882 = $i_0_i_i1452 + 1 | 0; //@line 55718
              $i_0_i_i1452 = $2882;
              $2881 = HEAP8[$cmd + 4 + $2882 | 0] | 0;
             }
             HEAP32[$1 >> 2] = $i_0_i_i1452; //@line 55725
             if ((HEAP8[$cmd + 4 + $i_0_i_i1452 | 0] | 0) != 38) {
              $2930 = $i_0_i_i1452; //@line 55729
              break;
             }
             $2887 = $i_0_i_i1452 + 1 | 0; //@line 55732
             HEAP32[$1 >> 2] = $2887; //@line 55733
             if ((_cmd_match_expr_cmp($cmd, $val2_i745, $base) | 0) == 0) {
              label = 16071; //@line 55738
              break L20379;
             }
             while (1) {
              $2892 = HEAP32[$1 >> 2] | 0; //@line 55744
              while (1) {
               $2893 = $cmd + 4 + $2892 | 0; //@line 55747
               $2894 = HEAP8[$2893] | 0; //@line 55748
               if (!(($2894 << 24 >> 24 | 0) == 13 | ($2894 << 24 >> 24 | 0) == 32 | ($2894 << 24 >> 24 | 0) == 9 | ($2894 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $2892 = $2892 + 1 | 0; //@line 55754
              }
              HEAP32[$1 >> 2] = $2892; //@line 55756
              $2897 = HEAP8[$2893] | 0; //@line 55757
              if ($2897 << 24 >> 24 == 61) {
               if ((HEAP8[$2892 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1463 = 1;
                $storemerge4201_in = $2892;
               } else {
                $i_0_i_i3064 = $2892;
                $2904 = 61;
                label = 16062; //@line 55768
               }
              } else {
               $i_0_i_i3064 = $2892;
               $2904 = $2897;
               label = 16062; //@line 55772
              }
              if ((label | 0) == 16062) {
               while (1) {
                label = 0; //@line 55776
                if (!(($2904 << 24 >> 24 | 0) == 13 | ($2904 << 24 >> 24 | 0) == 32 | ($2904 << 24 >> 24 | 0) == 9 | ($2904 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $2905 = $i_0_i_i3064 + 1 | 0; //@line 55782
                $i_0_i_i3064 = $2905;
                $2904 = HEAP8[$cmd + 4 + $2905 | 0] | 0;
                label = 16062; //@line 55787
               }
               HEAP32[$1 >> 2] = $i_0_i_i3064; //@line 55790
               if ((HEAP8[$cmd + 4 + $i_0_i_i3064 | 0] | 0) != 33) {
                break;
               }
               if ((HEAP8[$i_0_i_i3064 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1463 = 2;
                $storemerge4201_in = $i_0_i_i3064;
               } else {
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4201_in + 2; //@line 55809
              if ((_cmd_match_expr_cmp($cmd, $val2_i1462, $base) | 0) == 0) {
               label = 16067; //@line 55814
               break L20379;
              }
              if (($op_0_i1463 | 0) == 1) {
               HEAP32[$val2_i745 >> 2] = (HEAP32[$val2_i745 >> 2] | 0) == (HEAP32[$val2_i1462 >> 2] | 0); //@line 55822
               continue;
              } else if (($op_0_i1463 | 0) == 2) {
               HEAP32[$val2_i745 >> 2] = (HEAP32[$val2_i745 >> 2] | 0) != (HEAP32[$val2_i1462 >> 2] | 0); //@line 55830
               continue;
              } else {
               continue;
              }
             }
             HEAP32[$val2_i407 >> 2] = HEAP32[$val2_i745 >> 2] & HEAP32[$val2_i407 >> 2]; //@line 55840
             $2867 = $i_0_i_i3064; //@line 55842
            }
            if ((label | 0) == 17249) {
             label = 0; //@line 55845
             HEAP32[$1 >> 2] = $2867; //@line 55846
             $2930 = $2867; //@line 55848
            }
            HEAP32[$val2_i144 >> 2] = HEAP32[$val2_i407 >> 2] ^ HEAP32[$val2_i144 >> 2]; //@line 55854
            $i_0_i_i_i408 = $2930; //@line 55856
           }
           HEAP32[$val2_i78 >> 2] = HEAP32[$val2_i144 >> 2] | HEAP32[$val2_i78 >> 2]; //@line 55861
           $2697 = $i_0_i_i_i408; //@line 55863
          }
          if ((label | 0) == 17247) {
           label = 0; //@line 55866
           HEAP32[$1 >> 2] = $2697; //@line 55867
           $2938 = $2697; //@line 55869
          }
          if ((HEAP32[$val2 >> 2] | 0) == 0) {
           $2945 = 0; //@line 55876
          } else {
           $2945 = (HEAP32[$val2_i78 >> 2] | 0) != 0 | 0; //@line 55881
          }
          HEAP32[$val2 >> 2] = $2945; //@line 55884
          $i_0_i_i_i79 = $2938; //@line 55886
         }
         if ((label | 0) == 15896) {
          $2946 = $i_0_i_i_i79; //@line 55921
          L20638 : while (1) {
           $2947 = $cmd + 4 + $2946 | 0; //@line 55924
           $2948 = HEAP8[$2947] | 0; //@line 55925
           if (($2948 << 24 >> 24 | 0) == 13 | ($2948 << 24 >> 24 | 0) == 32 | ($2948 << 24 >> 24 | 0) == 9 | ($2948 << 24 >> 24 | 0) == 10) {
            $2946 = $2946 + 1 | 0; //@line 55929
            continue;
           }
           HEAP32[$1 >> 2] = $2946; //@line 55932
           $2951 = HEAP8[$2947] | 0; //@line 55933
           if ($2951 << 24 >> 24 != 124) {
            $i_0_i_i = $2946;
            $3894 = $2951;
            label = 16456; //@line 55937
            break;
           }
           if ((HEAP8[$2946 + 1 + ($cmd + 4) | 0] | 0) != 124) {
            $i_0_i_i = $2946;
            $3894 = $2951;
            label = 16456; //@line 55946
            break;
           }
           $5861 = $2946 + 2 | 0; //@line 55949
           HEAP32[$1 >> 2] = $5861; //@line 55950
           if ((_cmd_match_expr_cmp($cmd, $val2_i27, $base) | 0) == 0) {
            break;
           }
           while (1) {
            $2959 = HEAP32[$1 >> 2] | 0; //@line 55960
            while (1) {
             $2960 = $cmd + 4 + $2959 | 0; //@line 55963
             $2961 = HEAP8[$2960] | 0; //@line 55964
             if (!(($2961 << 24 >> 24 | 0) == 13 | ($2961 << 24 >> 24 | 0) == 32 | ($2961 << 24 >> 24 | 0) == 9 | ($2961 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2959 = $2959 + 1 | 0; //@line 55970
            }
            HEAP32[$1 >> 2] = $2959; //@line 55972
            $2964 = HEAP8[$2960] | 0; //@line 55973
            if ($2964 << 24 >> 24 == 61) {
             if ((HEAP8[$2959 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1467 = 1;
              $storemerge4200_in = $2959;
             } else {
              $i_0_i_i3084 = $2959;
              $2971 = 61;
              label = 16090; //@line 55984
             }
            } else {
             $i_0_i_i3084 = $2959;
             $2971 = $2964;
             label = 16090; //@line 55988
            }
            if ((label | 0) == 16090) {
             while (1) {
              label = 0; //@line 55992
              if (!(($2971 << 24 >> 24 | 0) == 13 | ($2971 << 24 >> 24 | 0) == 32 | ($2971 << 24 >> 24 | 0) == 9 | ($2971 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $2972 = $i_0_i_i3084 + 1 | 0; //@line 55998
              $i_0_i_i3084 = $2972;
              $2971 = HEAP8[$cmd + 4 + $2972 | 0] | 0;
              label = 16090; //@line 56003
             }
             HEAP32[$1 >> 2] = $i_0_i_i3084; //@line 56006
             if ((HEAP8[$cmd + 4 + $i_0_i_i3084 | 0] | 0) != 33) {
              $2994 = $i_0_i_i3084; //@line 56010
              break;
             }
             if ((HEAP8[$i_0_i_i3084 + 1 + ($cmd + 4) | 0] | 0) == 61) {
              $op_0_i1467 = 2;
              $storemerge4200_in = $i_0_i_i3084;
             } else {
              $2994 = $i_0_i_i3084; //@line 56020
              break;
             }
            }
            HEAP32[$1 >> 2] = $storemerge4200_in + 2; //@line 56027
            if ((_cmd_match_expr_cmp($cmd, $val2_i1466, $base) | 0) == 0) {
             label = 16095; //@line 56032
             break L20638;
            }
            if (($op_0_i1467 | 0) == 1) {
             HEAP32[$val2_i27 >> 2] = (HEAP32[$val2_i27 >> 2] | 0) == (HEAP32[$val2_i1466 >> 2] | 0); //@line 56040
             continue;
            } else if (($op_0_i1467 | 0) == 2) {
             HEAP32[$val2_i27 >> 2] = (HEAP32[$val2_i27 >> 2] | 0) != (HEAP32[$val2_i1466 >> 2] | 0); //@line 56048
             continue;
            } else {
             continue;
            }
           }
           while (1) {
            $2996 = $2994; //@line 56058
            while (1) {
             $2997 = $cmd + 4 + $2996 | 0; //@line 56061
             $2998 = HEAP8[$2997] | 0; //@line 56062
             if (!(($2998 << 24 >> 24 | 0) == 13 | ($2998 << 24 >> 24 | 0) == 32 | ($2998 << 24 >> 24 | 0) == 9 | ($2998 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $2996 = $2996 + 1 | 0; //@line 56068
            }
            HEAP32[$1 >> 2] = $2996; //@line 56070
            $3001 = HEAP8[$2997] | 0; //@line 56071
            if ($3001 << 24 >> 24 == 38) {
             if ((HEAP8[$2996 + 1 + ($cmd + 4) | 0] | 0) == 38) {
              label = 17233; //@line 56079
              break;
             } else {
              $i_0_i_i1479 = $2996;
              $3008 = 38;
             }
            } else {
             $i_0_i_i1479 = $2996;
             $3008 = $3001;
            }
            while (1) {
             if (!(($3008 << 24 >> 24 | 0) == 13 | ($3008 << 24 >> 24 | 0) == 32 | ($3008 << 24 >> 24 | 0) == 9 | ($3008 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $3009 = $i_0_i_i1479 + 1 | 0; //@line 56093
             $i_0_i_i1479 = $3009;
             $3008 = HEAP8[$cmd + 4 + $3009 | 0] | 0;
            }
            HEAP32[$1 >> 2] = $i_0_i_i1479; //@line 56100
            if ((HEAP8[$cmd + 4 + $i_0_i_i1479 | 0] | 0) != 38) {
             $i_0_i_i_i420 = $i_0_i_i1479; //@line 56104
             break;
            }
            $3014 = $i_0_i_i1479 + 1 | 0; //@line 56107
            HEAP32[$1 >> 2] = $3014; //@line 56108
            if ((_cmd_match_expr_cmp($cmd, $val2_i748, $base) | 0) == 0) {
             label = 16122; //@line 56113
             break L20638;
            }
            while (1) {
             $3019 = HEAP32[$1 >> 2] | 0; //@line 56119
             while (1) {
              $3020 = $cmd + 4 + $3019 | 0; //@line 56122
              $3021 = HEAP8[$3020] | 0; //@line 56123
              if (!(($3021 << 24 >> 24 | 0) == 13 | ($3021 << 24 >> 24 | 0) == 32 | ($3021 << 24 >> 24 | 0) == 9 | ($3021 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3019 = $3019 + 1 | 0; //@line 56129
             }
             HEAP32[$1 >> 2] = $3019; //@line 56131
             $3024 = HEAP8[$3020] | 0; //@line 56132
             if ($3024 << 24 >> 24 == 61) {
              if ((HEAP8[$3019 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1490 = 1;
               $storemerge4199_in = $3019;
              } else {
               $i_0_i_i3104 = $3019;
               $3031 = 61;
               label = 16113; //@line 56143
              }
             } else {
              $i_0_i_i3104 = $3019;
              $3031 = $3024;
              label = 16113; //@line 56147
             }
             if ((label | 0) == 16113) {
              while (1) {
               label = 0; //@line 56151
               if (!(($3031 << 24 >> 24 | 0) == 13 | ($3031 << 24 >> 24 | 0) == 32 | ($3031 << 24 >> 24 | 0) == 9 | ($3031 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3032 = $i_0_i_i3104 + 1 | 0; //@line 56157
               $i_0_i_i3104 = $3032;
               $3031 = HEAP8[$cmd + 4 + $3032 | 0] | 0;
               label = 16113; //@line 56162
              }
              HEAP32[$1 >> 2] = $i_0_i_i3104; //@line 56165
              if ((HEAP8[$cmd + 4 + $i_0_i_i3104 | 0] | 0) != 33) {
               break;
              }
              if ((HEAP8[$i_0_i_i3104 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1490 = 2;
               $storemerge4199_in = $i_0_i_i3104;
              } else {
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4199_in + 2; //@line 56184
             if ((_cmd_match_expr_cmp($cmd, $val2_i1489, $base) | 0) == 0) {
              label = 16118; //@line 56189
              break L20638;
             }
             if (($op_0_i1490 | 0) == 1) {
              HEAP32[$val2_i748 >> 2] = (HEAP32[$val2_i748 >> 2] | 0) == (HEAP32[$val2_i1489 >> 2] | 0); //@line 56197
              continue;
             } else if (($op_0_i1490 | 0) == 2) {
              HEAP32[$val2_i748 >> 2] = (HEAP32[$val2_i748 >> 2] | 0) != (HEAP32[$val2_i1489 >> 2] | 0); //@line 56205
              continue;
             } else {
              continue;
             }
            }
            HEAP32[$val2_i27 >> 2] = HEAP32[$val2_i748 >> 2] & HEAP32[$val2_i27 >> 2]; //@line 56215
            $2994 = $i_0_i_i3104; //@line 56217
           }
           if ((label | 0) == 17233) {
            label = 0; //@line 56220
            HEAP32[$1 >> 2] = $2994; //@line 56221
            $i_0_i_i_i420 = $2994; //@line 56223
           }
           while (1) {
            $3057 = $cmd + 4 + $i_0_i_i_i420 | 0; //@line 56227
            $3058 = HEAP8[$3057] | 0; //@line 56228
            if (($3058 << 24 >> 24 | 0) == 13 | ($3058 << 24 >> 24 | 0) == 32 | ($3058 << 24 >> 24 | 0) == 9 | ($3058 << 24 >> 24 | 0) == 10) {
             $i_0_i_i_i420 = $i_0_i_i_i420 + 1 | 0; //@line 56232
             continue;
            }
            HEAP32[$1 >> 2] = $i_0_i_i_i420; //@line 56235
            if ((HEAP8[$3057] | 0) != 94) {
             $3171 = $i_0_i_i_i420; //@line 56239
             break;
            }
            $3064 = $i_0_i_i_i420 + 1 | 0; //@line 56242
            HEAP32[$1 >> 2] = $3064; //@line 56243
            if ((_cmd_match_expr_cmp($cmd, $val2_i419, $base) | 0) == 0) {
             label = 16167; //@line 56248
             break L20638;
            }
            while (1) {
             $3069 = HEAP32[$1 >> 2] | 0; //@line 56254
             while (1) {
              $3070 = $cmd + 4 + $3069 | 0; //@line 56257
              $3071 = HEAP8[$3070] | 0; //@line 56258
              if (!(($3071 << 24 >> 24 | 0) == 13 | ($3071 << 24 >> 24 | 0) == 32 | ($3071 << 24 >> 24 | 0) == 9 | ($3071 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3069 = $3069 + 1 | 0; //@line 56264
             }
             HEAP32[$1 >> 2] = $3069; //@line 56266
             $3074 = HEAP8[$3070] | 0; //@line 56267
             if ($3074 << 24 >> 24 == 61) {
              if ((HEAP8[$3069 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1494 = 1;
               $storemerge4198_in = $3069;
              } else {
               $i_0_i_i3124 = $3069;
               $3081 = 61;
               label = 16133; //@line 56278
              }
             } else {
              $i_0_i_i3124 = $3069;
              $3081 = $3074;
              label = 16133; //@line 56282
             }
             if ((label | 0) == 16133) {
              while (1) {
               label = 0; //@line 56286
               if (!(($3081 << 24 >> 24 | 0) == 13 | ($3081 << 24 >> 24 | 0) == 32 | ($3081 << 24 >> 24 | 0) == 9 | ($3081 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3082 = $i_0_i_i3124 + 1 | 0; //@line 56292
               $i_0_i_i3124 = $3082;
               $3081 = HEAP8[$cmd + 4 + $3082 | 0] | 0;
               label = 16133; //@line 56297
              }
              HEAP32[$1 >> 2] = $i_0_i_i3124; //@line 56300
              if ((HEAP8[$cmd + 4 + $i_0_i_i3124 | 0] | 0) != 33) {
               $3104 = $i_0_i_i3124; //@line 56304
               break;
              }
              if ((HEAP8[$i_0_i_i3124 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1494 = 2;
               $storemerge4198_in = $i_0_i_i3124;
              } else {
               $3104 = $i_0_i_i3124; //@line 56314
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4198_in + 2; //@line 56321
             if ((_cmd_match_expr_cmp($cmd, $val2_i1493, $base) | 0) == 0) {
              label = 16138; //@line 56326
              break L20638;
             }
             if (($op_0_i1494 | 0) == 1) {
              HEAP32[$val2_i419 >> 2] = (HEAP32[$val2_i419 >> 2] | 0) == (HEAP32[$val2_i1493 >> 2] | 0); //@line 56334
              continue;
             } else if (($op_0_i1494 | 0) == 2) {
              HEAP32[$val2_i419 >> 2] = (HEAP32[$val2_i419 >> 2] | 0) != (HEAP32[$val2_i1493 >> 2] | 0); //@line 56342
              continue;
             } else {
              continue;
             }
            }
            while (1) {
             $3106 = $3104; //@line 56352
             while (1) {
              $3107 = $cmd + 4 + $3106 | 0; //@line 56355
              $3108 = HEAP8[$3107] | 0; //@line 56356
              if (!(($3108 << 24 >> 24 | 0) == 13 | ($3108 << 24 >> 24 | 0) == 32 | ($3108 << 24 >> 24 | 0) == 9 | ($3108 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3106 = $3106 + 1 | 0; //@line 56362
             }
             HEAP32[$1 >> 2] = $3106; //@line 56364
             $3111 = HEAP8[$3107] | 0; //@line 56365
             if ($3111 << 24 >> 24 == 38) {
              if ((HEAP8[$3106 + 1 + ($cmd + 4) | 0] | 0) == 38) {
               label = 17234; //@line 56373
               break;
              } else {
               $i_0_i_i1506 = $3106;
               $3118 = 38;
              }
             } else {
              $i_0_i_i1506 = $3106;
              $3118 = $3111;
             }
             while (1) {
              if (!(($3118 << 24 >> 24 | 0) == 13 | ($3118 << 24 >> 24 | 0) == 32 | ($3118 << 24 >> 24 | 0) == 9 | ($3118 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3119 = $i_0_i_i1506 + 1 | 0; //@line 56387
              $i_0_i_i1506 = $3119;
              $3118 = HEAP8[$cmd + 4 + $3119 | 0] | 0;
             }
             HEAP32[$1 >> 2] = $i_0_i_i1506; //@line 56394
             if ((HEAP8[$cmd + 4 + $i_0_i_i1506 | 0] | 0) != 38) {
              $3167 = $i_0_i_i1506; //@line 56398
              break;
             }
             $3124 = $i_0_i_i1506 + 1 | 0; //@line 56401
             HEAP32[$1 >> 2] = $3124; //@line 56402
             if ((_cmd_match_expr_cmp($cmd, $val2_i751, $base) | 0) == 0) {
              label = 16165; //@line 56407
              break L20638;
             }
             while (1) {
              $3129 = HEAP32[$1 >> 2] | 0; //@line 56413
              while (1) {
               $3130 = $cmd + 4 + $3129 | 0; //@line 56416
               $3131 = HEAP8[$3130] | 0; //@line 56417
               if (!(($3131 << 24 >> 24 | 0) == 13 | ($3131 << 24 >> 24 | 0) == 32 | ($3131 << 24 >> 24 | 0) == 9 | ($3131 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3129 = $3129 + 1 | 0; //@line 56423
              }
              HEAP32[$1 >> 2] = $3129; //@line 56425
              $3134 = HEAP8[$3130] | 0; //@line 56426
              if ($3134 << 24 >> 24 == 61) {
               if ((HEAP8[$3129 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1517 = 1;
                $storemerge4197_in = $3129;
               } else {
                $i_0_i_i3144 = $3129;
                $3141 = 61;
                label = 16156; //@line 56437
               }
              } else {
               $i_0_i_i3144 = $3129;
               $3141 = $3134;
               label = 16156; //@line 56441
              }
              if ((label | 0) == 16156) {
               while (1) {
                label = 0; //@line 56445
                if (!(($3141 << 24 >> 24 | 0) == 13 | ($3141 << 24 >> 24 | 0) == 32 | ($3141 << 24 >> 24 | 0) == 9 | ($3141 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3142 = $i_0_i_i3144 + 1 | 0; //@line 56451
                $i_0_i_i3144 = $3142;
                $3141 = HEAP8[$cmd + 4 + $3142 | 0] | 0;
                label = 16156; //@line 56456
               }
               HEAP32[$1 >> 2] = $i_0_i_i3144; //@line 56459
               if ((HEAP8[$cmd + 4 + $i_0_i_i3144 | 0] | 0) != 33) {
                break;
               }
               if ((HEAP8[$i_0_i_i3144 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1517 = 2;
                $storemerge4197_in = $i_0_i_i3144;
               } else {
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4197_in + 2; //@line 56478
              if ((_cmd_match_expr_cmp($cmd, $val2_i1516, $base) | 0) == 0) {
               label = 16161; //@line 56483
               break L20638;
              }
              if (($op_0_i1517 | 0) == 1) {
               HEAP32[$val2_i751 >> 2] = (HEAP32[$val2_i751 >> 2] | 0) == (HEAP32[$val2_i1516 >> 2] | 0); //@line 56491
               continue;
              } else if (($op_0_i1517 | 0) == 2) {
               HEAP32[$val2_i751 >> 2] = (HEAP32[$val2_i751 >> 2] | 0) != (HEAP32[$val2_i1516 >> 2] | 0); //@line 56499
               continue;
              } else {
               continue;
              }
             }
             HEAP32[$val2_i419 >> 2] = HEAP32[$val2_i751 >> 2] & HEAP32[$val2_i419 >> 2]; //@line 56509
             $3104 = $i_0_i_i3144; //@line 56511
            }
            if ((label | 0) == 17234) {
             label = 0; //@line 56514
             HEAP32[$1 >> 2] = $3104; //@line 56515
             $3167 = $3104; //@line 56517
            }
            HEAP32[$val2_i27 >> 2] = HEAP32[$val2_i419 >> 2] ^ HEAP32[$val2_i27 >> 2]; //@line 56523
            $i_0_i_i_i420 = $3167; //@line 56525
           }
           while (1) {
            $3173 = $3171; //@line 56530
            while (1) {
             $3174 = $cmd + 4 + $3173 | 0; //@line 56533
             $3175 = HEAP8[$3174] | 0; //@line 56534
             if (!(($3175 << 24 >> 24 | 0) == 13 | ($3175 << 24 >> 24 | 0) == 32 | ($3175 << 24 >> 24 | 0) == 9 | ($3175 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $3173 = $3173 + 1 | 0; //@line 56540
            }
            HEAP32[$1 >> 2] = $3173; //@line 56542
            $3178 = HEAP8[$3174] | 0; //@line 56543
            if ($3178 << 24 >> 24 == 124) {
             if ((HEAP8[$3173 + 1 + ($cmd + 4) | 0] | 0) == 124) {
              label = 17235; //@line 56551
              break;
             } else {
              $i_0_i_i440 = $3173;
              $3185 = 124;
             }
            } else {
             $i_0_i_i440 = $3173;
             $3185 = $3178;
            }
            while (1) {
             if (!(($3185 << 24 >> 24 | 0) == 13 | ($3185 << 24 >> 24 | 0) == 32 | ($3185 << 24 >> 24 | 0) == 9 | ($3185 << 24 >> 24 | 0) == 10)) {
              break;
             }
             $3186 = $i_0_i_i440 + 1 | 0; //@line 56565
             $i_0_i_i440 = $3186;
             $3185 = HEAP8[$cmd + 4 + $3186 | 0] | 0;
            }
            HEAP32[$1 >> 2] = $i_0_i_i440; //@line 56572
            if ((HEAP8[$cmd + 4 + $i_0_i_i440 | 0] | 0) != 124) {
             $i_0_i_i_i92 = $i_0_i_i440; //@line 56576
             break;
            }
            $3191 = $i_0_i_i440 + 1 | 0; //@line 56579
            HEAP32[$1 >> 2] = $3191; //@line 56580
            if ((_cmd_match_expr_cmp($cmd, $val2_i147, $base) | 0) == 0) {
             label = 16262; //@line 56585
             break L20638;
            }
            while (1) {
             $3196 = HEAP32[$1 >> 2] | 0; //@line 56591
             while (1) {
              $3197 = $cmd + 4 + $3196 | 0; //@line 56594
              $3198 = HEAP8[$3197] | 0; //@line 56595
              if (!(($3198 << 24 >> 24 | 0) == 13 | ($3198 << 24 >> 24 | 0) == 32 | ($3198 << 24 >> 24 | 0) == 9 | ($3198 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3196 = $3196 + 1 | 0; //@line 56601
             }
             HEAP32[$1 >> 2] = $3196; //@line 56603
             $3201 = HEAP8[$3197] | 0; //@line 56604
             if ($3201 << 24 >> 24 == 61) {
              if ((HEAP8[$3196 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1521 = 1;
               $storemerge4196_in = $3196;
              } else {
               $i_0_i_i3164 = $3196;
               $3208 = 61;
               label = 16183; //@line 56615
              }
             } else {
              $i_0_i_i3164 = $3196;
              $3208 = $3201;
              label = 16183; //@line 56619
             }
             if ((label | 0) == 16183) {
              while (1) {
               label = 0; //@line 56623
               if (!(($3208 << 24 >> 24 | 0) == 13 | ($3208 << 24 >> 24 | 0) == 32 | ($3208 << 24 >> 24 | 0) == 9 | ($3208 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3209 = $i_0_i_i3164 + 1 | 0; //@line 56629
               $i_0_i_i3164 = $3209;
               $3208 = HEAP8[$cmd + 4 + $3209 | 0] | 0;
               label = 16183; //@line 56634
              }
              HEAP32[$1 >> 2] = $i_0_i_i3164; //@line 56637
              if ((HEAP8[$cmd + 4 + $i_0_i_i3164 | 0] | 0) != 33) {
               $3231 = $i_0_i_i3164; //@line 56641
               break;
              }
              if ((HEAP8[$i_0_i_i3164 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1521 = 2;
               $storemerge4196_in = $i_0_i_i3164;
              } else {
               $3231 = $i_0_i_i3164; //@line 56651
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4196_in + 2; //@line 56658
             if ((_cmd_match_expr_cmp($cmd, $val2_i1520, $base) | 0) == 0) {
              label = 16188; //@line 56663
              break L20638;
             }
             if (($op_0_i1521 | 0) == 1) {
              HEAP32[$val2_i147 >> 2] = (HEAP32[$val2_i147 >> 2] | 0) == (HEAP32[$val2_i1520 >> 2] | 0); //@line 56671
              continue;
             } else if (($op_0_i1521 | 0) == 2) {
              HEAP32[$val2_i147 >> 2] = (HEAP32[$val2_i147 >> 2] | 0) != (HEAP32[$val2_i1520 >> 2] | 0); //@line 56679
              continue;
             } else {
              continue;
             }
            }
            while (1) {
             $3233 = $3231; //@line 56689
             while (1) {
              $3234 = $cmd + 4 + $3233 | 0; //@line 56692
              $3235 = HEAP8[$3234] | 0; //@line 56693
              if (!(($3235 << 24 >> 24 | 0) == 13 | ($3235 << 24 >> 24 | 0) == 32 | ($3235 << 24 >> 24 | 0) == 9 | ($3235 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3233 = $3233 + 1 | 0; //@line 56699
             }
             HEAP32[$1 >> 2] = $3233; //@line 56701
             $3238 = HEAP8[$3234] | 0; //@line 56702
             if ($3238 << 24 >> 24 == 38) {
              if ((HEAP8[$3233 + 1 + ($cmd + 4) | 0] | 0) == 38) {
               label = 17236; //@line 56710
               break;
              } else {
               $i_0_i_i1533 = $3233;
               $3245 = 38;
              }
             } else {
              $i_0_i_i1533 = $3233;
              $3245 = $3238;
             }
             while (1) {
              if (!(($3245 << 24 >> 24 | 0) == 13 | ($3245 << 24 >> 24 | 0) == 32 | ($3245 << 24 >> 24 | 0) == 9 | ($3245 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3246 = $i_0_i_i1533 + 1 | 0; //@line 56724
              $i_0_i_i1533 = $3246;
              $3245 = HEAP8[$cmd + 4 + $3246 | 0] | 0;
             }
             HEAP32[$1 >> 2] = $i_0_i_i1533; //@line 56731
             if ((HEAP8[$cmd + 4 + $i_0_i_i1533 | 0] | 0) != 38) {
              $i_0_i_i_i451 = $i_0_i_i1533; //@line 56735
              break;
             }
             $3251 = $i_0_i_i1533 + 1 | 0; //@line 56738
             HEAP32[$1 >> 2] = $3251; //@line 56739
             if ((_cmd_match_expr_cmp($cmd, $val2_i754, $base) | 0) == 0) {
              label = 16215; //@line 56744
              break L20638;
             }
             while (1) {
              $3256 = HEAP32[$1 >> 2] | 0; //@line 56750
              while (1) {
               $3257 = $cmd + 4 + $3256 | 0; //@line 56753
               $3258 = HEAP8[$3257] | 0; //@line 56754
               if (!(($3258 << 24 >> 24 | 0) == 13 | ($3258 << 24 >> 24 | 0) == 32 | ($3258 << 24 >> 24 | 0) == 9 | ($3258 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3256 = $3256 + 1 | 0; //@line 56760
              }
              HEAP32[$1 >> 2] = $3256; //@line 56762
              $3261 = HEAP8[$3257] | 0; //@line 56763
              if ($3261 << 24 >> 24 == 61) {
               if ((HEAP8[$3256 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1544 = 1;
                $storemerge4195_in = $3256;
               } else {
                $i_0_i_i3184 = $3256;
                $3268 = 61;
                label = 16206; //@line 56774
               }
              } else {
               $i_0_i_i3184 = $3256;
               $3268 = $3261;
               label = 16206; //@line 56778
              }
              if ((label | 0) == 16206) {
               while (1) {
                label = 0; //@line 56782
                if (!(($3268 << 24 >> 24 | 0) == 13 | ($3268 << 24 >> 24 | 0) == 32 | ($3268 << 24 >> 24 | 0) == 9 | ($3268 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3269 = $i_0_i_i3184 + 1 | 0; //@line 56788
                $i_0_i_i3184 = $3269;
                $3268 = HEAP8[$cmd + 4 + $3269 | 0] | 0;
                label = 16206; //@line 56793
               }
               HEAP32[$1 >> 2] = $i_0_i_i3184; //@line 56796
               if ((HEAP8[$cmd + 4 + $i_0_i_i3184 | 0] | 0) != 33) {
                break;
               }
               if ((HEAP8[$i_0_i_i3184 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1544 = 2;
                $storemerge4195_in = $i_0_i_i3184;
               } else {
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4195_in + 2; //@line 56815
              if ((_cmd_match_expr_cmp($cmd, $val2_i1543, $base) | 0) == 0) {
               label = 16211; //@line 56820
               break L20638;
              }
              if (($op_0_i1544 | 0) == 1) {
               HEAP32[$val2_i754 >> 2] = (HEAP32[$val2_i754 >> 2] | 0) == (HEAP32[$val2_i1543 >> 2] | 0); //@line 56828
               continue;
              } else if (($op_0_i1544 | 0) == 2) {
               HEAP32[$val2_i754 >> 2] = (HEAP32[$val2_i754 >> 2] | 0) != (HEAP32[$val2_i1543 >> 2] | 0); //@line 56836
               continue;
              } else {
               continue;
              }
             }
             HEAP32[$val2_i147 >> 2] = HEAP32[$val2_i754 >> 2] & HEAP32[$val2_i147 >> 2]; //@line 56846
             $3231 = $i_0_i_i3184; //@line 56848
            }
            if ((label | 0) == 17236) {
             label = 0; //@line 56851
             HEAP32[$1 >> 2] = $3231; //@line 56852
             $i_0_i_i_i451 = $3231; //@line 56854
            }
            while (1) {
             $3294 = $cmd + 4 + $i_0_i_i_i451 | 0; //@line 56858
             $3295 = HEAP8[$3294] | 0; //@line 56859
             if (($3295 << 24 >> 24 | 0) == 13 | ($3295 << 24 >> 24 | 0) == 32 | ($3295 << 24 >> 24 | 0) == 9 | ($3295 << 24 >> 24 | 0) == 10) {
              $i_0_i_i_i451 = $i_0_i_i_i451 + 1 | 0; //@line 56863
              continue;
             }
             HEAP32[$1 >> 2] = $i_0_i_i_i451; //@line 56866
             if ((HEAP8[$3294] | 0) != 94) {
              break;
             }
             $3301 = $i_0_i_i_i451 + 1 | 0; //@line 56872
             HEAP32[$1 >> 2] = $3301; //@line 56873
             if ((_cmd_match_expr_cmp($cmd, $val2_i450, $base) | 0) == 0) {
              label = 16260; //@line 56878
              break L20638;
             }
             while (1) {
              $3306 = HEAP32[$1 >> 2] | 0; //@line 56884
              while (1) {
               $3307 = $cmd + 4 + $3306 | 0; //@line 56887
               $3308 = HEAP8[$3307] | 0; //@line 56888
               if (!(($3308 << 24 >> 24 | 0) == 13 | ($3308 << 24 >> 24 | 0) == 32 | ($3308 << 24 >> 24 | 0) == 9 | ($3308 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3306 = $3306 + 1 | 0; //@line 56894
              }
              HEAP32[$1 >> 2] = $3306; //@line 56896
              $3311 = HEAP8[$3307] | 0; //@line 56897
              if ($3311 << 24 >> 24 == 61) {
               if ((HEAP8[$3306 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1548 = 1;
                $storemerge4194_in = $3306;
               } else {
                $i_0_i_i3204 = $3306;
                $3318 = 61;
                label = 16226; //@line 56908
               }
              } else {
               $i_0_i_i3204 = $3306;
               $3318 = $3311;
               label = 16226; //@line 56912
              }
              if ((label | 0) == 16226) {
               while (1) {
                label = 0; //@line 56916
                if (!(($3318 << 24 >> 24 | 0) == 13 | ($3318 << 24 >> 24 | 0) == 32 | ($3318 << 24 >> 24 | 0) == 9 | ($3318 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3319 = $i_0_i_i3204 + 1 | 0; //@line 56922
                $i_0_i_i3204 = $3319;
                $3318 = HEAP8[$cmd + 4 + $3319 | 0] | 0;
                label = 16226; //@line 56927
               }
               HEAP32[$1 >> 2] = $i_0_i_i3204; //@line 56930
               if ((HEAP8[$cmd + 4 + $i_0_i_i3204 | 0] | 0) != 33) {
                $3341 = $i_0_i_i3204; //@line 56934
                break;
               }
               if ((HEAP8[$i_0_i_i3204 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1548 = 2;
                $storemerge4194_in = $i_0_i_i3204;
               } else {
                $3341 = $i_0_i_i3204; //@line 56944
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4194_in + 2; //@line 56951
              if ((_cmd_match_expr_cmp($cmd, $val2_i1547, $base) | 0) == 0) {
               label = 16231; //@line 56956
               break L20638;
              }
              if (($op_0_i1548 | 0) == 1) {
               HEAP32[$val2_i450 >> 2] = (HEAP32[$val2_i450 >> 2] | 0) == (HEAP32[$val2_i1547 >> 2] | 0); //@line 56964
               continue;
              } else if (($op_0_i1548 | 0) == 2) {
               HEAP32[$val2_i450 >> 2] = (HEAP32[$val2_i450 >> 2] | 0) != (HEAP32[$val2_i1547 >> 2] | 0); //@line 56972
               continue;
              } else {
               continue;
              }
             }
             while (1) {
              $3343 = $3341; //@line 56982
              while (1) {
               $3344 = $cmd + 4 + $3343 | 0; //@line 56985
               $3345 = HEAP8[$3344] | 0; //@line 56986
               if (!(($3345 << 24 >> 24 | 0) == 13 | ($3345 << 24 >> 24 | 0) == 32 | ($3345 << 24 >> 24 | 0) == 9 | ($3345 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3343 = $3343 + 1 | 0; //@line 56992
              }
              HEAP32[$1 >> 2] = $3343; //@line 56994
              $3348 = HEAP8[$3344] | 0; //@line 56995
              if ($3348 << 24 >> 24 == 38) {
               if ((HEAP8[$3343 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                label = 17237; //@line 57003
                break;
               } else {
                $i_0_i_i1560 = $3343;
                $3355 = 38;
               }
              } else {
               $i_0_i_i1560 = $3343;
               $3355 = $3348;
              }
              while (1) {
               if (!(($3355 << 24 >> 24 | 0) == 13 | ($3355 << 24 >> 24 | 0) == 32 | ($3355 << 24 >> 24 | 0) == 9 | ($3355 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3356 = $i_0_i_i1560 + 1 | 0; //@line 57017
               $i_0_i_i1560 = $3356;
               $3355 = HEAP8[$cmd + 4 + $3356 | 0] | 0;
              }
              HEAP32[$1 >> 2] = $i_0_i_i1560; //@line 57024
              if ((HEAP8[$cmd + 4 + $i_0_i_i1560 | 0] | 0) != 38) {
               $3404 = $i_0_i_i1560; //@line 57028
               break;
              }
              $3361 = $i_0_i_i1560 + 1 | 0; //@line 57031
              HEAP32[$1 >> 2] = $3361; //@line 57032
              if ((_cmd_match_expr_cmp($cmd, $val2_i757, $base) | 0) == 0) {
               label = 16258; //@line 57037
               break L20638;
              }
              while (1) {
               $3366 = HEAP32[$1 >> 2] | 0; //@line 57043
               while (1) {
                $3367 = $cmd + 4 + $3366 | 0; //@line 57046
                $3368 = HEAP8[$3367] | 0; //@line 57047
                if (!(($3368 << 24 >> 24 | 0) == 13 | ($3368 << 24 >> 24 | 0) == 32 | ($3368 << 24 >> 24 | 0) == 9 | ($3368 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3366 = $3366 + 1 | 0; //@line 57053
               }
               HEAP32[$1 >> 2] = $3366; //@line 57055
               $3371 = HEAP8[$3367] | 0; //@line 57056
               if ($3371 << 24 >> 24 == 61) {
                if ((HEAP8[$3366 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1571 = 1;
                 $storemerge4193_in = $3366;
                } else {
                 $i_0_i_i3224 = $3366;
                 $3378 = 61;
                 label = 16249; //@line 57067
                }
               } else {
                $i_0_i_i3224 = $3366;
                $3378 = $3371;
                label = 16249; //@line 57071
               }
               if ((label | 0) == 16249) {
                while (1) {
                 label = 0; //@line 57075
                 if (!(($3378 << 24 >> 24 | 0) == 13 | ($3378 << 24 >> 24 | 0) == 32 | ($3378 << 24 >> 24 | 0) == 9 | ($3378 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $3379 = $i_0_i_i3224 + 1 | 0; //@line 57081
                 $i_0_i_i3224 = $3379;
                 $3378 = HEAP8[$cmd + 4 + $3379 | 0] | 0;
                 label = 16249; //@line 57086
                }
                HEAP32[$1 >> 2] = $i_0_i_i3224; //@line 57089
                if ((HEAP8[$cmd + 4 + $i_0_i_i3224 | 0] | 0) != 33) {
                 break;
                }
                if ((HEAP8[$i_0_i_i3224 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1571 = 2;
                 $storemerge4193_in = $i_0_i_i3224;
                } else {
                 break;
                }
               }
               HEAP32[$1 >> 2] = $storemerge4193_in + 2; //@line 57108
               if ((_cmd_match_expr_cmp($cmd, $val2_i1570, $base) | 0) == 0) {
                label = 16254; //@line 57113
                break L20638;
               }
               if (($op_0_i1571 | 0) == 1) {
                HEAP32[$val2_i757 >> 2] = (HEAP32[$val2_i757 >> 2] | 0) == (HEAP32[$val2_i1570 >> 2] | 0); //@line 57121
                continue;
               } else if (($op_0_i1571 | 0) == 2) {
                HEAP32[$val2_i757 >> 2] = (HEAP32[$val2_i757 >> 2] | 0) != (HEAP32[$val2_i1570 >> 2] | 0); //@line 57129
                continue;
               } else {
                continue;
               }
              }
              HEAP32[$val2_i450 >> 2] = HEAP32[$val2_i757 >> 2] & HEAP32[$val2_i450 >> 2]; //@line 57139
              $3341 = $i_0_i_i3224; //@line 57141
             }
             if ((label | 0) == 17237) {
              label = 0; //@line 57144
              HEAP32[$1 >> 2] = $3341; //@line 57145
              $3404 = $3341; //@line 57147
             }
             HEAP32[$val2_i147 >> 2] = HEAP32[$val2_i450 >> 2] ^ HEAP32[$val2_i147 >> 2]; //@line 57153
             $i_0_i_i_i451 = $3404; //@line 57155
            }
            HEAP32[$val2_i27 >> 2] = HEAP32[$val2_i147 >> 2] | HEAP32[$val2_i27 >> 2]; //@line 57160
            $3171 = $i_0_i_i_i451; //@line 57162
           }
           if ((label | 0) == 17235) {
            label = 0; //@line 57165
            HEAP32[$1 >> 2] = $3171; //@line 57166
            $i_0_i_i_i92 = $3171; //@line 57168
           }
           while (1) {
            $3412 = $cmd + 4 + $i_0_i_i_i92 | 0; //@line 57172
            $3413 = HEAP8[$3412] | 0; //@line 57173
            if (($3413 << 24 >> 24 | 0) == 13 | ($3413 << 24 >> 24 | 0) == 32 | ($3413 << 24 >> 24 | 0) == 9 | ($3413 << 24 >> 24 | 0) == 10) {
             $i_0_i_i_i92 = $i_0_i_i_i92 + 1 | 0; //@line 57177
             continue;
            }
            HEAP32[$1 >> 2] = $i_0_i_i_i92; //@line 57180
            if ((HEAP8[$3412] | 0) != 38) {
             break;
            }
            if ((HEAP8[$i_0_i_i_i92 + 1 + ($cmd + 4) | 0] | 0) != 38) {
             break;
            }
            $5865 = $i_0_i_i_i92 + 2 | 0; //@line 57193
            HEAP32[$1 >> 2] = $5865; //@line 57194
            if ((_cmd_match_expr_cmp($cmd, $val2_i91, $base) | 0) == 0) {
             label = 16447; //@line 57199
             break L20638;
            }
            while (1) {
             $3424 = HEAP32[$1 >> 2] | 0; //@line 57205
             while (1) {
              $3425 = $cmd + 4 + $3424 | 0; //@line 57208
              $3426 = HEAP8[$3425] | 0; //@line 57209
              if (!(($3426 << 24 >> 24 | 0) == 13 | ($3426 << 24 >> 24 | 0) == 32 | ($3426 << 24 >> 24 | 0) == 9 | ($3426 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3424 = $3424 + 1 | 0; //@line 57215
             }
             HEAP32[$1 >> 2] = $3424; //@line 57217
             $3429 = HEAP8[$3425] | 0; //@line 57218
             if ($3429 << 24 >> 24 == 61) {
              if ((HEAP8[$3424 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1575 = 1;
               $storemerge4192_in = $3424;
              } else {
               $i_0_i_i3244 = $3424;
               $3436 = 61;
               label = 16273; //@line 57229
              }
             } else {
              $i_0_i_i3244 = $3424;
              $3436 = $3429;
              label = 16273; //@line 57233
             }
             if ((label | 0) == 16273) {
              while (1) {
               label = 0; //@line 57237
               if (!(($3436 << 24 >> 24 | 0) == 13 | ($3436 << 24 >> 24 | 0) == 32 | ($3436 << 24 >> 24 | 0) == 9 | ($3436 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3437 = $i_0_i_i3244 + 1 | 0; //@line 57243
               $i_0_i_i3244 = $3437;
               $3436 = HEAP8[$cmd + 4 + $3437 | 0] | 0;
               label = 16273; //@line 57248
              }
              HEAP32[$1 >> 2] = $i_0_i_i3244; //@line 57251
              if ((HEAP8[$cmd + 4 + $i_0_i_i3244 | 0] | 0) != 33) {
               $3459 = $i_0_i_i3244; //@line 57255
               break;
              }
              if ((HEAP8[$i_0_i_i3244 + 1 + ($cmd + 4) | 0] | 0) == 61) {
               $op_0_i1575 = 2;
               $storemerge4192_in = $i_0_i_i3244;
              } else {
               $3459 = $i_0_i_i3244; //@line 57265
               break;
              }
             }
             HEAP32[$1 >> 2] = $storemerge4192_in + 2; //@line 57272
             if ((_cmd_match_expr_cmp($cmd, $val2_i1574, $base) | 0) == 0) {
              label = 16278; //@line 57277
              break L20638;
             }
             if (($op_0_i1575 | 0) == 1) {
              HEAP32[$val2_i91 >> 2] = (HEAP32[$val2_i91 >> 2] | 0) == (HEAP32[$val2_i1574 >> 2] | 0); //@line 57285
              continue;
             } else if (($op_0_i1575 | 0) == 2) {
              HEAP32[$val2_i91 >> 2] = (HEAP32[$val2_i91 >> 2] | 0) != (HEAP32[$val2_i1574 >> 2] | 0); //@line 57293
              continue;
             } else {
              continue;
             }
            }
            while (1) {
             $3461 = $3459; //@line 57303
             while (1) {
              $3462 = $cmd + 4 + $3461 | 0; //@line 57306
              $3463 = HEAP8[$3462] | 0; //@line 57307
              if (!(($3463 << 24 >> 24 | 0) == 13 | ($3463 << 24 >> 24 | 0) == 32 | ($3463 << 24 >> 24 | 0) == 9 | ($3463 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3461 = $3461 + 1 | 0; //@line 57313
             }
             HEAP32[$1 >> 2] = $3461; //@line 57315
             $3466 = HEAP8[$3462] | 0; //@line 57316
             if ($3466 << 24 >> 24 == 38) {
              if ((HEAP8[$3461 + 1 + ($cmd + 4) | 0] | 0) == 38) {
               label = 17239; //@line 57324
               break;
              } else {
               $i_0_i_i1587 = $3461;
               $3473 = 38;
              }
             } else {
              $i_0_i_i1587 = $3461;
              $3473 = $3466;
             }
             while (1) {
              if (!(($3473 << 24 >> 24 | 0) == 13 | ($3473 << 24 >> 24 | 0) == 32 | ($3473 << 24 >> 24 | 0) == 9 | ($3473 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3474 = $i_0_i_i1587 + 1 | 0; //@line 57338
              $i_0_i_i1587 = $3474;
              $3473 = HEAP8[$cmd + 4 + $3474 | 0] | 0;
             }
             HEAP32[$1 >> 2] = $i_0_i_i1587; //@line 57345
             if ((HEAP8[$cmd + 4 + $i_0_i_i1587 | 0] | 0) != 38) {
              $i_0_i_i_i463 = $i_0_i_i1587; //@line 57349
              break;
             }
             $3479 = $i_0_i_i1587 + 1 | 0; //@line 57352
             HEAP32[$1 >> 2] = $3479; //@line 57353
             if ((_cmd_match_expr_cmp($cmd, $val2_i760, $base) | 0) == 0) {
              label = 16305; //@line 57358
              break L20638;
             }
             while (1) {
              $3484 = HEAP32[$1 >> 2] | 0; //@line 57364
              while (1) {
               $3485 = $cmd + 4 + $3484 | 0; //@line 57367
               $3486 = HEAP8[$3485] | 0; //@line 57368
               if (!(($3486 << 24 >> 24 | 0) == 13 | ($3486 << 24 >> 24 | 0) == 32 | ($3486 << 24 >> 24 | 0) == 9 | ($3486 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3484 = $3484 + 1 | 0; //@line 57374
              }
              HEAP32[$1 >> 2] = $3484; //@line 57376
              $3489 = HEAP8[$3485] | 0; //@line 57377
              if ($3489 << 24 >> 24 == 61) {
               if ((HEAP8[$3484 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1598 = 1;
                $storemerge4191_in = $3484;
               } else {
                $i_0_i_i3264 = $3484;
                $3496 = 61;
                label = 16296; //@line 57388
               }
              } else {
               $i_0_i_i3264 = $3484;
               $3496 = $3489;
               label = 16296; //@line 57392
              }
              if ((label | 0) == 16296) {
               while (1) {
                label = 0; //@line 57396
                if (!(($3496 << 24 >> 24 | 0) == 13 | ($3496 << 24 >> 24 | 0) == 32 | ($3496 << 24 >> 24 | 0) == 9 | ($3496 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3497 = $i_0_i_i3264 + 1 | 0; //@line 57402
                $i_0_i_i3264 = $3497;
                $3496 = HEAP8[$cmd + 4 + $3497 | 0] | 0;
                label = 16296; //@line 57407
               }
               HEAP32[$1 >> 2] = $i_0_i_i3264; //@line 57410
               if ((HEAP8[$cmd + 4 + $i_0_i_i3264 | 0] | 0) != 33) {
                break;
               }
               if ((HEAP8[$i_0_i_i3264 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1598 = 2;
                $storemerge4191_in = $i_0_i_i3264;
               } else {
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4191_in + 2; //@line 57429
              if ((_cmd_match_expr_cmp($cmd, $val2_i1597, $base) | 0) == 0) {
               label = 16301; //@line 57434
               break L20638;
              }
              if (($op_0_i1598 | 0) == 1) {
               HEAP32[$val2_i760 >> 2] = (HEAP32[$val2_i760 >> 2] | 0) == (HEAP32[$val2_i1597 >> 2] | 0); //@line 57442
               continue;
              } else if (($op_0_i1598 | 0) == 2) {
               HEAP32[$val2_i760 >> 2] = (HEAP32[$val2_i760 >> 2] | 0) != (HEAP32[$val2_i1597 >> 2] | 0); //@line 57450
               continue;
              } else {
               continue;
              }
             }
             HEAP32[$val2_i91 >> 2] = HEAP32[$val2_i760 >> 2] & HEAP32[$val2_i91 >> 2]; //@line 57460
             $3459 = $i_0_i_i3264; //@line 57462
            }
            if ((label | 0) == 17239) {
             label = 0; //@line 57465
             HEAP32[$1 >> 2] = $3459; //@line 57466
             $i_0_i_i_i463 = $3459; //@line 57468
            }
            while (1) {
             $3522 = $cmd + 4 + $i_0_i_i_i463 | 0; //@line 57472
             $3523 = HEAP8[$3522] | 0; //@line 57473
             if (($3523 << 24 >> 24 | 0) == 13 | ($3523 << 24 >> 24 | 0) == 32 | ($3523 << 24 >> 24 | 0) == 9 | ($3523 << 24 >> 24 | 0) == 10) {
              $i_0_i_i_i463 = $i_0_i_i_i463 + 1 | 0; //@line 57477
              continue;
             }
             HEAP32[$1 >> 2] = $i_0_i_i_i463; //@line 57480
             if ((HEAP8[$3522] | 0) != 94) {
              $3636 = $i_0_i_i_i463; //@line 57484
              break;
             }
             $3529 = $i_0_i_i_i463 + 1 | 0; //@line 57487
             HEAP32[$1 >> 2] = $3529; //@line 57488
             if ((_cmd_match_expr_cmp($cmd, $val2_i462, $base) | 0) == 0) {
              label = 16350; //@line 57493
              break L20638;
             }
             while (1) {
              $3534 = HEAP32[$1 >> 2] | 0; //@line 57499
              while (1) {
               $3535 = $cmd + 4 + $3534 | 0; //@line 57502
               $3536 = HEAP8[$3535] | 0; //@line 57503
               if (!(($3536 << 24 >> 24 | 0) == 13 | ($3536 << 24 >> 24 | 0) == 32 | ($3536 << 24 >> 24 | 0) == 9 | ($3536 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3534 = $3534 + 1 | 0; //@line 57509
              }
              HEAP32[$1 >> 2] = $3534; //@line 57511
              $3539 = HEAP8[$3535] | 0; //@line 57512
              if ($3539 << 24 >> 24 == 61) {
               if ((HEAP8[$3534 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1602 = 1;
                $storemerge4190_in = $3534;
               } else {
                $i_0_i_i3284 = $3534;
                $3546 = 61;
                label = 16316; //@line 57523
               }
              } else {
               $i_0_i_i3284 = $3534;
               $3546 = $3539;
               label = 16316; //@line 57527
              }
              if ((label | 0) == 16316) {
               while (1) {
                label = 0; //@line 57531
                if (!(($3546 << 24 >> 24 | 0) == 13 | ($3546 << 24 >> 24 | 0) == 32 | ($3546 << 24 >> 24 | 0) == 9 | ($3546 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3547 = $i_0_i_i3284 + 1 | 0; //@line 57537
                $i_0_i_i3284 = $3547;
                $3546 = HEAP8[$cmd + 4 + $3547 | 0] | 0;
                label = 16316; //@line 57542
               }
               HEAP32[$1 >> 2] = $i_0_i_i3284; //@line 57545
               if ((HEAP8[$cmd + 4 + $i_0_i_i3284 | 0] | 0) != 33) {
                $3569 = $i_0_i_i3284; //@line 57549
                break;
               }
               if ((HEAP8[$i_0_i_i3284 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1602 = 2;
                $storemerge4190_in = $i_0_i_i3284;
               } else {
                $3569 = $i_0_i_i3284; //@line 57559
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4190_in + 2; //@line 57566
              if ((_cmd_match_expr_cmp($cmd, $val2_i1601, $base) | 0) == 0) {
               label = 16321; //@line 57571
               break L20638;
              }
              if (($op_0_i1602 | 0) == 1) {
               HEAP32[$val2_i462 >> 2] = (HEAP32[$val2_i462 >> 2] | 0) == (HEAP32[$val2_i1601 >> 2] | 0); //@line 57579
               continue;
              } else if (($op_0_i1602 | 0) == 2) {
               HEAP32[$val2_i462 >> 2] = (HEAP32[$val2_i462 >> 2] | 0) != (HEAP32[$val2_i1601 >> 2] | 0); //@line 57587
               continue;
              } else {
               continue;
              }
             }
             while (1) {
              $3571 = $3569; //@line 57597
              while (1) {
               $3572 = $cmd + 4 + $3571 | 0; //@line 57600
               $3573 = HEAP8[$3572] | 0; //@line 57601
               if (!(($3573 << 24 >> 24 | 0) == 13 | ($3573 << 24 >> 24 | 0) == 32 | ($3573 << 24 >> 24 | 0) == 9 | ($3573 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3571 = $3571 + 1 | 0; //@line 57607
              }
              HEAP32[$1 >> 2] = $3571; //@line 57609
              $3576 = HEAP8[$3572] | 0; //@line 57610
              if ($3576 << 24 >> 24 == 38) {
               if ((HEAP8[$3571 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                label = 17240; //@line 57618
                break;
               } else {
                $i_0_i_i1614 = $3571;
                $3583 = 38;
               }
              } else {
               $i_0_i_i1614 = $3571;
               $3583 = $3576;
              }
              while (1) {
               if (!(($3583 << 24 >> 24 | 0) == 13 | ($3583 << 24 >> 24 | 0) == 32 | ($3583 << 24 >> 24 | 0) == 9 | ($3583 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3584 = $i_0_i_i1614 + 1 | 0; //@line 57632
               $i_0_i_i1614 = $3584;
               $3583 = HEAP8[$cmd + 4 + $3584 | 0] | 0;
              }
              HEAP32[$1 >> 2] = $i_0_i_i1614; //@line 57639
              if ((HEAP8[$cmd + 4 + $i_0_i_i1614 | 0] | 0) != 38) {
               $3632 = $i_0_i_i1614; //@line 57643
               break;
              }
              $3589 = $i_0_i_i1614 + 1 | 0; //@line 57646
              HEAP32[$1 >> 2] = $3589; //@line 57647
              if ((_cmd_match_expr_cmp($cmd, $val2_i763, $base) | 0) == 0) {
               label = 16348; //@line 57652
               break L20638;
              }
              while (1) {
               $3594 = HEAP32[$1 >> 2] | 0; //@line 57658
               while (1) {
                $3595 = $cmd + 4 + $3594 | 0; //@line 57661
                $3596 = HEAP8[$3595] | 0; //@line 57662
                if (!(($3596 << 24 >> 24 | 0) == 13 | ($3596 << 24 >> 24 | 0) == 32 | ($3596 << 24 >> 24 | 0) == 9 | ($3596 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3594 = $3594 + 1 | 0; //@line 57668
               }
               HEAP32[$1 >> 2] = $3594; //@line 57670
               $3599 = HEAP8[$3595] | 0; //@line 57671
               if ($3599 << 24 >> 24 == 61) {
                if ((HEAP8[$3594 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1625 = 1;
                 $storemerge4189_in = $3594;
                } else {
                 $i_0_i_i3304 = $3594;
                 $3606 = 61;
                 label = 16339; //@line 57682
                }
               } else {
                $i_0_i_i3304 = $3594;
                $3606 = $3599;
                label = 16339; //@line 57686
               }
               if ((label | 0) == 16339) {
                while (1) {
                 label = 0; //@line 57690
                 if (!(($3606 << 24 >> 24 | 0) == 13 | ($3606 << 24 >> 24 | 0) == 32 | ($3606 << 24 >> 24 | 0) == 9 | ($3606 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $3607 = $i_0_i_i3304 + 1 | 0; //@line 57696
                 $i_0_i_i3304 = $3607;
                 $3606 = HEAP8[$cmd + 4 + $3607 | 0] | 0;
                 label = 16339; //@line 57701
                }
                HEAP32[$1 >> 2] = $i_0_i_i3304; //@line 57704
                if ((HEAP8[$cmd + 4 + $i_0_i_i3304 | 0] | 0) != 33) {
                 break;
                }
                if ((HEAP8[$i_0_i_i3304 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1625 = 2;
                 $storemerge4189_in = $i_0_i_i3304;
                } else {
                 break;
                }
               }
               HEAP32[$1 >> 2] = $storemerge4189_in + 2; //@line 57723
               if ((_cmd_match_expr_cmp($cmd, $val2_i1624, $base) | 0) == 0) {
                label = 16344; //@line 57728
                break L20638;
               }
               if (($op_0_i1625 | 0) == 1) {
                HEAP32[$val2_i763 >> 2] = (HEAP32[$val2_i763 >> 2] | 0) == (HEAP32[$val2_i1624 >> 2] | 0); //@line 57736
                continue;
               } else if (($op_0_i1625 | 0) == 2) {
                HEAP32[$val2_i763 >> 2] = (HEAP32[$val2_i763 >> 2] | 0) != (HEAP32[$val2_i1624 >> 2] | 0); //@line 57744
                continue;
               } else {
                continue;
               }
              }
              HEAP32[$val2_i462 >> 2] = HEAP32[$val2_i763 >> 2] & HEAP32[$val2_i462 >> 2]; //@line 57754
              $3569 = $i_0_i_i3304; //@line 57756
             }
             if ((label | 0) == 17240) {
              label = 0; //@line 57759
              HEAP32[$1 >> 2] = $3569; //@line 57760
              $3632 = $3569; //@line 57762
             }
             HEAP32[$val2_i91 >> 2] = HEAP32[$val2_i462 >> 2] ^ HEAP32[$val2_i91 >> 2]; //@line 57768
             $i_0_i_i_i463 = $3632; //@line 57770
            }
            while (1) {
             $3638 = $3636; //@line 57775
             while (1) {
              $3639 = $cmd + 4 + $3638 | 0; //@line 57778
              $3640 = HEAP8[$3639] | 0; //@line 57779
              if (!(($3640 << 24 >> 24 | 0) == 13 | ($3640 << 24 >> 24 | 0) == 32 | ($3640 << 24 >> 24 | 0) == 9 | ($3640 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3638 = $3638 + 1 | 0; //@line 57785
             }
             HEAP32[$1 >> 2] = $3638; //@line 57787
             $3643 = HEAP8[$3639] | 0; //@line 57788
             if ($3643 << 24 >> 24 == 124) {
              if ((HEAP8[$3638 + 1 + ($cmd + 4) | 0] | 0) == 124) {
               label = 17241; //@line 57796
               break;
              } else {
               $i_0_i_i483 = $3638;
               $3650 = 124;
              }
             } else {
              $i_0_i_i483 = $3638;
              $3650 = $3643;
             }
             while (1) {
              if (!(($3650 << 24 >> 24 | 0) == 13 | ($3650 << 24 >> 24 | 0) == 32 | ($3650 << 24 >> 24 | 0) == 9 | ($3650 << 24 >> 24 | 0) == 10)) {
               break;
              }
              $3651 = $i_0_i_i483 + 1 | 0; //@line 57810
              $i_0_i_i483 = $3651;
              $3650 = HEAP8[$cmd + 4 + $3651 | 0] | 0;
             }
             HEAP32[$1 >> 2] = $i_0_i_i483; //@line 57817
             if ((HEAP8[$cmd + 4 + $i_0_i_i483 | 0] | 0) != 124) {
              $3877 = $i_0_i_i483; //@line 57821
              break;
             }
             $3656 = $i_0_i_i483 + 1 | 0; //@line 57824
             HEAP32[$1 >> 2] = $3656; //@line 57825
             if ((_cmd_match_expr_cmp($cmd, $val2_i150, $base) | 0) == 0) {
              label = 16445; //@line 57830
              break L20638;
             }
             while (1) {
              $3661 = HEAP32[$1 >> 2] | 0; //@line 57836
              while (1) {
               $3662 = $cmd + 4 + $3661 | 0; //@line 57839
               $3663 = HEAP8[$3662] | 0; //@line 57840
               if (!(($3663 << 24 >> 24 | 0) == 13 | ($3663 << 24 >> 24 | 0) == 32 | ($3663 << 24 >> 24 | 0) == 9 | ($3663 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3661 = $3661 + 1 | 0; //@line 57846
              }
              HEAP32[$1 >> 2] = $3661; //@line 57848
              $3666 = HEAP8[$3662] | 0; //@line 57849
              if ($3666 << 24 >> 24 == 61) {
               if ((HEAP8[$3661 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1629 = 1;
                $storemerge4188_in = $3661;
               } else {
                $i_0_i_i3324 = $3661;
                $3673 = 61;
                label = 16366; //@line 57860
               }
              } else {
               $i_0_i_i3324 = $3661;
               $3673 = $3666;
               label = 16366; //@line 57864
              }
              if ((label | 0) == 16366) {
               while (1) {
                label = 0; //@line 57868
                if (!(($3673 << 24 >> 24 | 0) == 13 | ($3673 << 24 >> 24 | 0) == 32 | ($3673 << 24 >> 24 | 0) == 9 | ($3673 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3674 = $i_0_i_i3324 + 1 | 0; //@line 57874
                $i_0_i_i3324 = $3674;
                $3673 = HEAP8[$cmd + 4 + $3674 | 0] | 0;
                label = 16366; //@line 57879
               }
               HEAP32[$1 >> 2] = $i_0_i_i3324; //@line 57882
               if ((HEAP8[$cmd + 4 + $i_0_i_i3324 | 0] | 0) != 33) {
                $3696 = $i_0_i_i3324; //@line 57886
                break;
               }
               if ((HEAP8[$i_0_i_i3324 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1629 = 2;
                $storemerge4188_in = $i_0_i_i3324;
               } else {
                $3696 = $i_0_i_i3324; //@line 57896
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4188_in + 2; //@line 57903
              if ((_cmd_match_expr_cmp($cmd, $val2_i1628, $base) | 0) == 0) {
               label = 16371; //@line 57908
               break L20638;
              }
              if (($op_0_i1629 | 0) == 1) {
               HEAP32[$val2_i150 >> 2] = (HEAP32[$val2_i150 >> 2] | 0) == (HEAP32[$val2_i1628 >> 2] | 0); //@line 57916
               continue;
              } else if (($op_0_i1629 | 0) == 2) {
               HEAP32[$val2_i150 >> 2] = (HEAP32[$val2_i150 >> 2] | 0) != (HEAP32[$val2_i1628 >> 2] | 0); //@line 57924
               continue;
              } else {
               continue;
              }
             }
             while (1) {
              $3698 = $3696; //@line 57934
              while (1) {
               $3699 = $cmd + 4 + $3698 | 0; //@line 57937
               $3700 = HEAP8[$3699] | 0; //@line 57938
               if (!(($3700 << 24 >> 24 | 0) == 13 | ($3700 << 24 >> 24 | 0) == 32 | ($3700 << 24 >> 24 | 0) == 9 | ($3700 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3698 = $3698 + 1 | 0; //@line 57944
              }
              HEAP32[$1 >> 2] = $3698; //@line 57946
              $3703 = HEAP8[$3699] | 0; //@line 57947
              if ($3703 << 24 >> 24 == 38) {
               if ((HEAP8[$3698 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                label = 17242; //@line 57955
                break;
               } else {
                $i_0_i_i1641 = $3698;
                $3710 = 38;
               }
              } else {
               $i_0_i_i1641 = $3698;
               $3710 = $3703;
              }
              while (1) {
               if (!(($3710 << 24 >> 24 | 0) == 13 | ($3710 << 24 >> 24 | 0) == 32 | ($3710 << 24 >> 24 | 0) == 9 | ($3710 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3711 = $i_0_i_i1641 + 1 | 0; //@line 57969
               $i_0_i_i1641 = $3711;
               $3710 = HEAP8[$cmd + 4 + $3711 | 0] | 0;
              }
              HEAP32[$1 >> 2] = $i_0_i_i1641; //@line 57976
              if ((HEAP8[$cmd + 4 + $i_0_i_i1641 | 0] | 0) != 38) {
               $i_0_i_i_i494 = $i_0_i_i1641; //@line 57980
               break;
              }
              $3716 = $i_0_i_i1641 + 1 | 0; //@line 57983
              HEAP32[$1 >> 2] = $3716; //@line 57984
              if ((_cmd_match_expr_cmp($cmd, $val2_i766, $base) | 0) == 0) {
               label = 16398; //@line 57989
               break L20638;
              }
              while (1) {
               $3721 = HEAP32[$1 >> 2] | 0; //@line 57995
               while (1) {
                $3722 = $cmd + 4 + $3721 | 0; //@line 57998
                $3723 = HEAP8[$3722] | 0; //@line 57999
                if (!(($3723 << 24 >> 24 | 0) == 13 | ($3723 << 24 >> 24 | 0) == 32 | ($3723 << 24 >> 24 | 0) == 9 | ($3723 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3721 = $3721 + 1 | 0; //@line 58005
               }
               HEAP32[$1 >> 2] = $3721; //@line 58007
               $3726 = HEAP8[$3722] | 0; //@line 58008
               if ($3726 << 24 >> 24 == 61) {
                if ((HEAP8[$3721 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1652 = 1;
                 $storemerge4187_in = $3721;
                } else {
                 $i_0_i_i3344 = $3721;
                 $3733 = 61;
                 label = 16389; //@line 58019
                }
               } else {
                $i_0_i_i3344 = $3721;
                $3733 = $3726;
                label = 16389; //@line 58023
               }
               if ((label | 0) == 16389) {
                while (1) {
                 label = 0; //@line 58027
                 if (!(($3733 << 24 >> 24 | 0) == 13 | ($3733 << 24 >> 24 | 0) == 32 | ($3733 << 24 >> 24 | 0) == 9 | ($3733 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $3734 = $i_0_i_i3344 + 1 | 0; //@line 58033
                 $i_0_i_i3344 = $3734;
                 $3733 = HEAP8[$cmd + 4 + $3734 | 0] | 0;
                 label = 16389; //@line 58038
                }
                HEAP32[$1 >> 2] = $i_0_i_i3344; //@line 58041
                if ((HEAP8[$cmd + 4 + $i_0_i_i3344 | 0] | 0) != 33) {
                 break;
                }
                if ((HEAP8[$i_0_i_i3344 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1652 = 2;
                 $storemerge4187_in = $i_0_i_i3344;
                } else {
                 break;
                }
               }
               HEAP32[$1 >> 2] = $storemerge4187_in + 2; //@line 58060
               if ((_cmd_match_expr_cmp($cmd, $val2_i1651, $base) | 0) == 0) {
                label = 16394; //@line 58065
                break L20638;
               }
               if (($op_0_i1652 | 0) == 1) {
                HEAP32[$val2_i766 >> 2] = (HEAP32[$val2_i766 >> 2] | 0) == (HEAP32[$val2_i1651 >> 2] | 0); //@line 58073
                continue;
               } else if (($op_0_i1652 | 0) == 2) {
                HEAP32[$val2_i766 >> 2] = (HEAP32[$val2_i766 >> 2] | 0) != (HEAP32[$val2_i1651 >> 2] | 0); //@line 58081
                continue;
               } else {
                continue;
               }
              }
              HEAP32[$val2_i150 >> 2] = HEAP32[$val2_i766 >> 2] & HEAP32[$val2_i150 >> 2]; //@line 58091
              $3696 = $i_0_i_i3344; //@line 58093
             }
             if ((label | 0) == 17242) {
              label = 0; //@line 58096
              HEAP32[$1 >> 2] = $3696; //@line 58097
              $i_0_i_i_i494 = $3696; //@line 58099
             }
             while (1) {
              $3759 = $cmd + 4 + $i_0_i_i_i494 | 0; //@line 58103
              $3760 = HEAP8[$3759] | 0; //@line 58104
              if (($3760 << 24 >> 24 | 0) == 13 | ($3760 << 24 >> 24 | 0) == 32 | ($3760 << 24 >> 24 | 0) == 9 | ($3760 << 24 >> 24 | 0) == 10) {
               $i_0_i_i_i494 = $i_0_i_i_i494 + 1 | 0; //@line 58108
               continue;
              }
              HEAP32[$1 >> 2] = $i_0_i_i_i494; //@line 58111
              if ((HEAP8[$3759] | 0) != 94) {
               break;
              }
              $3766 = $i_0_i_i_i494 + 1 | 0; //@line 58117
              HEAP32[$1 >> 2] = $3766; //@line 58118
              if ((_cmd_match_expr_cmp($cmd, $val2_i493, $base) | 0) == 0) {
               label = 16443; //@line 58123
               break L20638;
              }
              while (1) {
               $3771 = HEAP32[$1 >> 2] | 0; //@line 58129
               while (1) {
                $3772 = $cmd + 4 + $3771 | 0; //@line 58132
                $3773 = HEAP8[$3772] | 0; //@line 58133
                if (!(($3773 << 24 >> 24 | 0) == 13 | ($3773 << 24 >> 24 | 0) == 32 | ($3773 << 24 >> 24 | 0) == 9 | ($3773 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3771 = $3771 + 1 | 0; //@line 58139
               }
               HEAP32[$1 >> 2] = $3771; //@line 58141
               $3776 = HEAP8[$3772] | 0; //@line 58142
               if ($3776 << 24 >> 24 == 61) {
                if ((HEAP8[$3771 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1656 = 1;
                 $storemerge4186_in = $3771;
                } else {
                 $i_0_i_i3364 = $3771;
                 $3783 = 61;
                 label = 16409; //@line 58153
                }
               } else {
                $i_0_i_i3364 = $3771;
                $3783 = $3776;
                label = 16409; //@line 58157
               }
               if ((label | 0) == 16409) {
                while (1) {
                 label = 0; //@line 58161
                 if (!(($3783 << 24 >> 24 | 0) == 13 | ($3783 << 24 >> 24 | 0) == 32 | ($3783 << 24 >> 24 | 0) == 9 | ($3783 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $3784 = $i_0_i_i3364 + 1 | 0; //@line 58167
                 $i_0_i_i3364 = $3784;
                 $3783 = HEAP8[$cmd + 4 + $3784 | 0] | 0;
                 label = 16409; //@line 58172
                }
                HEAP32[$1 >> 2] = $i_0_i_i3364; //@line 58175
                if ((HEAP8[$cmd + 4 + $i_0_i_i3364 | 0] | 0) != 33) {
                 $3806 = $i_0_i_i3364; //@line 58179
                 break;
                }
                if ((HEAP8[$i_0_i_i3364 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1656 = 2;
                 $storemerge4186_in = $i_0_i_i3364;
                } else {
                 $3806 = $i_0_i_i3364; //@line 58189
                 break;
                }
               }
               HEAP32[$1 >> 2] = $storemerge4186_in + 2; //@line 58196
               if ((_cmd_match_expr_cmp($cmd, $val2_i1655, $base) | 0) == 0) {
                label = 16414; //@line 58201
                break L20638;
               }
               if (($op_0_i1656 | 0) == 1) {
                HEAP32[$val2_i493 >> 2] = (HEAP32[$val2_i493 >> 2] | 0) == (HEAP32[$val2_i1655 >> 2] | 0); //@line 58209
                continue;
               } else if (($op_0_i1656 | 0) == 2) {
                HEAP32[$val2_i493 >> 2] = (HEAP32[$val2_i493 >> 2] | 0) != (HEAP32[$val2_i1655 >> 2] | 0); //@line 58217
                continue;
               } else {
                continue;
               }
              }
              while (1) {
               $3808 = $3806; //@line 58227
               while (1) {
                $3809 = $cmd + 4 + $3808 | 0; //@line 58230
                $3810 = HEAP8[$3809] | 0; //@line 58231
                if (!(($3810 << 24 >> 24 | 0) == 13 | ($3810 << 24 >> 24 | 0) == 32 | ($3810 << 24 >> 24 | 0) == 9 | ($3810 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3808 = $3808 + 1 | 0; //@line 58237
               }
               HEAP32[$1 >> 2] = $3808; //@line 58239
               $3813 = HEAP8[$3809] | 0; //@line 58240
               if ($3813 << 24 >> 24 == 38) {
                if ((HEAP8[$3808 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                 label = 17243; //@line 58248
                 break;
                } else {
                 $i_0_i_i1668 = $3808;
                 $3820 = 38;
                }
               } else {
                $i_0_i_i1668 = $3808;
                $3820 = $3813;
               }
               while (1) {
                if (!(($3820 << 24 >> 24 | 0) == 13 | ($3820 << 24 >> 24 | 0) == 32 | ($3820 << 24 >> 24 | 0) == 9 | ($3820 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3821 = $i_0_i_i1668 + 1 | 0; //@line 58262
                $i_0_i_i1668 = $3821;
                $3820 = HEAP8[$cmd + 4 + $3821 | 0] | 0;
               }
               HEAP32[$1 >> 2] = $i_0_i_i1668; //@line 58269
               if ((HEAP8[$cmd + 4 + $i_0_i_i1668 | 0] | 0) != 38) {
                $3869 = $i_0_i_i1668; //@line 58273
                break;
               }
               $3826 = $i_0_i_i1668 + 1 | 0; //@line 58276
               HEAP32[$1 >> 2] = $3826; //@line 58277
               if ((_cmd_match_expr_cmp($cmd, $val2_i769, $base) | 0) == 0) {
                label = 16441; //@line 58282
                break L20638;
               }
               while (1) {
                $3831 = HEAP32[$1 >> 2] | 0; //@line 58288
                while (1) {
                 $3832 = $cmd + 4 + $3831 | 0; //@line 58291
                 $3833 = HEAP8[$3832] | 0; //@line 58292
                 if (!(($3833 << 24 >> 24 | 0) == 13 | ($3833 << 24 >> 24 | 0) == 32 | ($3833 << 24 >> 24 | 0) == 9 | ($3833 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $3831 = $3831 + 1 | 0; //@line 58298
                }
                HEAP32[$1 >> 2] = $3831; //@line 58300
                $3836 = HEAP8[$3832] | 0; //@line 58301
                if ($3836 << 24 >> 24 == 61) {
                 if ((HEAP8[$3831 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                  $op_0_i1679 = 1;
                  $storemerge4185_in = $3831;
                 } else {
                  $i_0_i_i3384 = $3831;
                  $3843 = 61;
                  label = 16432; //@line 58312
                 }
                } else {
                 $i_0_i_i3384 = $3831;
                 $3843 = $3836;
                 label = 16432; //@line 58316
                }
                if ((label | 0) == 16432) {
                 while (1) {
                  label = 0; //@line 58320
                  if (!(($3843 << 24 >> 24 | 0) == 13 | ($3843 << 24 >> 24 | 0) == 32 | ($3843 << 24 >> 24 | 0) == 9 | ($3843 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $3844 = $i_0_i_i3384 + 1 | 0; //@line 58326
                  $i_0_i_i3384 = $3844;
                  $3843 = HEAP8[$cmd + 4 + $3844 | 0] | 0;
                  label = 16432; //@line 58331
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i3384; //@line 58334
                 if ((HEAP8[$cmd + 4 + $i_0_i_i3384 | 0] | 0) != 33) {
                  break;
                 }
                 if ((HEAP8[$i_0_i_i3384 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                  $op_0_i1679 = 2;
                  $storemerge4185_in = $i_0_i_i3384;
                 } else {
                  break;
                 }
                }
                HEAP32[$1 >> 2] = $storemerge4185_in + 2; //@line 58353
                if ((_cmd_match_expr_cmp($cmd, $val2_i1678, $base) | 0) == 0) {
                 label = 16437; //@line 58358
                 break L20638;
                }
                if (($op_0_i1679 | 0) == 1) {
                 HEAP32[$val2_i769 >> 2] = (HEAP32[$val2_i769 >> 2] | 0) == (HEAP32[$val2_i1678 >> 2] | 0); //@line 58366
                 continue;
                } else if (($op_0_i1679 | 0) == 2) {
                 HEAP32[$val2_i769 >> 2] = (HEAP32[$val2_i769 >> 2] | 0) != (HEAP32[$val2_i1678 >> 2] | 0); //@line 58374
                 continue;
                } else {
                 continue;
                }
               }
               HEAP32[$val2_i493 >> 2] = HEAP32[$val2_i769 >> 2] & HEAP32[$val2_i493 >> 2]; //@line 58384
               $3806 = $i_0_i_i3384; //@line 58386
              }
              if ((label | 0) == 17243) {
               label = 0; //@line 58389
               HEAP32[$1 >> 2] = $3806; //@line 58390
               $3869 = $3806; //@line 58392
              }
              HEAP32[$val2_i150 >> 2] = HEAP32[$val2_i493 >> 2] ^ HEAP32[$val2_i150 >> 2]; //@line 58398
              $i_0_i_i_i494 = $3869; //@line 58400
             }
             HEAP32[$val2_i91 >> 2] = HEAP32[$val2_i150 >> 2] | HEAP32[$val2_i91 >> 2]; //@line 58405
             $3636 = $i_0_i_i_i494; //@line 58407
            }
            if ((label | 0) == 17241) {
             label = 0; //@line 58410
             HEAP32[$1 >> 2] = $3636; //@line 58411
             $3877 = $3636; //@line 58413
            }
            if ((HEAP32[$val2_i27 >> 2] | 0) == 0) {
             $3884 = 0; //@line 58420
            } else {
             $3884 = (HEAP32[$val2_i91 >> 2] | 0) != 0 | 0; //@line 58425
            }
            HEAP32[$val2_i27 >> 2] = $3884; //@line 58428
            $i_0_i_i_i92 = $3877; //@line 58430
           }
           if ((HEAP32[$val2 >> 2] | 0) == 0) {
            $3892 = (HEAP32[$val2_i27 >> 2] | 0) != 0 | 0; //@line 58440
           } else {
            $3892 = 1; //@line 58442
           }
           HEAP32[$val2 >> 2] = $3892; //@line 58445
           $2946 = $i_0_i_i_i92; //@line 58447
          }
          if ((label | 0) == 16095) {
           HEAP32[$1 >> 2] = $5861; //@line 58450
          } else if ((label | 0) == 16118) {
           HEAP32[$1 >> 2] = $3014; //@line 58454
           label = 16122; //@line 58456
          } else if ((label | 0) == 16138) {
           HEAP32[$1 >> 2] = $3064; //@line 58459
           label = 16167; //@line 58461
          } else if ((label | 0) == 16161) {
           HEAP32[$1 >> 2] = $3124; //@line 58464
           label = 16165; //@line 58466
          } else if ((label | 0) == 16188) {
           HEAP32[$1 >> 2] = $3191; //@line 58469
           label = 16262; //@line 58471
          } else if ((label | 0) == 16211) {
           HEAP32[$1 >> 2] = $3251; //@line 58474
           label = 16215; //@line 58476
          } else if ((label | 0) == 16231) {
           HEAP32[$1 >> 2] = $3301; //@line 58479
           label = 16260; //@line 58481
          } else if ((label | 0) == 16254) {
           HEAP32[$1 >> 2] = $3361; //@line 58484
           label = 16258; //@line 58486
          } else if ((label | 0) == 16278) {
           HEAP32[$1 >> 2] = $5865; //@line 58489
           label = 16447; //@line 58491
          } else if ((label | 0) == 16301) {
           HEAP32[$1 >> 2] = $3479; //@line 58494
           label = 16305; //@line 58496
          } else if ((label | 0) == 16321) {
           HEAP32[$1 >> 2] = $3529; //@line 58499
           label = 16350; //@line 58501
          } else if ((label | 0) == 16344) {
           HEAP32[$1 >> 2] = $3589; //@line 58504
           label = 16348; //@line 58506
          } else if ((label | 0) == 16371) {
           HEAP32[$1 >> 2] = $3656; //@line 58509
           label = 16445; //@line 58511
          } else if ((label | 0) == 16394) {
           HEAP32[$1 >> 2] = $3716; //@line 58514
           label = 16398; //@line 58516
          } else if ((label | 0) == 16414) {
           HEAP32[$1 >> 2] = $3766; //@line 58519
           label = 16443; //@line 58521
          } else if ((label | 0) == 16437) {
           HEAP32[$1 >> 2] = $3826; //@line 58524
           label = 16441; //@line 58526
          } else if ((label | 0) == 16456) {
           while (1) {
            label = 0; //@line 58530
            if (!(($3894 << 24 >> 24 | 0) == 13 | ($3894 << 24 >> 24 | 0) == 32 | ($3894 << 24 >> 24 | 0) == 9 | ($3894 << 24 >> 24 | 0) == 10)) {
             break;
            }
            $3895 = $i_0_i_i + 1 | 0; //@line 58536
            $i_0_i_i = $3895;
            $3894 = HEAP8[$cmd + 4 + $3895 | 0] | 0;
            label = 16456; //@line 58541
           }
           HEAP32[$1 >> 2] = $i_0_i_i; //@line 58544
           if ((HEAP8[$cmd + 4 + $i_0_i_i | 0] | 0) != 58) {
            HEAP32[$1 >> 2] = $2; //@line 58548
            $_0 = 0; //@line 58550
            STACKTOP = sp; //@line 58552
            return $_0 | 0; //@line 58553
           }
           $3900 = $i_0_i_i + 1 | 0; //@line 58555
           HEAP32[$1 >> 2] = $3900; //@line 58556
           do {
            if ((_cmd_match_expr_cmp($cmd, $val3, $base) | 0) != 0) {
             while (1) {
              $3912 = HEAP32[$1 >> 2] | 0; //@line 58571
              while (1) {
               $3913 = $cmd + 4 + $3912 | 0; //@line 58574
               $3914 = HEAP8[$3913] | 0; //@line 58575
               if (!(($3914 << 24 >> 24 | 0) == 13 | ($3914 << 24 >> 24 | 0) == 32 | ($3914 << 24 >> 24 | 0) == 9 | ($3914 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3912 = $3912 + 1 | 0; //@line 58581
              }
              HEAP32[$1 >> 2] = $3912; //@line 58583
              $3917 = HEAP8[$3913] | 0; //@line 58584
              if ($3917 << 24 >> 24 == 61) {
               if ((HEAP8[$3912 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1683 = 1;
                $storemerge4184_in = $3912;
               } else {
                $i_0_i_i3404 = $3912;
                $3924 = 61;
                label = 16466; //@line 58595
               }
              } else {
               $i_0_i_i3404 = $3912;
               $3924 = $3917;
               label = 16466; //@line 58599
              }
              if ((label | 0) == 16466) {
               while (1) {
                label = 0; //@line 58603
                if (!(($3924 << 24 >> 24 | 0) == 13 | ($3924 << 24 >> 24 | 0) == 32 | ($3924 << 24 >> 24 | 0) == 9 | ($3924 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3925 = $i_0_i_i3404 + 1 | 0; //@line 58609
                $i_0_i_i3404 = $3925;
                $3924 = HEAP8[$cmd + 4 + $3925 | 0] | 0;
                label = 16466; //@line 58614
               }
               HEAP32[$1 >> 2] = $i_0_i_i3404; //@line 58617
               if ((HEAP8[$cmd + 4 + $i_0_i_i3404 | 0] | 0) != 33) {
                break;
               }
               if ((HEAP8[$i_0_i_i3404 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                $op_0_i1683 = 2;
                $storemerge4184_in = $i_0_i_i3404;
               } else {
                break;
               }
              }
              HEAP32[$1 >> 2] = $storemerge4184_in + 2; //@line 58636
              if ((_cmd_match_expr_cmp($cmd, $val2_i1682, $base) | 0) == 0) {
               label = 16472; //@line 58641
               break;
              }
              if (($op_0_i1683 | 0) == 1) {
               HEAP32[$val3 >> 2] = (HEAP32[$val3 >> 2] | 0) == (HEAP32[$val2_i1682 >> 2] | 0); //@line 58649
               continue;
              } else if (($op_0_i1683 | 0) == 2) {
               HEAP32[$val3 >> 2] = (HEAP32[$val3 >> 2] | 0) != (HEAP32[$val2_i1682 >> 2] | 0); //@line 58657
               continue;
              } else {
               continue;
              }
             }
             if ((label | 0) == 16472) {
              HEAP32[$1 >> 2] = $3900; //@line 58665
              break;
             }
             $3948 = $i_0_i_i3404; //@line 58671
             L21200 : while (1) {
              $3950 = $3948; //@line 58675
              while (1) {
               $3951 = $cmd + 4 + $3950 | 0; //@line 58678
               $3952 = HEAP8[$3951] | 0; //@line 58679
               if (!(($3952 << 24 >> 24 | 0) == 13 | ($3952 << 24 >> 24 | 0) == 32 | ($3952 << 24 >> 24 | 0) == 9 | ($3952 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3950 = $3950 + 1 | 0; //@line 58685
              }
              HEAP32[$1 >> 2] = $3950; //@line 58687
              $3955 = HEAP8[$3951] | 0; //@line 58688
              if ($3955 << 24 >> 24 == 38) {
               if ((HEAP8[$3950 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                label = 17231; //@line 58696
                break;
               } else {
                $i_0_i_i1695 = $3950;
                $3962 = 38;
               }
              } else {
               $i_0_i_i1695 = $3950;
               $3962 = $3955;
              }
              while (1) {
               if (!(($3962 << 24 >> 24 | 0) == 13 | ($3962 << 24 >> 24 | 0) == 32 | ($3962 << 24 >> 24 | 0) == 9 | ($3962 << 24 >> 24 | 0) == 10)) {
                break;
               }
               $3963 = $i_0_i_i1695 + 1 | 0; //@line 58710
               $i_0_i_i1695 = $3963;
               $3962 = HEAP8[$cmd + 4 + $3963 | 0] | 0;
              }
              HEAP32[$1 >> 2] = $i_0_i_i1695; //@line 58717
              if ((HEAP8[$cmd + 4 + $i_0_i_i1695 | 0] | 0) != 38) {
               $3967 = $i_0_i_i1695; //@line 58721
               break;
              }
              $3972 = $i_0_i_i1695 + 1 | 0; //@line 58724
              HEAP32[$1 >> 2] = $3972; //@line 58725
              if ((_cmd_match_expr_cmp($cmd, $val2_i772, $base) | 0) == 0) {
               label = 16500; //@line 58730
               break;
              }
              while (1) {
               $3977 = HEAP32[$1 >> 2] | 0; //@line 58736
               while (1) {
                $3978 = $cmd + 4 + $3977 | 0; //@line 58739
                $3979 = HEAP8[$3978] | 0; //@line 58740
                if (!(($3979 << 24 >> 24 | 0) == 13 | ($3979 << 24 >> 24 | 0) == 32 | ($3979 << 24 >> 24 | 0) == 9 | ($3979 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $3977 = $3977 + 1 | 0; //@line 58746
               }
               HEAP32[$1 >> 2] = $3977; //@line 58748
               $3982 = HEAP8[$3978] | 0; //@line 58749
               if ($3982 << 24 >> 24 == 61) {
                if ((HEAP8[$3977 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1706 = 1;
                 $storemerge4183_in = $3977;
                } else {
                 $i_0_i_i3424 = $3977;
                 $3989 = 61;
                 label = 16491; //@line 58760
                }
               } else {
                $i_0_i_i3424 = $3977;
                $3989 = $3982;
                label = 16491; //@line 58764
               }
               if ((label | 0) == 16491) {
                while (1) {
                 label = 0; //@line 58768
                 if (!(($3989 << 24 >> 24 | 0) == 13 | ($3989 << 24 >> 24 | 0) == 32 | ($3989 << 24 >> 24 | 0) == 9 | ($3989 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $3990 = $i_0_i_i3424 + 1 | 0; //@line 58774
                 $i_0_i_i3424 = $3990;
                 $3989 = HEAP8[$cmd + 4 + $3990 | 0] | 0;
                 label = 16491; //@line 58779
                }
                HEAP32[$1 >> 2] = $i_0_i_i3424; //@line 58782
                if ((HEAP8[$cmd + 4 + $i_0_i_i3424 | 0] | 0) != 33) {
                 break;
                }
                if ((HEAP8[$i_0_i_i3424 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1706 = 2;
                 $storemerge4183_in = $i_0_i_i3424;
                } else {
                 break;
                }
               }
               HEAP32[$1 >> 2] = $storemerge4183_in + 2; //@line 58801
               if ((_cmd_match_expr_cmp($cmd, $val2_i1705, $base) | 0) == 0) {
                label = 16496; //@line 58806
                break L21200;
               }
               if (($op_0_i1706 | 0) == 1) {
                HEAP32[$val2_i772 >> 2] = (HEAP32[$val2_i772 >> 2] | 0) == (HEAP32[$val2_i1705 >> 2] | 0); //@line 58814
                continue;
               } else if (($op_0_i1706 | 0) == 2) {
                HEAP32[$val2_i772 >> 2] = (HEAP32[$val2_i772 >> 2] | 0) != (HEAP32[$val2_i1705 >> 2] | 0); //@line 58822
                continue;
               } else {
                continue;
               }
              }
              HEAP32[$val3 >> 2] = HEAP32[$val2_i772 >> 2] & HEAP32[$val3 >> 2]; //@line 58832
              $3948 = $i_0_i_i3424; //@line 58834
             }
             if ((label | 0) == 16496) {
              HEAP32[$1 >> 2] = $3972; //@line 58837
              label = 16500; //@line 58839
             } else if ((label | 0) == 17231) {
              HEAP32[$1 >> 2] = $3948; //@line 58842
              $3967 = $3948; //@line 58844
             }
             if ((label | 0) == 16500) {
              HEAP32[$1 >> 2] = $3900; //@line 58847
              break;
             }
             $i_0_i_i_i506 = $3967; //@line 58856
             L21239 : while (1) {
              $4015 = $cmd + 4 + $i_0_i_i_i506 | 0; //@line 58859
              $4016 = HEAP8[$4015] | 0; //@line 58860
              if (($4016 << 24 >> 24 | 0) == 13 | ($4016 << 24 >> 24 | 0) == 32 | ($4016 << 24 >> 24 | 0) == 9 | ($4016 << 24 >> 24 | 0) == 10) {
               $i_0_i_i_i506 = $i_0_i_i_i506 + 1 | 0; //@line 58864
               continue;
              }
              HEAP32[$1 >> 2] = $i_0_i_i_i506; //@line 58867
              if ((HEAP8[$4015] | 0) != 94) {
               label = 16505; //@line 58871
               break;
              }
              $4029 = $i_0_i_i_i506 + 1 | 0; //@line 58874
              HEAP32[$1 >> 2] = $4029; //@line 58875
              if ((_cmd_match_expr_cmp($cmd, $val2_i505, $base) | 0) == 0) {
               break;
              }
              while (1) {
               $4034 = HEAP32[$1 >> 2] | 0; //@line 58885
               while (1) {
                $4035 = $cmd + 4 + $4034 | 0; //@line 58888
                $4036 = HEAP8[$4035] | 0; //@line 58889
                if (!(($4036 << 24 >> 24 | 0) == 13 | ($4036 << 24 >> 24 | 0) == 32 | ($4036 << 24 >> 24 | 0) == 9 | ($4036 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $4034 = $4034 + 1 | 0; //@line 58895
               }
               HEAP32[$1 >> 2] = $4034; //@line 58897
               $4039 = HEAP8[$4035] | 0; //@line 58898
               if ($4039 << 24 >> 24 == 61) {
                if ((HEAP8[$4034 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1710 = 1;
                 $storemerge4182_in = $4034;
                } else {
                 $i_0_i_i3444 = $4034;
                 $4046 = 61;
                 label = 16512; //@line 58909
                }
               } else {
                $i_0_i_i3444 = $4034;
                $4046 = $4039;
                label = 16512; //@line 58913
               }
               if ((label | 0) == 16512) {
                while (1) {
                 label = 0; //@line 58917
                 if (!(($4046 << 24 >> 24 | 0) == 13 | ($4046 << 24 >> 24 | 0) == 32 | ($4046 << 24 >> 24 | 0) == 9 | ($4046 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $4047 = $i_0_i_i3444 + 1 | 0; //@line 58923
                 $i_0_i_i3444 = $4047;
                 $4046 = HEAP8[$cmd + 4 + $4047 | 0] | 0;
                 label = 16512; //@line 58928
                }
                HEAP32[$1 >> 2] = $i_0_i_i3444; //@line 58931
                if ((HEAP8[$cmd + 4 + $i_0_i_i3444 | 0] | 0) != 33) {
                 $4069 = $i_0_i_i3444; //@line 58935
                 break;
                }
                if ((HEAP8[$i_0_i_i3444 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                 $op_0_i1710 = 2;
                 $storemerge4182_in = $i_0_i_i3444;
                } else {
                 $4069 = $i_0_i_i3444; //@line 58945
                 break;
                }
               }
               HEAP32[$1 >> 2] = $storemerge4182_in + 2; //@line 58952
               if ((_cmd_match_expr_cmp($cmd, $val2_i1709, $base) | 0) == 0) {
                label = 16517; //@line 58957
                break L21239;
               }
               if (($op_0_i1710 | 0) == 1) {
                HEAP32[$val2_i505 >> 2] = (HEAP32[$val2_i505 >> 2] | 0) == (HEAP32[$val2_i1709 >> 2] | 0); //@line 58965
                continue;
               } else if (($op_0_i1710 | 0) == 2) {
                HEAP32[$val2_i505 >> 2] = (HEAP32[$val2_i505 >> 2] | 0) != (HEAP32[$val2_i1709 >> 2] | 0); //@line 58973
                continue;
               } else {
                continue;
               }
              }
              while (1) {
               $4071 = $4069; //@line 58983
               while (1) {
                $4072 = $cmd + 4 + $4071 | 0; //@line 58986
                $4073 = HEAP8[$4072] | 0; //@line 58987
                if (!(($4073 << 24 >> 24 | 0) == 13 | ($4073 << 24 >> 24 | 0) == 32 | ($4073 << 24 >> 24 | 0) == 9 | ($4073 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $4071 = $4071 + 1 | 0; //@line 58993
               }
               HEAP32[$1 >> 2] = $4071; //@line 58995
               $4076 = HEAP8[$4072] | 0; //@line 58996
               if ($4076 << 24 >> 24 == 38) {
                if ((HEAP8[$4071 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                 label = 17230; //@line 59004
                 break;
                } else {
                 $i_0_i_i1722 = $4071;
                 $4083 = 38;
                }
               } else {
                $i_0_i_i1722 = $4071;
                $4083 = $4076;
               }
               while (1) {
                if (!(($4083 << 24 >> 24 | 0) == 13 | ($4083 << 24 >> 24 | 0) == 32 | ($4083 << 24 >> 24 | 0) == 9 | ($4083 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $4084 = $i_0_i_i1722 + 1 | 0; //@line 59018
                $i_0_i_i1722 = $4084;
                $4083 = HEAP8[$cmd + 4 + $4084 | 0] | 0;
               }
               HEAP32[$1 >> 2] = $i_0_i_i1722; //@line 59025
               if ((HEAP8[$cmd + 4 + $i_0_i_i1722 | 0] | 0) != 38) {
                $4132 = $i_0_i_i1722; //@line 59029
                break;
               }
               $4089 = $i_0_i_i1722 + 1 | 0; //@line 59032
               HEAP32[$1 >> 2] = $4089; //@line 59033
               if ((_cmd_match_expr_cmp($cmd, $val2_i775, $base) | 0) == 0) {
                label = 16544; //@line 59038
                break L21239;
               }
               while (1) {
                $4094 = HEAP32[$1 >> 2] | 0; //@line 59044
                while (1) {
                 $4095 = $cmd + 4 + $4094 | 0; //@line 59047
                 $4096 = HEAP8[$4095] | 0; //@line 59048
                 if (!(($4096 << 24 >> 24 | 0) == 13 | ($4096 << 24 >> 24 | 0) == 32 | ($4096 << 24 >> 24 | 0) == 9 | ($4096 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $4094 = $4094 + 1 | 0; //@line 59054
                }
                HEAP32[$1 >> 2] = $4094; //@line 59056
                $4099 = HEAP8[$4095] | 0; //@line 59057
                if ($4099 << 24 >> 24 == 61) {
                 if ((HEAP8[$4094 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                  $op_0_i1733 = 1;
                  $storemerge4181_in = $4094;
                 } else {
                  $i_0_i_i3464 = $4094;
                  $4106 = 61;
                  label = 16535; //@line 59068
                 }
                } else {
                 $i_0_i_i3464 = $4094;
                 $4106 = $4099;
                 label = 16535; //@line 59072
                }
                if ((label | 0) == 16535) {
                 while (1) {
                  label = 0; //@line 59076
                  if (!(($4106 << 24 >> 24 | 0) == 13 | ($4106 << 24 >> 24 | 0) == 32 | ($4106 << 24 >> 24 | 0) == 9 | ($4106 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4107 = $i_0_i_i3464 + 1 | 0; //@line 59082
                  $i_0_i_i3464 = $4107;
                  $4106 = HEAP8[$cmd + 4 + $4107 | 0] | 0;
                  label = 16535; //@line 59087
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i3464; //@line 59090
                 if ((HEAP8[$cmd + 4 + $i_0_i_i3464 | 0] | 0) != 33) {
                  break;
                 }
                 if ((HEAP8[$i_0_i_i3464 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                  $op_0_i1733 = 2;
                  $storemerge4181_in = $i_0_i_i3464;
                 } else {
                  break;
                 }
                }
                HEAP32[$1 >> 2] = $storemerge4181_in + 2; //@line 59109
                if ((_cmd_match_expr_cmp($cmd, $val2_i1732, $base) | 0) == 0) {
                 label = 16540; //@line 59114
                 break L21239;
                }
                if (($op_0_i1733 | 0) == 1) {
                 HEAP32[$val2_i775 >> 2] = (HEAP32[$val2_i775 >> 2] | 0) == (HEAP32[$val2_i1732 >> 2] | 0); //@line 59122
                 continue;
                } else if (($op_0_i1733 | 0) == 2) {
                 HEAP32[$val2_i775 >> 2] = (HEAP32[$val2_i775 >> 2] | 0) != (HEAP32[$val2_i1732 >> 2] | 0); //@line 59130
                 continue;
                } else {
                 continue;
                }
               }
               HEAP32[$val2_i505 >> 2] = HEAP32[$val2_i775 >> 2] & HEAP32[$val2_i505 >> 2]; //@line 59140
               $4069 = $i_0_i_i3464; //@line 59142
              }
              if ((label | 0) == 17230) {
               label = 0; //@line 59145
               HEAP32[$1 >> 2] = $4069; //@line 59146
               $4132 = $4069; //@line 59148
              }
              HEAP32[$val3 >> 2] = HEAP32[$val2_i505 >> 2] ^ HEAP32[$val3 >> 2]; //@line 59154
              $i_0_i_i_i506 = $4132; //@line 59156
             }
             if ((label | 0) == 16505) {
              $4136 = $i_0_i_i_i506; //@line 59167
              L21302 : while (1) {
               $4138 = $4136; //@line 59171
               while (1) {
                $4139 = $cmd + 4 + $4138 | 0; //@line 59174
                $4140 = HEAP8[$4139] | 0; //@line 59175
                if (!(($4140 << 24 >> 24 | 0) == 13 | ($4140 << 24 >> 24 | 0) == 32 | ($4140 << 24 >> 24 | 0) == 9 | ($4140 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $4138 = $4138 + 1 | 0; //@line 59181
               }
               HEAP32[$1 >> 2] = $4138; //@line 59183
               $4143 = HEAP8[$4139] | 0; //@line 59184
               if ($4143 << 24 >> 24 == 124) {
                if ((HEAP8[$4138 + 1 + ($cmd + 4) | 0] | 0) == 124) {
                 label = 17227; //@line 59192
                 break;
                } else {
                 $i_0_i_i526 = $4138;
                 $4150 = 124;
                }
               } else {
                $i_0_i_i526 = $4138;
                $4150 = $4143;
               }
               while (1) {
                if (!(($4150 << 24 >> 24 | 0) == 13 | ($4150 << 24 >> 24 | 0) == 32 | ($4150 << 24 >> 24 | 0) == 9 | ($4150 << 24 >> 24 | 0) == 10)) {
                 break;
                }
                $4151 = $i_0_i_i526 + 1 | 0; //@line 59206
                $i_0_i_i526 = $4151;
                $4150 = HEAP8[$cmd + 4 + $4151 | 0] | 0;
               }
               HEAP32[$1 >> 2] = $i_0_i_i526; //@line 59213
               if ((HEAP8[$cmd + 4 + $i_0_i_i526 | 0] | 0) != 124) {
                $4155 = $i_0_i_i526; //@line 59217
                label = 16556; //@line 59218
                break;
               }
               $4172 = $i_0_i_i526 + 1 | 0; //@line 59221
               HEAP32[$1 >> 2] = $4172; //@line 59222
               if ((_cmd_match_expr_cmp($cmd, $val2_i153, $base) | 0) == 0) {
                break;
               }
               while (1) {
                $4177 = HEAP32[$1 >> 2] | 0; //@line 59232
                while (1) {
                 $4178 = $cmd + 4 + $4177 | 0; //@line 59235
                 $4179 = HEAP8[$4178] | 0; //@line 59236
                 if (!(($4179 << 24 >> 24 | 0) == 13 | ($4179 << 24 >> 24 | 0) == 32 | ($4179 << 24 >> 24 | 0) == 9 | ($4179 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $4177 = $4177 + 1 | 0; //@line 59242
                }
                HEAP32[$1 >> 2] = $4177; //@line 59244
                $4182 = HEAP8[$4178] | 0; //@line 59245
                if ($4182 << 24 >> 24 == 61) {
                 if ((HEAP8[$4177 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                  $op_0_i1737 = 1;
                  $storemerge4180_in = $4177;
                 } else {
                  $i_0_i_i3484 = $4177;
                  $4189 = 61;
                  label = 16563; //@line 59256
                 }
                } else {
                 $i_0_i_i3484 = $4177;
                 $4189 = $4182;
                 label = 16563; //@line 59260
                }
                if ((label | 0) == 16563) {
                 while (1) {
                  label = 0; //@line 59264
                  if (!(($4189 << 24 >> 24 | 0) == 13 | ($4189 << 24 >> 24 | 0) == 32 | ($4189 << 24 >> 24 | 0) == 9 | ($4189 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4190 = $i_0_i_i3484 + 1 | 0; //@line 59270
                  $i_0_i_i3484 = $4190;
                  $4189 = HEAP8[$cmd + 4 + $4190 | 0] | 0;
                  label = 16563; //@line 59275
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i3484; //@line 59278
                 if ((HEAP8[$cmd + 4 + $i_0_i_i3484 | 0] | 0) != 33) {
                  $4212 = $i_0_i_i3484; //@line 59282
                  break;
                 }
                 if ((HEAP8[$i_0_i_i3484 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                  $op_0_i1737 = 2;
                  $storemerge4180_in = $i_0_i_i3484;
                 } else {
                  $4212 = $i_0_i_i3484; //@line 59292
                  break;
                 }
                }
                HEAP32[$1 >> 2] = $storemerge4180_in + 2; //@line 59299
                if ((_cmd_match_expr_cmp($cmd, $val2_i1736, $base) | 0) == 0) {
                 label = 16568; //@line 59304
                 break L21302;
                }
                if (($op_0_i1737 | 0) == 1) {
                 HEAP32[$val2_i153 >> 2] = (HEAP32[$val2_i153 >> 2] | 0) == (HEAP32[$val2_i1736 >> 2] | 0); //@line 59312
                 continue;
                } else if (($op_0_i1737 | 0) == 2) {
                 HEAP32[$val2_i153 >> 2] = (HEAP32[$val2_i153 >> 2] | 0) != (HEAP32[$val2_i1736 >> 2] | 0); //@line 59320
                 continue;
                } else {
                 continue;
                }
               }
               while (1) {
                $4214 = $4212; //@line 59330
                while (1) {
                 $4215 = $cmd + 4 + $4214 | 0; //@line 59333
                 $4216 = HEAP8[$4215] | 0; //@line 59334
                 if (!(($4216 << 24 >> 24 | 0) == 13 | ($4216 << 24 >> 24 | 0) == 32 | ($4216 << 24 >> 24 | 0) == 9 | ($4216 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $4214 = $4214 + 1 | 0; //@line 59340
                }
                HEAP32[$1 >> 2] = $4214; //@line 59342
                $4219 = HEAP8[$4215] | 0; //@line 59343
                if ($4219 << 24 >> 24 == 38) {
                 if ((HEAP8[$4214 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                  label = 17228; //@line 59351
                  break;
                 } else {
                  $i_0_i_i1749 = $4214;
                  $4226 = 38;
                 }
                } else {
                 $i_0_i_i1749 = $4214;
                 $4226 = $4219;
                }
                while (1) {
                 if (!(($4226 << 24 >> 24 | 0) == 13 | ($4226 << 24 >> 24 | 0) == 32 | ($4226 << 24 >> 24 | 0) == 9 | ($4226 << 24 >> 24 | 0) == 10)) {
                  break;
                 }
                 $4227 = $i_0_i_i1749 + 1 | 0; //@line 59365
                 $i_0_i_i1749 = $4227;
                 $4226 = HEAP8[$cmd + 4 + $4227 | 0] | 0;
                }
                HEAP32[$1 >> 2] = $i_0_i_i1749; //@line 59372
                if ((HEAP8[$cmd + 4 + $i_0_i_i1749 | 0] | 0) != 38) {
                 $i_0_i_i_i537 = $i_0_i_i1749; //@line 59376
                 break;
                }
                $4232 = $i_0_i_i1749 + 1 | 0; //@line 59379
                HEAP32[$1 >> 2] = $4232; //@line 59380
                if ((_cmd_match_expr_cmp($cmd, $val2_i778, $base) | 0) == 0) {
                 label = 16595; //@line 59385
                 break L21302;
                }
                while (1) {
                 $4237 = HEAP32[$1 >> 2] | 0; //@line 59391
                 while (1) {
                  $4238 = $cmd + 4 + $4237 | 0; //@line 59394
                  $4239 = HEAP8[$4238] | 0; //@line 59395
                  if (!(($4239 << 24 >> 24 | 0) == 13 | ($4239 << 24 >> 24 | 0) == 32 | ($4239 << 24 >> 24 | 0) == 9 | ($4239 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4237 = $4237 + 1 | 0; //@line 59401
                 }
                 HEAP32[$1 >> 2] = $4237; //@line 59403
                 $4242 = HEAP8[$4238] | 0; //@line 59404
                 if ($4242 << 24 >> 24 == 61) {
                  if ((HEAP8[$4237 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                   $op_0_i1760 = 1;
                   $storemerge4179_in = $4237;
                  } else {
                   $i_0_i_i3504 = $4237;
                   $4249 = 61;
                   label = 16586; //@line 59415
                  }
                 } else {
                  $i_0_i_i3504 = $4237;
                  $4249 = $4242;
                  label = 16586; //@line 59419
                 }
                 if ((label | 0) == 16586) {
                  while (1) {
                   label = 0; //@line 59423
                   if (!(($4249 << 24 >> 24 | 0) == 13 | ($4249 << 24 >> 24 | 0) == 32 | ($4249 << 24 >> 24 | 0) == 9 | ($4249 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4250 = $i_0_i_i3504 + 1 | 0; //@line 59429
                   $i_0_i_i3504 = $4250;
                   $4249 = HEAP8[$cmd + 4 + $4250 | 0] | 0;
                   label = 16586; //@line 59434
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i3504; //@line 59437
                  if ((HEAP8[$cmd + 4 + $i_0_i_i3504 | 0] | 0) != 33) {
                   break;
                  }
                  if ((HEAP8[$i_0_i_i3504 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                   $op_0_i1760 = 2;
                   $storemerge4179_in = $i_0_i_i3504;
                  } else {
                   break;
                  }
                 }
                 HEAP32[$1 >> 2] = $storemerge4179_in + 2; //@line 59456
                 if ((_cmd_match_expr_cmp($cmd, $val2_i1759, $base) | 0) == 0) {
                  label = 16591; //@line 59461
                  break L21302;
                 }
                 if (($op_0_i1760 | 0) == 1) {
                  HEAP32[$val2_i778 >> 2] = (HEAP32[$val2_i778 >> 2] | 0) == (HEAP32[$val2_i1759 >> 2] | 0); //@line 59469
                  continue;
                 } else if (($op_0_i1760 | 0) == 2) {
                  HEAP32[$val2_i778 >> 2] = (HEAP32[$val2_i778 >> 2] | 0) != (HEAP32[$val2_i1759 >> 2] | 0); //@line 59477
                  continue;
                 } else {
                  continue;
                 }
                }
                HEAP32[$val2_i153 >> 2] = HEAP32[$val2_i778 >> 2] & HEAP32[$val2_i153 >> 2]; //@line 59487
                $4212 = $i_0_i_i3504; //@line 59489
               }
               if ((label | 0) == 17228) {
                label = 0; //@line 59492
                HEAP32[$1 >> 2] = $4212; //@line 59493
                $i_0_i_i_i537 = $4212; //@line 59495
               }
               while (1) {
                $4275 = $cmd + 4 + $i_0_i_i_i537 | 0; //@line 59499
                $4276 = HEAP8[$4275] | 0; //@line 59500
                if (($4276 << 24 >> 24 | 0) == 13 | ($4276 << 24 >> 24 | 0) == 32 | ($4276 << 24 >> 24 | 0) == 9 | ($4276 << 24 >> 24 | 0) == 10) {
                 $i_0_i_i_i537 = $i_0_i_i_i537 + 1 | 0; //@line 59504
                 continue;
                }
                HEAP32[$1 >> 2] = $i_0_i_i_i537; //@line 59507
                if ((HEAP8[$4275] | 0) != 94) {
                 break;
                }
                $4282 = $i_0_i_i_i537 + 1 | 0; //@line 59513
                HEAP32[$1 >> 2] = $4282; //@line 59514
                if ((_cmd_match_expr_cmp($cmd, $val2_i536, $base) | 0) == 0) {
                 label = 16640; //@line 59519
                 break L21302;
                }
                while (1) {
                 $4287 = HEAP32[$1 >> 2] | 0; //@line 59525
                 while (1) {
                  $4288 = $cmd + 4 + $4287 | 0; //@line 59528
                  $4289 = HEAP8[$4288] | 0; //@line 59529
                  if (!(($4289 << 24 >> 24 | 0) == 13 | ($4289 << 24 >> 24 | 0) == 32 | ($4289 << 24 >> 24 | 0) == 9 | ($4289 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4287 = $4287 + 1 | 0; //@line 59535
                 }
                 HEAP32[$1 >> 2] = $4287; //@line 59537
                 $4292 = HEAP8[$4288] | 0; //@line 59538
                 if ($4292 << 24 >> 24 == 61) {
                  if ((HEAP8[$4287 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                   $op_0_i1764 = 1;
                   $storemerge4178_in = $4287;
                  } else {
                   $i_0_i_i3524 = $4287;
                   $4299 = 61;
                   label = 16606; //@line 59549
                  }
                 } else {
                  $i_0_i_i3524 = $4287;
                  $4299 = $4292;
                  label = 16606; //@line 59553
                 }
                 if ((label | 0) == 16606) {
                  while (1) {
                   label = 0; //@line 59557
                   if (!(($4299 << 24 >> 24 | 0) == 13 | ($4299 << 24 >> 24 | 0) == 32 | ($4299 << 24 >> 24 | 0) == 9 | ($4299 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4300 = $i_0_i_i3524 + 1 | 0; //@line 59563
                   $i_0_i_i3524 = $4300;
                   $4299 = HEAP8[$cmd + 4 + $4300 | 0] | 0;
                   label = 16606; //@line 59568
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i3524; //@line 59571
                  if ((HEAP8[$cmd + 4 + $i_0_i_i3524 | 0] | 0) != 33) {
                   $4322 = $i_0_i_i3524; //@line 59575
                   break;
                  }
                  if ((HEAP8[$i_0_i_i3524 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                   $op_0_i1764 = 2;
                   $storemerge4178_in = $i_0_i_i3524;
                  } else {
                   $4322 = $i_0_i_i3524; //@line 59585
                   break;
                  }
                 }
                 HEAP32[$1 >> 2] = $storemerge4178_in + 2; //@line 59592
                 if ((_cmd_match_expr_cmp($cmd, $val2_i1763, $base) | 0) == 0) {
                  label = 16611; //@line 59597
                  break L21302;
                 }
                 if (($op_0_i1764 | 0) == 1) {
                  HEAP32[$val2_i536 >> 2] = (HEAP32[$val2_i536 >> 2] | 0) == (HEAP32[$val2_i1763 >> 2] | 0); //@line 59605
                  continue;
                 } else if (($op_0_i1764 | 0) == 2) {
                  HEAP32[$val2_i536 >> 2] = (HEAP32[$val2_i536 >> 2] | 0) != (HEAP32[$val2_i1763 >> 2] | 0); //@line 59613
                  continue;
                 } else {
                  continue;
                 }
                }
                while (1) {
                 $4324 = $4322; //@line 59623
                 while (1) {
                  $4325 = $cmd + 4 + $4324 | 0; //@line 59626
                  $4326 = HEAP8[$4325] | 0; //@line 59627
                  if (!(($4326 << 24 >> 24 | 0) == 13 | ($4326 << 24 >> 24 | 0) == 32 | ($4326 << 24 >> 24 | 0) == 9 | ($4326 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4324 = $4324 + 1 | 0; //@line 59633
                 }
                 HEAP32[$1 >> 2] = $4324; //@line 59635
                 $4329 = HEAP8[$4325] | 0; //@line 59636
                 if ($4329 << 24 >> 24 == 38) {
                  if ((HEAP8[$4324 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                   label = 17229; //@line 59644
                   break;
                  } else {
                   $i_0_i_i1776 = $4324;
                   $4336 = 38;
                  }
                 } else {
                  $i_0_i_i1776 = $4324;
                  $4336 = $4329;
                 }
                 while (1) {
                  if (!(($4336 << 24 >> 24 | 0) == 13 | ($4336 << 24 >> 24 | 0) == 32 | ($4336 << 24 >> 24 | 0) == 9 | ($4336 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4337 = $i_0_i_i1776 + 1 | 0; //@line 59658
                  $i_0_i_i1776 = $4337;
                  $4336 = HEAP8[$cmd + 4 + $4337 | 0] | 0;
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i1776; //@line 59665
                 if ((HEAP8[$cmd + 4 + $i_0_i_i1776 | 0] | 0) != 38) {
                  $4385 = $i_0_i_i1776; //@line 59669
                  break;
                 }
                 $4342 = $i_0_i_i1776 + 1 | 0; //@line 59672
                 HEAP32[$1 >> 2] = $4342; //@line 59673
                 if ((_cmd_match_expr_cmp($cmd, $val2_i781, $base) | 0) == 0) {
                  label = 16638; //@line 59678
                  break L21302;
                 }
                 while (1) {
                  $4347 = HEAP32[$1 >> 2] | 0; //@line 59684
                  while (1) {
                   $4348 = $cmd + 4 + $4347 | 0; //@line 59687
                   $4349 = HEAP8[$4348] | 0; //@line 59688
                   if (!(($4349 << 24 >> 24 | 0) == 13 | ($4349 << 24 >> 24 | 0) == 32 | ($4349 << 24 >> 24 | 0) == 9 | ($4349 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4347 = $4347 + 1 | 0; //@line 59694
                  }
                  HEAP32[$1 >> 2] = $4347; //@line 59696
                  $4352 = HEAP8[$4348] | 0; //@line 59697
                  if ($4352 << 24 >> 24 == 61) {
                   if ((HEAP8[$4347 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1787 = 1;
                    $storemerge4177_in = $4347;
                   } else {
                    $i_0_i_i3544 = $4347;
                    $4359 = 61;
                    label = 16629; //@line 59708
                   }
                  } else {
                   $i_0_i_i3544 = $4347;
                   $4359 = $4352;
                   label = 16629; //@line 59712
                  }
                  if ((label | 0) == 16629) {
                   while (1) {
                    label = 0; //@line 59716
                    if (!(($4359 << 24 >> 24 | 0) == 13 | ($4359 << 24 >> 24 | 0) == 32 | ($4359 << 24 >> 24 | 0) == 9 | ($4359 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4360 = $i_0_i_i3544 + 1 | 0; //@line 59722
                    $i_0_i_i3544 = $4360;
                    $4359 = HEAP8[$cmd + 4 + $4360 | 0] | 0;
                    label = 16629; //@line 59727
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i3544; //@line 59730
                   if ((HEAP8[$cmd + 4 + $i_0_i_i3544 | 0] | 0) != 33) {
                    break;
                   }
                   if ((HEAP8[$i_0_i_i3544 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1787 = 2;
                    $storemerge4177_in = $i_0_i_i3544;
                   } else {
                    break;
                   }
                  }
                  HEAP32[$1 >> 2] = $storemerge4177_in + 2; //@line 59749
                  if ((_cmd_match_expr_cmp($cmd, $val2_i1786, $base) | 0) == 0) {
                   label = 16634; //@line 59754
                   break L21302;
                  }
                  if (($op_0_i1787 | 0) == 1) {
                   HEAP32[$val2_i781 >> 2] = (HEAP32[$val2_i781 >> 2] | 0) == (HEAP32[$val2_i1786 >> 2] | 0); //@line 59762
                   continue;
                  } else if (($op_0_i1787 | 0) == 2) {
                   HEAP32[$val2_i781 >> 2] = (HEAP32[$val2_i781 >> 2] | 0) != (HEAP32[$val2_i1786 >> 2] | 0); //@line 59770
                   continue;
                  } else {
                   continue;
                  }
                 }
                 HEAP32[$val2_i536 >> 2] = HEAP32[$val2_i781 >> 2] & HEAP32[$val2_i536 >> 2]; //@line 59780
                 $4322 = $i_0_i_i3544; //@line 59782
                }
                if ((label | 0) == 17229) {
                 label = 0; //@line 59785
                 HEAP32[$1 >> 2] = $4322; //@line 59786
                 $4385 = $4322; //@line 59788
                }
                HEAP32[$val2_i153 >> 2] = HEAP32[$val2_i536 >> 2] ^ HEAP32[$val2_i153 >> 2]; //@line 59794
                $i_0_i_i_i537 = $4385; //@line 59796
               }
               HEAP32[$val3 >> 2] = HEAP32[$val2_i153 >> 2] | HEAP32[$val3 >> 2]; //@line 59801
               $4136 = $i_0_i_i_i537; //@line 59803
              }
              if ((label | 0) == 16568) {
               HEAP32[$1 >> 2] = $4172; //@line 59806
              } else if ((label | 0) == 16591) {
               HEAP32[$1 >> 2] = $4232; //@line 59810
               label = 16595; //@line 59812
              } else if ((label | 0) == 16611) {
               HEAP32[$1 >> 2] = $4282; //@line 59815
               label = 16640; //@line 59817
              } else if ((label | 0) == 16634) {
               HEAP32[$1 >> 2] = $4342; //@line 59820
               label = 16638; //@line 59822
              } else if ((label | 0) == 17227) {
               HEAP32[$1 >> 2] = $4136; //@line 59825
               $4155 = $4136; //@line 59827
               label = 16556; //@line 59828
              }
              if ((label | 0) == 16556) {
               $i_0_i_i_i105 = $4155; //@line 59848
               L21439 : while (1) {
                $4393 = $cmd + 4 + $i_0_i_i_i105 | 0; //@line 59851
                $4394 = HEAP8[$4393] | 0; //@line 59852
                if (($4394 << 24 >> 24 | 0) == 13 | ($4394 << 24 >> 24 | 0) == 32 | ($4394 << 24 >> 24 | 0) == 9 | ($4394 << 24 >> 24 | 0) == 10) {
                 $i_0_i_i_i105 = $i_0_i_i_i105 + 1 | 0; //@line 59856
                 continue;
                }
                HEAP32[$1 >> 2] = $i_0_i_i_i105; //@line 59859
                if ((HEAP8[$4393] | 0) != 38) {
                 label = 16647; //@line 59863
                 break;
                }
                if ((HEAP8[$i_0_i_i_i105 + 1 + ($cmd + 4) | 0] | 0) != 38) {
                 label = 16647; //@line 59871
                 break;
                }
                $5857 = $i_0_i_i_i105 + 2 | 0; //@line 59874
                HEAP32[$1 >> 2] = $5857; //@line 59875
                if ((_cmd_match_expr_cmp($cmd, $val2_i104, $base) | 0) == 0) {
                 break;
                }
                while (1) {
                 $4436 = HEAP32[$1 >> 2] | 0; //@line 59885
                 while (1) {
                  $4437 = $cmd + 4 + $4436 | 0; //@line 59888
                  $4438 = HEAP8[$4437] | 0; //@line 59889
                  if (!(($4438 << 24 >> 24 | 0) == 13 | ($4438 << 24 >> 24 | 0) == 32 | ($4438 << 24 >> 24 | 0) == 9 | ($4438 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4436 = $4436 + 1 | 0; //@line 59895
                 }
                 HEAP32[$1 >> 2] = $4436; //@line 59897
                 $4441 = HEAP8[$4437] | 0; //@line 59898
                 if ($4441 << 24 >> 24 == 61) {
                  if ((HEAP8[$4436 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                   $op_0_i1791 = 1;
                   $storemerge4176_in = $4436;
                  } else {
                   $i_0_i_i3564 = $4436;
                   $4448 = 61;
                   label = 16654; //@line 59909
                  }
                 } else {
                  $i_0_i_i3564 = $4436;
                  $4448 = $4441;
                  label = 16654; //@line 59913
                 }
                 if ((label | 0) == 16654) {
                  while (1) {
                   label = 0; //@line 59917
                   if (!(($4448 << 24 >> 24 | 0) == 13 | ($4448 << 24 >> 24 | 0) == 32 | ($4448 << 24 >> 24 | 0) == 9 | ($4448 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4449 = $i_0_i_i3564 + 1 | 0; //@line 59923
                   $i_0_i_i3564 = $4449;
                   $4448 = HEAP8[$cmd + 4 + $4449 | 0] | 0;
                   label = 16654; //@line 59928
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i3564; //@line 59931
                  if ((HEAP8[$cmd + 4 + $i_0_i_i3564 | 0] | 0) != 33) {
                   $4471 = $i_0_i_i3564; //@line 59935
                   break;
                  }
                  if ((HEAP8[$i_0_i_i3564 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                   $op_0_i1791 = 2;
                   $storemerge4176_in = $i_0_i_i3564;
                  } else {
                   $4471 = $i_0_i_i3564; //@line 59945
                   break;
                  }
                 }
                 HEAP32[$1 >> 2] = $storemerge4176_in + 2; //@line 59952
                 if ((_cmd_match_expr_cmp($cmd, $val2_i1790, $base) | 0) == 0) {
                  label = 16659; //@line 59957
                  break L21439;
                 }
                 if (($op_0_i1791 | 0) == 1) {
                  HEAP32[$val2_i104 >> 2] = (HEAP32[$val2_i104 >> 2] | 0) == (HEAP32[$val2_i1790 >> 2] | 0); //@line 59965
                  continue;
                 } else if (($op_0_i1791 | 0) == 2) {
                  HEAP32[$val2_i104 >> 2] = (HEAP32[$val2_i104 >> 2] | 0) != (HEAP32[$val2_i1790 >> 2] | 0); //@line 59973
                  continue;
                 } else {
                  continue;
                 }
                }
                while (1) {
                 $4473 = $4471; //@line 59983
                 while (1) {
                  $4474 = $cmd + 4 + $4473 | 0; //@line 59986
                  $4475 = HEAP8[$4474] | 0; //@line 59987
                  if (!(($4475 << 24 >> 24 | 0) == 13 | ($4475 << 24 >> 24 | 0) == 32 | ($4475 << 24 >> 24 | 0) == 9 | ($4475 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4473 = $4473 + 1 | 0; //@line 59993
                 }
                 HEAP32[$1 >> 2] = $4473; //@line 59995
                 $4478 = HEAP8[$4474] | 0; //@line 59996
                 if ($4478 << 24 >> 24 == 38) {
                  if ((HEAP8[$4473 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                   label = 17222; //@line 60004
                   break;
                  } else {
                   $i_0_i_i1803 = $4473;
                   $4485 = 38;
                  }
                 } else {
                  $i_0_i_i1803 = $4473;
                  $4485 = $4478;
                 }
                 while (1) {
                  if (!(($4485 << 24 >> 24 | 0) == 13 | ($4485 << 24 >> 24 | 0) == 32 | ($4485 << 24 >> 24 | 0) == 9 | ($4485 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4486 = $i_0_i_i1803 + 1 | 0; //@line 60018
                  $i_0_i_i1803 = $4486;
                  $4485 = HEAP8[$cmd + 4 + $4486 | 0] | 0;
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i1803; //@line 60025
                 if ((HEAP8[$cmd + 4 + $i_0_i_i1803 | 0] | 0) != 38) {
                  $i_0_i_i_i549 = $i_0_i_i1803; //@line 60029
                  break;
                 }
                 $4491 = $i_0_i_i1803 + 1 | 0; //@line 60032
                 HEAP32[$1 >> 2] = $4491; //@line 60033
                 if ((_cmd_match_expr_cmp($cmd, $val2_i784, $base) | 0) == 0) {
                  label = 16686; //@line 60038
                  break L21439;
                 }
                 while (1) {
                  $4496 = HEAP32[$1 >> 2] | 0; //@line 60044
                  while (1) {
                   $4497 = $cmd + 4 + $4496 | 0; //@line 60047
                   $4498 = HEAP8[$4497] | 0; //@line 60048
                   if (!(($4498 << 24 >> 24 | 0) == 13 | ($4498 << 24 >> 24 | 0) == 32 | ($4498 << 24 >> 24 | 0) == 9 | ($4498 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4496 = $4496 + 1 | 0; //@line 60054
                  }
                  HEAP32[$1 >> 2] = $4496; //@line 60056
                  $4501 = HEAP8[$4497] | 0; //@line 60057
                  if ($4501 << 24 >> 24 == 61) {
                   if ((HEAP8[$4496 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1814 = 1;
                    $storemerge4175_in = $4496;
                   } else {
                    $i_0_i_i3584 = $4496;
                    $4508 = 61;
                    label = 16677; //@line 60068
                   }
                  } else {
                   $i_0_i_i3584 = $4496;
                   $4508 = $4501;
                   label = 16677; //@line 60072
                  }
                  if ((label | 0) == 16677) {
                   while (1) {
                    label = 0; //@line 60076
                    if (!(($4508 << 24 >> 24 | 0) == 13 | ($4508 << 24 >> 24 | 0) == 32 | ($4508 << 24 >> 24 | 0) == 9 | ($4508 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4509 = $i_0_i_i3584 + 1 | 0; //@line 60082
                    $i_0_i_i3584 = $4509;
                    $4508 = HEAP8[$cmd + 4 + $4509 | 0] | 0;
                    label = 16677; //@line 60087
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i3584; //@line 60090
                   if ((HEAP8[$cmd + 4 + $i_0_i_i3584 | 0] | 0) != 33) {
                    break;
                   }
                   if ((HEAP8[$i_0_i_i3584 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1814 = 2;
                    $storemerge4175_in = $i_0_i_i3584;
                   } else {
                    break;
                   }
                  }
                  HEAP32[$1 >> 2] = $storemerge4175_in + 2; //@line 60109
                  if ((_cmd_match_expr_cmp($cmd, $val2_i1813, $base) | 0) == 0) {
                   label = 16682; //@line 60114
                   break L21439;
                  }
                  if (($op_0_i1814 | 0) == 1) {
                   HEAP32[$val2_i784 >> 2] = (HEAP32[$val2_i784 >> 2] | 0) == (HEAP32[$val2_i1813 >> 2] | 0); //@line 60122
                   continue;
                  } else if (($op_0_i1814 | 0) == 2) {
                   HEAP32[$val2_i784 >> 2] = (HEAP32[$val2_i784 >> 2] | 0) != (HEAP32[$val2_i1813 >> 2] | 0); //@line 60130
                   continue;
                  } else {
                   continue;
                  }
                 }
                 HEAP32[$val2_i104 >> 2] = HEAP32[$val2_i784 >> 2] & HEAP32[$val2_i104 >> 2]; //@line 60140
                 $4471 = $i_0_i_i3584; //@line 60142
                }
                if ((label | 0) == 17222) {
                 label = 0; //@line 60145
                 HEAP32[$1 >> 2] = $4471; //@line 60146
                 $i_0_i_i_i549 = $4471; //@line 60148
                }
                while (1) {
                 $4534 = $cmd + 4 + $i_0_i_i_i549 | 0; //@line 60152
                 $4535 = HEAP8[$4534] | 0; //@line 60153
                 if (($4535 << 24 >> 24 | 0) == 13 | ($4535 << 24 >> 24 | 0) == 32 | ($4535 << 24 >> 24 | 0) == 9 | ($4535 << 24 >> 24 | 0) == 10) {
                  $i_0_i_i_i549 = $i_0_i_i_i549 + 1 | 0; //@line 60157
                  continue;
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i_i549; //@line 60160
                 if ((HEAP8[$4534] | 0) != 94) {
                  $4648 = $i_0_i_i_i549; //@line 60164
                  break;
                 }
                 $4541 = $i_0_i_i_i549 + 1 | 0; //@line 60167
                 HEAP32[$1 >> 2] = $4541; //@line 60168
                 if ((_cmd_match_expr_cmp($cmd, $val2_i548, $base) | 0) == 0) {
                  label = 16731; //@line 60173
                  break L21439;
                 }
                 while (1) {
                  $4546 = HEAP32[$1 >> 2] | 0; //@line 60179
                  while (1) {
                   $4547 = $cmd + 4 + $4546 | 0; //@line 60182
                   $4548 = HEAP8[$4547] | 0; //@line 60183
                   if (!(($4548 << 24 >> 24 | 0) == 13 | ($4548 << 24 >> 24 | 0) == 32 | ($4548 << 24 >> 24 | 0) == 9 | ($4548 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4546 = $4546 + 1 | 0; //@line 60189
                  }
                  HEAP32[$1 >> 2] = $4546; //@line 60191
                  $4551 = HEAP8[$4547] | 0; //@line 60192
                  if ($4551 << 24 >> 24 == 61) {
                   if ((HEAP8[$4546 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1818 = 1;
                    $storemerge4174_in = $4546;
                   } else {
                    $i_0_i_i3604 = $4546;
                    $4558 = 61;
                    label = 16697; //@line 60203
                   }
                  } else {
                   $i_0_i_i3604 = $4546;
                   $4558 = $4551;
                   label = 16697; //@line 60207
                  }
                  if ((label | 0) == 16697) {
                   while (1) {
                    label = 0; //@line 60211
                    if (!(($4558 << 24 >> 24 | 0) == 13 | ($4558 << 24 >> 24 | 0) == 32 | ($4558 << 24 >> 24 | 0) == 9 | ($4558 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4559 = $i_0_i_i3604 + 1 | 0; //@line 60217
                    $i_0_i_i3604 = $4559;
                    $4558 = HEAP8[$cmd + 4 + $4559 | 0] | 0;
                    label = 16697; //@line 60222
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i3604; //@line 60225
                   if ((HEAP8[$cmd + 4 + $i_0_i_i3604 | 0] | 0) != 33) {
                    $4581 = $i_0_i_i3604; //@line 60229
                    break;
                   }
                   if ((HEAP8[$i_0_i_i3604 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1818 = 2;
                    $storemerge4174_in = $i_0_i_i3604;
                   } else {
                    $4581 = $i_0_i_i3604; //@line 60239
                    break;
                   }
                  }
                  HEAP32[$1 >> 2] = $storemerge4174_in + 2; //@line 60246
                  if ((_cmd_match_expr_cmp($cmd, $val2_i1817, $base) | 0) == 0) {
                   label = 16702; //@line 60251
                   break L21439;
                  }
                  if (($op_0_i1818 | 0) == 1) {
                   HEAP32[$val2_i548 >> 2] = (HEAP32[$val2_i548 >> 2] | 0) == (HEAP32[$val2_i1817 >> 2] | 0); //@line 60259
                   continue;
                  } else if (($op_0_i1818 | 0) == 2) {
                   HEAP32[$val2_i548 >> 2] = (HEAP32[$val2_i548 >> 2] | 0) != (HEAP32[$val2_i1817 >> 2] | 0); //@line 60267
                   continue;
                  } else {
                   continue;
                  }
                 }
                 while (1) {
                  $4583 = $4581; //@line 60277
                  while (1) {
                   $4584 = $cmd + 4 + $4583 | 0; //@line 60280
                   $4585 = HEAP8[$4584] | 0; //@line 60281
                   if (!(($4585 << 24 >> 24 | 0) == 13 | ($4585 << 24 >> 24 | 0) == 32 | ($4585 << 24 >> 24 | 0) == 9 | ($4585 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4583 = $4583 + 1 | 0; //@line 60287
                  }
                  HEAP32[$1 >> 2] = $4583; //@line 60289
                  $4588 = HEAP8[$4584] | 0; //@line 60290
                  if ($4588 << 24 >> 24 == 38) {
                   if ((HEAP8[$4583 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                    label = 17223; //@line 60298
                    break;
                   } else {
                    $i_0_i_i1830 = $4583;
                    $4595 = 38;
                   }
                  } else {
                   $i_0_i_i1830 = $4583;
                   $4595 = $4588;
                  }
                  while (1) {
                   if (!(($4595 << 24 >> 24 | 0) == 13 | ($4595 << 24 >> 24 | 0) == 32 | ($4595 << 24 >> 24 | 0) == 9 | ($4595 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4596 = $i_0_i_i1830 + 1 | 0; //@line 60312
                   $i_0_i_i1830 = $4596;
                   $4595 = HEAP8[$cmd + 4 + $4596 | 0] | 0;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i1830; //@line 60319
                  if ((HEAP8[$cmd + 4 + $i_0_i_i1830 | 0] | 0) != 38) {
                   $4644 = $i_0_i_i1830; //@line 60323
                   break;
                  }
                  $4601 = $i_0_i_i1830 + 1 | 0; //@line 60326
                  HEAP32[$1 >> 2] = $4601; //@line 60327
                  if ((_cmd_match_expr_cmp($cmd, $val2_i787, $base) | 0) == 0) {
                   label = 16729; //@line 60332
                   break L21439;
                  }
                  while (1) {
                   $4606 = HEAP32[$1 >> 2] | 0; //@line 60338
                   while (1) {
                    $4607 = $cmd + 4 + $4606 | 0; //@line 60341
                    $4608 = HEAP8[$4607] | 0; //@line 60342
                    if (!(($4608 << 24 >> 24 | 0) == 13 | ($4608 << 24 >> 24 | 0) == 32 | ($4608 << 24 >> 24 | 0) == 9 | ($4608 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4606 = $4606 + 1 | 0; //@line 60348
                   }
                   HEAP32[$1 >> 2] = $4606; //@line 60350
                   $4611 = HEAP8[$4607] | 0; //@line 60351
                   if ($4611 << 24 >> 24 == 61) {
                    if ((HEAP8[$4606 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1841 = 1;
                     $storemerge4173_in = $4606;
                    } else {
                     $i_0_i_i3624 = $4606;
                     $4618 = 61;
                     label = 16720; //@line 60362
                    }
                   } else {
                    $i_0_i_i3624 = $4606;
                    $4618 = $4611;
                    label = 16720; //@line 60366
                   }
                   if ((label | 0) == 16720) {
                    while (1) {
                     label = 0; //@line 60370
                     if (!(($4618 << 24 >> 24 | 0) == 13 | ($4618 << 24 >> 24 | 0) == 32 | ($4618 << 24 >> 24 | 0) == 9 | ($4618 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $4619 = $i_0_i_i3624 + 1 | 0; //@line 60376
                     $i_0_i_i3624 = $4619;
                     $4618 = HEAP8[$cmd + 4 + $4619 | 0] | 0;
                     label = 16720; //@line 60381
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3624; //@line 60384
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3624 | 0] | 0) != 33) {
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3624 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1841 = 2;
                     $storemerge4173_in = $i_0_i_i3624;
                    } else {
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4173_in + 2; //@line 60403
                   if ((_cmd_match_expr_cmp($cmd, $val2_i1840, $base) | 0) == 0) {
                    label = 16725; //@line 60408
                    break L21439;
                   }
                   if (($op_0_i1841 | 0) == 1) {
                    HEAP32[$val2_i787 >> 2] = (HEAP32[$val2_i787 >> 2] | 0) == (HEAP32[$val2_i1840 >> 2] | 0); //@line 60416
                    continue;
                   } else if (($op_0_i1841 | 0) == 2) {
                    HEAP32[$val2_i787 >> 2] = (HEAP32[$val2_i787 >> 2] | 0) != (HEAP32[$val2_i1840 >> 2] | 0); //@line 60424
                    continue;
                   } else {
                    continue;
                   }
                  }
                  HEAP32[$val2_i548 >> 2] = HEAP32[$val2_i787 >> 2] & HEAP32[$val2_i548 >> 2]; //@line 60434
                  $4581 = $i_0_i_i3624; //@line 60436
                 }
                 if ((label | 0) == 17223) {
                  label = 0; //@line 60439
                  HEAP32[$1 >> 2] = $4581; //@line 60440
                  $4644 = $4581; //@line 60442
                 }
                 HEAP32[$val2_i104 >> 2] = HEAP32[$val2_i548 >> 2] ^ HEAP32[$val2_i104 >> 2]; //@line 60448
                 $i_0_i_i_i549 = $4644; //@line 60450
                }
                while (1) {
                 $4650 = $4648; //@line 60455
                 while (1) {
                  $4651 = $cmd + 4 + $4650 | 0; //@line 60458
                  $4652 = HEAP8[$4651] | 0; //@line 60459
                  if (!(($4652 << 24 >> 24 | 0) == 13 | ($4652 << 24 >> 24 | 0) == 32 | ($4652 << 24 >> 24 | 0) == 9 | ($4652 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4650 = $4650 + 1 | 0; //@line 60465
                 }
                 HEAP32[$1 >> 2] = $4650; //@line 60467
                 $4655 = HEAP8[$4651] | 0; //@line 60468
                 if ($4655 << 24 >> 24 == 124) {
                  if ((HEAP8[$4650 + 1 + ($cmd + 4) | 0] | 0) == 124) {
                   label = 17224; //@line 60476
                   break;
                  } else {
                   $i_0_i_i569 = $4650;
                   $4662 = 124;
                  }
                 } else {
                  $i_0_i_i569 = $4650;
                  $4662 = $4655;
                 }
                 while (1) {
                  if (!(($4662 << 24 >> 24 | 0) == 13 | ($4662 << 24 >> 24 | 0) == 32 | ($4662 << 24 >> 24 | 0) == 9 | ($4662 << 24 >> 24 | 0) == 10)) {
                   break;
                  }
                  $4663 = $i_0_i_i569 + 1 | 0; //@line 60490
                  $i_0_i_i569 = $4663;
                  $4662 = HEAP8[$cmd + 4 + $4663 | 0] | 0;
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i569; //@line 60497
                 if ((HEAP8[$cmd + 4 + $i_0_i_i569 | 0] | 0) != 124) {
                  $4889 = $i_0_i_i569; //@line 60501
                  break;
                 }
                 $4668 = $i_0_i_i569 + 1 | 0; //@line 60504
                 HEAP32[$1 >> 2] = $4668; //@line 60505
                 if ((_cmd_match_expr_cmp($cmd, $val2_i156, $base) | 0) == 0) {
                  label = 16826; //@line 60510
                  break L21439;
                 }
                 while (1) {
                  $4673 = HEAP32[$1 >> 2] | 0; //@line 60516
                  while (1) {
                   $4674 = $cmd + 4 + $4673 | 0; //@line 60519
                   $4675 = HEAP8[$4674] | 0; //@line 60520
                   if (!(($4675 << 24 >> 24 | 0) == 13 | ($4675 << 24 >> 24 | 0) == 32 | ($4675 << 24 >> 24 | 0) == 9 | ($4675 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4673 = $4673 + 1 | 0; //@line 60526
                  }
                  HEAP32[$1 >> 2] = $4673; //@line 60528
                  $4678 = HEAP8[$4674] | 0; //@line 60529
                  if ($4678 << 24 >> 24 == 61) {
                   if ((HEAP8[$4673 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1845 = 1;
                    $storemerge4172_in = $4673;
                   } else {
                    $i_0_i_i3644 = $4673;
                    $4685 = 61;
                    label = 16747; //@line 60540
                   }
                  } else {
                   $i_0_i_i3644 = $4673;
                   $4685 = $4678;
                   label = 16747; //@line 60544
                  }
                  if ((label | 0) == 16747) {
                   while (1) {
                    label = 0; //@line 60548
                    if (!(($4685 << 24 >> 24 | 0) == 13 | ($4685 << 24 >> 24 | 0) == 32 | ($4685 << 24 >> 24 | 0) == 9 | ($4685 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4686 = $i_0_i_i3644 + 1 | 0; //@line 60554
                    $i_0_i_i3644 = $4686;
                    $4685 = HEAP8[$cmd + 4 + $4686 | 0] | 0;
                    label = 16747; //@line 60559
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i3644; //@line 60562
                   if ((HEAP8[$cmd + 4 + $i_0_i_i3644 | 0] | 0) != 33) {
                    $4708 = $i_0_i_i3644; //@line 60566
                    break;
                   }
                   if ((HEAP8[$i_0_i_i3644 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1845 = 2;
                    $storemerge4172_in = $i_0_i_i3644;
                   } else {
                    $4708 = $i_0_i_i3644; //@line 60576
                    break;
                   }
                  }
                  HEAP32[$1 >> 2] = $storemerge4172_in + 2; //@line 60583
                  if ((_cmd_match_expr_cmp($cmd, $val2_i1844, $base) | 0) == 0) {
                   label = 16752; //@line 60588
                   break L21439;
                  }
                  if (($op_0_i1845 | 0) == 1) {
                   HEAP32[$val2_i156 >> 2] = (HEAP32[$val2_i156 >> 2] | 0) == (HEAP32[$val2_i1844 >> 2] | 0); //@line 60596
                   continue;
                  } else if (($op_0_i1845 | 0) == 2) {
                   HEAP32[$val2_i156 >> 2] = (HEAP32[$val2_i156 >> 2] | 0) != (HEAP32[$val2_i1844 >> 2] | 0); //@line 60604
                   continue;
                  } else {
                   continue;
                  }
                 }
                 while (1) {
                  $4710 = $4708; //@line 60614
                  while (1) {
                   $4711 = $cmd + 4 + $4710 | 0; //@line 60617
                   $4712 = HEAP8[$4711] | 0; //@line 60618
                   if (!(($4712 << 24 >> 24 | 0) == 13 | ($4712 << 24 >> 24 | 0) == 32 | ($4712 << 24 >> 24 | 0) == 9 | ($4712 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4710 = $4710 + 1 | 0; //@line 60624
                  }
                  HEAP32[$1 >> 2] = $4710; //@line 60626
                  $4715 = HEAP8[$4711] | 0; //@line 60627
                  if ($4715 << 24 >> 24 == 38) {
                   if ((HEAP8[$4710 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                    label = 17225; //@line 60635
                    break;
                   } else {
                    $i_0_i_i1857 = $4710;
                    $4722 = 38;
                   }
                  } else {
                   $i_0_i_i1857 = $4710;
                   $4722 = $4715;
                  }
                  while (1) {
                   if (!(($4722 << 24 >> 24 | 0) == 13 | ($4722 << 24 >> 24 | 0) == 32 | ($4722 << 24 >> 24 | 0) == 9 | ($4722 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4723 = $i_0_i_i1857 + 1 | 0; //@line 60649
                   $i_0_i_i1857 = $4723;
                   $4722 = HEAP8[$cmd + 4 + $4723 | 0] | 0;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i1857; //@line 60656
                  if ((HEAP8[$cmd + 4 + $i_0_i_i1857 | 0] | 0) != 38) {
                   $i_0_i_i_i580 = $i_0_i_i1857; //@line 60660
                   break;
                  }
                  $4728 = $i_0_i_i1857 + 1 | 0; //@line 60663
                  HEAP32[$1 >> 2] = $4728; //@line 60664
                  if ((_cmd_match_expr_cmp($cmd, $val2_i790, $base) | 0) == 0) {
                   label = 16779; //@line 60669
                   break L21439;
                  }
                  while (1) {
                   $4733 = HEAP32[$1 >> 2] | 0; //@line 60675
                   while (1) {
                    $4734 = $cmd + 4 + $4733 | 0; //@line 60678
                    $4735 = HEAP8[$4734] | 0; //@line 60679
                    if (!(($4735 << 24 >> 24 | 0) == 13 | ($4735 << 24 >> 24 | 0) == 32 | ($4735 << 24 >> 24 | 0) == 9 | ($4735 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4733 = $4733 + 1 | 0; //@line 60685
                   }
                   HEAP32[$1 >> 2] = $4733; //@line 60687
                   $4738 = HEAP8[$4734] | 0; //@line 60688
                   if ($4738 << 24 >> 24 == 61) {
                    if ((HEAP8[$4733 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1868 = 1;
                     $storemerge4171_in = $4733;
                    } else {
                     $i_0_i_i3664 = $4733;
                     $4745 = 61;
                     label = 16770; //@line 60699
                    }
                   } else {
                    $i_0_i_i3664 = $4733;
                    $4745 = $4738;
                    label = 16770; //@line 60703
                   }
                   if ((label | 0) == 16770) {
                    while (1) {
                     label = 0; //@line 60707
                     if (!(($4745 << 24 >> 24 | 0) == 13 | ($4745 << 24 >> 24 | 0) == 32 | ($4745 << 24 >> 24 | 0) == 9 | ($4745 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $4746 = $i_0_i_i3664 + 1 | 0; //@line 60713
                     $i_0_i_i3664 = $4746;
                     $4745 = HEAP8[$cmd + 4 + $4746 | 0] | 0;
                     label = 16770; //@line 60718
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3664; //@line 60721
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3664 | 0] | 0) != 33) {
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3664 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1868 = 2;
                     $storemerge4171_in = $i_0_i_i3664;
                    } else {
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4171_in + 2; //@line 60740
                   if ((_cmd_match_expr_cmp($cmd, $val2_i1867, $base) | 0) == 0) {
                    label = 16775; //@line 60745
                    break L21439;
                   }
                   if (($op_0_i1868 | 0) == 1) {
                    HEAP32[$val2_i790 >> 2] = (HEAP32[$val2_i790 >> 2] | 0) == (HEAP32[$val2_i1867 >> 2] | 0); //@line 60753
                    continue;
                   } else if (($op_0_i1868 | 0) == 2) {
                    HEAP32[$val2_i790 >> 2] = (HEAP32[$val2_i790 >> 2] | 0) != (HEAP32[$val2_i1867 >> 2] | 0); //@line 60761
                    continue;
                   } else {
                    continue;
                   }
                  }
                  HEAP32[$val2_i156 >> 2] = HEAP32[$val2_i790 >> 2] & HEAP32[$val2_i156 >> 2]; //@line 60771
                  $4708 = $i_0_i_i3664; //@line 60773
                 }
                 if ((label | 0) == 17225) {
                  label = 0; //@line 60776
                  HEAP32[$1 >> 2] = $4708; //@line 60777
                  $i_0_i_i_i580 = $4708; //@line 60779
                 }
                 while (1) {
                  $4771 = $cmd + 4 + $i_0_i_i_i580 | 0; //@line 60783
                  $4772 = HEAP8[$4771] | 0; //@line 60784
                  if (($4772 << 24 >> 24 | 0) == 13 | ($4772 << 24 >> 24 | 0) == 32 | ($4772 << 24 >> 24 | 0) == 9 | ($4772 << 24 >> 24 | 0) == 10) {
                   $i_0_i_i_i580 = $i_0_i_i_i580 + 1 | 0; //@line 60788
                   continue;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i_i580; //@line 60791
                  if ((HEAP8[$4771] | 0) != 94) {
                   break;
                  }
                  $4778 = $i_0_i_i_i580 + 1 | 0; //@line 60797
                  HEAP32[$1 >> 2] = $4778; //@line 60798
                  if ((_cmd_match_expr_cmp($cmd, $val2_i579, $base) | 0) == 0) {
                   label = 16824; //@line 60803
                   break L21439;
                  }
                  while (1) {
                   $4783 = HEAP32[$1 >> 2] | 0; //@line 60809
                   while (1) {
                    $4784 = $cmd + 4 + $4783 | 0; //@line 60812
                    $4785 = HEAP8[$4784] | 0; //@line 60813
                    if (!(($4785 << 24 >> 24 | 0) == 13 | ($4785 << 24 >> 24 | 0) == 32 | ($4785 << 24 >> 24 | 0) == 9 | ($4785 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4783 = $4783 + 1 | 0; //@line 60819
                   }
                   HEAP32[$1 >> 2] = $4783; //@line 60821
                   $4788 = HEAP8[$4784] | 0; //@line 60822
                   if ($4788 << 24 >> 24 == 61) {
                    if ((HEAP8[$4783 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1872 = 1;
                     $storemerge4170_in = $4783;
                    } else {
                     $i_0_i_i3684 = $4783;
                     $4795 = 61;
                     label = 16790; //@line 60833
                    }
                   } else {
                    $i_0_i_i3684 = $4783;
                    $4795 = $4788;
                    label = 16790; //@line 60837
                   }
                   if ((label | 0) == 16790) {
                    while (1) {
                     label = 0; //@line 60841
                     if (!(($4795 << 24 >> 24 | 0) == 13 | ($4795 << 24 >> 24 | 0) == 32 | ($4795 << 24 >> 24 | 0) == 9 | ($4795 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $4796 = $i_0_i_i3684 + 1 | 0; //@line 60847
                     $i_0_i_i3684 = $4796;
                     $4795 = HEAP8[$cmd + 4 + $4796 | 0] | 0;
                     label = 16790; //@line 60852
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3684; //@line 60855
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3684 | 0] | 0) != 33) {
                     $4818 = $i_0_i_i3684; //@line 60859
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3684 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1872 = 2;
                     $storemerge4170_in = $i_0_i_i3684;
                    } else {
                     $4818 = $i_0_i_i3684; //@line 60869
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4170_in + 2; //@line 60876
                   if ((_cmd_match_expr_cmp($cmd, $val2_i1871, $base) | 0) == 0) {
                    label = 16795; //@line 60881
                    break L21439;
                   }
                   if (($op_0_i1872 | 0) == 1) {
                    HEAP32[$val2_i579 >> 2] = (HEAP32[$val2_i579 >> 2] | 0) == (HEAP32[$val2_i1871 >> 2] | 0); //@line 60889
                    continue;
                   } else if (($op_0_i1872 | 0) == 2) {
                    HEAP32[$val2_i579 >> 2] = (HEAP32[$val2_i579 >> 2] | 0) != (HEAP32[$val2_i1871 >> 2] | 0); //@line 60897
                    continue;
                   } else {
                    continue;
                   }
                  }
                  while (1) {
                   $4820 = $4818; //@line 60907
                   while (1) {
                    $4821 = $cmd + 4 + $4820 | 0; //@line 60910
                    $4822 = HEAP8[$4821] | 0; //@line 60911
                    if (!(($4822 << 24 >> 24 | 0) == 13 | ($4822 << 24 >> 24 | 0) == 32 | ($4822 << 24 >> 24 | 0) == 9 | ($4822 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4820 = $4820 + 1 | 0; //@line 60917
                   }
                   HEAP32[$1 >> 2] = $4820; //@line 60919
                   $4825 = HEAP8[$4821] | 0; //@line 60920
                   if ($4825 << 24 >> 24 == 38) {
                    if ((HEAP8[$4820 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                     label = 17226; //@line 60928
                     break;
                    } else {
                     $i_0_i_i1884 = $4820;
                     $4832 = 38;
                    }
                   } else {
                    $i_0_i_i1884 = $4820;
                    $4832 = $4825;
                   }
                   while (1) {
                    if (!(($4832 << 24 >> 24 | 0) == 13 | ($4832 << 24 >> 24 | 0) == 32 | ($4832 << 24 >> 24 | 0) == 9 | ($4832 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4833 = $i_0_i_i1884 + 1 | 0; //@line 60942
                    $i_0_i_i1884 = $4833;
                    $4832 = HEAP8[$cmd + 4 + $4833 | 0] | 0;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i1884; //@line 60949
                   if ((HEAP8[$cmd + 4 + $i_0_i_i1884 | 0] | 0) != 38) {
                    $4881 = $i_0_i_i1884; //@line 60953
                    break;
                   }
                   $4838 = $i_0_i_i1884 + 1 | 0; //@line 60956
                   HEAP32[$1 >> 2] = $4838; //@line 60957
                   if ((_cmd_match_expr_cmp($cmd, $val2_i793, $base) | 0) == 0) {
                    label = 16822; //@line 60962
                    break L21439;
                   }
                   while (1) {
                    $4843 = HEAP32[$1 >> 2] | 0; //@line 60968
                    while (1) {
                     $4844 = $cmd + 4 + $4843 | 0; //@line 60971
                     $4845 = HEAP8[$4844] | 0; //@line 60972
                     if (!(($4845 << 24 >> 24 | 0) == 13 | ($4845 << 24 >> 24 | 0) == 32 | ($4845 << 24 >> 24 | 0) == 9 | ($4845 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $4843 = $4843 + 1 | 0; //@line 60978
                    }
                    HEAP32[$1 >> 2] = $4843; //@line 60980
                    $4848 = HEAP8[$4844] | 0; //@line 60981
                    if ($4848 << 24 >> 24 == 61) {
                     if ((HEAP8[$4843 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1895 = 1;
                      $storemerge4169_in = $4843;
                     } else {
                      $i_0_i_i3704 = $4843;
                      $4855 = 61;
                      label = 16813; //@line 60992
                     }
                    } else {
                     $i_0_i_i3704 = $4843;
                     $4855 = $4848;
                     label = 16813; //@line 60996
                    }
                    if ((label | 0) == 16813) {
                     while (1) {
                      label = 0; //@line 61000
                      if (!(($4855 << 24 >> 24 | 0) == 13 | ($4855 << 24 >> 24 | 0) == 32 | ($4855 << 24 >> 24 | 0) == 9 | ($4855 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $4856 = $i_0_i_i3704 + 1 | 0; //@line 61006
                      $i_0_i_i3704 = $4856;
                      $4855 = HEAP8[$cmd + 4 + $4856 | 0] | 0;
                      label = 16813; //@line 61011
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3704; //@line 61014
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3704 | 0] | 0) != 33) {
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3704 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1895 = 2;
                      $storemerge4169_in = $i_0_i_i3704;
                     } else {
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4169_in + 2; //@line 61033
                    if ((_cmd_match_expr_cmp($cmd, $val2_i1894, $base) | 0) == 0) {
                     label = 16818; //@line 61038
                     break L21439;
                    }
                    if (($op_0_i1895 | 0) == 1) {
                     HEAP32[$val2_i793 >> 2] = (HEAP32[$val2_i793 >> 2] | 0) == (HEAP32[$val2_i1894 >> 2] | 0); //@line 61046
                     continue;
                    } else if (($op_0_i1895 | 0) == 2) {
                     HEAP32[$val2_i793 >> 2] = (HEAP32[$val2_i793 >> 2] | 0) != (HEAP32[$val2_i1894 >> 2] | 0); //@line 61054
                     continue;
                    } else {
                     continue;
                    }
                   }
                   HEAP32[$val2_i579 >> 2] = HEAP32[$val2_i793 >> 2] & HEAP32[$val2_i579 >> 2]; //@line 61064
                   $4818 = $i_0_i_i3704; //@line 61066
                  }
                  if ((label | 0) == 17226) {
                   label = 0; //@line 61069
                   HEAP32[$1 >> 2] = $4818; //@line 61070
                   $4881 = $4818; //@line 61072
                  }
                  HEAP32[$val2_i156 >> 2] = HEAP32[$val2_i579 >> 2] ^ HEAP32[$val2_i156 >> 2]; //@line 61078
                  $i_0_i_i_i580 = $4881; //@line 61080
                 }
                 HEAP32[$val2_i104 >> 2] = HEAP32[$val2_i156 >> 2] | HEAP32[$val2_i104 >> 2]; //@line 61085
                 $4648 = $i_0_i_i_i580; //@line 61087
                }
                if ((label | 0) == 17224) {
                 label = 0; //@line 61090
                 HEAP32[$1 >> 2] = $4648; //@line 61091
                 $4889 = $4648; //@line 61093
                }
                if ((HEAP32[$val3 >> 2] | 0) == 0) {
                 $4896 = 0; //@line 61100
                } else {
                 $4896 = (HEAP32[$val2_i104 >> 2] | 0) != 0 | 0; //@line 61105
                }
                HEAP32[$val3 >> 2] = $4896; //@line 61108
                $i_0_i_i_i105 = $4889; //@line 61110
               }
               if ((label | 0) == 16647) {
                $i_0_i_i_i41 = $i_0_i_i_i105; //@line 61145
                L21698 : while (1) {
                 $4897 = $cmd + 4 + $i_0_i_i_i41 | 0; //@line 61148
                 $4898 = HEAP8[$4897] | 0; //@line 61149
                 if (($4898 << 24 >> 24 | 0) == 13 | ($4898 << 24 >> 24 | 0) == 32 | ($4898 << 24 >> 24 | 0) == 9 | ($4898 << 24 >> 24 | 0) == 10) {
                  $i_0_i_i_i41 = $i_0_i_i_i41 + 1 | 0; //@line 61153
                  continue;
                 }
                 HEAP32[$1 >> 2] = $i_0_i_i_i41; //@line 61156
                 if ((HEAP8[$4897] | 0) != 124) {
                  label = 17207; //@line 61160
                  break;
                 }
                 if ((HEAP8[$i_0_i_i_i41 + 1 + ($cmd + 4) | 0] | 0) != 124) {
                  label = 17207; //@line 61168
                  break;
                 }
                 $5849 = $i_0_i_i_i41 + 2 | 0; //@line 61171
                 HEAP32[$1 >> 2] = $5849; //@line 61172
                 if ((_cmd_match_expr_cmp($cmd, $val2_i40, $base) | 0) == 0) {
                  break;
                 }
                 while (1) {
                  $4909 = HEAP32[$1 >> 2] | 0; //@line 61182
                  while (1) {
                   $4910 = $cmd + 4 + $4909 | 0; //@line 61185
                   $4911 = HEAP8[$4910] | 0; //@line 61186
                   if (!(($4911 << 24 >> 24 | 0) == 13 | ($4911 << 24 >> 24 | 0) == 32 | ($4911 << 24 >> 24 | 0) == 9 | ($4911 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4909 = $4909 + 1 | 0; //@line 61192
                  }
                  HEAP32[$1 >> 2] = $4909; //@line 61194
                  $4914 = HEAP8[$4910] | 0; //@line 61195
                  if ($4914 << 24 >> 24 == 61) {
                   if ((HEAP8[$4909 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1899 = 1;
                    $storemerge4168_in = $4909;
                   } else {
                    $i_0_i_i3724 = $4909;
                    $4921 = 61;
                    label = 16841; //@line 61206
                   }
                  } else {
                   $i_0_i_i3724 = $4909;
                   $4921 = $4914;
                   label = 16841; //@line 61210
                  }
                  if ((label | 0) == 16841) {
                   while (1) {
                    label = 0; //@line 61214
                    if (!(($4921 << 24 >> 24 | 0) == 13 | ($4921 << 24 >> 24 | 0) == 32 | ($4921 << 24 >> 24 | 0) == 9 | ($4921 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4922 = $i_0_i_i3724 + 1 | 0; //@line 61220
                    $i_0_i_i3724 = $4922;
                    $4921 = HEAP8[$cmd + 4 + $4922 | 0] | 0;
                    label = 16841; //@line 61225
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i3724; //@line 61228
                   if ((HEAP8[$cmd + 4 + $i_0_i_i3724 | 0] | 0) != 33) {
                    $4944 = $i_0_i_i3724; //@line 61232
                    break;
                   }
                   if ((HEAP8[$i_0_i_i3724 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                    $op_0_i1899 = 2;
                    $storemerge4168_in = $i_0_i_i3724;
                   } else {
                    $4944 = $i_0_i_i3724; //@line 61242
                    break;
                   }
                  }
                  HEAP32[$1 >> 2] = $storemerge4168_in + 2; //@line 61249
                  if ((_cmd_match_expr_cmp($cmd, $val2_i1898, $base) | 0) == 0) {
                   label = 16846; //@line 61254
                   break L21698;
                  }
                  if (($op_0_i1899 | 0) == 1) {
                   HEAP32[$val2_i40 >> 2] = (HEAP32[$val2_i40 >> 2] | 0) == (HEAP32[$val2_i1898 >> 2] | 0); //@line 61262
                   continue;
                  } else if (($op_0_i1899 | 0) == 2) {
                   HEAP32[$val2_i40 >> 2] = (HEAP32[$val2_i40 >> 2] | 0) != (HEAP32[$val2_i1898 >> 2] | 0); //@line 61270
                   continue;
                  } else {
                   continue;
                  }
                 }
                 while (1) {
                  $4946 = $4944; //@line 61280
                  while (1) {
                   $4947 = $cmd + 4 + $4946 | 0; //@line 61283
                   $4948 = HEAP8[$4947] | 0; //@line 61284
                   if (!(($4948 << 24 >> 24 | 0) == 13 | ($4948 << 24 >> 24 | 0) == 32 | ($4948 << 24 >> 24 | 0) == 9 | ($4948 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4946 = $4946 + 1 | 0; //@line 61290
                  }
                  HEAP32[$1 >> 2] = $4946; //@line 61292
                  $4951 = HEAP8[$4947] | 0; //@line 61293
                  if ($4951 << 24 >> 24 == 38) {
                   if ((HEAP8[$4946 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                    label = 17210; //@line 61301
                    break;
                   } else {
                    $i_0_i_i1911 = $4946;
                    $4958 = 38;
                   }
                  } else {
                   $i_0_i_i1911 = $4946;
                   $4958 = $4951;
                  }
                  while (1) {
                   if (!(($4958 << 24 >> 24 | 0) == 13 | ($4958 << 24 >> 24 | 0) == 32 | ($4958 << 24 >> 24 | 0) == 9 | ($4958 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $4959 = $i_0_i_i1911 + 1 | 0; //@line 61315
                   $i_0_i_i1911 = $4959;
                   $4958 = HEAP8[$cmd + 4 + $4959 | 0] | 0;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i1911; //@line 61322
                  if ((HEAP8[$cmd + 4 + $i_0_i_i1911 | 0] | 0) != 38) {
                   $i_0_i_i_i592 = $i_0_i_i1911; //@line 61326
                   break;
                  }
                  $4964 = $i_0_i_i1911 + 1 | 0; //@line 61329
                  HEAP32[$1 >> 2] = $4964; //@line 61330
                  if ((_cmd_match_expr_cmp($cmd, $val2_i796, $base) | 0) == 0) {
                   label = 16873; //@line 61335
                   break L21698;
                  }
                  while (1) {
                   $4969 = HEAP32[$1 >> 2] | 0; //@line 61341
                   while (1) {
                    $4970 = $cmd + 4 + $4969 | 0; //@line 61344
                    $4971 = HEAP8[$4970] | 0; //@line 61345
                    if (!(($4971 << 24 >> 24 | 0) == 13 | ($4971 << 24 >> 24 | 0) == 32 | ($4971 << 24 >> 24 | 0) == 9 | ($4971 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $4969 = $4969 + 1 | 0; //@line 61351
                   }
                   HEAP32[$1 >> 2] = $4969; //@line 61353
                   $4974 = HEAP8[$4970] | 0; //@line 61354
                   if ($4974 << 24 >> 24 == 61) {
                    if ((HEAP8[$4969 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1922 = 1;
                     $storemerge4167_in = $4969;
                    } else {
                     $i_0_i_i3744 = $4969;
                     $4981 = 61;
                     label = 16864; //@line 61365
                    }
                   } else {
                    $i_0_i_i3744 = $4969;
                    $4981 = $4974;
                    label = 16864; //@line 61369
                   }
                   if ((label | 0) == 16864) {
                    while (1) {
                     label = 0; //@line 61373
                     if (!(($4981 << 24 >> 24 | 0) == 13 | ($4981 << 24 >> 24 | 0) == 32 | ($4981 << 24 >> 24 | 0) == 9 | ($4981 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $4982 = $i_0_i_i3744 + 1 | 0; //@line 61379
                     $i_0_i_i3744 = $4982;
                     $4981 = HEAP8[$cmd + 4 + $4982 | 0] | 0;
                     label = 16864; //@line 61384
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3744; //@line 61387
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3744 | 0] | 0) != 33) {
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3744 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1922 = 2;
                     $storemerge4167_in = $i_0_i_i3744;
                    } else {
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4167_in + 2; //@line 61406
                   if ((_cmd_match_expr_cmp($cmd, $val2_i1921, $base) | 0) == 0) {
                    label = 16869; //@line 61411
                    break L21698;
                   }
                   if (($op_0_i1922 | 0) == 1) {
                    HEAP32[$val2_i796 >> 2] = (HEAP32[$val2_i796 >> 2] | 0) == (HEAP32[$val2_i1921 >> 2] | 0); //@line 61419
                    continue;
                   } else if (($op_0_i1922 | 0) == 2) {
                    HEAP32[$val2_i796 >> 2] = (HEAP32[$val2_i796 >> 2] | 0) != (HEAP32[$val2_i1921 >> 2] | 0); //@line 61427
                    continue;
                   } else {
                    continue;
                   }
                  }
                  HEAP32[$val2_i40 >> 2] = HEAP32[$val2_i796 >> 2] & HEAP32[$val2_i40 >> 2]; //@line 61437
                  $4944 = $i_0_i_i3744; //@line 61439
                 }
                 if ((label | 0) == 17210) {
                  label = 0; //@line 61442
                  HEAP32[$1 >> 2] = $4944; //@line 61443
                  $i_0_i_i_i592 = $4944; //@line 61445
                 }
                 while (1) {
                  $5007 = $cmd + 4 + $i_0_i_i_i592 | 0; //@line 61449
                  $5008 = HEAP8[$5007] | 0; //@line 61450
                  if (($5008 << 24 >> 24 | 0) == 13 | ($5008 << 24 >> 24 | 0) == 32 | ($5008 << 24 >> 24 | 0) == 9 | ($5008 << 24 >> 24 | 0) == 10) {
                   $i_0_i_i_i592 = $i_0_i_i_i592 + 1 | 0; //@line 61454
                   continue;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i_i592; //@line 61457
                  if ((HEAP8[$5007] | 0) != 94) {
                   $5121 = $i_0_i_i_i592; //@line 61461
                   break;
                  }
                  $5014 = $i_0_i_i_i592 + 1 | 0; //@line 61464
                  HEAP32[$1 >> 2] = $5014; //@line 61465
                  if ((_cmd_match_expr_cmp($cmd, $val2_i591, $base) | 0) == 0) {
                   label = 16918; //@line 61470
                   break L21698;
                  }
                  while (1) {
                   $5019 = HEAP32[$1 >> 2] | 0; //@line 61476
                   while (1) {
                    $5020 = $cmd + 4 + $5019 | 0; //@line 61479
                    $5021 = HEAP8[$5020] | 0; //@line 61480
                    if (!(($5021 << 24 >> 24 | 0) == 13 | ($5021 << 24 >> 24 | 0) == 32 | ($5021 << 24 >> 24 | 0) == 9 | ($5021 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5019 = $5019 + 1 | 0; //@line 61486
                   }
                   HEAP32[$1 >> 2] = $5019; //@line 61488
                   $5024 = HEAP8[$5020] | 0; //@line 61489
                   if ($5024 << 24 >> 24 == 61) {
                    if ((HEAP8[$5019 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1926 = 1;
                     $storemerge4166_in = $5019;
                    } else {
                     $i_0_i_i3764 = $5019;
                     $5031 = 61;
                     label = 16884; //@line 61500
                    }
                   } else {
                    $i_0_i_i3764 = $5019;
                    $5031 = $5024;
                    label = 16884; //@line 61504
                   }
                   if ((label | 0) == 16884) {
                    while (1) {
                     label = 0; //@line 61508
                     if (!(($5031 << 24 >> 24 | 0) == 13 | ($5031 << 24 >> 24 | 0) == 32 | ($5031 << 24 >> 24 | 0) == 9 | ($5031 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5032 = $i_0_i_i3764 + 1 | 0; //@line 61514
                     $i_0_i_i3764 = $5032;
                     $5031 = HEAP8[$cmd + 4 + $5032 | 0] | 0;
                     label = 16884; //@line 61519
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3764; //@line 61522
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3764 | 0] | 0) != 33) {
                     $5054 = $i_0_i_i3764; //@line 61526
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3764 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1926 = 2;
                     $storemerge4166_in = $i_0_i_i3764;
                    } else {
                     $5054 = $i_0_i_i3764; //@line 61536
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4166_in + 2; //@line 61543
                   if ((_cmd_match_expr_cmp($cmd, $val2_i1925, $base) | 0) == 0) {
                    label = 16889; //@line 61548
                    break L21698;
                   }
                   if (($op_0_i1926 | 0) == 1) {
                    HEAP32[$val2_i591 >> 2] = (HEAP32[$val2_i591 >> 2] | 0) == (HEAP32[$val2_i1925 >> 2] | 0); //@line 61556
                    continue;
                   } else if (($op_0_i1926 | 0) == 2) {
                    HEAP32[$val2_i591 >> 2] = (HEAP32[$val2_i591 >> 2] | 0) != (HEAP32[$val2_i1925 >> 2] | 0); //@line 61564
                    continue;
                   } else {
                    continue;
                   }
                  }
                  while (1) {
                   $5056 = $5054; //@line 61574
                   while (1) {
                    $5057 = $cmd + 4 + $5056 | 0; //@line 61577
                    $5058 = HEAP8[$5057] | 0; //@line 61578
                    if (!(($5058 << 24 >> 24 | 0) == 13 | ($5058 << 24 >> 24 | 0) == 32 | ($5058 << 24 >> 24 | 0) == 9 | ($5058 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5056 = $5056 + 1 | 0; //@line 61584
                   }
                   HEAP32[$1 >> 2] = $5056; //@line 61586
                   $5061 = HEAP8[$5057] | 0; //@line 61587
                   if ($5061 << 24 >> 24 == 38) {
                    if ((HEAP8[$5056 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                     label = 17211; //@line 61595
                     break;
                    } else {
                     $i_0_i_i1938 = $5056;
                     $5068 = 38;
                    }
                   } else {
                    $i_0_i_i1938 = $5056;
                    $5068 = $5061;
                   }
                   while (1) {
                    if (!(($5068 << 24 >> 24 | 0) == 13 | ($5068 << 24 >> 24 | 0) == 32 | ($5068 << 24 >> 24 | 0) == 9 | ($5068 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5069 = $i_0_i_i1938 + 1 | 0; //@line 61609
                    $i_0_i_i1938 = $5069;
                    $5068 = HEAP8[$cmd + 4 + $5069 | 0] | 0;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i1938; //@line 61616
                   if ((HEAP8[$cmd + 4 + $i_0_i_i1938 | 0] | 0) != 38) {
                    $5117 = $i_0_i_i1938; //@line 61620
                    break;
                   }
                   $5074 = $i_0_i_i1938 + 1 | 0; //@line 61623
                   HEAP32[$1 >> 2] = $5074; //@line 61624
                   if ((_cmd_match_expr_cmp($cmd, $val2_i799, $base) | 0) == 0) {
                    label = 16916; //@line 61629
                    break L21698;
                   }
                   while (1) {
                    $5079 = HEAP32[$1 >> 2] | 0; //@line 61635
                    while (1) {
                     $5080 = $cmd + 4 + $5079 | 0; //@line 61638
                     $5081 = HEAP8[$5080] | 0; //@line 61639
                     if (!(($5081 << 24 >> 24 | 0) == 13 | ($5081 << 24 >> 24 | 0) == 32 | ($5081 << 24 >> 24 | 0) == 9 | ($5081 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5079 = $5079 + 1 | 0; //@line 61645
                    }
                    HEAP32[$1 >> 2] = $5079; //@line 61647
                    $5084 = HEAP8[$5080] | 0; //@line 61648
                    if ($5084 << 24 >> 24 == 61) {
                     if ((HEAP8[$5079 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1949 = 1;
                      $storemerge4165_in = $5079;
                     } else {
                      $i_0_i_i3784 = $5079;
                      $5091 = 61;
                      label = 16907; //@line 61659
                     }
                    } else {
                     $i_0_i_i3784 = $5079;
                     $5091 = $5084;
                     label = 16907; //@line 61663
                    }
                    if ((label | 0) == 16907) {
                     while (1) {
                      label = 0; //@line 61667
                      if (!(($5091 << 24 >> 24 | 0) == 13 | ($5091 << 24 >> 24 | 0) == 32 | ($5091 << 24 >> 24 | 0) == 9 | ($5091 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5092 = $i_0_i_i3784 + 1 | 0; //@line 61673
                      $i_0_i_i3784 = $5092;
                      $5091 = HEAP8[$cmd + 4 + $5092 | 0] | 0;
                      label = 16907; //@line 61678
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3784; //@line 61681
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3784 | 0] | 0) != 33) {
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3784 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1949 = 2;
                      $storemerge4165_in = $i_0_i_i3784;
                     } else {
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4165_in + 2; //@line 61700
                    if ((_cmd_match_expr_cmp($cmd, $val2_i1948, $base) | 0) == 0) {
                     label = 16912; //@line 61705
                     break L21698;
                    }
                    if (($op_0_i1949 | 0) == 1) {
                     HEAP32[$val2_i799 >> 2] = (HEAP32[$val2_i799 >> 2] | 0) == (HEAP32[$val2_i1948 >> 2] | 0); //@line 61713
                     continue;
                    } else if (($op_0_i1949 | 0) == 2) {
                     HEAP32[$val2_i799 >> 2] = (HEAP32[$val2_i799 >> 2] | 0) != (HEAP32[$val2_i1948 >> 2] | 0); //@line 61721
                     continue;
                    } else {
                     continue;
                    }
                   }
                   HEAP32[$val2_i591 >> 2] = HEAP32[$val2_i799 >> 2] & HEAP32[$val2_i591 >> 2]; //@line 61731
                   $5054 = $i_0_i_i3784; //@line 61733
                  }
                  if ((label | 0) == 17211) {
                   label = 0; //@line 61736
                   HEAP32[$1 >> 2] = $5054; //@line 61737
                   $5117 = $5054; //@line 61739
                  }
                  HEAP32[$val2_i40 >> 2] = HEAP32[$val2_i591 >> 2] ^ HEAP32[$val2_i40 >> 2]; //@line 61745
                  $i_0_i_i_i592 = $5117; //@line 61747
                 }
                 while (1) {
                  $5123 = $5121; //@line 61752
                  while (1) {
                   $5124 = $cmd + 4 + $5123 | 0; //@line 61755
                   $5125 = HEAP8[$5124] | 0; //@line 61756
                   if (!(($5125 << 24 >> 24 | 0) == 13 | ($5125 << 24 >> 24 | 0) == 32 | ($5125 << 24 >> 24 | 0) == 9 | ($5125 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $5123 = $5123 + 1 | 0; //@line 61762
                  }
                  HEAP32[$1 >> 2] = $5123; //@line 61764
                  $5128 = HEAP8[$5124] | 0; //@line 61765
                  if ($5128 << 24 >> 24 == 124) {
                   if ((HEAP8[$5123 + 1 + ($cmd + 4) | 0] | 0) == 124) {
                    label = 17212; //@line 61773
                    break;
                   } else {
                    $i_0_i_i612 = $5123;
                    $5135 = 124;
                   }
                  } else {
                   $i_0_i_i612 = $5123;
                   $5135 = $5128;
                  }
                  while (1) {
                   if (!(($5135 << 24 >> 24 | 0) == 13 | ($5135 << 24 >> 24 | 0) == 32 | ($5135 << 24 >> 24 | 0) == 9 | ($5135 << 24 >> 24 | 0) == 10)) {
                    break;
                   }
                   $5136 = $i_0_i_i612 + 1 | 0; //@line 61787
                   $i_0_i_i612 = $5136;
                   $5135 = HEAP8[$cmd + 4 + $5136 | 0] | 0;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i612; //@line 61794
                  if ((HEAP8[$cmd + 4 + $i_0_i_i612 | 0] | 0) != 124) {
                   $i_0_i_i_i118 = $i_0_i_i612; //@line 61798
                   break;
                  }
                  $5141 = $i_0_i_i612 + 1 | 0; //@line 61801
                  HEAP32[$1 >> 2] = $5141; //@line 61802
                  if ((_cmd_match_expr_cmp($cmd, $val2_i159, $base) | 0) == 0) {
                   label = 17013; //@line 61807
                   break L21698;
                  }
                  while (1) {
                   $5146 = HEAP32[$1 >> 2] | 0; //@line 61813
                   while (1) {
                    $5147 = $cmd + 4 + $5146 | 0; //@line 61816
                    $5148 = HEAP8[$5147] | 0; //@line 61817
                    if (!(($5148 << 24 >> 24 | 0) == 13 | ($5148 << 24 >> 24 | 0) == 32 | ($5148 << 24 >> 24 | 0) == 9 | ($5148 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5146 = $5146 + 1 | 0; //@line 61823
                   }
                   HEAP32[$1 >> 2] = $5146; //@line 61825
                   $5151 = HEAP8[$5147] | 0; //@line 61826
                   if ($5151 << 24 >> 24 == 61) {
                    if ((HEAP8[$5146 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1953 = 1;
                     $storemerge4164_in = $5146;
                    } else {
                     $i_0_i_i3804 = $5146;
                     $5158 = 61;
                     label = 16934; //@line 61837
                    }
                   } else {
                    $i_0_i_i3804 = $5146;
                    $5158 = $5151;
                    label = 16934; //@line 61841
                   }
                   if ((label | 0) == 16934) {
                    while (1) {
                     label = 0; //@line 61845
                     if (!(($5158 << 24 >> 24 | 0) == 13 | ($5158 << 24 >> 24 | 0) == 32 | ($5158 << 24 >> 24 | 0) == 9 | ($5158 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5159 = $i_0_i_i3804 + 1 | 0; //@line 61851
                     $i_0_i_i3804 = $5159;
                     $5158 = HEAP8[$cmd + 4 + $5159 | 0] | 0;
                     label = 16934; //@line 61856
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3804; //@line 61859
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3804 | 0] | 0) != 33) {
                     $5181 = $i_0_i_i3804; //@line 61863
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3804 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i1953 = 2;
                     $storemerge4164_in = $i_0_i_i3804;
                    } else {
                     $5181 = $i_0_i_i3804; //@line 61873
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4164_in + 2; //@line 61880
                   if ((_cmd_match_expr_cmp($cmd, $val2_i1952, $base) | 0) == 0) {
                    label = 16939; //@line 61885
                    break L21698;
                   }
                   if (($op_0_i1953 | 0) == 1) {
                    HEAP32[$val2_i159 >> 2] = (HEAP32[$val2_i159 >> 2] | 0) == (HEAP32[$val2_i1952 >> 2] | 0); //@line 61893
                    continue;
                   } else if (($op_0_i1953 | 0) == 2) {
                    HEAP32[$val2_i159 >> 2] = (HEAP32[$val2_i159 >> 2] | 0) != (HEAP32[$val2_i1952 >> 2] | 0); //@line 61901
                    continue;
                   } else {
                    continue;
                   }
                  }
                  while (1) {
                   $5183 = $5181; //@line 61911
                   while (1) {
                    $5184 = $cmd + 4 + $5183 | 0; //@line 61914
                    $5185 = HEAP8[$5184] | 0; //@line 61915
                    if (!(($5185 << 24 >> 24 | 0) == 13 | ($5185 << 24 >> 24 | 0) == 32 | ($5185 << 24 >> 24 | 0) == 9 | ($5185 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5183 = $5183 + 1 | 0; //@line 61921
                   }
                   HEAP32[$1 >> 2] = $5183; //@line 61923
                   $5188 = HEAP8[$5184] | 0; //@line 61924
                   if ($5188 << 24 >> 24 == 38) {
                    if ((HEAP8[$5183 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                     label = 17213; //@line 61932
                     break;
                    } else {
                     $i_0_i_i1965 = $5183;
                     $5195 = 38;
                    }
                   } else {
                    $i_0_i_i1965 = $5183;
                    $5195 = $5188;
                   }
                   while (1) {
                    if (!(($5195 << 24 >> 24 | 0) == 13 | ($5195 << 24 >> 24 | 0) == 32 | ($5195 << 24 >> 24 | 0) == 9 | ($5195 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5196 = $i_0_i_i1965 + 1 | 0; //@line 61946
                    $i_0_i_i1965 = $5196;
                    $5195 = HEAP8[$cmd + 4 + $5196 | 0] | 0;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i1965; //@line 61953
                   if ((HEAP8[$cmd + 4 + $i_0_i_i1965 | 0] | 0) != 38) {
                    $i_0_i_i_i623 = $i_0_i_i1965; //@line 61957
                    break;
                   }
                   $5201 = $i_0_i_i1965 + 1 | 0; //@line 61960
                   HEAP32[$1 >> 2] = $5201; //@line 61961
                   if ((_cmd_match_expr_cmp($cmd, $val2_i802, $base) | 0) == 0) {
                    label = 16966; //@line 61966
                    break L21698;
                   }
                   while (1) {
                    $5206 = HEAP32[$1 >> 2] | 0; //@line 61972
                    while (1) {
                     $5207 = $cmd + 4 + $5206 | 0; //@line 61975
                     $5208 = HEAP8[$5207] | 0; //@line 61976
                     if (!(($5208 << 24 >> 24 | 0) == 13 | ($5208 << 24 >> 24 | 0) == 32 | ($5208 << 24 >> 24 | 0) == 9 | ($5208 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5206 = $5206 + 1 | 0; //@line 61982
                    }
                    HEAP32[$1 >> 2] = $5206; //@line 61984
                    $5211 = HEAP8[$5207] | 0; //@line 61985
                    if ($5211 << 24 >> 24 == 61) {
                     if ((HEAP8[$5206 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1976 = 1;
                      $storemerge4163_in = $5206;
                     } else {
                      $i_0_i_i3824 = $5206;
                      $5218 = 61;
                      label = 16957; //@line 61996
                     }
                    } else {
                     $i_0_i_i3824 = $5206;
                     $5218 = $5211;
                     label = 16957; //@line 62000
                    }
                    if ((label | 0) == 16957) {
                     while (1) {
                      label = 0; //@line 62004
                      if (!(($5218 << 24 >> 24 | 0) == 13 | ($5218 << 24 >> 24 | 0) == 32 | ($5218 << 24 >> 24 | 0) == 9 | ($5218 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5219 = $i_0_i_i3824 + 1 | 0; //@line 62010
                      $i_0_i_i3824 = $5219;
                      $5218 = HEAP8[$cmd + 4 + $5219 | 0] | 0;
                      label = 16957; //@line 62015
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3824; //@line 62018
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3824 | 0] | 0) != 33) {
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3824 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1976 = 2;
                      $storemerge4163_in = $i_0_i_i3824;
                     } else {
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4163_in + 2; //@line 62037
                    if ((_cmd_match_expr_cmp($cmd, $val2_i1975, $base) | 0) == 0) {
                     label = 16962; //@line 62042
                     break L21698;
                    }
                    if (($op_0_i1976 | 0) == 1) {
                     HEAP32[$val2_i802 >> 2] = (HEAP32[$val2_i802 >> 2] | 0) == (HEAP32[$val2_i1975 >> 2] | 0); //@line 62050
                     continue;
                    } else if (($op_0_i1976 | 0) == 2) {
                     HEAP32[$val2_i802 >> 2] = (HEAP32[$val2_i802 >> 2] | 0) != (HEAP32[$val2_i1975 >> 2] | 0); //@line 62058
                     continue;
                    } else {
                     continue;
                    }
                   }
                   HEAP32[$val2_i159 >> 2] = HEAP32[$val2_i802 >> 2] & HEAP32[$val2_i159 >> 2]; //@line 62068
                   $5181 = $i_0_i_i3824; //@line 62070
                  }
                  if ((label | 0) == 17213) {
                   label = 0; //@line 62073
                   HEAP32[$1 >> 2] = $5181; //@line 62074
                   $i_0_i_i_i623 = $5181; //@line 62076
                  }
                  while (1) {
                   $5244 = $cmd + 4 + $i_0_i_i_i623 | 0; //@line 62080
                   $5245 = HEAP8[$5244] | 0; //@line 62081
                   if (($5245 << 24 >> 24 | 0) == 13 | ($5245 << 24 >> 24 | 0) == 32 | ($5245 << 24 >> 24 | 0) == 9 | ($5245 << 24 >> 24 | 0) == 10) {
                    $i_0_i_i_i623 = $i_0_i_i_i623 + 1 | 0; //@line 62085
                    continue;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i_i623; //@line 62088
                   if ((HEAP8[$5244] | 0) != 94) {
                    break;
                   }
                   $5251 = $i_0_i_i_i623 + 1 | 0; //@line 62094
                   HEAP32[$1 >> 2] = $5251; //@line 62095
                   if ((_cmd_match_expr_cmp($cmd, $val2_i622, $base) | 0) == 0) {
                    label = 17011; //@line 62100
                    break L21698;
                   }
                   while (1) {
                    $5256 = HEAP32[$1 >> 2] | 0; //@line 62106
                    while (1) {
                     $5257 = $cmd + 4 + $5256 | 0; //@line 62109
                     $5258 = HEAP8[$5257] | 0; //@line 62110
                     if (!(($5258 << 24 >> 24 | 0) == 13 | ($5258 << 24 >> 24 | 0) == 32 | ($5258 << 24 >> 24 | 0) == 9 | ($5258 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5256 = $5256 + 1 | 0; //@line 62116
                    }
                    HEAP32[$1 >> 2] = $5256; //@line 62118
                    $5261 = HEAP8[$5257] | 0; //@line 62119
                    if ($5261 << 24 >> 24 == 61) {
                     if ((HEAP8[$5256 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1980 = 1;
                      $storemerge4162_in = $5256;
                     } else {
                      $i_0_i_i3844 = $5256;
                      $5268 = 61;
                      label = 16977; //@line 62130
                     }
                    } else {
                     $i_0_i_i3844 = $5256;
                     $5268 = $5261;
                     label = 16977; //@line 62134
                    }
                    if ((label | 0) == 16977) {
                     while (1) {
                      label = 0; //@line 62138
                      if (!(($5268 << 24 >> 24 | 0) == 13 | ($5268 << 24 >> 24 | 0) == 32 | ($5268 << 24 >> 24 | 0) == 9 | ($5268 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5269 = $i_0_i_i3844 + 1 | 0; //@line 62144
                      $i_0_i_i3844 = $5269;
                      $5268 = HEAP8[$cmd + 4 + $5269 | 0] | 0;
                      label = 16977; //@line 62149
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3844; //@line 62152
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3844 | 0] | 0) != 33) {
                      $5291 = $i_0_i_i3844; //@line 62156
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3844 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i1980 = 2;
                      $storemerge4162_in = $i_0_i_i3844;
                     } else {
                      $5291 = $i_0_i_i3844; //@line 62166
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4162_in + 2; //@line 62173
                    if ((_cmd_match_expr_cmp($cmd, $val2_i1979, $base) | 0) == 0) {
                     label = 16982; //@line 62178
                     break L21698;
                    }
                    if (($op_0_i1980 | 0) == 1) {
                     HEAP32[$val2_i622 >> 2] = (HEAP32[$val2_i622 >> 2] | 0) == (HEAP32[$val2_i1979 >> 2] | 0); //@line 62186
                     continue;
                    } else if (($op_0_i1980 | 0) == 2) {
                     HEAP32[$val2_i622 >> 2] = (HEAP32[$val2_i622 >> 2] | 0) != (HEAP32[$val2_i1979 >> 2] | 0); //@line 62194
                     continue;
                    } else {
                     continue;
                    }
                   }
                   while (1) {
                    $5293 = $5291; //@line 62204
                    while (1) {
                     $5294 = $cmd + 4 + $5293 | 0; //@line 62207
                     $5295 = HEAP8[$5294] | 0; //@line 62208
                     if (!(($5295 << 24 >> 24 | 0) == 13 | ($5295 << 24 >> 24 | 0) == 32 | ($5295 << 24 >> 24 | 0) == 9 | ($5295 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5293 = $5293 + 1 | 0; //@line 62214
                    }
                    HEAP32[$1 >> 2] = $5293; //@line 62216
                    $5298 = HEAP8[$5294] | 0; //@line 62217
                    if ($5298 << 24 >> 24 == 38) {
                     if ((HEAP8[$5293 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                      label = 17214; //@line 62225
                      break;
                     } else {
                      $i_0_i_i1992 = $5293;
                      $5305 = 38;
                     }
                    } else {
                     $i_0_i_i1992 = $5293;
                     $5305 = $5298;
                    }
                    while (1) {
                     if (!(($5305 << 24 >> 24 | 0) == 13 | ($5305 << 24 >> 24 | 0) == 32 | ($5305 << 24 >> 24 | 0) == 9 | ($5305 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5306 = $i_0_i_i1992 + 1 | 0; //@line 62239
                     $i_0_i_i1992 = $5306;
                     $5305 = HEAP8[$cmd + 4 + $5306 | 0] | 0;
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i1992; //@line 62246
                    if ((HEAP8[$cmd + 4 + $i_0_i_i1992 | 0] | 0) != 38) {
                     $5354 = $i_0_i_i1992; //@line 62250
                     break;
                    }
                    $5311 = $i_0_i_i1992 + 1 | 0; //@line 62253
                    HEAP32[$1 >> 2] = $5311; //@line 62254
                    if ((_cmd_match_expr_cmp($cmd, $val2_i805, $base) | 0) == 0) {
                     label = 17009; //@line 62259
                     break L21698;
                    }
                    while (1) {
                     $5316 = HEAP32[$1 >> 2] | 0; //@line 62265
                     while (1) {
                      $5317 = $cmd + 4 + $5316 | 0; //@line 62268
                      $5318 = HEAP8[$5317] | 0; //@line 62269
                      if (!(($5318 << 24 >> 24 | 0) == 13 | ($5318 << 24 >> 24 | 0) == 32 | ($5318 << 24 >> 24 | 0) == 9 | ($5318 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5316 = $5316 + 1 | 0; //@line 62275
                     }
                     HEAP32[$1 >> 2] = $5316; //@line 62277
                     $5321 = HEAP8[$5317] | 0; //@line 62278
                     if ($5321 << 24 >> 24 == 61) {
                      if ((HEAP8[$5316 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2003 = 1;
                       $storemerge4161_in = $5316;
                      } else {
                       $i_0_i_i3864 = $5316;
                       $5328 = 61;
                       label = 17e3; //@line 62289
                      }
                     } else {
                      $i_0_i_i3864 = $5316;
                      $5328 = $5321;
                      label = 17e3; //@line 62293
                     }
                     if ((label | 0) == 17e3) {
                      while (1) {
                       label = 0; //@line 62297
                       if (!(($5328 << 24 >> 24 | 0) == 13 | ($5328 << 24 >> 24 | 0) == 32 | ($5328 << 24 >> 24 | 0) == 9 | ($5328 << 24 >> 24 | 0) == 10)) {
                        break;
                       }
                       $5329 = $i_0_i_i3864 + 1 | 0; //@line 62303
                       $i_0_i_i3864 = $5329;
                       $5328 = HEAP8[$cmd + 4 + $5329 | 0] | 0;
                       label = 17e3; //@line 62308
                      }
                      HEAP32[$1 >> 2] = $i_0_i_i3864; //@line 62311
                      if ((HEAP8[$cmd + 4 + $i_0_i_i3864 | 0] | 0) != 33) {
                       break;
                      }
                      if ((HEAP8[$i_0_i_i3864 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2003 = 2;
                       $storemerge4161_in = $i_0_i_i3864;
                      } else {
                       break;
                      }
                     }
                     HEAP32[$1 >> 2] = $storemerge4161_in + 2; //@line 62330
                     if ((_cmd_match_expr_cmp($cmd, $val2_i2002, $base) | 0) == 0) {
                      label = 17005; //@line 62335
                      break L21698;
                     }
                     if (($op_0_i2003 | 0) == 1) {
                      HEAP32[$val2_i805 >> 2] = (HEAP32[$val2_i805 >> 2] | 0) == (HEAP32[$val2_i2002 >> 2] | 0); //@line 62343
                      continue;
                     } else if (($op_0_i2003 | 0) == 2) {
                      HEAP32[$val2_i805 >> 2] = (HEAP32[$val2_i805 >> 2] | 0) != (HEAP32[$val2_i2002 >> 2] | 0); //@line 62351
                      continue;
                     } else {
                      continue;
                     }
                    }
                    HEAP32[$val2_i622 >> 2] = HEAP32[$val2_i805 >> 2] & HEAP32[$val2_i622 >> 2]; //@line 62361
                    $5291 = $i_0_i_i3864; //@line 62363
                   }
                   if ((label | 0) == 17214) {
                    label = 0; //@line 62366
                    HEAP32[$1 >> 2] = $5291; //@line 62367
                    $5354 = $5291; //@line 62369
                   }
                   HEAP32[$val2_i159 >> 2] = HEAP32[$val2_i622 >> 2] ^ HEAP32[$val2_i159 >> 2]; //@line 62375
                   $i_0_i_i_i623 = $5354; //@line 62377
                  }
                  HEAP32[$val2_i40 >> 2] = HEAP32[$val2_i159 >> 2] | HEAP32[$val2_i40 >> 2]; //@line 62382
                  $5121 = $i_0_i_i_i623; //@line 62384
                 }
                 if ((label | 0) == 17212) {
                  label = 0; //@line 62387
                  HEAP32[$1 >> 2] = $5121; //@line 62388
                  $i_0_i_i_i118 = $5121; //@line 62390
                 }
                 while (1) {
                  $5362 = $cmd + 4 + $i_0_i_i_i118 | 0; //@line 62394
                  $5363 = HEAP8[$5362] | 0; //@line 62395
                  if (($5363 << 24 >> 24 | 0) == 13 | ($5363 << 24 >> 24 | 0) == 32 | ($5363 << 24 >> 24 | 0) == 9 | ($5363 << 24 >> 24 | 0) == 10) {
                   $i_0_i_i_i118 = $i_0_i_i_i118 + 1 | 0; //@line 62399
                   continue;
                  }
                  HEAP32[$1 >> 2] = $i_0_i_i_i118; //@line 62402
                  if ((HEAP8[$5362] | 0) != 38) {
                   break;
                  }
                  if ((HEAP8[$i_0_i_i_i118 + 1 + ($cmd + 4) | 0] | 0) != 38) {
                   break;
                  }
                  $5853 = $i_0_i_i_i118 + 2 | 0; //@line 62415
                  HEAP32[$1 >> 2] = $5853; //@line 62416
                  if ((_cmd_match_expr_cmp($cmd, $val2_i117, $base) | 0) == 0) {
                   label = 17198; //@line 62421
                   break L21698;
                  }
                  while (1) {
                   $5374 = HEAP32[$1 >> 2] | 0; //@line 62427
                   while (1) {
                    $5375 = $cmd + 4 + $5374 | 0; //@line 62430
                    $5376 = HEAP8[$5375] | 0; //@line 62431
                    if (!(($5376 << 24 >> 24 | 0) == 13 | ($5376 << 24 >> 24 | 0) == 32 | ($5376 << 24 >> 24 | 0) == 9 | ($5376 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5374 = $5374 + 1 | 0; //@line 62437
                   }
                   HEAP32[$1 >> 2] = $5374; //@line 62439
                   $5379 = HEAP8[$5375] | 0; //@line 62440
                   if ($5379 << 24 >> 24 == 61) {
                    if ((HEAP8[$5374 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i2007 = 1;
                     $storemerge4160_in = $5374;
                    } else {
                     $i_0_i_i3884 = $5374;
                     $5386 = 61;
                     label = 17024; //@line 62451
                    }
                   } else {
                    $i_0_i_i3884 = $5374;
                    $5386 = $5379;
                    label = 17024; //@line 62455
                   }
                   if ((label | 0) == 17024) {
                    while (1) {
                     label = 0; //@line 62459
                     if (!(($5386 << 24 >> 24 | 0) == 13 | ($5386 << 24 >> 24 | 0) == 32 | ($5386 << 24 >> 24 | 0) == 9 | ($5386 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5387 = $i_0_i_i3884 + 1 | 0; //@line 62465
                     $i_0_i_i3884 = $5387;
                     $5386 = HEAP8[$cmd + 4 + $5387 | 0] | 0;
                     label = 17024; //@line 62470
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i3884; //@line 62473
                    if ((HEAP8[$cmd + 4 + $i_0_i_i3884 | 0] | 0) != 33) {
                     $5409 = $i_0_i_i3884; //@line 62477
                     break;
                    }
                    if ((HEAP8[$i_0_i_i3884 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                     $op_0_i2007 = 2;
                     $storemerge4160_in = $i_0_i_i3884;
                    } else {
                     $5409 = $i_0_i_i3884; //@line 62487
                     break;
                    }
                   }
                   HEAP32[$1 >> 2] = $storemerge4160_in + 2; //@line 62494
                   if ((_cmd_match_expr_cmp($cmd, $val2_i2006, $base) | 0) == 0) {
                    label = 17029; //@line 62499
                    break L21698;
                   }
                   if (($op_0_i2007 | 0) == 1) {
                    HEAP32[$val2_i117 >> 2] = (HEAP32[$val2_i117 >> 2] | 0) == (HEAP32[$val2_i2006 >> 2] | 0); //@line 62507
                    continue;
                   } else if (($op_0_i2007 | 0) == 2) {
                    HEAP32[$val2_i117 >> 2] = (HEAP32[$val2_i117 >> 2] | 0) != (HEAP32[$val2_i2006 >> 2] | 0); //@line 62515
                    continue;
                   } else {
                    continue;
                   }
                  }
                  while (1) {
                   $5411 = $5409; //@line 62525
                   while (1) {
                    $5412 = $cmd + 4 + $5411 | 0; //@line 62528
                    $5413 = HEAP8[$5412] | 0; //@line 62529
                    if (!(($5413 << 24 >> 24 | 0) == 13 | ($5413 << 24 >> 24 | 0) == 32 | ($5413 << 24 >> 24 | 0) == 9 | ($5413 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5411 = $5411 + 1 | 0; //@line 62535
                   }
                   HEAP32[$1 >> 2] = $5411; //@line 62537
                   $5416 = HEAP8[$5412] | 0; //@line 62538
                   if ($5416 << 24 >> 24 == 38) {
                    if ((HEAP8[$5411 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                     label = 17216; //@line 62546
                     break;
                    } else {
                     $i_0_i_i2019 = $5411;
                     $5423 = 38;
                    }
                   } else {
                    $i_0_i_i2019 = $5411;
                    $5423 = $5416;
                   }
                   while (1) {
                    if (!(($5423 << 24 >> 24 | 0) == 13 | ($5423 << 24 >> 24 | 0) == 32 | ($5423 << 24 >> 24 | 0) == 9 | ($5423 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5424 = $i_0_i_i2019 + 1 | 0; //@line 62560
                    $i_0_i_i2019 = $5424;
                    $5423 = HEAP8[$cmd + 4 + $5424 | 0] | 0;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i2019; //@line 62567
                   if ((HEAP8[$cmd + 4 + $i_0_i_i2019 | 0] | 0) != 38) {
                    $i_0_i_i_i635 = $i_0_i_i2019; //@line 62571
                    break;
                   }
                   $5429 = $i_0_i_i2019 + 1 | 0; //@line 62574
                   HEAP32[$1 >> 2] = $5429; //@line 62575
                   if ((_cmd_match_expr_cmp($cmd, $val2_i808, $base) | 0) == 0) {
                    label = 17056; //@line 62580
                    break L21698;
                   }
                   while (1) {
                    $5434 = HEAP32[$1 >> 2] | 0; //@line 62586
                    while (1) {
                     $5435 = $cmd + 4 + $5434 | 0; //@line 62589
                     $5436 = HEAP8[$5435] | 0; //@line 62590
                     if (!(($5436 << 24 >> 24 | 0) == 13 | ($5436 << 24 >> 24 | 0) == 32 | ($5436 << 24 >> 24 | 0) == 9 | ($5436 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5434 = $5434 + 1 | 0; //@line 62596
                    }
                    HEAP32[$1 >> 2] = $5434; //@line 62598
                    $5439 = HEAP8[$5435] | 0; //@line 62599
                    if ($5439 << 24 >> 24 == 61) {
                     if ((HEAP8[$5434 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i2030 = 1;
                      $storemerge4159_in = $5434;
                     } else {
                      $i_0_i_i3904 = $5434;
                      $5446 = 61;
                      label = 17047; //@line 62610
                     }
                    } else {
                     $i_0_i_i3904 = $5434;
                     $5446 = $5439;
                     label = 17047; //@line 62614
                    }
                    if ((label | 0) == 17047) {
                     while (1) {
                      label = 0; //@line 62618
                      if (!(($5446 << 24 >> 24 | 0) == 13 | ($5446 << 24 >> 24 | 0) == 32 | ($5446 << 24 >> 24 | 0) == 9 | ($5446 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5447 = $i_0_i_i3904 + 1 | 0; //@line 62624
                      $i_0_i_i3904 = $5447;
                      $5446 = HEAP8[$cmd + 4 + $5447 | 0] | 0;
                      label = 17047; //@line 62629
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3904; //@line 62632
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3904 | 0] | 0) != 33) {
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3904 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i2030 = 2;
                      $storemerge4159_in = $i_0_i_i3904;
                     } else {
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4159_in + 2; //@line 62651
                    if ((_cmd_match_expr_cmp($cmd, $val2_i2029, $base) | 0) == 0) {
                     label = 17052; //@line 62656
                     break L21698;
                    }
                    if (($op_0_i2030 | 0) == 1) {
                     HEAP32[$val2_i808 >> 2] = (HEAP32[$val2_i808 >> 2] | 0) == (HEAP32[$val2_i2029 >> 2] | 0); //@line 62664
                     continue;
                    } else if (($op_0_i2030 | 0) == 2) {
                     HEAP32[$val2_i808 >> 2] = (HEAP32[$val2_i808 >> 2] | 0) != (HEAP32[$val2_i2029 >> 2] | 0); //@line 62672
                     continue;
                    } else {
                     continue;
                    }
                   }
                   HEAP32[$val2_i117 >> 2] = HEAP32[$val2_i808 >> 2] & HEAP32[$val2_i117 >> 2]; //@line 62682
                   $5409 = $i_0_i_i3904; //@line 62684
                  }
                  if ((label | 0) == 17216) {
                   label = 0; //@line 62687
                   HEAP32[$1 >> 2] = $5409; //@line 62688
                   $i_0_i_i_i635 = $5409; //@line 62690
                  }
                  while (1) {
                   $5472 = $cmd + 4 + $i_0_i_i_i635 | 0; //@line 62694
                   $5473 = HEAP8[$5472] | 0; //@line 62695
                   if (($5473 << 24 >> 24 | 0) == 13 | ($5473 << 24 >> 24 | 0) == 32 | ($5473 << 24 >> 24 | 0) == 9 | ($5473 << 24 >> 24 | 0) == 10) {
                    $i_0_i_i_i635 = $i_0_i_i_i635 + 1 | 0; //@line 62699
                    continue;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i_i635; //@line 62702
                   if ((HEAP8[$5472] | 0) != 94) {
                    $5586 = $i_0_i_i_i635; //@line 62706
                    break;
                   }
                   $5479 = $i_0_i_i_i635 + 1 | 0; //@line 62709
                   HEAP32[$1 >> 2] = $5479; //@line 62710
                   if ((_cmd_match_expr_cmp($cmd, $val2_i634, $base) | 0) == 0) {
                    label = 17101; //@line 62715
                    break L21698;
                   }
                   while (1) {
                    $5484 = HEAP32[$1 >> 2] | 0; //@line 62721
                    while (1) {
                     $5485 = $cmd + 4 + $5484 | 0; //@line 62724
                     $5486 = HEAP8[$5485] | 0; //@line 62725
                     if (!(($5486 << 24 >> 24 | 0) == 13 | ($5486 << 24 >> 24 | 0) == 32 | ($5486 << 24 >> 24 | 0) == 9 | ($5486 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5484 = $5484 + 1 | 0; //@line 62731
                    }
                    HEAP32[$1 >> 2] = $5484; //@line 62733
                    $5489 = HEAP8[$5485] | 0; //@line 62734
                    if ($5489 << 24 >> 24 == 61) {
                     if ((HEAP8[$5484 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i2034 = 1;
                      $storemerge4158_in = $5484;
                     } else {
                      $i_0_i_i3924 = $5484;
                      $5496 = 61;
                      label = 17067; //@line 62745
                     }
                    } else {
                     $i_0_i_i3924 = $5484;
                     $5496 = $5489;
                     label = 17067; //@line 62749
                    }
                    if ((label | 0) == 17067) {
                     while (1) {
                      label = 0; //@line 62753
                      if (!(($5496 << 24 >> 24 | 0) == 13 | ($5496 << 24 >> 24 | 0) == 32 | ($5496 << 24 >> 24 | 0) == 9 | ($5496 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5497 = $i_0_i_i3924 + 1 | 0; //@line 62759
                      $i_0_i_i3924 = $5497;
                      $5496 = HEAP8[$cmd + 4 + $5497 | 0] | 0;
                      label = 17067; //@line 62764
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3924; //@line 62767
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3924 | 0] | 0) != 33) {
                      $5519 = $i_0_i_i3924; //@line 62771
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3924 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i2034 = 2;
                      $storemerge4158_in = $i_0_i_i3924;
                     } else {
                      $5519 = $i_0_i_i3924; //@line 62781
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4158_in + 2; //@line 62788
                    if ((_cmd_match_expr_cmp($cmd, $val2_i2033, $base) | 0) == 0) {
                     label = 17072; //@line 62793
                     break L21698;
                    }
                    if (($op_0_i2034 | 0) == 1) {
                     HEAP32[$val2_i634 >> 2] = (HEAP32[$val2_i634 >> 2] | 0) == (HEAP32[$val2_i2033 >> 2] | 0); //@line 62801
                     continue;
                    } else if (($op_0_i2034 | 0) == 2) {
                     HEAP32[$val2_i634 >> 2] = (HEAP32[$val2_i634 >> 2] | 0) != (HEAP32[$val2_i2033 >> 2] | 0); //@line 62809
                     continue;
                    } else {
                     continue;
                    }
                   }
                   while (1) {
                    $5521 = $5519; //@line 62819
                    while (1) {
                     $5522 = $cmd + 4 + $5521 | 0; //@line 62822
                     $5523 = HEAP8[$5522] | 0; //@line 62823
                     if (!(($5523 << 24 >> 24 | 0) == 13 | ($5523 << 24 >> 24 | 0) == 32 | ($5523 << 24 >> 24 | 0) == 9 | ($5523 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5521 = $5521 + 1 | 0; //@line 62829
                    }
                    HEAP32[$1 >> 2] = $5521; //@line 62831
                    $5526 = HEAP8[$5522] | 0; //@line 62832
                    if ($5526 << 24 >> 24 == 38) {
                     if ((HEAP8[$5521 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                      label = 17217; //@line 62840
                      break;
                     } else {
                      $i_0_i_i2046 = $5521;
                      $5533 = 38;
                     }
                    } else {
                     $i_0_i_i2046 = $5521;
                     $5533 = $5526;
                    }
                    while (1) {
                     if (!(($5533 << 24 >> 24 | 0) == 13 | ($5533 << 24 >> 24 | 0) == 32 | ($5533 << 24 >> 24 | 0) == 9 | ($5533 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5534 = $i_0_i_i2046 + 1 | 0; //@line 62854
                     $i_0_i_i2046 = $5534;
                     $5533 = HEAP8[$cmd + 4 + $5534 | 0] | 0;
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i2046; //@line 62861
                    if ((HEAP8[$cmd + 4 + $i_0_i_i2046 | 0] | 0) != 38) {
                     $5582 = $i_0_i_i2046; //@line 62865
                     break;
                    }
                    $5539 = $i_0_i_i2046 + 1 | 0; //@line 62868
                    HEAP32[$1 >> 2] = $5539; //@line 62869
                    if ((_cmd_match_expr_cmp($cmd, $val2_i811, $base) | 0) == 0) {
                     label = 17099; //@line 62874
                     break L21698;
                    }
                    while (1) {
                     $5544 = HEAP32[$1 >> 2] | 0; //@line 62880
                     while (1) {
                      $5545 = $cmd + 4 + $5544 | 0; //@line 62883
                      $5546 = HEAP8[$5545] | 0; //@line 62884
                      if (!(($5546 << 24 >> 24 | 0) == 13 | ($5546 << 24 >> 24 | 0) == 32 | ($5546 << 24 >> 24 | 0) == 9 | ($5546 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5544 = $5544 + 1 | 0; //@line 62890
                     }
                     HEAP32[$1 >> 2] = $5544; //@line 62892
                     $5549 = HEAP8[$5545] | 0; //@line 62893
                     if ($5549 << 24 >> 24 == 61) {
                      if ((HEAP8[$5544 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2057 = 1;
                       $storemerge4157_in = $5544;
                      } else {
                       $i_0_i_i3944 = $5544;
                       $5556 = 61;
                       label = 17090; //@line 62904
                      }
                     } else {
                      $i_0_i_i3944 = $5544;
                      $5556 = $5549;
                      label = 17090; //@line 62908
                     }
                     if ((label | 0) == 17090) {
                      while (1) {
                       label = 0; //@line 62912
                       if (!(($5556 << 24 >> 24 | 0) == 13 | ($5556 << 24 >> 24 | 0) == 32 | ($5556 << 24 >> 24 | 0) == 9 | ($5556 << 24 >> 24 | 0) == 10)) {
                        break;
                       }
                       $5557 = $i_0_i_i3944 + 1 | 0; //@line 62918
                       $i_0_i_i3944 = $5557;
                       $5556 = HEAP8[$cmd + 4 + $5557 | 0] | 0;
                       label = 17090; //@line 62923
                      }
                      HEAP32[$1 >> 2] = $i_0_i_i3944; //@line 62926
                      if ((HEAP8[$cmd + 4 + $i_0_i_i3944 | 0] | 0) != 33) {
                       break;
                      }
                      if ((HEAP8[$i_0_i_i3944 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2057 = 2;
                       $storemerge4157_in = $i_0_i_i3944;
                      } else {
                       break;
                      }
                     }
                     HEAP32[$1 >> 2] = $storemerge4157_in + 2; //@line 62945
                     if ((_cmd_match_expr_cmp($cmd, $val2_i2056, $base) | 0) == 0) {
                      label = 17095; //@line 62950
                      break L21698;
                     }
                     if (($op_0_i2057 | 0) == 1) {
                      HEAP32[$val2_i811 >> 2] = (HEAP32[$val2_i811 >> 2] | 0) == (HEAP32[$val2_i2056 >> 2] | 0); //@line 62958
                      continue;
                     } else if (($op_0_i2057 | 0) == 2) {
                      HEAP32[$val2_i811 >> 2] = (HEAP32[$val2_i811 >> 2] | 0) != (HEAP32[$val2_i2056 >> 2] | 0); //@line 62966
                      continue;
                     } else {
                      continue;
                     }
                    }
                    HEAP32[$val2_i634 >> 2] = HEAP32[$val2_i811 >> 2] & HEAP32[$val2_i634 >> 2]; //@line 62976
                    $5519 = $i_0_i_i3944; //@line 62978
                   }
                   if ((label | 0) == 17217) {
                    label = 0; //@line 62981
                    HEAP32[$1 >> 2] = $5519; //@line 62982
                    $5582 = $5519; //@line 62984
                   }
                   HEAP32[$val2_i117 >> 2] = HEAP32[$val2_i634 >> 2] ^ HEAP32[$val2_i117 >> 2]; //@line 62990
                   $i_0_i_i_i635 = $5582; //@line 62992
                  }
                  while (1) {
                   $5588 = $5586; //@line 62997
                   while (1) {
                    $5589 = $cmd + 4 + $5588 | 0; //@line 63000
                    $5590 = HEAP8[$5589] | 0; //@line 63001
                    if (!(($5590 << 24 >> 24 | 0) == 13 | ($5590 << 24 >> 24 | 0) == 32 | ($5590 << 24 >> 24 | 0) == 9 | ($5590 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5588 = $5588 + 1 | 0; //@line 63007
                   }
                   HEAP32[$1 >> 2] = $5588; //@line 63009
                   $5593 = HEAP8[$5589] | 0; //@line 63010
                   if ($5593 << 24 >> 24 == 124) {
                    if ((HEAP8[$5588 + 1 + ($cmd + 4) | 0] | 0) == 124) {
                     label = 17218; //@line 63018
                     break;
                    } else {
                     $i_0_i_i655 = $5588;
                     $5600 = 124;
                    }
                   } else {
                    $i_0_i_i655 = $5588;
                    $5600 = $5593;
                   }
                   while (1) {
                    if (!(($5600 << 24 >> 24 | 0) == 13 | ($5600 << 24 >> 24 | 0) == 32 | ($5600 << 24 >> 24 | 0) == 9 | ($5600 << 24 >> 24 | 0) == 10)) {
                     break;
                    }
                    $5601 = $i_0_i_i655 + 1 | 0; //@line 63032
                    $i_0_i_i655 = $5601;
                    $5600 = HEAP8[$cmd + 4 + $5601 | 0] | 0;
                   }
                   HEAP32[$1 >> 2] = $i_0_i_i655; //@line 63039
                   if ((HEAP8[$cmd + 4 + $i_0_i_i655 | 0] | 0) != 124) {
                    $5827 = $i_0_i_i655; //@line 63043
                    break;
                   }
                   $5606 = $i_0_i_i655 + 1 | 0; //@line 63046
                   HEAP32[$1 >> 2] = $5606; //@line 63047
                   if ((_cmd_match_expr_cmp($cmd, $val2_i162, $base) | 0) == 0) {
                    label = 17196; //@line 63052
                    break L21698;
                   }
                   while (1) {
                    $5611 = HEAP32[$1 >> 2] | 0; //@line 63058
                    while (1) {
                     $5612 = $cmd + 4 + $5611 | 0; //@line 63061
                     $5613 = HEAP8[$5612] | 0; //@line 63062
                     if (!(($5613 << 24 >> 24 | 0) == 13 | ($5613 << 24 >> 24 | 0) == 32 | ($5613 << 24 >> 24 | 0) == 9 | ($5613 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5611 = $5611 + 1 | 0; //@line 63068
                    }
                    HEAP32[$1 >> 2] = $5611; //@line 63070
                    $5616 = HEAP8[$5612] | 0; //@line 63071
                    if ($5616 << 24 >> 24 == 61) {
                     if ((HEAP8[$5611 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i2061 = 1;
                      $storemerge4156_in = $5611;
                     } else {
                      $i_0_i_i3964 = $5611;
                      $5623 = 61;
                      label = 17117; //@line 63082
                     }
                    } else {
                     $i_0_i_i3964 = $5611;
                     $5623 = $5616;
                     label = 17117; //@line 63086
                    }
                    if ((label | 0) == 17117) {
                     while (1) {
                      label = 0; //@line 63090
                      if (!(($5623 << 24 >> 24 | 0) == 13 | ($5623 << 24 >> 24 | 0) == 32 | ($5623 << 24 >> 24 | 0) == 9 | ($5623 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5624 = $i_0_i_i3964 + 1 | 0; //@line 63096
                      $i_0_i_i3964 = $5624;
                      $5623 = HEAP8[$cmd + 4 + $5624 | 0] | 0;
                      label = 17117; //@line 63101
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i3964; //@line 63104
                     if ((HEAP8[$cmd + 4 + $i_0_i_i3964 | 0] | 0) != 33) {
                      $5646 = $i_0_i_i3964; //@line 63108
                      break;
                     }
                     if ((HEAP8[$i_0_i_i3964 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                      $op_0_i2061 = 2;
                      $storemerge4156_in = $i_0_i_i3964;
                     } else {
                      $5646 = $i_0_i_i3964; //@line 63118
                      break;
                     }
                    }
                    HEAP32[$1 >> 2] = $storemerge4156_in + 2; //@line 63125
                    if ((_cmd_match_expr_cmp($cmd, $val2_i2060, $base) | 0) == 0) {
                     label = 17122; //@line 63130
                     break L21698;
                    }
                    if (($op_0_i2061 | 0) == 1) {
                     HEAP32[$val2_i162 >> 2] = (HEAP32[$val2_i162 >> 2] | 0) == (HEAP32[$val2_i2060 >> 2] | 0); //@line 63138
                     continue;
                    } else if (($op_0_i2061 | 0) == 2) {
                     HEAP32[$val2_i162 >> 2] = (HEAP32[$val2_i162 >> 2] | 0) != (HEAP32[$val2_i2060 >> 2] | 0); //@line 63146
                     continue;
                    } else {
                     continue;
                    }
                   }
                   while (1) {
                    $5648 = $5646; //@line 63156
                    while (1) {
                     $5649 = $cmd + 4 + $5648 | 0; //@line 63159
                     $5650 = HEAP8[$5649] | 0; //@line 63160
                     if (!(($5650 << 24 >> 24 | 0) == 13 | ($5650 << 24 >> 24 | 0) == 32 | ($5650 << 24 >> 24 | 0) == 9 | ($5650 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5648 = $5648 + 1 | 0; //@line 63166
                    }
                    HEAP32[$1 >> 2] = $5648; //@line 63168
                    $5653 = HEAP8[$5649] | 0; //@line 63169
                    if ($5653 << 24 >> 24 == 38) {
                     if ((HEAP8[$5648 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                      label = 17219; //@line 63177
                      break;
                     } else {
                      $i_0_i_i2073 = $5648;
                      $5660 = 38;
                     }
                    } else {
                     $i_0_i_i2073 = $5648;
                     $5660 = $5653;
                    }
                    while (1) {
                     if (!(($5660 << 24 >> 24 | 0) == 13 | ($5660 << 24 >> 24 | 0) == 32 | ($5660 << 24 >> 24 | 0) == 9 | ($5660 << 24 >> 24 | 0) == 10)) {
                      break;
                     }
                     $5661 = $i_0_i_i2073 + 1 | 0; //@line 63191
                     $i_0_i_i2073 = $5661;
                     $5660 = HEAP8[$cmd + 4 + $5661 | 0] | 0;
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i2073; //@line 63198
                    if ((HEAP8[$cmd + 4 + $i_0_i_i2073 | 0] | 0) != 38) {
                     $i_0_i_i_i666 = $i_0_i_i2073; //@line 63202
                     break;
                    }
                    $5666 = $i_0_i_i2073 + 1 | 0; //@line 63205
                    HEAP32[$1 >> 2] = $5666; //@line 63206
                    if ((_cmd_match_expr_cmp($cmd, $val2_i814, $base) | 0) == 0) {
                     label = 17149; //@line 63211
                     break L21698;
                    }
                    while (1) {
                     $5671 = HEAP32[$1 >> 2] | 0; //@line 63217
                     while (1) {
                      $5672 = $cmd + 4 + $5671 | 0; //@line 63220
                      $5673 = HEAP8[$5672] | 0; //@line 63221
                      if (!(($5673 << 24 >> 24 | 0) == 13 | ($5673 << 24 >> 24 | 0) == 32 | ($5673 << 24 >> 24 | 0) == 9 | ($5673 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5671 = $5671 + 1 | 0; //@line 63227
                     }
                     HEAP32[$1 >> 2] = $5671; //@line 63229
                     $5676 = HEAP8[$5672] | 0; //@line 63230
                     if ($5676 << 24 >> 24 == 61) {
                      if ((HEAP8[$5671 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2084 = 1;
                       $storemerge4155_in = $5671;
                      } else {
                       $i_0_i_i3984 = $5671;
                       $5683 = 61;
                       label = 17140; //@line 63241
                      }
                     } else {
                      $i_0_i_i3984 = $5671;
                      $5683 = $5676;
                      label = 17140; //@line 63245
                     }
                     if ((label | 0) == 17140) {
                      while (1) {
                       label = 0; //@line 63249
                       if (!(($5683 << 24 >> 24 | 0) == 13 | ($5683 << 24 >> 24 | 0) == 32 | ($5683 << 24 >> 24 | 0) == 9 | ($5683 << 24 >> 24 | 0) == 10)) {
                        break;
                       }
                       $5684 = $i_0_i_i3984 + 1 | 0; //@line 63255
                       $i_0_i_i3984 = $5684;
                       $5683 = HEAP8[$cmd + 4 + $5684 | 0] | 0;
                       label = 17140; //@line 63260
                      }
                      HEAP32[$1 >> 2] = $i_0_i_i3984; //@line 63263
                      if ((HEAP8[$cmd + 4 + $i_0_i_i3984 | 0] | 0) != 33) {
                       break;
                      }
                      if ((HEAP8[$i_0_i_i3984 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2084 = 2;
                       $storemerge4155_in = $i_0_i_i3984;
                      } else {
                       break;
                      }
                     }
                     HEAP32[$1 >> 2] = $storemerge4155_in + 2; //@line 63282
                     if ((_cmd_match_expr_cmp($cmd, $val2_i2083, $base) | 0) == 0) {
                      label = 17145; //@line 63287
                      break L21698;
                     }
                     if (($op_0_i2084 | 0) == 1) {
                      HEAP32[$val2_i814 >> 2] = (HEAP32[$val2_i814 >> 2] | 0) == (HEAP32[$val2_i2083 >> 2] | 0); //@line 63295
                      continue;
                     } else if (($op_0_i2084 | 0) == 2) {
                      HEAP32[$val2_i814 >> 2] = (HEAP32[$val2_i814 >> 2] | 0) != (HEAP32[$val2_i2083 >> 2] | 0); //@line 63303
                      continue;
                     } else {
                      continue;
                     }
                    }
                    HEAP32[$val2_i162 >> 2] = HEAP32[$val2_i814 >> 2] & HEAP32[$val2_i162 >> 2]; //@line 63313
                    $5646 = $i_0_i_i3984; //@line 63315
                   }
                   if ((label | 0) == 17219) {
                    label = 0; //@line 63318
                    HEAP32[$1 >> 2] = $5646; //@line 63319
                    $i_0_i_i_i666 = $5646; //@line 63321
                   }
                   while (1) {
                    $5709 = $cmd + 4 + $i_0_i_i_i666 | 0; //@line 63325
                    $5710 = HEAP8[$5709] | 0; //@line 63326
                    if (($5710 << 24 >> 24 | 0) == 13 | ($5710 << 24 >> 24 | 0) == 32 | ($5710 << 24 >> 24 | 0) == 9 | ($5710 << 24 >> 24 | 0) == 10) {
                     $i_0_i_i_i666 = $i_0_i_i_i666 + 1 | 0; //@line 63330
                     continue;
                    }
                    HEAP32[$1 >> 2] = $i_0_i_i_i666; //@line 63333
                    if ((HEAP8[$5709] | 0) != 94) {
                     break;
                    }
                    $5716 = $i_0_i_i_i666 + 1 | 0; //@line 63339
                    HEAP32[$1 >> 2] = $5716; //@line 63340
                    if ((_cmd_match_expr_cmp($cmd, $val2_i665, $base) | 0) == 0) {
                     label = 17194; //@line 63345
                     break L21698;
                    }
                    while (1) {
                     $5721 = HEAP32[$1 >> 2] | 0; //@line 63351
                     while (1) {
                      $5722 = $cmd + 4 + $5721 | 0; //@line 63354
                      $5723 = HEAP8[$5722] | 0; //@line 63355
                      if (!(($5723 << 24 >> 24 | 0) == 13 | ($5723 << 24 >> 24 | 0) == 32 | ($5723 << 24 >> 24 | 0) == 9 | ($5723 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5721 = $5721 + 1 | 0; //@line 63361
                     }
                     HEAP32[$1 >> 2] = $5721; //@line 63363
                     $5726 = HEAP8[$5722] | 0; //@line 63364
                     if ($5726 << 24 >> 24 == 61) {
                      if ((HEAP8[$5721 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2088 = 1;
                       $storemerge4154_in = $5721;
                      } else {
                       $i_0_i_i4004 = $5721;
                       $5733 = 61;
                       label = 17160; //@line 63375
                      }
                     } else {
                      $i_0_i_i4004 = $5721;
                      $5733 = $5726;
                      label = 17160; //@line 63379
                     }
                     if ((label | 0) == 17160) {
                      while (1) {
                       label = 0; //@line 63383
                       if (!(($5733 << 24 >> 24 | 0) == 13 | ($5733 << 24 >> 24 | 0) == 32 | ($5733 << 24 >> 24 | 0) == 9 | ($5733 << 24 >> 24 | 0) == 10)) {
                        break;
                       }
                       $5734 = $i_0_i_i4004 + 1 | 0; //@line 63389
                       $i_0_i_i4004 = $5734;
                       $5733 = HEAP8[$cmd + 4 + $5734 | 0] | 0;
                       label = 17160; //@line 63394
                      }
                      HEAP32[$1 >> 2] = $i_0_i_i4004; //@line 63397
                      if ((HEAP8[$cmd + 4 + $i_0_i_i4004 | 0] | 0) != 33) {
                       $5756 = $i_0_i_i4004; //@line 63401
                       break;
                      }
                      if ((HEAP8[$i_0_i_i4004 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                       $op_0_i2088 = 2;
                       $storemerge4154_in = $i_0_i_i4004;
                      } else {
                       $5756 = $i_0_i_i4004; //@line 63411
                       break;
                      }
                     }
                     HEAP32[$1 >> 2] = $storemerge4154_in + 2; //@line 63418
                     if ((_cmd_match_expr_cmp($cmd, $val2_i2087, $base) | 0) == 0) {
                      label = 17165; //@line 63423
                      break L21698;
                     }
                     if (($op_0_i2088 | 0) == 1) {
                      HEAP32[$val2_i665 >> 2] = (HEAP32[$val2_i665 >> 2] | 0) == (HEAP32[$val2_i2087 >> 2] | 0); //@line 63431
                      continue;
                     } else if (($op_0_i2088 | 0) == 2) {
                      HEAP32[$val2_i665 >> 2] = (HEAP32[$val2_i665 >> 2] | 0) != (HEAP32[$val2_i2087 >> 2] | 0); //@line 63439
                      continue;
                     } else {
                      continue;
                     }
                    }
                    while (1) {
                     $5758 = $5756; //@line 63449
                     while (1) {
                      $5759 = $cmd + 4 + $5758 | 0; //@line 63452
                      $5760 = HEAP8[$5759] | 0; //@line 63453
                      if (!(($5760 << 24 >> 24 | 0) == 13 | ($5760 << 24 >> 24 | 0) == 32 | ($5760 << 24 >> 24 | 0) == 9 | ($5760 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5758 = $5758 + 1 | 0; //@line 63459
                     }
                     HEAP32[$1 >> 2] = $5758; //@line 63461
                     $5763 = HEAP8[$5759] | 0; //@line 63462
                     if ($5763 << 24 >> 24 == 38) {
                      if ((HEAP8[$5758 + 1 + ($cmd + 4) | 0] | 0) == 38) {
                       label = 17220; //@line 63470
                       break;
                      } else {
                       $i_0_i_i2100 = $5758;
                       $5770 = 38;
                      }
                     } else {
                      $i_0_i_i2100 = $5758;
                      $5770 = $5763;
                     }
                     while (1) {
                      if (!(($5770 << 24 >> 24 | 0) == 13 | ($5770 << 24 >> 24 | 0) == 32 | ($5770 << 24 >> 24 | 0) == 9 | ($5770 << 24 >> 24 | 0) == 10)) {
                       break;
                      }
                      $5771 = $i_0_i_i2100 + 1 | 0; //@line 63484
                      $i_0_i_i2100 = $5771;
                      $5770 = HEAP8[$cmd + 4 + $5771 | 0] | 0;
                     }
                     HEAP32[$1 >> 2] = $i_0_i_i2100; //@line 63491
                     if ((HEAP8[$cmd + 4 + $i_0_i_i2100 | 0] | 0) != 38) {
                      $5819 = $i_0_i_i2100; //@line 63495
                      break;
                     }
                     $5776 = $i_0_i_i2100 + 1 | 0; //@line 63498
                     HEAP32[$1 >> 2] = $5776; //@line 63499
                     if ((_cmd_match_expr_cmp($cmd, $val2_i817, $base) | 0) == 0) {
                      label = 17192; //@line 63504
                      break L21698;
                     }
                     while (1) {
                      $5781 = HEAP32[$1 >> 2] | 0; //@line 63510
                      while (1) {
                       $5782 = $cmd + 4 + $5781 | 0; //@line 63513
                       $5783 = HEAP8[$5782] | 0; //@line 63514
                       if (!(($5783 << 24 >> 24 | 0) == 13 | ($5783 << 24 >> 24 | 0) == 32 | ($5783 << 24 >> 24 | 0) == 9 | ($5783 << 24 >> 24 | 0) == 10)) {
                        break;
                       }
                       $5781 = $5781 + 1 | 0; //@line 63520
                      }
                      HEAP32[$1 >> 2] = $5781; //@line 63522
                      $5786 = HEAP8[$5782] | 0; //@line 63523
                      if ($5786 << 24 >> 24 == 61) {
                       if ((HEAP8[$5781 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                        $op_0_i2111 = 1;
                        $storemerge_in = $5781;
                       } else {
                        $i_0_i_i4024 = $5781;
                        $5793 = 61;
                        label = 17183; //@line 63534
                       }
                      } else {
                       $i_0_i_i4024 = $5781;
                       $5793 = $5786;
                       label = 17183; //@line 63538
                      }
                      if ((label | 0) == 17183) {
                       while (1) {
                        label = 0; //@line 63542
                        if (!(($5793 << 24 >> 24 | 0) == 13 | ($5793 << 24 >> 24 | 0) == 32 | ($5793 << 24 >> 24 | 0) == 9 | ($5793 << 24 >> 24 | 0) == 10)) {
                         break;
                        }
                        $5794 = $i_0_i_i4024 + 1 | 0; //@line 63548
                        $i_0_i_i4024 = $5794;
                        $5793 = HEAP8[$cmd + 4 + $5794 | 0] | 0;
                        label = 17183; //@line 63553
                       }
                       HEAP32[$1 >> 2] = $i_0_i_i4024; //@line 63556
                       if ((HEAP8[$cmd + 4 + $i_0_i_i4024 | 0] | 0) != 33) {
                        break;
                       }
                       if ((HEAP8[$i_0_i_i4024 + 1 + ($cmd + 4) | 0] | 0) == 61) {
                        $op_0_i2111 = 2;
                        $storemerge_in = $i_0_i_i4024;
                       } else {
                        break;
                       }
                      }
                      HEAP32[$1 >> 2] = $storemerge_in + 2; //@line 63575
                      if ((_cmd_match_expr_cmp($cmd, $val2_i2110, $base) | 0) == 0) {
                       label = 17188; //@line 63580
                       break L21698;
                      }
                      if (($op_0_i2111 | 0) == 1) {
                       HEAP32[$val2_i817 >> 2] = (HEAP32[$val2_i817 >> 2] | 0) == (HEAP32[$val2_i2110 >> 2] | 0); //@line 63588
                       continue;
                      } else if (($op_0_i2111 | 0) == 2) {
                       HEAP32[$val2_i817 >> 2] = (HEAP32[$val2_i817 >> 2] | 0) != (HEAP32[$val2_i2110 >> 2] | 0); //@line 63596
                       continue;
                      } else {
                       continue;
                      }
                     }
                     HEAP32[$val2_i665 >> 2] = HEAP32[$val2_i817 >> 2] & HEAP32[$val2_i665 >> 2]; //@line 63606
                     $5756 = $i_0_i_i4024; //@line 63608
                    }
                    if ((label | 0) == 17220) {
                     label = 0; //@line 63611
                     HEAP32[$1 >> 2] = $5756; //@line 63612
                     $5819 = $5756; //@line 63614
                    }
                    HEAP32[$val2_i162 >> 2] = HEAP32[$val2_i665 >> 2] ^ HEAP32[$val2_i162 >> 2]; //@line 63620
                    $i_0_i_i_i666 = $5819; //@line 63622
                   }
                   HEAP32[$val2_i117 >> 2] = HEAP32[$val2_i162 >> 2] | HEAP32[$val2_i117 >> 2]; //@line 63627
                   $5586 = $i_0_i_i_i666; //@line 63629
                  }
                  if ((label | 0) == 17218) {
                   label = 0; //@line 63632
                   HEAP32[$1 >> 2] = $5586; //@line 63633
                   $5827 = $5586; //@line 63635
                  }
                  if ((HEAP32[$val2_i40 >> 2] | 0) == 0) {
                   $5834 = 0; //@line 63642
                  } else {
                   $5834 = (HEAP32[$val2_i117 >> 2] | 0) != 0 | 0; //@line 63647
                  }
                  HEAP32[$val2_i40 >> 2] = $5834; //@line 63650
                  $i_0_i_i_i118 = $5827; //@line 63652
                 }
                 if ((HEAP32[$val3 >> 2] | 0) == 0) {
                  $5842 = (HEAP32[$val2_i40 >> 2] | 0) != 0 | 0; //@line 63662
                 } else {
                  $5842 = 1; //@line 63664
                 }
                 HEAP32[$val3 >> 2] = $5842; //@line 63667
                 $i_0_i_i_i41 = $i_0_i_i_i118; //@line 63669
                }
                if ((label | 0) == 16846) {
                 HEAP32[$1 >> 2] = $5849; //@line 63672
                } else if ((label | 0) == 16869) {
                 HEAP32[$1 >> 2] = $4964; //@line 63676
                 label = 16873; //@line 63678
                } else if ((label | 0) == 16889) {
                 HEAP32[$1 >> 2] = $5014; //@line 63681
                 label = 16918; //@line 63683
                } else if ((label | 0) == 16912) {
                 HEAP32[$1 >> 2] = $5074; //@line 63686
                 label = 16916; //@line 63688
                } else if ((label | 0) == 16939) {
                 HEAP32[$1 >> 2] = $5141; //@line 63691
                 label = 17013; //@line 63693
                } else if ((label | 0) == 16962) {
                 HEAP32[$1 >> 2] = $5201; //@line 63696
                 label = 16966; //@line 63698
                } else if ((label | 0) == 16982) {
                 HEAP32[$1 >> 2] = $5251; //@line 63701
                 label = 17011; //@line 63703
                } else if ((label | 0) == 17005) {
                 HEAP32[$1 >> 2] = $5311; //@line 63706
                 label = 17009; //@line 63708
                } else if ((label | 0) == 17029) {
                 HEAP32[$1 >> 2] = $5853; //@line 63711
                 label = 17198; //@line 63713
                } else if ((label | 0) == 17052) {
                 HEAP32[$1 >> 2] = $5429; //@line 63716
                 label = 17056; //@line 63718
                } else if ((label | 0) == 17072) {
                 HEAP32[$1 >> 2] = $5479; //@line 63721
                 label = 17101; //@line 63723
                } else if ((label | 0) == 17095) {
                 HEAP32[$1 >> 2] = $5539; //@line 63726
                 label = 17099; //@line 63728
                } else if ((label | 0) == 17122) {
                 HEAP32[$1 >> 2] = $5606; //@line 63731
                 label = 17196; //@line 63733
                } else if ((label | 0) == 17145) {
                 HEAP32[$1 >> 2] = $5666; //@line 63736
                 label = 17149; //@line 63738
                } else if ((label | 0) == 17165) {
                 HEAP32[$1 >> 2] = $5716; //@line 63741
                 label = 17194; //@line 63743
                } else if ((label | 0) == 17188) {
                 HEAP32[$1 >> 2] = $5776; //@line 63746
                 label = 17192; //@line 63748
                } else if ((label | 0) == 17207) {
                 HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) != 0 ? HEAP32[$val2 >> 2] | 0 : HEAP32[$val3 >> 2] | 0; //@line 63756
                 $_0 = 1; //@line 63758
                 STACKTOP = sp; //@line 63760
                 return $_0 | 0; //@line 63761
                }
                if ((label | 0) == 16873) {
                 HEAP32[$1 >> 2] = $5849; //@line 63764
                } else if ((label | 0) == 16916) {
                 HEAP32[$1 >> 2] = $5014; //@line 63768
                 label = 16918; //@line 63770
                } else if ((label | 0) == 16966) {
                 HEAP32[$1 >> 2] = $5141; //@line 63773
                 label = 17013; //@line 63775
                } else if ((label | 0) == 17009) {
                 HEAP32[$1 >> 2] = $5251; //@line 63778
                 label = 17011; //@line 63780
                } else if ((label | 0) == 17056) {
                 HEAP32[$1 >> 2] = $5853; //@line 63783
                 label = 17198; //@line 63785
                } else if ((label | 0) == 17099) {
                 HEAP32[$1 >> 2] = $5479; //@line 63788
                 label = 17101; //@line 63790
                } else if ((label | 0) == 17149) {
                 HEAP32[$1 >> 2] = $5606; //@line 63793
                 label = 17196; //@line 63795
                } else if ((label | 0) == 17192) {
                 HEAP32[$1 >> 2] = $5716; //@line 63798
                 label = 17194; //@line 63800
                }
                if ((label | 0) == 16918) {
                 HEAP32[$1 >> 2] = $5849; //@line 63803
                } else if ((label | 0) == 17011) {
                 HEAP32[$1 >> 2] = $5141; //@line 63807
                 label = 17013; //@line 63809
                } else if ((label | 0) == 17101) {
                 HEAP32[$1 >> 2] = $5853; //@line 63812
                 label = 17198; //@line 63814
                } else if ((label | 0) == 17194) {
                 HEAP32[$1 >> 2] = $5606; //@line 63817
                 label = 17196; //@line 63819
                }
                if ((label | 0) == 17013) {
                 HEAP32[$1 >> 2] = $5849; //@line 63822
                } else if ((label | 0) == 17196) {
                 HEAP32[$1 >> 2] = $5853; //@line 63826
                 label = 17198; //@line 63828
                }
                if ((label | 0) == 17198) {
                 HEAP32[$1 >> 2] = $5849; //@line 63831
                }
                HEAP32[$1 >> 2] = $3900; //@line 63834
                break;
               } else if ((label | 0) == 16659) {
                HEAP32[$1 >> 2] = $5857; //@line 63839
               } else if ((label | 0) == 16682) {
                HEAP32[$1 >> 2] = $4491; //@line 63843
                label = 16686; //@line 63845
               } else if ((label | 0) == 16702) {
                HEAP32[$1 >> 2] = $4541; //@line 63848
                label = 16731; //@line 63850
               } else if ((label | 0) == 16725) {
                HEAP32[$1 >> 2] = $4601; //@line 63853
                label = 16729; //@line 63855
               } else if ((label | 0) == 16752) {
                HEAP32[$1 >> 2] = $4668; //@line 63858
                label = 16826; //@line 63860
               } else if ((label | 0) == 16775) {
                HEAP32[$1 >> 2] = $4728; //@line 63863
                label = 16779; //@line 63865
               } else if ((label | 0) == 16795) {
                HEAP32[$1 >> 2] = $4778; //@line 63868
                label = 16824; //@line 63870
               } else if ((label | 0) == 16818) {
                HEAP32[$1 >> 2] = $4838; //@line 63873
                label = 16822; //@line 63875
               }
               if ((label | 0) == 16686) {
                HEAP32[$1 >> 2] = $5857; //@line 63878
               } else if ((label | 0) == 16729) {
                HEAP32[$1 >> 2] = $4541; //@line 63882
                label = 16731; //@line 63884
               } else if ((label | 0) == 16779) {
                HEAP32[$1 >> 2] = $4668; //@line 63887
                label = 16826; //@line 63889
               } else if ((label | 0) == 16822) {
                HEAP32[$1 >> 2] = $4778; //@line 63892
                label = 16824; //@line 63894
               }
               if ((label | 0) == 16731) {
                HEAP32[$1 >> 2] = $5857; //@line 63897
               } else if ((label | 0) == 16824) {
                HEAP32[$1 >> 2] = $4668; //@line 63901
                label = 16826; //@line 63903
               }
               if ((label | 0) == 16826) {
                HEAP32[$1 >> 2] = $5857; //@line 63906
               }
               HEAP32[$1 >> 2] = $3900; //@line 63909
               break;
              } else if ((label | 0) == 16595) {
               HEAP32[$1 >> 2] = $4172; //@line 63914
              } else if ((label | 0) == 16638) {
               HEAP32[$1 >> 2] = $4282; //@line 63918
               label = 16640; //@line 63920
              }
              if ((label | 0) == 16640) {
               HEAP32[$1 >> 2] = $4172; //@line 63923
              }
              HEAP32[$1 >> 2] = $3900; //@line 63926
              break;
             } else if ((label | 0) == 16517) {
              HEAP32[$1 >> 2] = $4029; //@line 63931
             } else if ((label | 0) == 16540) {
              HEAP32[$1 >> 2] = $4089; //@line 63935
              label = 16544; //@line 63937
             }
             if ((label | 0) == 16544) {
              HEAP32[$1 >> 2] = $4029; //@line 63940
             }
             HEAP32[$1 >> 2] = $3900; //@line 63943
            }
           } while (0);
           HEAP32[$1 >> 2] = $2; //@line 63947
           $_0 = 0; //@line 63949
           STACKTOP = sp; //@line 63951
           return $_0 | 0; //@line 63952
          }
          if ((label | 0) == 16122) {
           HEAP32[$1 >> 2] = $5861; //@line 63955
          } else if ((label | 0) == 16165) {
           HEAP32[$1 >> 2] = $3064; //@line 63959
           label = 16167; //@line 63961
          } else if ((label | 0) == 16215) {
           HEAP32[$1 >> 2] = $3191; //@line 63964
           label = 16262; //@line 63966
          } else if ((label | 0) == 16258) {
           HEAP32[$1 >> 2] = $3301; //@line 63969
           label = 16260; //@line 63971
          } else if ((label | 0) == 16305) {
           HEAP32[$1 >> 2] = $5865; //@line 63974
           label = 16447; //@line 63976
          } else if ((label | 0) == 16348) {
           HEAP32[$1 >> 2] = $3529; //@line 63979
           label = 16350; //@line 63981
          } else if ((label | 0) == 16398) {
           HEAP32[$1 >> 2] = $3656; //@line 63984
           label = 16445; //@line 63986
          } else if ((label | 0) == 16441) {
           HEAP32[$1 >> 2] = $3766; //@line 63989
           label = 16443; //@line 63991
          }
          if ((label | 0) == 16167) {
           HEAP32[$1 >> 2] = $5861; //@line 63994
          } else if ((label | 0) == 16260) {
           HEAP32[$1 >> 2] = $3191; //@line 63998
           label = 16262; //@line 64000
          } else if ((label | 0) == 16350) {
           HEAP32[$1 >> 2] = $5865; //@line 64003
           label = 16447; //@line 64005
          } else if ((label | 0) == 16443) {
           HEAP32[$1 >> 2] = $3656; //@line 64008
           label = 16445; //@line 64010
          }
          if ((label | 0) == 16262) {
           HEAP32[$1 >> 2] = $5861; //@line 64013
          } else if ((label | 0) == 16445) {
           HEAP32[$1 >> 2] = $5865; //@line 64017
           label = 16447; //@line 64019
          }
          if ((label | 0) == 16447) {
           HEAP32[$1 >> 2] = $5861; //@line 64022
          }
          HEAP32[$1 >> 2] = $1950; //@line 64025
          break;
         } else if ((label | 0) == 15908) {
          HEAP32[$1 >> 2] = $5869; //@line 64030
         } else if ((label | 0) == 15931) {
          HEAP32[$1 >> 2] = $2540; //@line 64034
          label = 15935; //@line 64036
         } else if ((label | 0) == 15951) {
          HEAP32[$1 >> 2] = $2590; //@line 64039
          label = 15980; //@line 64041
         } else if ((label | 0) == 15974) {
          HEAP32[$1 >> 2] = $2650; //@line 64044
          label = 15978; //@line 64046
         } else if ((label | 0) == 16001) {
          HEAP32[$1 >> 2] = $2717; //@line 64049
          label = 16075; //@line 64051
         } else if ((label | 0) == 16024) {
          HEAP32[$1 >> 2] = $2777; //@line 64054
          label = 16028; //@line 64056
         } else if ((label | 0) == 16044) {
          HEAP32[$1 >> 2] = $2827; //@line 64059
          label = 16073; //@line 64061
         } else if ((label | 0) == 16067) {
          HEAP32[$1 >> 2] = $2887; //@line 64064
          label = 16071; //@line 64066
         }
         if ((label | 0) == 15935) {
          HEAP32[$1 >> 2] = $5869; //@line 64069
         } else if ((label | 0) == 15978) {
          HEAP32[$1 >> 2] = $2590; //@line 64073
          label = 15980; //@line 64075
         } else if ((label | 0) == 16028) {
          HEAP32[$1 >> 2] = $2717; //@line 64078
          label = 16075; //@line 64080
         } else if ((label | 0) == 16071) {
          HEAP32[$1 >> 2] = $2827; //@line 64083
          label = 16073; //@line 64085
         }
         if ((label | 0) == 15980) {
          HEAP32[$1 >> 2] = $5869; //@line 64088
         } else if ((label | 0) == 16073) {
          HEAP32[$1 >> 2] = $2717; //@line 64092
          label = 16075; //@line 64094
         }
         if ((label | 0) == 16075) {
          HEAP32[$1 >> 2] = $5869; //@line 64097
         }
         HEAP32[$1 >> 2] = $1950; //@line 64100
         break;
        } else if ((label | 0) == 15844) {
         HEAP32[$1 >> 2] = $2221; //@line 64105
        } else if ((label | 0) == 15887) {
         HEAP32[$1 >> 2] = $2331; //@line 64109
         label = 15889; //@line 64111
        }
        if ((label | 0) == 15889) {
         HEAP32[$1 >> 2] = $2221; //@line 64114
        }
        HEAP32[$1 >> 2] = $1950; //@line 64117
        break;
       } else if ((label | 0) == 15766) {
        HEAP32[$1 >> 2] = $2078; //@line 64122
       } else if ((label | 0) == 15789) {
        HEAP32[$1 >> 2] = $2138; //@line 64126
        label = 15793; //@line 64128
       }
       if ((label | 0) == 15793) {
        HEAP32[$1 >> 2] = $2078; //@line 64131
       }
       HEAP32[$1 >> 2] = $1950; //@line 64134
      }
     } while (0);
     HEAP32[$1 >> 2] = $2; //@line 64138
     $_0 = 0; //@line 64140
     STACKTOP = sp; //@line 64142
     return $_0 | 0; //@line 64143
    }
    if ((label | 0) == 15373) {
     HEAP32[$1 >> 2] = $5873; //@line 64146
    } else if ((label | 0) == 15416) {
     HEAP32[$1 >> 2] = $1114; //@line 64150
     label = 15418; //@line 64152
    } else if ((label | 0) == 15466) {
     HEAP32[$1 >> 2] = $1241; //@line 64155
     label = 15513; //@line 64157
    } else if ((label | 0) == 15509) {
     HEAP32[$1 >> 2] = $1351; //@line 64160
     label = 15511; //@line 64162
    } else if ((label | 0) == 15556) {
     HEAP32[$1 >> 2] = $5877; //@line 64165
     label = 15698; //@line 64167
    } else if ((label | 0) == 15599) {
     HEAP32[$1 >> 2] = $1579; //@line 64170
     label = 15601; //@line 64172
    } else if ((label | 0) == 15649) {
     HEAP32[$1 >> 2] = $1706; //@line 64175
     label = 15696; //@line 64177
    } else if ((label | 0) == 15692) {
     HEAP32[$1 >> 2] = $1816; //@line 64180
     label = 15694; //@line 64182
    }
    if ((label | 0) == 15418) {
     HEAP32[$1 >> 2] = $5873; //@line 64185
    } else if ((label | 0) == 15511) {
     HEAP32[$1 >> 2] = $1241; //@line 64189
     label = 15513; //@line 64191
    } else if ((label | 0) == 15601) {
     HEAP32[$1 >> 2] = $5877; //@line 64194
     label = 15698; //@line 64196
    } else if ((label | 0) == 15694) {
     HEAP32[$1 >> 2] = $1706; //@line 64199
     label = 15696; //@line 64201
    }
    if ((label | 0) == 15513) {
     HEAP32[$1 >> 2] = $5873; //@line 64204
    } else if ((label | 0) == 15696) {
     HEAP32[$1 >> 2] = $5877; //@line 64208
     label = 15698; //@line 64210
    }
    if ((label | 0) == 15698) {
     HEAP32[$1 >> 2] = $5873; //@line 64213
    }
    HEAP32[$1 >> 2] = $2; //@line 64216
    $_0 = 0; //@line 64218
    STACKTOP = sp; //@line 64220
    return $_0 | 0; //@line 64221
   } else if ((label | 0) == 15159) {
    HEAP32[$1 >> 2] = $5881; //@line 64224
   } else if ((label | 0) == 15275) {
    HEAP32[$1 >> 2] = $828; //@line 64228
    label = 15279; //@line 64230
   } else if ((label | 0) == 15295) {
    HEAP32[$1 >> 2] = $878; //@line 64233
    label = 15324; //@line 64235
   } else if ((label | 0) == 15318) {
    HEAP32[$1 >> 2] = $938; //@line 64238
    label = 15322; //@line 64240
   }
   if ((label | 0) == 15186) {
    HEAP32[$1 >> 2] = $5881; //@line 64243
   } else if ((label | 0) == 15229) {
    HEAP32[$1 >> 2] = $641; //@line 64247
    label = 15231; //@line 64249
   } else if ((label | 0) == 15279) {
    HEAP32[$1 >> 2] = $768; //@line 64252
    label = 15326; //@line 64254
   } else if ((label | 0) == 15322) {
    HEAP32[$1 >> 2] = $878; //@line 64257
    label = 15324; //@line 64259
   }
   if ((label | 0) == 15231) {
    HEAP32[$1 >> 2] = $5881; //@line 64262
   } else if ((label | 0) == 15324) {
    HEAP32[$1 >> 2] = $768; //@line 64266
    label = 15326; //@line 64268
   }
   if ((label | 0) == 15326) {
    HEAP32[$1 >> 2] = $5881; //@line 64271
   }
   HEAP32[$1 >> 2] = $2; //@line 64274
   $_0 = 0; //@line 64276
   STACKTOP = sp; //@line 64278
   return $_0 | 0; //@line 64279
  } else if ((label | 0) == 15095) {
   HEAP32[$1 >> 2] = $272; //@line 64282
  }
  if ((label | 0) == 15140) {
   HEAP32[$1 >> 2] = $272; //@line 64286
  }
  HEAP32[$1 >> 2] = $2; //@line 64289
  $_0 = 0; //@line 64291
  STACKTOP = sp; //@line 64293
  return $_0 | 0; //@line 64294
 } else if ((label | 0) == 15017) {
  HEAP32[$1 >> 2] = $130; //@line 64297
 } else if ((label | 0) == 15040) {
  HEAP32[$1 >> 2] = $190; //@line 64301
  label = 15044; //@line 64303
 }
 if ((label | 0) == 15044) {
  HEAP32[$1 >> 2] = $130; //@line 64306
 }
 HEAP32[$1 >> 2] = $2; //@line 64309
 $_0 = 0; //@line 64311
 STACKTOP = sp; //@line 64313
 return $_0 | 0; //@line 64314
}
function _cmd_match_expr_cmp($cmd, $val, $base) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 $base = $base | 0;
 var $val2 = 0, $1 = 0, $2 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $19 = 0, $20 = 0, $21 = 0, $23 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $39 = 0, $i_0_i_i41 = 0, $40 = 0, $op_0 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 64332
 STACKTOP = STACKTOP + 8 | 0; //@line 64332
 $val2 = sp | 0; //@line 64333
 $1 = $cmd | 0; //@line 64334
 $2 = HEAP32[$1 >> 2] | 0; //@line 64335
 if ((_cmd_match_expr_shift($cmd, $val, $base) | 0) == 0) {
  $_0 = 0; //@line 64340
  STACKTOP = sp; //@line 64342
  return $_0 | 0; //@line 64343
 }
 L22384 : while (1) {
  $7 = HEAP32[$1 >> 2] | 0; //@line 64348
  while (1) {
   $8 = $cmd + 4 + $7 | 0; //@line 64351
   $9 = HEAP8[$8] | 0; //@line 64352
   if (!(($9 << 24 >> 24 | 0) == 13 | ($9 << 24 >> 24 | 0) == 32 | ($9 << 24 >> 24 | 0) == 9 | ($9 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $7 = $7 + 1 | 0; //@line 64358
  }
  HEAP32[$1 >> 2] = $7; //@line 64360
  $12 = HEAP8[$8] | 0; //@line 64361
  do {
   if ($12 << 24 >> 24 == 60) {
    if ((HEAP8[$7 + 1 + ($cmd + 4) | 0] | 0) != 61) {
     $20 = $7;
     $19 = 60;
     label = 17296; //@line 64371
     break;
    }
    HEAP32[$1 >> 2] = $7 + 2; //@line 64375
    $op_0 = 1; //@line 64377
   } else {
    $20 = $7;
    $19 = $12;
    label = 17296; //@line 64380
   }
  } while (0);
  L22393 : do {
   if ((label | 0) == 17296) {
    while (1) {
     label = 0; //@line 64386
     if (!(($19 << 24 >> 24 | 0) == 13 | ($19 << 24 >> 24 | 0) == 32 | ($19 << 24 >> 24 | 0) == 9 | ($19 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $21 = $20 + 1 | 0; //@line 64392
     $20 = $21;
     $19 = HEAP8[$cmd + 4 + $21 | 0] | 0;
     label = 17296; //@line 64397
    }
    HEAP32[$1 >> 2] = $20; //@line 64400
    $23 = HEAP8[$cmd + 4 + $20 | 0] | 0; //@line 64401
    if ($23 << 24 >> 24 == 60) {
     HEAP32[$1 >> 2] = $20 + 1; //@line 64405
     $op_0 = 2; //@line 64407
     break;
    } else {
     $28 = $20;
     $27 = $23;
    }
    while (1) {
     if (!(($27 << 24 >> 24 | 0) == 13 | ($27 << 24 >> 24 | 0) == 32 | ($27 << 24 >> 24 | 0) == 9 | ($27 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $30 = $28 + 1 | 0; //@line 64418
     $28 = $30;
     $27 = HEAP8[$cmd + 4 + $30 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $28; //@line 64425
    $32 = HEAP8[$cmd + 4 + $28 | 0] | 0; //@line 64426
    do {
     if ($32 << 24 >> 24 == 62) {
      if ((HEAP8[$28 + 1 + ($cmd + 4) | 0] | 0) != 61) {
       $i_0_i_i41 = $28;
       $39 = 62;
       break;
      }
      HEAP32[$1 >> 2] = $28 + 2; //@line 64439
      $op_0 = 3; //@line 64441
      break L22393;
     } else {
      $i_0_i_i41 = $28;
      $39 = $32;
     }
    } while (0);
    while (1) {
     if (!(($39 << 24 >> 24 | 0) == 13 | ($39 << 24 >> 24 | 0) == 32 | ($39 << 24 >> 24 | 0) == 9 | ($39 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $40 = $i_0_i_i41 + 1 | 0; //@line 64453
     $i_0_i_i41 = $40;
     $39 = HEAP8[$cmd + 4 + $40 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $i_0_i_i41; //@line 64460
    if ((HEAP8[$cmd + 4 + $i_0_i_i41 | 0] | 0) != 62) {
     $_0 = 1; //@line 64464
     label = 17319; //@line 64465
     break L22384;
    }
    HEAP32[$1 >> 2] = $i_0_i_i41 + 1; //@line 64469
    $op_0 = 4; //@line 64471
   }
  } while (0);
  if ((_cmd_match_expr_shift($cmd, $val2, $base) | 0) == 0) {
   break;
  }
  if (($op_0 | 0) == 3) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) >>> 0 >= (HEAP32[$val2 >> 2] | 0) >>> 0; //@line 64486
   continue;
  } else if (($op_0 | 0) == 4) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) >>> 0 > (HEAP32[$val2 >> 2] | 0) >>> 0; //@line 64494
   continue;
  } else if (($op_0 | 0) == 2) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) >>> 0 < (HEAP32[$val2 >> 2] | 0) >>> 0; //@line 64502
   continue;
  } else if (($op_0 | 0) == 1) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) >>> 0 <= (HEAP32[$val2 >> 2] | 0) >>> 0; //@line 64510
   continue;
  } else {
   continue;
  }
 }
 if ((label | 0) == 17319) {
  STACKTOP = sp; //@line 64519
  return $_0 | 0; //@line 64520
 }
 HEAP32[$1 >> 2] = $2; //@line 64522
 $_0 = 0; //@line 64524
 STACKTOP = sp; //@line 64526
 return $_0 | 0; //@line 64527
}
function _cmd_match_expr_shift($cmd, $val, $base) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 $base = $base | 0;
 var $val2_i53 = 0, $val2_i = 0, $val2 = 0, $1 = 0, $2 = 0, $8 = 0, $9 = 0, $10 = 0, $13 = 0, $16 = 0, $i_0_i_i84 = 0, $18 = 0, $storemerge93_in = 0, $op_0_i54 = 0, $28 = 0, $30 = 0, $31 = 0, $32 = 0, $35 = 0, $42 = 0, $43 = 0, $44 = 0, $46 = 0, $53 = 0, $54 = 0, $55 = 0, $57 = 0, $64 = 0, $i_0_i_i44 = 0, $65 = 0, $74 = 0, $op_0 = 0, $79 = 0, $80 = 0, $81 = 0, $84 = 0, $87 = 0, $i_0_i_i66 = 0, $89 = 0, $storemerge_in = 0, $op_0_i = 0, $98 = 0, $102 = 0, $104 = 0, $110 = 0, $_0 = 0, $125 = 0, $130 = 0, $131 = 0, $132 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 64554
 STACKTOP = STACKTOP + 24 | 0; //@line 64554
 $val2_i53 = sp | 0; //@line 64555
 $val2_i = sp + 8 | 0; //@line 64556
 $val2 = sp + 16 | 0; //@line 64557
 $1 = $cmd | 0; //@line 64558
 $2 = HEAP32[$1 >> 2] | 0; //@line 64559
 if ((_cmd_match_expr_product($cmd, $val, $base) | 0) == 0) {
  $_0 = 0; //@line 64565
  STACKTOP = sp; //@line 64567
  return $_0 | 0; //@line 64568
 }
 while (1) {
  $8 = HEAP32[$1 >> 2] | 0; //@line 64573
  while (1) {
   $9 = $cmd + 4 + $8 | 0; //@line 64576
   $10 = HEAP8[$9] | 0; //@line 64577
   if (!(($10 << 24 >> 24 | 0) == 13 | ($10 << 24 >> 24 | 0) == 32 | ($10 << 24 >> 24 | 0) == 9 | ($10 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $8 = $8 + 1 | 0; //@line 64583
  }
  HEAP32[$1 >> 2] = $8; //@line 64585
  $13 = HEAP8[$9] | 0; //@line 64586
  if ($13 << 24 >> 24 == 43) {
   $op_0_i54 = 1;
   $storemerge93_in = $8;
  } else {
   $i_0_i_i84 = $8;
   $16 = $13;
   while (1) {
    if (!(($16 << 24 >> 24 | 0) == 13 | ($16 << 24 >> 24 | 0) == 32 | ($16 << 24 >> 24 | 0) == 9 | ($16 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $18 = $i_0_i_i84 + 1 | 0; //@line 64598
    $i_0_i_i84 = $18;
    $16 = HEAP8[$cmd + 4 + $18 | 0] | 0;
   }
   HEAP32[$1 >> 2] = $i_0_i_i84; //@line 64605
   if ((HEAP8[$cmd + 4 + $i_0_i_i84 | 0] | 0) == 45) {
    $op_0_i54 = 2;
    $storemerge93_in = $i_0_i_i84;
   } else {
    break;
   }
  }
  HEAP32[$1 >> 2] = $storemerge93_in + 1; //@line 64617
  if ((_cmd_match_expr_product($cmd, $val2_i53, $base) | 0) == 0) {
   label = 17331; //@line 64622
   break;
  }
  $28 = HEAP32[$val2_i53 >> 2] | 0; //@line 64627
  HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) + (($op_0_i54 | 0) == 1 ? $28 : -$28 | 0); //@line 64631
 }
 if ((label | 0) == 17331) {
  HEAP32[$1 >> 2] = $2; //@line 64634
  $_0 = 0; //@line 64636
  STACKTOP = sp; //@line 64638
  return $_0 | 0; //@line 64639
 }
 $30 = $i_0_i_i84; //@line 64643
 L22443 : while (1) {
  $31 = $cmd + 4 + $30 | 0; //@line 64646
  $32 = HEAP8[$31] | 0; //@line 64647
  if (($32 << 24 >> 24 | 0) == 13 | ($32 << 24 >> 24 | 0) == 32 | ($32 << 24 >> 24 | 0) == 9 | ($32 << 24 >> 24 | 0) == 10) {
   $30 = $30 + 1 | 0; //@line 64651
   continue;
  }
  HEAP32[$1 >> 2] = $30; //@line 64654
  $35 = HEAP8[$31] | 0; //@line 64655
  do {
   if ($35 << 24 >> 24 == 60) {
    if ((HEAP8[$30 + 1 + ($cmd + 4) | 0] | 0) != 60) {
     $43 = $30;
     $42 = 60;
     label = 17337; //@line 64665
     break;
    }
    if ((HEAP8[$30 + 2 + ($cmd + 4) | 0] | 0) != 60) {
     $43 = $30;
     $42 = $35;
     label = 17337; //@line 64674
     break;
    }
    $125 = $30 + 3 | 0; //@line 64677
    HEAP32[$1 >> 2] = $125; //@line 64678
    $op_0 = 1;
    $74 = $125;
   } else {
    $43 = $30;
    $42 = $35;
    label = 17337; //@line 64683
   }
  } while (0);
  L22452 : do {
   if ((label | 0) == 17337) {
    while (1) {
     label = 0; //@line 64689
     if (!(($42 << 24 >> 24 | 0) == 13 | ($42 << 24 >> 24 | 0) == 32 | ($42 << 24 >> 24 | 0) == 9 | ($42 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $44 = $43 + 1 | 0; //@line 64695
     $43 = $44;
     $42 = HEAP8[$cmd + 4 + $44 | 0] | 0;
     label = 17337; //@line 64700
    }
    HEAP32[$1 >> 2] = $43; //@line 64703
    $46 = HEAP8[$cmd + 4 + $43 | 0] | 0; //@line 64704
    do {
     if ($46 << 24 >> 24 == 62) {
      if ((HEAP8[$43 + 1 + ($cmd + 4) | 0] | 0) != 62) {
       $54 = $43;
       $53 = 62;
       break;
      }
      if ((HEAP8[$43 + 2 + ($cmd + 4) | 0] | 0) != 62) {
       $54 = $43;
       $53 = $46;
       break;
      }
      $130 = $43 + 3 | 0; //@line 64724
      HEAP32[$1 >> 2] = $130; //@line 64725
      $op_0 = 2;
      $74 = $130;
      break L22452;
     } else {
      $54 = $43;
      $53 = $46;
     }
    } while (0);
    while (1) {
     if (!(($53 << 24 >> 24 | 0) == 13 | ($53 << 24 >> 24 | 0) == 32 | ($53 << 24 >> 24 | 0) == 9 | ($53 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $55 = $54 + 1 | 0; //@line 64739
     $54 = $55;
     $53 = HEAP8[$cmd + 4 + $55 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $54; //@line 64746
    $57 = HEAP8[$cmd + 4 + $54 | 0] | 0; //@line 64747
    do {
     if ($57 << 24 >> 24 == 60) {
      if ((HEAP8[$54 + 1 + ($cmd + 4) | 0] | 0) != 60) {
       $i_0_i_i44 = $54;
       $64 = 60;
       break;
      }
      $131 = $54 + 2 | 0; //@line 64759
      HEAP32[$1 >> 2] = $131; //@line 64760
      $op_0 = 3;
      $74 = $131;
      break L22452;
     } else {
      $i_0_i_i44 = $54;
      $64 = $57;
     }
    } while (0);
    while (1) {
     if (!(($64 << 24 >> 24 | 0) == 13 | ($64 << 24 >> 24 | 0) == 32 | ($64 << 24 >> 24 | 0) == 9 | ($64 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $65 = $i_0_i_i44 + 1 | 0; //@line 64774
     $i_0_i_i44 = $65;
     $64 = HEAP8[$cmd + 4 + $65 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $i_0_i_i44; //@line 64781
    if ((HEAP8[$cmd + 4 + $i_0_i_i44 | 0] | 0) != 62) {
     $_0 = 1; //@line 64785
     label = 17376; //@line 64786
     break L22443;
    }
    if ((HEAP8[$i_0_i_i44 + 1 + ($cmd + 4) | 0] | 0) != 62) {
     $_0 = 1; //@line 64794
     label = 17375; //@line 64795
     break L22443;
    }
    $132 = $i_0_i_i44 + 2 | 0; //@line 64798
    HEAP32[$1 >> 2] = $132; //@line 64799
    $op_0 = 4;
    $74 = $132;
   }
  } while (0);
  if ((_cmd_match_expr_product($cmd, $val2, $base) | 0) == 0) {
   break;
  }
  while (1) {
   $79 = HEAP32[$1 >> 2] | 0; //@line 64815
   while (1) {
    $80 = $cmd + 4 + $79 | 0; //@line 64818
    $81 = HEAP8[$80] | 0; //@line 64819
    if (!(($81 << 24 >> 24 | 0) == 13 | ($81 << 24 >> 24 | 0) == 32 | ($81 << 24 >> 24 | 0) == 9 | ($81 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $79 = $79 + 1 | 0; //@line 64825
   }
   HEAP32[$1 >> 2] = $79; //@line 64827
   $84 = HEAP8[$80] | 0; //@line 64828
   if ($84 << 24 >> 24 == 43) {
    $op_0_i = 1;
    $storemerge_in = $79;
   } else {
    $i_0_i_i66 = $79;
    $87 = $84;
    while (1) {
     if (!(($87 << 24 >> 24 | 0) == 13 | ($87 << 24 >> 24 | 0) == 32 | ($87 << 24 >> 24 | 0) == 9 | ($87 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $89 = $i_0_i_i66 + 1 | 0; //@line 64840
     $i_0_i_i66 = $89;
     $87 = HEAP8[$cmd + 4 + $89 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $i_0_i_i66; //@line 64847
    if ((HEAP8[$cmd + 4 + $i_0_i_i66 | 0] | 0) == 45) {
     $op_0_i = 2;
     $storemerge_in = $i_0_i_i66;
    } else {
     break;
    }
   }
   HEAP32[$1 >> 2] = $storemerge_in + 1; //@line 64859
   if ((_cmd_match_expr_product($cmd, $val2_i, $base) | 0) == 0) {
    label = 17358; //@line 64864
    break L22443;
   }
   $98 = HEAP32[$val2_i >> 2] | 0; //@line 64869
   HEAP32[$val2 >> 2] = (HEAP32[$val2 >> 2] | 0) + (($op_0_i | 0) == 1 ? $98 : -$98 | 0); //@line 64873
  }
  $102 = HEAP32[$val2 >> 2] & 31; //@line 64876
  HEAP32[$val2 >> 2] = $102; //@line 64877
  if (($op_0 | 0) == 3) {
   HEAP32[$val >> 2] = HEAP32[$val >> 2] << $102; //@line 64881
  } else if (($op_0 | 0) == 4) {
   HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) >>> ($102 >>> 0); //@line 64886
  } else if (($op_0 | 0) == 1) {
   $104 = HEAP32[$val >> 2] | 0; //@line 64889
   HEAP32[$val >> 2] = $104 << $102 | $104 >>> ((32 - $102 | 0) >>> 0); //@line 64894
  } else if (($op_0 | 0) == 2) {
   $110 = HEAP32[$val >> 2] | 0; //@line 64897
   HEAP32[$val >> 2] = $110 >>> ($102 >>> 0) | $110 << 32 - $102; //@line 64902
  }
  $30 = HEAP32[$1 >> 2] | 0; //@line 64906
 }
 if ((label | 0) == 17375) {
  STACKTOP = sp; //@line 64910
  return $_0 | 0; //@line 64911
 } else if ((label | 0) == 17376) {
  STACKTOP = sp; //@line 64915
  return $_0 | 0; //@line 64916
 } else if ((label | 0) == 17358) {
  HEAP32[$1 >> 2] = $74; //@line 64919
 }
 HEAP32[$1 >> 2] = $2; //@line 64922
 $_0 = 0; //@line 64924
 STACKTOP = sp; //@line 64926
 return $_0 | 0; //@line 64927
}
function _cmd_match_expr_product($cmd, $val, $base) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 $base = $base | 0;
 var $val2 = 0, $1 = 0, $2 = 0, $7 = 0, $8 = 0, $9 = 0, $12 = 0, $16 = 0, $17 = 0, $19 = 0, $21 = 0, $25 = 0, $i_0_i_i26 = 0, $27 = 0, $op_0 = 0, $44 = 0, $45 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 64942
 STACKTOP = STACKTOP + 8 | 0; //@line 64942
 $val2 = sp | 0; //@line 64943
 $1 = $cmd | 0; //@line 64944
 $2 = HEAP32[$1 >> 2] | 0; //@line 64945
 if ((_cmd_match_expr_neg($cmd, $val, $base) | 0) == 0) {
  $_0 = 0; //@line 64950
  STACKTOP = sp; //@line 64952
  return $_0 | 0; //@line 64953
 }
 L22504 : while (1) {
  $7 = HEAP32[$1 >> 2] | 0; //@line 64958
  while (1) {
   $8 = $cmd + 4 + $7 | 0; //@line 64961
   $9 = HEAP8[$8] | 0; //@line 64962
   if (!(($9 << 24 >> 24 | 0) == 13 | ($9 << 24 >> 24 | 0) == 32 | ($9 << 24 >> 24 | 0) == 9 | ($9 << 24 >> 24 | 0) == 10)) {
    break;
   }
   $7 = $7 + 1 | 0; //@line 64968
  }
  HEAP32[$1 >> 2] = $7; //@line 64970
  $12 = HEAP8[$8] | 0; //@line 64971
  do {
   if ($12 << 24 >> 24 == 42) {
    HEAP32[$1 >> 2] = $7 + 1; //@line 64976
    $op_0 = 1; //@line 64978
   } else {
    $17 = $7;
    $16 = $12;
    while (1) {
     if (!(($16 << 24 >> 24 | 0) == 13 | ($16 << 24 >> 24 | 0) == 32 | ($16 << 24 >> 24 | 0) == 9 | ($16 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $19 = $17 + 1 | 0; //@line 64987
     $17 = $19;
     $16 = HEAP8[$cmd + 4 + $19 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $17; //@line 64994
    $21 = HEAP8[$cmd + 4 + $17 | 0] | 0; //@line 64995
    if ($21 << 24 >> 24 == 47) {
     HEAP32[$1 >> 2] = $17 + 1; //@line 64999
     $op_0 = 2; //@line 65001
     break;
    } else {
     $i_0_i_i26 = $17;
     $25 = $21;
    }
    while (1) {
     if (!(($25 << 24 >> 24 | 0) == 13 | ($25 << 24 >> 24 | 0) == 32 | ($25 << 24 >> 24 | 0) == 9 | ($25 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $27 = $i_0_i_i26 + 1 | 0; //@line 65012
     $i_0_i_i26 = $27;
     $25 = HEAP8[$cmd + 4 + $27 | 0] | 0;
    }
    HEAP32[$1 >> 2] = $i_0_i_i26; //@line 65019
    if ((HEAP8[$cmd + 4 + $i_0_i_i26 | 0] | 0) != 37) {
     $_0 = 1; //@line 65023
     label = 17405; //@line 65024
     break L22504;
    }
    HEAP32[$1 >> 2] = $i_0_i_i26 + 1; //@line 65028
    $op_0 = 3; //@line 65030
   }
  } while (0);
  if ((_cmd_match_expr_neg($cmd, $val2, $base) | 0) == 0) {
   break;
  }
  if (($op_0 | 0) == 1) {
   HEAP32[$val >> 2] = Math_imul(HEAP32[$val2 >> 2] | 0, HEAP32[$val >> 2] | 0) | 0; //@line 65046
   continue;
  }
  $44 = HEAP32[$val2 >> 2] | 0; //@line 65051
  $45 = ($44 | 0) != 0; //@line 65052
  if (($op_0 | 0) == 2) {
   if ($45) {
    HEAP32[$val >> 2] = ((HEAP32[$val >> 2] | 0) >>> 0) / ($44 >>> 0) | 0; //@line 65059
    continue;
   } else {
    HEAP32[$val >> 2] = -1; //@line 65063
    continue;
   }
  } else {
   if ($45) {
    HEAP32[$val >> 2] = ((HEAP32[$val >> 2] | 0) >>> 0) % ($44 >>> 0) | 0; //@line 65071
    continue;
   } else {
    HEAP32[$val >> 2] = 0; //@line 65075
    continue;
   }
  }
 }
 if ((label | 0) == 17405) {
  STACKTOP = sp; //@line 65082
  return $_0 | 0; //@line 65083
 }
 HEAP32[$1 >> 2] = $2; //@line 65085
 $_0 = 0; //@line 65087
 STACKTOP = sp; //@line 65089
 return $_0 | 0; //@line 65090
}
function _pce_console_init($inp, $out) {
 $inp = $inp | 0;
 $out = $out | 0;
 HEAP32[15328] = $inp; //@line 65099
 HEAP32[15326] = $out; //@line 65100
 return;
}
function _cmd_match_expr_neg($cmd, $val, $base) {
 $cmd = $cmd | 0;
 $val = $val | 0;
 $base = $base | 0;
 var $str_i = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $6 = 0, $9 = 0, $11 = 0, $13 = 0, $14 = 0, $16 = 0, $18 = 0, $20 = 0, $22 = 0, $23 = 0, $25 = 0, $27 = 0, $29 = 0, $31 = 0, $i_0_i_i38 = 0, $33 = 0, $37 = 0, $38 = 0, $op_0 = 0, $39 = 0, $i_0_i_i47 = 0, $42 = 0, $i_0_i_i_i = 0, $46 = 0, $47 = 0, $50 = 0, $_024_i_i = 0, $55 = 0, $n_0_i_i = 0, $57 = 0, $66 = 0, $69 = 0, $72 = 0, $switch_i = 0, $i_0_i_i24_i = 0, $75 = 0, $76 = 0, $79 = 0, $_in_i_i = 0, $ret_037_i_i = 0, $cnt_036_i_i = 0, $i_035_i_i = 0, $81 = 0, $dig_0_i_i = 0, $97 = 0, $98 = 0, $99 = 0, $101 = 0, $ret_0_lcssa_i_i = 0, $cnt_0_lcssa_i_i = 0, $i_0_lcssa_i_i = 0, $_sym_i_i = 0, $111 = 0, $118 = 0, $120 = 0, $121 = 0, $i_0_i31_i = 0, $134 = 0, $135 = 0, $136 = 0, $139 = 0, $i_0_i_i36_i = 0, $148 = 0, $149 = 0, $156 = 0, $i_0_i_i45_i = 0, $158 = 0, $160 = 0, $_in_i47_i = 0, $ret_037_i48_i = 0, $cnt_036_i49_i = 0, $i_035_i50_i = 0, $162 = 0, $dig_0_i55_i = 0, $178 = 0, $179 = 0, $180 = 0, $182 = 0, $ret_0_lcssa_i56_i = 0, $cnt_0_lcssa_i57_i = 0, $i_0_lcssa_i58_i = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 65136
 STACKTOP = STACKTOP + 256 | 0; //@line 65136
 $str_i = sp | 0; //@line 65137
 $1 = $cmd | 0; //@line 65138
 $2 = HEAP32[$1 >> 2] | 0; //@line 65139
 $4 = $2; //@line 65141
 while (1) {
  $5 = $cmd + 4 + $4 | 0; //@line 65144
  $6 = HEAP8[$5] | 0; //@line 65145
  if (!(($6 << 24 >> 24 | 0) == 13 | ($6 << 24 >> 24 | 0) == 32 | ($6 << 24 >> 24 | 0) == 9 | ($6 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $4 = $4 + 1 | 0; //@line 65151
 }
 HEAP32[$1 >> 2] = $4; //@line 65153
 $9 = HEAP8[$5] | 0; //@line 65154
 do {
  if ($9 << 24 >> 24 == 33) {
   $11 = $4 + 1 | 0; //@line 65158
   HEAP32[$1 >> 2] = $11; //@line 65159
   $op_0 = 1;
   $38 = $11;
  } else {
   $14 = $4;
   $13 = $9;
   while (1) {
    if (!(($13 << 24 >> 24 | 0) == 13 | ($13 << 24 >> 24 | 0) == 32 | ($13 << 24 >> 24 | 0) == 9 | ($13 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $16 = $14 + 1 | 0; //@line 65170
    $14 = $16;
    $13 = HEAP8[$cmd + 4 + $16 | 0] | 0;
   }
   HEAP32[$1 >> 2] = $14; //@line 65177
   $18 = HEAP8[$cmd + 4 + $14 | 0] | 0; //@line 65178
   if ($18 << 24 >> 24 == 126) {
    $20 = $14 + 1 | 0; //@line 65181
    HEAP32[$1 >> 2] = $20; //@line 65182
    $op_0 = 2;
    $38 = $20;
    break;
   } else {
    $23 = $14;
    $22 = $18;
   }
   while (1) {
    if (!(($22 << 24 >> 24 | 0) == 13 | ($22 << 24 >> 24 | 0) == 32 | ($22 << 24 >> 24 | 0) == 9 | ($22 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $25 = $23 + 1 | 0; //@line 65195
    $23 = $25;
    $22 = HEAP8[$cmd + 4 + $25 | 0] | 0;
   }
   HEAP32[$1 >> 2] = $23; //@line 65202
   $27 = HEAP8[$cmd + 4 + $23 | 0] | 0; //@line 65203
   if ($27 << 24 >> 24 == 43) {
    $29 = $23 + 1 | 0; //@line 65206
    HEAP32[$1 >> 2] = $29; //@line 65207
    $op_0 = 3;
    $38 = $29;
    break;
   } else {
    $i_0_i_i38 = $23;
    $31 = $27;
   }
   while (1) {
    if (!(($31 << 24 >> 24 | 0) == 13 | ($31 << 24 >> 24 | 0) == 32 | ($31 << 24 >> 24 | 0) == 9 | ($31 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $33 = $i_0_i_i38 + 1 | 0; //@line 65220
    $i_0_i_i38 = $33;
    $31 = HEAP8[$cmd + 4 + $33 | 0] | 0;
   }
   HEAP32[$1 >> 2] = $i_0_i_i38; //@line 65227
   if ((HEAP8[$cmd + 4 + $i_0_i_i38 | 0] | 0) != 45) {
    $op_0 = 0;
    $38 = $i_0_i_i38;
    break;
   }
   $37 = $i_0_i_i38 + 1 | 0; //@line 65234
   HEAP32[$1 >> 2] = $37; //@line 65235
   $op_0 = 4;
   $38 = $37;
  }
 } while (0);
 $39 = $str_i | 0; //@line 65242
 $i_0_i_i47 = $38; //@line 65244
 while (1) {
  $42 = HEAP8[$cmd + 4 + $i_0_i_i47 | 0] | 0; //@line 65248
  if (!(($42 << 24 >> 24 | 0) == 13 | ($42 << 24 >> 24 | 0) == 32 | ($42 << 24 >> 24 | 0) == 9 | ($42 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i_i47 = $i_0_i_i47 + 1 | 0; //@line 65254
 }
 HEAP32[$1 >> 2] = $i_0_i_i47; //@line 65256
 $i_0_i_i_i = $i_0_i_i47; //@line 65258
 while (1) {
  $46 = $cmd + 4 + $i_0_i_i_i | 0; //@line 65261
  $47 = HEAP8[$46] | 0; //@line 65262
  if (!(($47 << 24 >> 24 | 0) == 13 | ($47 << 24 >> 24 | 0) == 32 | ($47 << 24 >> 24 | 0) == 9 | ($47 << 24 >> 24 | 0) == 10)) {
   break;
  }
  $i_0_i_i_i = $i_0_i_i_i + 1 | 0; //@line 65268
 }
 HEAP32[$1 >> 2] = $i_0_i_i_i; //@line 65270
 $50 = HEAP8[$46] | 0; //@line 65271
 if ((($50 << 24 >> 24) - 36 | 0) >>> 0 < 2) {
  HEAP8[$39] = $50; //@line 65278
  $n_0_i_i = 1;
  $55 = $i_0_i_i_i + 1 | 0;
  $_024_i_i = $str_i + 1 | 0;
 } else {
  $n_0_i_i = 0;
  $55 = $i_0_i_i_i;
  $_024_i_i = $39;
 }
 while (1) {
  $57 = HEAP8[$cmd + 4 + $55 | 0] | 0; //@line 65290
  if ($57 << 24 >> 24 == 0) {
   label = 17438; //@line 65294
   break;
  }
  if (!(($57 - 48 & 255) < 10 | ($57 - 97 & 255) < 26 | ($57 - 65 & 255) < 26 | $57 << 24 >> 24 == 95)) {
   label = 17438; //@line 65309
   break;
  }
  HEAP8[$_024_i_i] = $57; //@line 65313
  $66 = $n_0_i_i + 1 | 0; //@line 65315
  if ($66 >>> 0 < 256) {
   $n_0_i_i = $66;
   $55 = $55 + 1 | 0;
   $_024_i_i = $_024_i_i + 1 | 0;
  } else {
   label = 17437; //@line 65321
   break;
  }
 }
 L22581 : do {
  if ((label | 0) == 17437) {
   $69 = (HEAP32[$1 >> 2] | 0) + ($cmd + 4) | 0; //@line 65328
   _pce_printf(42512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = 39432, HEAP32[tempInt + 8 >> 2] = $69, tempInt) | 0); //@line 65329
   $134 = HEAP32[$1 >> 2] | 0; //@line 65332
   label = 17465; //@line 65333
  } else if ((label | 0) == 17438) {
   HEAP8[$_024_i_i] = 0; //@line 65336
   HEAP32[$1 >> 2] = $55; //@line 65337
   if (($n_0_i_i | 0) == 0) {
    $134 = $55; //@line 65341
    label = 17465; //@line 65342
    break;
   }
   $72 = HEAP8[$39] | 0; //@line 65345
   $switch_i = ($72 - 36 & 255) < 2; //@line 65347
   if (!$switch_i) {
    HEAP32[$1 >> 2] = $i_0_i_i47; //@line 65350
    $i_0_i_i24_i = $i_0_i_i47; //@line 65352
    while (1) {
     $75 = $cmd + 4 + $i_0_i_i24_i | 0; //@line 65355
     $76 = HEAP8[$75] | 0; //@line 65356
     if (!(($76 << 24 >> 24 | 0) == 13 | ($76 << 24 >> 24 | 0) == 32 | ($76 << 24 >> 24 | 0) == 9 | ($76 << 24 >> 24 | 0) == 10)) {
      break;
     }
     $i_0_i_i24_i = $i_0_i_i24_i + 1 | 0; //@line 65362
    }
    HEAP32[$1 >> 2] = $i_0_i_i24_i; //@line 65364
    $79 = HEAP8[$75] | 0; //@line 65365
    do {
     if ($79 << 24 >> 24 != 0) {
      $i_035_i_i = $i_0_i_i24_i;
      $cnt_036_i_i = 0;
      $ret_037_i_i = 0;
      $_in_i_i = $79;
      L22592 : while (1) {
       $81 = $_in_i_i << 24 >> 24; //@line 65376
       do {
        if (($_in_i_i - 48 & 255) < 10) {
         $dig_0_i_i = $81 - 48 | 0; //@line 65384
        } else {
         if (($_in_i_i - 97 & 255) < 6) {
          $dig_0_i_i = $81 - 87 | 0; //@line 65392
          break;
         }
         if (($_in_i_i - 65 & 255) >= 6) {
          $i_0_lcssa_i_i = $i_035_i_i;
          $cnt_0_lcssa_i_i = $cnt_036_i_i;
          $ret_0_lcssa_i_i = $ret_037_i_i;
          break L22592;
         }
         $dig_0_i_i = $81 - 55 | 0; //@line 65403
        }
       } while (0);
       if ($dig_0_i_i >>> 0 >= $base >>> 0) {
        $i_0_lcssa_i_i = $i_035_i_i;
        $cnt_0_lcssa_i_i = $cnt_036_i_i;
        $ret_0_lcssa_i_i = $ret_037_i_i;
        break;
       }
       $97 = $dig_0_i_i + (Math_imul($ret_037_i_i, $base) | 0) | 0; //@line 65414
       $98 = $cnt_036_i_i + 1 | 0; //@line 65415
       $99 = $i_035_i_i + 1 | 0; //@line 65416
       $101 = HEAP8[$cmd + 4 + $99 | 0] | 0; //@line 65418
       if ($101 << 24 >> 24 == 0) {
        $i_0_lcssa_i_i = $99;
        $cnt_0_lcssa_i_i = $98;
        $ret_0_lcssa_i_i = $97;
        break;
       } else {
        $i_035_i_i = $99;
        $cnt_036_i_i = $98;
        $ret_037_i_i = $97;
        $_in_i_i = $101;
       }
      }
      if (($cnt_0_lcssa_i_i | 0) == 0) {
       break;
      }
      HEAP32[$1 >> 2] = $i_0_lcssa_i_i; //@line 65436
      HEAP32[$val >> 2] = $ret_0_lcssa_i_i; //@line 65437
      if ((HEAP32[$1 >> 2] | 0) >>> 0 >= $55 >>> 0) {
       break L22581;
      }
     }
    } while (0);
    HEAP32[$1 >> 2] = $55; //@line 65446
   }
   $_sym_i_i = $switch_i ? $str_i + 1 | 0 : $39; //@line 65450
   if ($72 << 24 >> 24 == 36) {
    label = 17460; //@line 65454
   } else {
    $111 = HEAP32[15704] | 0; //@line 65456
    if (($111 | 0) == 0) {
     $118 = $72; //@line 65460
    } else {
     if ((FUNCTION_TABLE_iiii[$111 & 127](HEAP32[15706] | 0, $_sym_i_i, $val) | 0) == 0) {
      break;
     }
     $118 = HEAP8[$39] | 0; //@line 65471
    }
    if ($118 << 24 >> 24 != 37) {
     label = 17460; //@line 65477
    }
   }
   L22613 : do {
    if ((label | 0) == 17460) {
     $120 = HEAP32[15696] | 0; //@line 65482
     $121 = HEAP32[15698] | 0; //@line 65483
     $i_0_i31_i = 0; //@line 65485
     while (1) {
      if ($i_0_i31_i >>> 0 >= $120 >>> 0) {
       break L22613;
      }
      if ((_strcmp(HEAP32[$121 + ($i_0_i31_i << 3) >> 2] | 0, $_sym_i_i | 0) | 0) == 0) {
       break;
      } else {
       $i_0_i31_i = $i_0_i31_i + 1 | 0; //@line 65502
      }
     }
     HEAP32[$val >> 2] = HEAP32[$121 + ($i_0_i31_i << 3) + 4 >> 2]; //@line 65507
     break L22581;
    }
   } while (0);
   HEAP32[$1 >> 2] = $i_0_i_i47; //@line 65512
   $134 = $i_0_i_i47; //@line 65514
   label = 17465; //@line 65515
  }
 } while (0);
 L22620 : do {
  if ((label | 0) == 17465) {
   while (1) {
    label = 0; //@line 65521
    $135 = $cmd + 4 + $134 | 0; //@line 65523
    $136 = HEAP8[$135] | 0; //@line 65524
    if (!(($136 << 24 >> 24 | 0) == 13 | ($136 << 24 >> 24 | 0) == 32 | ($136 << 24 >> 24 | 0) == 9 | ($136 << 24 >> 24 | 0) == 10)) {
     break;
    }
    $134 = $134 + 1 | 0; //@line 65530
    label = 17465; //@line 65531
   }
   HEAP32[$1 >> 2] = $134; //@line 65533
   $139 = HEAP8[$135] | 0; //@line 65534
   do {
    if ($139 << 24 >> 24 == 40) {
     HEAP32[$1 >> 2] = $134 + 1; //@line 65539
     do {
      if ((_cmd_match_expr($cmd, $val, $base) | 0) != 0) {
       $i_0_i_i36_i = HEAP32[$1 >> 2] | 0; //@line 65547
       while (1) {
        $148 = $cmd + 4 + $i_0_i_i36_i | 0; //@line 65550
        $149 = HEAP8[$148] | 0; //@line 65551
        if (!(($149 << 24 >> 24 | 0) == 13 | ($149 << 24 >> 24 | 0) == 32 | ($149 << 24 >> 24 | 0) == 9 | ($149 << 24 >> 24 | 0) == 10)) {
         break;
        }
        $i_0_i_i36_i = $i_0_i_i36_i + 1 | 0; //@line 65557
       }
       HEAP32[$1 >> 2] = $i_0_i_i36_i; //@line 65559
       if ((HEAP8[$148] | 0) != 41) {
        break;
       }
       HEAP32[$1 >> 2] = $i_0_i_i36_i + 1; //@line 65566
       break L22620;
      }
     } while (0);
     HEAP32[$1 >> 2] = $i_0_i_i47; //@line 65571
    } else {
     $i_0_i_i45_i = $134;
     $156 = $139;
     while (1) {
      if (!(($156 << 24 >> 24 | 0) == 13 | ($156 << 24 >> 24 | 0) == 32 | ($156 << 24 >> 24 | 0) == 9 | ($156 << 24 >> 24 | 0) == 10)) {
       break;
      }
      $158 = $i_0_i_i45_i + 1 | 0; //@line 65581
      $i_0_i_i45_i = $158;
      $156 = HEAP8[$cmd + 4 + $158 | 0] | 0;
     }
     HEAP32[$1 >> 2] = $i_0_i_i45_i; //@line 65588
     $160 = HEAP8[$cmd + 4 + $i_0_i_i45_i | 0] | 0; //@line 65589
     if ($160 << 24 >> 24 == 0) {
      break;
     } else {
      $i_035_i50_i = $i_0_i_i45_i;
      $cnt_036_i49_i = 0;
      $ret_037_i48_i = 0;
      $_in_i47_i = $160;
     }
     L22639 : while (1) {
      $162 = $_in_i47_i << 24 >> 24; //@line 65602
      do {
       if (($_in_i47_i - 48 & 255) < 10) {
        $dig_0_i55_i = $162 - 48 | 0; //@line 65610
       } else {
        if (($_in_i47_i - 97 & 255) < 6) {
         $dig_0_i55_i = $162 - 87 | 0; //@line 65618
         break;
        }
        if (($_in_i47_i - 65 & 255) >= 6) {
         $i_0_lcssa_i58_i = $i_035_i50_i;
         $cnt_0_lcssa_i57_i = $cnt_036_i49_i;
         $ret_0_lcssa_i56_i = $ret_037_i48_i;
         break L22639;
        }
        $dig_0_i55_i = $162 - 55 | 0; //@line 65629
       }
      } while (0);
      if ($dig_0_i55_i >>> 0 >= $base >>> 0) {
       $i_0_lcssa_i58_i = $i_035_i50_i;
       $cnt_0_lcssa_i57_i = $cnt_036_i49_i;
       $ret_0_lcssa_i56_i = $ret_037_i48_i;
       break;
      }
      $178 = $dig_0_i55_i + (Math_imul($ret_037_i48_i, $base) | 0) | 0; //@line 65640
      $179 = $cnt_036_i49_i + 1 | 0; //@line 65641
      $180 = $i_035_i50_i + 1 | 0; //@line 65642
      $182 = HEAP8[$cmd + 4 + $180 | 0] | 0; //@line 65644
      if ($182 << 24 >> 24 == 0) {
       $i_0_lcssa_i58_i = $180;
       $cnt_0_lcssa_i57_i = $179;
       $ret_0_lcssa_i56_i = $178;
       break;
      } else {
       $i_035_i50_i = $180;
       $cnt_036_i49_i = $179;
       $ret_037_i48_i = $178;
       $_in_i47_i = $182;
      }
     }
     if (($cnt_0_lcssa_i57_i | 0) == 0) {
      break;
     }
     HEAP32[$1 >> 2] = $i_0_lcssa_i58_i; //@line 65662
     HEAP32[$val >> 2] = $ret_0_lcssa_i56_i; //@line 65663
     break L22620;
    }
   } while (0);
   HEAP32[$1 >> 2] = $2; //@line 65668
   $_0 = 0; //@line 65670
   STACKTOP = sp; //@line 65672
   return $_0 | 0; //@line 65673
  }
 } while (0);
 if (($op_0 | 0) == 2) {
  HEAP32[$val >> 2] = ~HEAP32[$val >> 2]; //@line 65679
  $_0 = 1; //@line 65681
  STACKTOP = sp; //@line 65683
  return $_0 | 0; //@line 65684
 } else if (($op_0 | 0) == 4) {
  HEAP32[$val >> 2] = -(HEAP32[$val >> 2] | 0); //@line 65688
  $_0 = 1; //@line 65690
  STACKTOP = sp; //@line 65692
  return $_0 | 0; //@line 65693
 } else if (($op_0 | 0) == 1) {
  HEAP32[$val >> 2] = (HEAP32[$val >> 2] | 0) == 0; //@line 65698
  $_0 = 1; //@line 65700
  STACKTOP = sp; //@line 65702
  return $_0 | 0; //@line 65703
 } else {
  $_0 = 1; //@line 65705
  STACKTOP = sp; //@line 65707
  return $_0 | 0; //@line 65708
 }
 return 0;
}
function _pce_printf($msg, varrp) {
 $msg = $msg | 0;
 varrp = varrp | 0;
 var $va = 0, $6 = 0, $7 = 0, $12 = 0, sp = 0;
 sp = STACKTOP; //@line 65719
 STACKTOP = STACKTOP + 16 | 0; //@line 65719
 $va = sp | 0; //@line 65720
 if ((HEAP32[15326] | 0) == 0) {
  HEAP32[15326] = HEAP32[_stdout >> 2]; //@line 65726
 }
 $6 = $va | 0; //@line 65729
 $7 = $va; //@line 65730
 HEAP32[$7 >> 2] = varrp; //@line 65731
 HEAP32[$7 + 4 >> 2] = 0; //@line 65731
 _vfprintf(HEAP32[15326] | 0, $msg | 0, $6 | 0) | 0; //@line 65733
 _fflush(HEAP32[15326] | 0) | 0; //@line 65735
 $12 = HEAP32[15322] | 0; //@line 65736
 if (($12 | 0) == 0) {
  STACKTOP = sp; //@line 65741
  return;
 }
 _vfprintf($12 | 0, $msg | 0, $6 | 0) | 0; //@line 65744
 _fflush(HEAP32[15322] | 0) | 0; //@line 65746
 STACKTOP = sp; //@line 65749
 return;
}
function _pce_prt_sep($str) {
 $str = $str | 0;
 var $1 = 0, $2 = 0, $5 = 0, $7 = 0, $10 = 0, $13 = 0, $15 = 0, $18 = 0, $20 = 0, $24 = 0, $28 = 0, $i_022 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $i_023 = 0, $36 = 0, $38 = 0, $41 = 0, $i_0 = 0, $44 = 0, $45 = 0, $47 = 0, $_lcssa21 = 0, $_lcssa = 0, $50 = 0, $52 = 0, $55 = 0;
 $1 = _strlen($str | 0) | 0; //@line 65766
 $2 = HEAP32[15326] | 0; //@line 65767
 if (($2 | 0) == 0) {
  $5 = HEAP32[_stdout >> 2] | 0; //@line 65771
  HEAP32[15326] = $5; //@line 65772
  $7 = $5; //@line 65774
 } else {
  $7 = $2; //@line 65776
 }
 _fputc(45, $7 | 0) | 0; //@line 65779
 _fflush(HEAP32[15326] | 0) | 0; //@line 65781
 $10 = HEAP32[15322] | 0; //@line 65782
 if (($10 | 0) != 0) {
  _fputc(45, $10 | 0) | 0; //@line 65786
  $13 = HEAP32[15322] | 0; //@line 65787
  _fflush($13 | 0) | 0; //@line 65788
 }
 $15 = HEAP32[15326] | 0; //@line 65791
 if (($15 | 0) == 0) {
  $18 = HEAP32[_stdout >> 2] | 0; //@line 65795
  HEAP32[15326] = $18; //@line 65796
  $20 = $18; //@line 65798
 } else {
  $20 = $15; //@line 65800
 }
 _fputs($str | 0, $20 | 0) | 0; //@line 65803
 _fflush(HEAP32[15326] | 0) | 0; //@line 65805
 $24 = HEAP32[15322] | 0; //@line 65806
 if (($24 | 0) != 0) {
  _fputs($str | 0, $24 | 0) | 0; //@line 65810
  $28 = HEAP32[15322] | 0; //@line 65811
  _fflush($28 | 0) | 0; //@line 65812
 }
 $i_022 = $1 + 1 | 0; //@line 65815
 $31 = HEAP32[15326] | 0; //@line 65817
 $32 = ($31 | 0) == 0; //@line 65818
 if ($i_022 >>> 0 < 78) {
  $i_023 = $i_022;
  $34 = $31;
  $33 = $32;
  while (1) {
   if ($33) {
    $36 = HEAP32[_stdout >> 2] | 0; //@line 65828
    HEAP32[15326] = $36; //@line 65829
    $38 = $36; //@line 65831
   } else {
    $38 = $34; //@line 65833
   }
   _fputc(45, $38 | 0) | 0; //@line 65836
   _fflush(HEAP32[15326] | 0) | 0; //@line 65838
   $41 = HEAP32[15322] | 0; //@line 65839
   if (($41 | 0) != 0) {
    _fputc(45, $41 | 0) | 0; //@line 65843
    $47 = HEAP32[15322] | 0; //@line 65844
    _fflush($47 | 0) | 0; //@line 65845
   }
   $i_0 = $i_023 + 1 | 0; //@line 65848
   $44 = HEAP32[15326] | 0; //@line 65850
   $45 = ($44 | 0) == 0; //@line 65851
   if ($i_0 >>> 0 < 78) {
    $i_023 = $i_0;
    $34 = $44;
    $33 = $45;
   } else {
    $_lcssa = $44;
    $_lcssa21 = $45;
    break;
   }
  }
 } else {
  $_lcssa = $31;
  $_lcssa21 = $32;
 }
 if ($_lcssa21) {
  $50 = HEAP32[_stdout >> 2] | 0; //@line 65867
  HEAP32[15326] = $50; //@line 65868
  $52 = $50; //@line 65870
 } else {
  $52 = $_lcssa; //@line 65872
 }
 _fputc(10, $52 | 0) | 0; //@line 65875
 _fflush(HEAP32[15326] | 0) | 0; //@line 65877
 $55 = HEAP32[15322] | 0; //@line 65878
 if (($55 | 0) == 0) {
  return;
 }
 _fputc(10, $55 | 0) | 0; //@line 65885
 _fflush(HEAP32[15322] | 0) | 0; //@line 65887
 return;
}
function _pce_getopt_help($tag, $usage, $opt) {
 $tag = $tag | 0;
 $usage = $usage | 0;
 $opt = $opt | 0;
 var $tmp_sroa_1_i_0_idx14 = 0, $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $8 = 0, $i_037_i = 0, $9 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $23 = 0, $28 = 0, $tmp_sroa_0_0_copyload26_i = 0, $34 = 0, $tmp_sroa_1_2__cast28_i = 0, $35 = 0, $37 = 0, $j_035_us_i = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $48 = 0, $53 = 0, $57 = 0, $60 = 0, $62 = 0, $63 = 0, $j_035_i = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $73 = 0, $79 = 0, $j_0_lcssa33_i = 0, $84 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $tmp_sroa_1_2__cast_i = 0, $_pre = 0, $93 = 0, $w_08_i = 0, $i_06_i = 0, $100 = 0, $n_0_i_i = 0, $n_1_i_i = 0, $110 = 0, $_0_i_i = 0, $w_0_lcssa_i = 0, $127 = 0, $129 = 0, $_015 = 0, $132 = 0, $134 = 0, $_pre_phi_i = 0, $n_0_i = 0, $142 = 0, $n_1_i = 0, $151 = 0, $152 = 0, $n_2_ph_i = 0, $n_216_i = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 65921
 STACKTOP = STACKTOP + 16 | 0; //@line 65921
 $tmp_sroa_1_i_0_idx14 = sp | 0; //@line 65923
 $1 = $opt | 0; //@line 65927
 $2 = HEAP16[$1 >> 1] | 0; //@line 65928
 do {
  if ($2 << 16 >> 16 < 0) {
   $w_0_lcssa_i = 2; //@line 65933
  } else {
   $4 = $opt + 16 | 0; //@line 65935
   $5 = HEAP16[$4 >> 1] | 0; //@line 65936
   if ($5 << 16 >> 16 > -1) {
    $i_037_i = 1;
    $8 = $4;
    $7 = $5;
    do {
     $9 = $i_037_i - 1 | 0; //@line 65945
     $10 = $opt + ($9 << 4) | 0; //@line 65946
     $11 = $7 << 16 >> 16; //@line 65947
     if ($7 << 16 >> 16 < 256) {
      $15 = _tolower($11 | 0) | 0; //@line 65953
     } else {
      $15 = $11; //@line 65955
     }
     $16 = $10 | 0; //@line 65958
     $17 = HEAP16[$16 >> 1] | 0; //@line 65959
     $18 = $17 << 16 >> 16; //@line 65960
     if ($17 << 16 >> 16 < 256) {
      $23 = _tolower($18 | 0) | 0; //@line 65966
     } else {
      $23 = $18; //@line 65968
     }
     do {
      if (($15 | 0) < ($23 | 0)) {
       $tmp_sroa_0_0_copyload26_i = HEAP16[$8 >> 1] | 0; //@line 65977
       label = 17538; //@line 65978
      } else {
       if (($15 | 0) > ($23 | 0)) {
        break;
       }
       $28 = HEAP16[$8 >> 1] | 0; //@line 65985
       if ($28 << 16 >> 16 > (HEAP16[$16 >> 1] | 0)) {
        $tmp_sroa_0_0_copyload26_i = $28; //@line 65990
        label = 17538; //@line 65991
       }
      }
     } while (0);
     if ((label | 0) == 17538) {
      label = 0; //@line 65996
      $34 = $8; //@line 65998
      $tmp_sroa_1_2__cast28_i = $opt + ($i_037_i << 4) + 2 | 0; //@line 66000
      HEAP16[$tmp_sroa_1_i_0_idx14 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i >> 1] | 0; //@line 66001
      HEAP16[$tmp_sroa_1_i_0_idx14 + 2 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i + 2 >> 1] | 0; //@line 66001
      HEAP16[$tmp_sroa_1_i_0_idx14 + 4 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i + 4 >> 1] | 0; //@line 66001
      HEAP16[$tmp_sroa_1_i_0_idx14 + 6 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i + 6 >> 1] | 0; //@line 66001
      HEAP16[$tmp_sroa_1_i_0_idx14 + 8 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i + 8 >> 1] | 0; //@line 66001
      HEAP16[$tmp_sroa_1_i_0_idx14 + 10 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i + 10 >> 1] | 0; //@line 66001
      HEAP16[$tmp_sroa_1_i_0_idx14 + 12 >> 1] = HEAP16[$tmp_sroa_1_2__cast28_i + 12 >> 1] | 0; //@line 66001
      $35 = $10; //@line 66002
      HEAP32[$34 >> 2] = HEAP32[$35 >> 2]; //@line 66003
      HEAP32[$34 + 4 >> 2] = HEAP32[$35 + 4 >> 2]; //@line 66003
      HEAP32[$34 + 8 >> 2] = HEAP32[$35 + 8 >> 2]; //@line 66003
      HEAP32[$34 + 12 >> 2] = HEAP32[$35 + 12 >> 2]; //@line 66003
      L22719 : do {
       if (($9 | 0) == 0) {
        $91 = $opt; //@line 66008
       } else {
        $37 = $tmp_sroa_0_0_copyload26_i << 16 >> 16; //@line 66010
        L22721 : do {
         if ($tmp_sroa_0_0_copyload26_i << 16 >> 16 < 256) {
          $j_035_us_i = $9; //@line 66014
          while (1) {
           $39 = $j_035_us_i - 1 | 0; //@line 66017
           $40 = _tolower($37 | 0) | 0; //@line 66018
           $41 = $opt + ($39 << 4) | 0; //@line 66019
           $42 = HEAP16[$41 >> 1] | 0; //@line 66020
           $43 = $42 << 16 >> 16; //@line 66021
           if ($42 << 16 >> 16 < 256) {
            $48 = _tolower($43 | 0) | 0; //@line 66027
           } else {
            $48 = $43; //@line 66029
           }
           if (($40 | 0) < ($48 | 0)) {
            $60 = $opt + ($j_035_us_i << 4) | 0; //@line 66036
           } else {
            if (($40 | 0) > ($48 | 0)) {
             $j_0_lcssa33_i = $j_035_us_i; //@line 66041
             break L22721;
            }
            $53 = HEAP16[$41 >> 1] | 0; //@line 66044
            if ($tmp_sroa_0_0_copyload26_i << 16 >> 16 < $53 << 16 >> 16) {
             $j_0_lcssa33_i = $j_035_us_i; //@line 66048
             break L22721;
            }
            $57 = $opt + ($j_035_us_i << 4) | 0; //@line 66052
            if ($tmp_sroa_0_0_copyload26_i << 16 >> 16 > $53 << 16 >> 16) {
             $60 = $57; //@line 66054
            } else {
             $91 = $57; //@line 66056
             break L22719;
            }
           }
           $62 = $60; //@line 66062
           $63 = $opt + ($39 << 4) | 0; //@line 66063
           HEAP32[$62 >> 2] = HEAP32[$63 >> 2]; //@line 66064
           HEAP32[$62 + 4 >> 2] = HEAP32[$63 + 4 >> 2]; //@line 66064
           HEAP32[$62 + 8 >> 2] = HEAP32[$63 + 8 >> 2]; //@line 66064
           HEAP32[$62 + 12 >> 2] = HEAP32[$63 + 12 >> 2]; //@line 66064
           if (($39 | 0) == 0) {
            $91 = $opt; //@line 66068
            break L22719;
           } else {
            $j_035_us_i = $39; //@line 66071
           }
          }
         } else {
          $j_035_i = $9; //@line 66075
          while (1) {
           $65 = $j_035_i - 1 | 0; //@line 66078
           $66 = $opt + ($65 << 4) | 0; //@line 66079
           $67 = HEAP16[$66 >> 1] | 0; //@line 66080
           $68 = $67 << 16 >> 16; //@line 66081
           if ($67 << 16 >> 16 < 256) {
            $73 = _tolower($68 | 0) | 0; //@line 66087
           } else {
            $73 = $68; //@line 66089
           }
           if (($37 | 0) < ($73 | 0)) {
            $86 = $opt + ($j_035_i << 4) | 0; //@line 66096
           } else {
            if (($37 | 0) > ($73 | 0)) {
             $j_0_lcssa33_i = $j_035_i; //@line 66101
             break L22721;
            }
            $79 = HEAP16[$66 >> 1] | 0; //@line 66104
            if ($tmp_sroa_0_0_copyload26_i << 16 >> 16 < $79 << 16 >> 16) {
             $j_0_lcssa33_i = $j_035_i; //@line 66108
             break L22721;
            }
            $84 = $opt + ($j_035_i << 4) | 0; //@line 66112
            if ($tmp_sroa_0_0_copyload26_i << 16 >> 16 > $79 << 16 >> 16) {
             $86 = $84; //@line 66114
            } else {
             $91 = $84; //@line 66116
             break L22719;
            }
           }
           $88 = $86; //@line 66122
           $89 = $opt + ($65 << 4) | 0; //@line 66123
           HEAP32[$88 >> 2] = HEAP32[$89 >> 2]; //@line 66124
           HEAP32[$88 + 4 >> 2] = HEAP32[$89 + 4 >> 2]; //@line 66124
           HEAP32[$88 + 8 >> 2] = HEAP32[$89 + 8 >> 2]; //@line 66124
           HEAP32[$88 + 12 >> 2] = HEAP32[$89 + 12 >> 2]; //@line 66124
           if (($65 | 0) == 0) {
            $91 = $opt; //@line 66128
            break L22719;
           } else {
            $j_035_i = $65; //@line 66131
           }
          }
         }
        } while (0);
        $91 = $opt + ($j_0_lcssa33_i << 4) | 0; //@line 66138
       }
      } while (0);
      HEAP16[$91 >> 1] = $tmp_sroa_0_0_copyload26_i; //@line 66143
      $tmp_sroa_1_2__cast_i = $91 + 2 | 0; //@line 66145
      HEAP16[$tmp_sroa_1_2__cast_i >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 >> 1] | 0; //@line 66146
      HEAP16[$tmp_sroa_1_2__cast_i + 2 >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 + 2 >> 1] | 0; //@line 66146
      HEAP16[$tmp_sroa_1_2__cast_i + 4 >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 + 4 >> 1] | 0; //@line 66146
      HEAP16[$tmp_sroa_1_2__cast_i + 6 >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 + 6 >> 1] | 0; //@line 66146
      HEAP16[$tmp_sroa_1_2__cast_i + 8 >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 + 8 >> 1] | 0; //@line 66146
      HEAP16[$tmp_sroa_1_2__cast_i + 10 >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 + 10 >> 1] | 0; //@line 66146
      HEAP16[$tmp_sroa_1_2__cast_i + 12 >> 1] = HEAP16[$tmp_sroa_1_i_0_idx14 + 12 >> 1] | 0; //@line 66146
     }
     $i_037_i = $i_037_i + 1 | 0; //@line 66149
     $8 = $opt + ($i_037_i << 4) | 0; //@line 66150
     $7 = HEAP16[$8 >> 1] | 0; //@line 66151
    } while ($7 << 16 >> 16 > -1);
    $_pre = HEAP16[$1 >> 1] | 0; //@line 66160
    if ($_pre << 16 >> 16 > -1) {
     $i_06_i = 0;
     $w_08_i = 0;
     $93 = $_pre;
    } else {
     $w_0_lcssa_i = 2; //@line 66169
     break;
    }
   } else {
    $i_06_i = 0;
    $w_08_i = 0;
    $93 = $2;
   }
   do {
    do {
     if ((HEAP32[$opt + ($i_06_i << 4) + 12 >> 2] | 0) == 0) {
      $_0_i_i = 0; //@line 66185
     } else {
      $100 = HEAP32[$opt + ($i_06_i << 4) + 4 >> 2] | 0; //@line 66189
      if ($93 << 16 >> 16 < 256) {
       $n_0_i_i = ($100 | 0) == 0 ? 2 : 4; //@line 66195
      } else {
       $n_0_i_i = 0; //@line 66197
      }
      if (($100 | 0) == 0) {
       $n_1_i_i = $n_0_i_i; //@line 66203
      } else {
       $n_1_i_i = $n_0_i_i + 2 + (_strlen($100 | 0) | 0) | 0; //@line 66209
      }
      $110 = HEAP32[$opt + ($i_06_i << 4) + 8 >> 2] | 0; //@line 66213
      if (($110 | 0) == 0) {
       $_0_i_i = $n_1_i_i; //@line 66217
       break;
      }
      $_0_i_i = $n_1_i_i + 1 + (_strlen($110 | 0) | 0) | 0; //@line 66224
     }
    } while (0);
    $w_08_i = $_0_i_i >>> 0 > $w_08_i >>> 0 ? $_0_i_i : $w_08_i; //@line 66229
    $i_06_i = $i_06_i + 1 | 0; //@line 66230
    $93 = HEAP16[$opt + ($i_06_i << 4) >> 1] | 0; //@line 66232
   } while ($93 << 16 >> 16 > -1);
   $w_0_lcssa_i = $w_08_i + 2 | 0; //@line 66242
  }
 } while (0);
 if (($tag | 0) != 0) {
  _printf(51504, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $tag, tempInt) | 0) | 0; //@line 66249
 }
 if (($usage | 0) != 0) {
  _puts($usage | 0) | 0; //@line 66255
 }
 $127 = HEAP16[$1 >> 1] | 0; //@line 66258
 if ($127 << 16 >> 16 > -1) {
  $_015 = $opt;
  $129 = $127;
 } else {
  STACKTOP = sp; //@line 66264
  return;
 }
 do {
  do {
   if ($129 << 16 >> 16 < 256) {
    $132 = $129 << 16 >> 16; //@line 66274
    _printf(36472, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $132, tempInt) | 0) | 0; //@line 66275
    $134 = $_015 + 4 | 0; //@line 66276
    if ((HEAP32[$134 >> 2] | 0) == 0) {
     $n_0_i = 2;
     $_pre_phi_i = $134;
     break;
    }
    _printf(33512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0) | 0; //@line 66284
    $n_0_i = 4;
    $_pre_phi_i = $134;
   } else {
    _printf(31712, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0) | 0; //@line 66288
    $n_0_i = 0;
    $_pre_phi_i = $_015 + 4 | 0;
   }
  } while (0);
  $142 = HEAP32[$_pre_phi_i >> 2] | 0; //@line 66295
  if (($142 | 0) == 0) {
   $n_1_i = $n_0_i; //@line 66299
  } else {
   _printf(30768, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $142, tempInt) | 0) | 0; //@line 66301
   $n_1_i = $n_0_i + 2 + (_strlen(HEAP32[$_pre_phi_i >> 2] | 0) | 0) | 0; //@line 66307
  }
  $151 = $_015 + 8 | 0; //@line 66310
  $152 = HEAP32[$151 >> 2] | 0; //@line 66311
  if (($152 | 0) == 0) {
   $n_2_ph_i = $n_1_i; //@line 66315
  } else {
   _printf(57944, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $152, tempInt) | 0) | 0; //@line 66317
   $n_2_ph_i = $n_1_i + 1 + (_strlen(HEAP32[$151 >> 2] | 0) | 0) | 0; //@line 66323
  }
  if ($n_2_ph_i >>> 0 < $w_0_lcssa_i >>> 0) {
   $n_216_i = $n_2_ph_i; //@line 66329
   do {
    _fputc(32, HEAP32[_stdout >> 2] | 0) | 0; //@line 66333
    $n_216_i = $n_216_i + 1 | 0; //@line 66334
   } while ($n_216_i >>> 0 < $w_0_lcssa_i >>> 0);
  }
  _puts(HEAP32[$_015 + 12 >> 2] | 0) | 0; //@line 66346
  $_015 = $_015 + 16 | 0; //@line 66347
  $129 = HEAP16[$_015 >> 1] | 0; //@line 66349
 } while ($129 << 16 >> 16 > -1);
 STACKTOP = sp; //@line 66358
 return;
}
function _pce_getopt($argc, $argv, $optarg, $opt) {
 $argc = $argc | 0;
 $argv = $argv | 0;
 $optarg = $optarg | 0;
 $opt = $opt | 0;
 var $_b = 0, $11 = 0, $17 = 0, $20 = 0, $22 = 0, $25 = 0, $26 = 0, $27 = 0, $31 = 0, $32 = 0, $35 = 0, $_05_i = 0, $43 = 0, $57 = 0, $63 = 0, $64 = 0, $76 = 0, $77 = 0, $_05_i34 = 0, $79 = 0, $80 = 0, $91 = 0, $92 = 0, $98 = 0, $99 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 66381
 if (($argc | 0) == 0 & ($argv | 0) == 0) {
  HEAP32[1672] = -1; //@line 66387
  $_0 = 0; //@line 66389
  STACKTOP = sp; //@line 66391
  return $_0 | 0; //@line 66392
 }
 if ((HEAP32[1672] | 0) < 0) {
  HEAP8[6696] = 0; //@line 66398
  HEAP32[1672] = 0; //@line 66399
  HEAP32[1670] = 1; //@line 66400
  HEAP32[15324] = 0; //@line 66401
  $_b = 0; //@line 66403
 } else {
  $_b = HEAP8[6696] | 0; //@line 66407
 }
 if ($_b | ($opt | 0) == 0) {
  $11 = HEAP32[1670] | 0; //@line 66414
  if (($11 | 0) >= ($argc | 0)) {
   $_0 = -1; //@line 66418
   STACKTOP = sp; //@line 66420
   return $_0 | 0; //@line 66421
  }
  HEAP32[1672] = $11; //@line 66423
  HEAP32[1670] = $11 + 1; //@line 66425
  HEAP32[$optarg >> 2] = $argv + ($11 << 2); //@line 66427
  $_0 = 0; //@line 66429
  STACKTOP = sp; //@line 66431
  return $_0 | 0; //@line 66432
 }
 $17 = HEAP32[15324] | 0; //@line 66434
 if (($17 | 0) == 0) {
  label = 17597; //@line 66438
 } else {
  $20 = HEAP8[$17] | 0; //@line 66440
  if ($20 << 24 >> 24 == 0) {
   label = 17597; //@line 66444
  } else {
   $76 = $20; //@line 66446
  }
 }
 L22806 : do {
  if ((label | 0) == 17597) {
   $22 = HEAP32[1670] | 0; //@line 66451
   if (($22 | 0) >= ($argc | 0)) {
    $_0 = -1; //@line 66455
    STACKTOP = sp; //@line 66457
    return $_0 | 0; //@line 66458
   }
   HEAP32[1672] = $22; //@line 66460
   $25 = $22 + 1 | 0; //@line 66461
   HEAP32[1670] = $25; //@line 66462
   $26 = $argv + ($22 << 2) | 0; //@line 66463
   $27 = HEAP32[$26 >> 2] | 0; //@line 66464
   HEAP32[15324] = $27; //@line 66465
   do {
    if ((HEAP8[$27] | 0) == 45) {
     $31 = $27 + 1 | 0; //@line 66471
     $32 = HEAP8[$31] | 0; //@line 66472
     if (($32 << 24 >> 24 | 0) == 0) {
      break;
     } else if (($32 << 24 >> 24 | 0) != 45) {
      HEAP32[15324] = $31; //@line 66476
      $76 = HEAP8[$31] | 0; //@line 66479
      break L22806;
     }
     $35 = $27 + 2 | 0; //@line 66482
     if ((HEAP8[$35] | 0) == 0) {
      HEAP8[6696] = 1; //@line 66487
      if (($25 | 0) >= ($argc | 0)) {
       $_0 = -1; //@line 66491
       STACKTOP = sp; //@line 66493
       return $_0 | 0; //@line 66494
      }
      HEAP32[1672] = $25; //@line 66496
      HEAP32[1670] = $22 + 2; //@line 66498
      HEAP32[$optarg >> 2] = $argv + ($25 << 2); //@line 66500
      $_0 = 0; //@line 66502
      STACKTOP = sp; //@line 66504
      return $_0 | 0; //@line 66505
     } else {
      $_05_i = $opt; //@line 66507
     }
     while (1) {
      $43 = $_05_i | 0; //@line 66511
      if ((HEAP16[$43 >> 1] | 0) <= -1) {
       break;
      }
      if ((_strcmp(HEAP32[$_05_i + 4 >> 2] | 0, $35 | 0) | 0) == 0) {
       label = 17606; //@line 66525
       break;
      } else {
       $_05_i = $_05_i + 16 | 0; //@line 66528
      }
     }
     do {
      if ((label | 0) == 17606) {
       if (($_05_i | 0) == 0) {
        break;
       }
       $57 = $_05_i + 2 | 0; //@line 66538
       if (((HEAPU16[$57 >> 1] | 0) + $25 | 0) > ($argc | 0)) {
        $63 = HEAP32[_stderr >> 2] | 0; //@line 66545
        $64 = HEAP32[$argv >> 2] | 0; //@line 66546
        _fprintf($63 | 0, 45944, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $64, HEAP32[tempInt + 8 >> 2] = $27, tempInt) | 0) | 0; //@line 66547
        $_0 = -3; //@line 66549
        STACKTOP = sp; //@line 66551
        return $_0 | 0; //@line 66552
       } else {
        HEAP32[$optarg >> 2] = $argv + ($25 << 2); //@line 66555
        HEAP32[1670] = (HEAP32[1670] | 0) + (HEAPU16[$57 >> 1] | 0); //@line 66560
        HEAP32[15324] = 0; //@line 66561
        $_0 = HEAP16[$43 >> 1] | 0; //@line 66565
        STACKTOP = sp; //@line 66567
        return $_0 | 0; //@line 66568
       }
      }
     } while (0);
     _fprintf(HEAP32[_stderr >> 2] | 0, 49752, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$argv >> 2], HEAP32[tempInt + 8 >> 2] = $27, tempInt) | 0) | 0; //@line 66574
     $_0 = -2; //@line 66576
     STACKTOP = sp; //@line 66578
     return $_0 | 0; //@line 66579
    }
   } while (0);
   HEAP32[$optarg >> 2] = $26; //@line 66582
   HEAP32[15324] = 0; //@line 66583
   $_0 = 0; //@line 66585
   STACKTOP = sp; //@line 66587
   return $_0 | 0; //@line 66588
  }
 } while (0);
 $77 = $76 << 24 >> 24; //@line 66592
 $_05_i34 = $opt; //@line 66594
 while (1) {
  $79 = $_05_i34 | 0; //@line 66597
  $80 = HEAP16[$79 >> 1] | 0; //@line 66598
  if ($80 << 16 >> 16 <= -1) {
   break;
  }
  if (($80 << 16 >> 16 | 0) == ($77 | 0)) {
   label = 17615; //@line 66609
   break;
  } else {
   $_05_i34 = $_05_i34 + 16 | 0; //@line 66612
  }
 }
 do {
  if ((label | 0) == 17615) {
   if (($_05_i34 | 0) == 0) {
    break;
   }
   $91 = HEAP32[1670] | 0; //@line 66622
   $92 = $_05_i34 + 2 | 0; //@line 66623
   if (((HEAPU16[$92 >> 1] | 0) + $91 | 0) > ($argc | 0)) {
    $98 = HEAP32[_stderr >> 2] | 0; //@line 66630
    $99 = HEAP32[$argv >> 2] | 0; //@line 66631
    _fprintf($98 | 0, 39392, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $99, HEAP32[tempInt + 8 >> 2] = $77, tempInt) | 0) | 0; //@line 66632
    $_0 = -3; //@line 66634
    STACKTOP = sp; //@line 66636
    return $_0 | 0; //@line 66637
   } else {
    HEAP32[$optarg >> 2] = $argv + ($91 << 2); //@line 66640
    HEAP32[1670] = (HEAP32[1670] | 0) + (HEAPU16[$92 >> 1] | 0); //@line 66645
    HEAP32[15324] = (HEAP32[15324] | 0) + 1; //@line 66648
    $_0 = HEAP16[$79 >> 1] | 0; //@line 66652
    STACKTOP = sp; //@line 66654
    return $_0 | 0; //@line 66655
   }
  }
 } while (0);
 _fprintf(HEAP32[_stderr >> 2] | 0, 42480, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = HEAP32[$argv >> 2], HEAP32[tempInt + 8 >> 2] = $77, tempInt) | 0) | 0; //@line 66661
 $_0 = -2; //@line 66663
 STACKTOP = sp; //@line 66665
 return $_0 | 0; //@line 66666
}
function _dsk_insert($dsks, $str, $eject) {
 $dsks = $dsks | 0;
 $str = $str | 0;
 $eject = $eject | 0;
 var $buf = 0, $1 = 0, $6 = 0, $i_032_lcssa33_ph = 0, $i_0323537 = 0, $13 = 0, $15 = 0, $16 = 0, $21 = 0, $_0 = 0, $32 = 0, $36 = 0, $40 = 0, $44 = 0, $48 = 0, $52 = 0, $56 = 0, $60 = 0, $64 = 0, $68 = 0, $72 = 0, $76 = 0, $80 = 0, $84 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 66684
 STACKTOP = STACKTOP + 16 | 0; //@line 66684
 $buf = sp | 0; //@line 66685
 $1 = HEAP8[$str] | 0; //@line 66686
 if (($1 << 24 >> 24 | 0) == 0) {
  $_0 = 1; //@line 66688
  STACKTOP = sp; //@line 66690
  return $_0 | 0; //@line 66691
 } else if (($1 << 24 >> 24 | 0) == 58) {
  HEAP8[$buf | 0] = 0; //@line 66694
  $_0 = 1; //@line 66696
  STACKTOP = sp; //@line 66698
  return $_0 | 0; //@line 66699
 } else {
  HEAP8[$buf | 0] = $1; //@line 66702
  $6 = HEAP8[$str + 1 | 0] | 0; //@line 66704
  do {
   if (($6 << 24 >> 24 | 0) == 0) {
    $i_0323537 = 1; //@line 66707
   } else if (($6 << 24 >> 24 | 0) == 58) {
    $i_032_lcssa33_ph = 1; //@line 66709
    label = 17637; //@line 66710
   } else {
    HEAP8[$buf + 1 | 0] = $6; //@line 66713
    $32 = HEAP8[$str + 2 | 0] | 0; //@line 66715
    if (($32 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 2; //@line 66717
     break;
    } else if (($32 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 2; //@line 66720
     label = 17637; //@line 66721
     break;
    }
    HEAP8[$buf + 2 | 0] = $32; //@line 66725
    $36 = HEAP8[$str + 3 | 0] | 0; //@line 66727
    if (($36 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 3; //@line 66729
     break;
    } else if (($36 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 3; //@line 66732
     label = 17637; //@line 66733
     break;
    }
    HEAP8[$buf + 3 | 0] = $36; //@line 66737
    $40 = HEAP8[$str + 4 | 0] | 0; //@line 66739
    if (($40 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 4; //@line 66741
     break;
    } else if (($40 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 4; //@line 66744
     label = 17637; //@line 66745
     break;
    }
    HEAP8[$buf + 4 | 0] = $40; //@line 66749
    $44 = HEAP8[$str + 5 | 0] | 0; //@line 66751
    if (($44 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 5; //@line 66753
     break;
    } else if (($44 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 5; //@line 66756
     label = 17637; //@line 66757
     break;
    }
    HEAP8[$buf + 5 | 0] = $44; //@line 66761
    $48 = HEAP8[$str + 6 | 0] | 0; //@line 66763
    if (($48 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 6; //@line 66765
     break;
    } else if (($48 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 6; //@line 66768
     label = 17637; //@line 66769
     break;
    }
    HEAP8[$buf + 6 | 0] = $48; //@line 66773
    $52 = HEAP8[$str + 7 | 0] | 0; //@line 66775
    if (($52 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 7; //@line 66777
     break;
    } else if (($52 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 7; //@line 66780
     label = 17637; //@line 66781
     break;
    }
    HEAP8[$buf + 7 | 0] = $52; //@line 66785
    $56 = HEAP8[$str + 8 | 0] | 0; //@line 66787
    if (($56 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 8; //@line 66789
     break;
    } else if (($56 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 8; //@line 66792
     label = 17637; //@line 66793
     break;
    }
    HEAP8[$buf + 8 | 0] = $56; //@line 66797
    $60 = HEAP8[$str + 9 | 0] | 0; //@line 66799
    if (($60 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 9; //@line 66801
     break;
    } else if (($60 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 9; //@line 66804
     label = 17637; //@line 66805
     break;
    }
    HEAP8[$buf + 9 | 0] = $60; //@line 66809
    $64 = HEAP8[$str + 10 | 0] | 0; //@line 66811
    if (($64 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 10; //@line 66813
     break;
    } else if (($64 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 10; //@line 66816
     label = 17637; //@line 66817
     break;
    }
    HEAP8[$buf + 10 | 0] = $64; //@line 66821
    $68 = HEAP8[$str + 11 | 0] | 0; //@line 66823
    if (($68 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 11; //@line 66825
     break;
    } else if (($68 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 11; //@line 66828
     label = 17637; //@line 66829
     break;
    }
    HEAP8[$buf + 11 | 0] = $68; //@line 66833
    $72 = HEAP8[$str + 12 | 0] | 0; //@line 66835
    if (($72 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 12; //@line 66837
     break;
    } else if (($72 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 12; //@line 66840
     label = 17637; //@line 66841
     break;
    }
    HEAP8[$buf + 12 | 0] = $72; //@line 66845
    $76 = HEAP8[$str + 13 | 0] | 0; //@line 66847
    if (($76 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 13; //@line 66849
     break;
    } else if (($76 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 13; //@line 66852
     label = 17637; //@line 66853
     break;
    }
    HEAP8[$buf + 13 | 0] = $76; //@line 66857
    $80 = HEAP8[$str + 14 | 0] | 0; //@line 66859
    if (($80 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 14; //@line 66861
     break;
    } else if (($80 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 14; //@line 66864
     label = 17637; //@line 66865
     break;
    }
    HEAP8[$buf + 14 | 0] = $80; //@line 66869
    $84 = HEAP8[$str + 15 | 0] | 0; //@line 66871
    if (($84 << 24 >> 24 | 0) == 0) {
     $i_0323537 = 15; //@line 66873
     break;
    } else if (($84 << 24 >> 24 | 0) == 58) {
     $i_032_lcssa33_ph = 15; //@line 66876
     label = 17637; //@line 66877
     break;
    }
    HEAP8[$buf + 15 | 0] = $84; //@line 66881
    $_0 = 1; //@line 66882
    STACKTOP = sp; //@line 66884
    return $_0 | 0; //@line 66885
   }
  } while (0);
  if ((label | 0) == 17637) {
   HEAP8[$buf + $i_032_lcssa33_ph | 0] = 0; //@line 66891
   $i_0323537 = $i_032_lcssa33_ph; //@line 66893
  }
  if ((HEAP8[$str + $i_0323537 | 0] | 0) == 0) {
   $_0 = 1; //@line 66901
   STACKTOP = sp; //@line 66903
   return $_0 | 0; //@line 66904
  }
  $13 = _strtoul($buf | 0, 0, 0) | 0; //@line 66907
  $15 = _pce_path_get($str + ($i_0323537 + 1) | 0) | 0; //@line 66910
  $16 = _dsk_auto_open($15, 0, 0, 0) | 0; //@line 66913
  _free($15); //@line 66915
  if (($16 | 0) == 0) {
   $_0 = 1; //@line 66918
   STACKTOP = sp; //@line 66920
   return $_0 | 0; //@line 66921
  }
  _dsk_set_drive($16, $13); //@line 66923
  do {
   if (($eject | 0) != 0) {
    $21 = _dsks_get_disk($dsks, $13) | 0; //@line 66928
    if (($21 | 0) == 0) {
     break;
    }
    _dsks_rmv_disk($dsks, $21) | 0; //@line 66934
    _dsk_del($21); //@line 66935
   }
  } while (0);
  if ((_dsks_add_disk($dsks, $16) | 0) == 0) {
   $_0 = 0; //@line 66943
   STACKTOP = sp; //@line 66945
   return $_0 | 0; //@line 66946
  }
  _dsk_del($16); //@line 66948
  $_0 = 1; //@line 66950
  STACKTOP = sp; //@line 66952
  return $_0 | 0; //@line 66953
 }
 return 0;
}
function _ini_get_cow($sct, $dsk) {
 $sct = $sct | 0;
 $dsk = $dsk | 0;
 var $1 = 0, $3 = 0, $_01621 = 0, $4 = 0, $8 = 0, $11 = 0, $14 = 0, $cow_017 = 0, $15 = 0, $16 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 66964
 $1 = _ini_next_val($sct, 0, 51456) | 0; //@line 66965
 if (($1 | 0) == 0) {
  $_0 = $dsk; //@line 66969
  STACKTOP = sp; //@line 66971
  return $_0 | 0; //@line 66972
 } else {
  $_01621 = $dsk;
  $3 = $1;
 }
 while (1) {
  $4 = _ini_val_get_str($3) | 0; //@line 66979
  if (($4 | 0) == 0) {
   label = 17670; //@line 66983
   break;
  }
  $8 = _dsk_qed_cow_new($_01621, $4) | 0; //@line 66986
  if (($8 | 0) == 0) {
   $11 = _dsk_cow_new($_01621, $4) | 0; //@line 66990
   if (($11 | 0) == 0) {
    label = 17673; //@line 66994
    break;
   } else {
    $cow_017 = $11; //@line 66997
   }
  } else {
   $cow_017 = $8; //@line 67000
  }
  _dsk_set_readonly($cow_017, 0); //@line 67003
  $15 = _dsk_get_drive($cow_017) | 0; //@line 67004
  _pce_log_tag(2, 56224, 45896, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $15, HEAP32[tempInt + 8 >> 2] = $4, tempInt) | 0); //@line 67005
  $16 = _ini_next_val($sct, $3, 51456) | 0; //@line 67006
  if (($16 | 0) == 0) {
   $_0 = $cow_017; //@line 67010
   label = 17678; //@line 67011
   break;
  } else {
   $_01621 = $cow_017;
   $3 = $16;
  }
 }
 if ((label | 0) == 17678) {
  STACKTOP = sp; //@line 67019
  return $_0 | 0; //@line 67020
 } else if ((label | 0) == 17670) {
  _dsk_del($_01621); //@line 67023
  $_0 = 0; //@line 67025
  STACKTOP = sp; //@line 67027
  return $_0 | 0; //@line 67028
 } else if ((label | 0) == 17673) {
  $14 = _dsk_get_drive($_01621) | 0; //@line 67031
  _pce_log_tag(0, 56224, 49712, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $14, HEAP32[tempInt + 8 >> 2] = $4, tempInt) | 0); //@line 67032
  _dsk_del($_01621); //@line 67033
  $_0 = 0; //@line 67035
  STACKTOP = sp; //@line 67037
  return $_0 | 0; //@line 67038
 }
 return 0;
}
function _ini_get_disk($sct, $ret) {
 $sct = $sct | 0;
 $ret = $ret | 0;
 var $vc_i = 0, $vh_i = 0, $vs_i = 0, $1 = 0, $start_i = 0, $blk_i_i = 0, $blk_n_i = 0, $fname_i = 0, $drive = 0, $c = 0, $h = 0, $s = 0, $n = 0, $ofs = 0, $ro = 0, $optional = 0, $type = 0, $val_0_ph = 0, $path_0_ph = 0, $val_0 = 0, $47 = 0, $50 = 0, $53 = 0, $57 = 0, $97 = 0, $98 = 0, $99 = 0, $100 = 0, $101 = 0, $p_0_i = 0, $103 = 0, $111 = 0, $115 = 0, $122 = 0, $dsk_1 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $209 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $220 = 0, $227 = 0, $232 = 0, $233 = 0, $238 = 0, $239 = 0, $244 = 0, $257 = 0, $259 = 0, $261 = 0, $263 = 0, $264 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 67076
 STACKTOP = STACKTOP + 136 | 0; //@line 67076
 $vc_i = sp | 0; //@line 67077
 $vh_i = sp + 8 | 0; //@line 67078
 $vs_i = sp + 16 | 0; //@line 67079
 $1 = sp + 24 | 0; //@line 67080
 $start_i = sp + 32 | 0; //@line 67081
 $blk_i_i = sp + 40 | 0; //@line 67082
 $blk_n_i = sp + 48 | 0; //@line 67083
 $fname_i = sp + 56 | 0; //@line 67084
 $drive = sp + 64 | 0; //@line 67085
 $c = sp + 72 | 0; //@line 67086
 $h = sp + 80 | 0; //@line 67087
 $s = sp + 88 | 0; //@line 67088
 $n = sp + 96 | 0; //@line 67089
 $ofs = sp + 104 | 0; //@line 67090
 $ro = sp + 112 | 0; //@line 67091
 $optional = sp + 120 | 0; //@line 67092
 $type = sp + 128 | 0; //@line 67093
 _ini_get_uint16($sct, 42448, $drive, 0) | 0; //@line 67094
 _ini_get_string($sct, 39384, $type, 36464) | 0; //@line 67095
 _ini_get_uint32($sct, 33504, $ofs, 0) | 0; //@line 67096
 _ini_get_uint32($sct, 31704, $c, 0) | 0; //@line 67097
 _ini_get_uint32($sct, 30760, $h, 0) | 0; //@line 67098
 _ini_get_uint32($sct, 57936, $s, 0) | 0; //@line 67099
 do {
  if ((_ini_get_uint32($sct, 57144, $n, 0) | 0) != 0) {
   if ((_ini_get_uint32($sct, 55952, $n, 0) | 0) == 0) {
    HEAP32[$n >> 2] = HEAP32[$n >> 2] & -512; //@line 67111
    break;
   }
   if ((_ini_get_uint32($sct, 55264, $n, 0) | 0) == 0) {
    HEAP32[$n >> 2] = HEAP32[$n >> 2] << 1; //@line 67121
    break;
   }
   if ((_ini_get_uint32($sct, 54600, $n, 0) | 0) == 0) {
    HEAP32[$n >> 2] = HEAP32[$n >> 2] << 11; //@line 67131
    break;
   }
   if ((_ini_get_uint32($sct, 53904, $n, 0) | 0) == 0) {
    HEAP32[$n >> 2] = HEAP32[$n >> 2] << 21; //@line 67141
    break;
   } else {
    HEAP32[$n >> 2] = 0; //@line 67145
    break;
   }
  }
 } while (0);
 _ini_get_bool($sct, 53296, $ro, 0) | 0; //@line 67150
 _ini_get_bool($sct, 52464, $optional, 0) | 0; //@line 67151
 $path_0_ph = 0;
 $val_0_ph = 0;
 L22922 : while (1) {
  $val_0 = $val_0_ph; //@line 67162
  do {
   $val_0 = _ini_next_val($sct, $val_0, 51832) | 0; //@line 67165
   if (($val_0 | 0) == 0) {
    label = 17734; //@line 67169
    break L22922;
   }
   $47 = _ini_val_get_str($val_0) | 0; //@line 67172
  } while (($47 | 0) == 0);
  _free($path_0_ph); //@line 67181
  $50 = _pce_path_get($47) | 0; //@line 67182
  if (($50 | 0) == 0) {
   $path_0_ph = 0;
   $val_0_ph = $val_0;
   continue;
  }
  $53 = _fopen($50 | 0, 51304) | 0; //@line 67189
  if (($53 | 0) == 0) {
   $path_0_ph = $50;
   $val_0_ph = $val_0;
   continue;
  }
  _fclose($53 | 0) | 0; //@line 67196
  $57 = HEAP32[$type >> 2] | 0; //@line 67197
  L22930 : do {
   if ((_strcmp($57 | 0, 50800) | 0) == 0) {
    $dsk_1 = _dsk_ram_open($50, HEAP32[$n >> 2] | 0, HEAP32[$c >> 2] | 0, HEAP32[$h >> 2] | 0, HEAP32[$s >> 2] | 0, HEAP32[$ro >> 2] | 0) | 0; //@line 67210
   } else {
    if ((_strcmp($57 | 0, 50472) | 0) == 0) {
     $dsk_1 = _dsk_img_open($50, HEAP32[$ofs >> 2] | 0, 0, HEAP32[$ro >> 2] | 0) | 0; //@line 67222
     break;
    }
    if ((_strcmp($57 | 0, 49520) | 0) == 0) {
     $dsk_1 = _dsk_dosemu_open($50, HEAP32[$ro >> 2] | 0) | 0; //@line 67232
     break;
    }
    if ((_strcmp($57 | 0, 49056) | 0) == 0) {
     $dsk_1 = _dsk_pce_open($50, HEAP32[$ro >> 2] | 0) | 0; //@line 67242
     break;
    }
    if ((_strcmp($57 | 0, 48664) | 0) == 0) {
     $dsk_1 = _dsk_qed_open($50, HEAP32[$ro >> 2] | 0) | 0; //@line 67252
     break;
    }
    if ((_strcmp($57 | 0, 48264) | 0) == 0) {
     $97 = HEAP32[$c >> 2] | 0; //@line 67259
     $98 = HEAP32[$h >> 2] | 0; //@line 67260
     $99 = HEAP32[$s >> 2] | 0; //@line 67261
     $100 = HEAP32[$ro >> 2] | 0; //@line 67262
     HEAP32[$1 >> 2] = $100; //@line 67263
     $101 = _dsk_part_open($97, $98, $99, $100) | 0; //@line 67264
     if (($101 | 0) == 0) {
      $path_0_ph = $50;
      $val_0_ph = $val_0;
      continue L22922;
     } else {
      $p_0_i = 0; //@line 67271
     }
     while (1) {
      $103 = _ini_next_sct($sct, $p_0_i, 48264) | 0; //@line 67275
      if (($103 | 0) == 0) {
       $dsk_1 = $101; //@line 67279
       break L22930;
      }
      _ini_get_uint32($103, 33504, $start_i, 0) | 0; //@line 67282
      _ini_get_uint32($103, 41e3, $blk_i_i, 0) | 0; //@line 67283
      _ini_get_uint32($103, 40768, $blk_n_i, 0) | 0; //@line 67284
      _ini_get_string($103, 51832, $fname_i, 0) | 0; //@line 67285
      _ini_get_bool($103, 53296, $1, 0) | 0; //@line 67286
      $111 = HEAP32[$fname_i >> 2] | 0; //@line 67287
      if (($111 | 0) == 0) {
       label = 17710; //@line 67291
       break;
      }
      $115 = _pce_path_get($111) | 0; //@line 67294
      $122 = (_dsk_part_add_partition($101, $115, HEAP32[$start_i >> 2] | 0, 0, HEAP32[$blk_i_i >> 2] | 0, HEAP32[$blk_n_i >> 2] | 0, HEAP32[$1 >> 2] | 0) | 0) == 0; //@line 67302
      _free($115); //@line 67303
      if ($122) {
       $p_0_i = $103; //@line 67306
      } else {
       label = 17712; //@line 67308
       break;
      }
     }
     if ((label | 0) == 17710) {
      label = 0; //@line 67313
      _dsk_del($101); //@line 67314
      $path_0_ph = $50;
      $val_0_ph = $val_0;
      continue L22922;
     } else if ((label | 0) == 17712) {
      label = 0; //@line 67320
      _dsk_del($101); //@line 67321
      $path_0_ph = $50;
      $val_0_ph = $val_0;
      continue L22922;
     }
    }
    if ((_strcmp($57 | 0, 47888) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 1, HEAP32[$ro >> 2] | 0) | 0; //@line 67334
     break;
    }
    if ((_strcmp($57 | 0, 47584) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 2, HEAP32[$ro >> 2] | 0) | 0; //@line 67344
     break;
    }
    if ((_strcmp($57 | 0, 47296) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 3, HEAP32[$ro >> 2] | 0) | 0; //@line 67354
     break;
    }
    if ((_strcmp($57 | 0, 47008) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 4, HEAP32[$ro >> 2] | 0) | 0; //@line 67364
     break;
    }
    if ((_strcmp($57 | 0, 46712) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 4, HEAP32[$ro >> 2] | 0) | 0; //@line 67374
     break;
    }
    if ((_strcmp($57 | 0, 46456) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 6, HEAP32[$ro >> 2] | 0) | 0; //@line 67384
     break;
    }
    if ((_strcmp($57 | 0, 45744) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 0, HEAP32[$ro >> 2] | 0) | 0; //@line 67394
     break;
    }
    if ((_strcmp($57 | 0, 45440) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 11, HEAP32[$ro >> 2] | 0) | 0; //@line 67404
     break;
    }
    if ((_strcmp($57 | 0, 45096) | 0) == 0) {
     $dsk_1 = _dsk_psi_open($50, 16, HEAP32[$ro >> 2] | 0) | 0; //@line 67414
     break;
    }
    if ((_strcmp($57 | 0, 36464) | 0) != 0) {
     $path_0_ph = $50;
     $val_0_ph = $val_0;
     continue L22922;
    }
    $dsk_1 = _dsk_auto_open($50, HEAP32[$ofs >> 2] | 0, 0, HEAP32[$ro >> 2] | 0) | 0; //@line 67430
   }
  } while (0);
  if (($dsk_1 | 0) == 0) {
   $path_0_ph = $50;
   $val_0_ph = $val_0;
  } else {
   break;
  }
 }
 if ((label | 0) == 17734) {
  HEAP32[$ret >> 2] = 0; //@line 67443
  _free($path_0_ph); //@line 67444
  if ((HEAP32[$optional >> 2] | 0) != 0) {
   $_0 = 0; //@line 67449
   STACKTOP = sp; //@line 67451
   return $_0 | 0; //@line 67452
  }
  _pce_log(0, 44752, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$drive >> 2], tempInt) | 0); //@line 67455
  $_0 = 1; //@line 67457
  STACKTOP = sp; //@line 67459
  return $_0 | 0; //@line 67460
 }
 _dsk_set_drive($dsk_1, HEAP32[$drive >> 2] | 0); //@line 67463
 do {
  if ((HEAP32[$c >> 2] | 0) == 0) {
   if ((HEAP32[$h >> 2] | 0) != 0) {
    label = 17739; //@line 67473
    break;
   }
   if ((HEAP32[$s >> 2] | 0) != 0) {
    label = 17739; //@line 67480
   }
  } else {
   label = 17739; //@line 67483
  }
 } while (0);
 if ((label | 0) == 17739) {
  $202 = _dsk_get_block_cnt($dsk_1) | 0; //@line 67487
  $203 = HEAP32[$c >> 2] | 0; //@line 67488
  $204 = HEAP32[$h >> 2] | 0; //@line 67489
  $205 = HEAP32[$s >> 2] | 0; //@line 67490
  _dsk_set_geometry($dsk_1, $202, $203, $204, $205) | 0; //@line 67491
 }
 $209 = HEAP32[$type >> 2] | 0; //@line 67495
 $211 = HEAP32[$dsk_1 + 28 >> 2] | 0; //@line 67497
 $212 = $dsk_1 + 32 | 0; //@line 67498
 $213 = HEAP32[$212 >> 2] | 0; //@line 67499
 $214 = $dsk_1 + 36 | 0; //@line 67500
 $215 = HEAP32[$214 >> 2] | 0; //@line 67501
 $216 = $dsk_1 + 40 | 0; //@line 67502
 $217 = HEAP32[$216 >> 2] | 0; //@line 67503
 $220 = (HEAP32[$ro >> 2] | 0) != 0 ? 44128 : 43808; //@line 67506
 _pce_log_tag(2, 56224, 44384, (tempInt = STACKTOP, STACKTOP = STACKTOP + 64 | 0, HEAP32[tempInt >> 2] = HEAP32[$drive >> 2], HEAP32[tempInt + 8 >> 2] = $209, HEAP32[tempInt + 16 >> 2] = $211, HEAP32[tempInt + 24 >> 2] = $213, HEAP32[tempInt + 32 >> 2] = $215, HEAP32[tempInt + 40 >> 2] = $217, HEAP32[tempInt + 48 >> 2] = $220, HEAP32[tempInt + 56 >> 2] = $50, tempInt) | 0); //@line 67507
 _free($50); //@line 67508
 _ini_get_uint32($sct, 42280, $vc_i, 0) | 0; //@line 67512
 _ini_get_uint32($sct, 41944, $vh_i, 0) | 0; //@line 67513
 _ini_get_uint32($sct, 41568, $vs_i, 0) | 0; //@line 67514
 $227 = HEAP32[$vc_i >> 2] | 0; //@line 67515
 if (($227 | 0) == 0) {
  $232 = HEAP32[$212 >> 2] | 0; //@line 67521
 } else {
  $232 = $227; //@line 67523
 }
 HEAP32[$vc_i >> 2] = $232; //@line 67526
 $233 = HEAP32[$vh_i >> 2] | 0; //@line 67527
 if (($233 | 0) == 0) {
  $238 = HEAP32[$214 >> 2] | 0; //@line 67533
 } else {
  $238 = $233; //@line 67535
 }
 HEAP32[$vh_i >> 2] = $238; //@line 67538
 $239 = HEAP32[$vs_i >> 2] | 0; //@line 67539
 if (($239 | 0) == 0) {
  $244 = HEAP32[$216 >> 2] | 0; //@line 67545
 } else {
  $244 = $239; //@line 67547
 }
 HEAP32[$vs_i >> 2] = $244; //@line 67550
 _dsk_set_visible_chs($dsk_1, $232, $238, $244); //@line 67551
 do {
  if ((HEAP32[$212 >> 2] | 0) == (HEAP32[$vc_i >> 2] | 0)) {
   if ((HEAP32[$214 >> 2] | 0) != (HEAP32[$vh_i >> 2] | 0)) {
    label = 17749; //@line 67563
    break;
   }
   if ((HEAP32[$216 >> 2] | 0) != (HEAP32[$vs_i >> 2] | 0)) {
    label = 17749; //@line 67571
   }
  } else {
   label = 17749; //@line 67574
  }
 } while (0);
 if ((label | 0) == 17749) {
  $257 = _dsk_get_drive($dsk_1) | 0; //@line 67578
  $259 = HEAP32[$dsk_1 + 44 >> 2] | 0; //@line 67580
  $261 = HEAP32[$dsk_1 + 48 >> 2] | 0; //@line 67582
  $263 = HEAP32[$dsk_1 + 52 >> 2] | 0; //@line 67584
  _pce_log_tag(2, 56224, 41232, (tempInt = STACKTOP, STACKTOP = STACKTOP + 32 | 0, HEAP32[tempInt >> 2] = $257, HEAP32[tempInt + 8 >> 2] = $259, HEAP32[tempInt + 16 >> 2] = $261, HEAP32[tempInt + 24 >> 2] = $263, tempInt) | 0); //@line 67585
 }
 $264 = _ini_get_cow($sct, $dsk_1) | 0; //@line 67588
 if (($264 | 0) != 0) {
  HEAP32[$ret >> 2] = $264; //@line 67592
  $_0 = 0; //@line 67594
  STACKTOP = sp; //@line 67596
  return $_0 | 0; //@line 67597
 }
 HEAP32[$ret >> 2] = 0; //@line 67599
 if ((HEAP32[$optional >> 2] | 0) != 0) {
  $_0 = 0; //@line 67604
  STACKTOP = sp; //@line 67606
  return $_0 | 0; //@line 67607
 }
 _pce_log(0, 43184, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$drive >> 2], tempInt) | 0); //@line 67610
 $_0 = 1; //@line 67612
 STACKTOP = sp; //@line 67614
 return $_0 | 0; //@line 67615
}
function _ini_get_disks($ini) {
 $ini = $ini | 0;
 var $dsk = 0, $drive = 0, $1 = 0, $2 = 0, $4 = 0, $11 = 0, $12 = 0, sp = 0;
 sp = STACKTOP; //@line 67625
 STACKTOP = STACKTOP + 16 | 0; //@line 67625
 $dsk = sp | 0; //@line 67626
 $drive = sp + 8 | 0; //@line 67627
 $1 = _dsks_new() | 0; //@line 67628
 $2 = _ini_next_sct($ini, 0, 42920) | 0; //@line 67629
 if (($2 | 0) == 0) {
  STACKTOP = sp; //@line 67633
  return $1 | 0; //@line 67634
 } else {
  $4 = $2; //@line 67636
 }
 do {
  _ini_get_uint16($4, 42448, $drive, 0) | 0; //@line 67640
  do {
   if ((_dsks_get_disk($1, HEAP32[$drive >> 2] | 0) | 0) == 0) {
    $11 = (_ini_get_disk($4, $dsk) | 0) == 0; //@line 67648
    $12 = HEAP32[$dsk >> 2] | 0; //@line 67649
    if (!($11 & ($12 | 0) != 0)) {
     break;
    }
    _dsks_add_disk($1, $12) | 0; //@line 67656
   }
  } while (0);
  $4 = _ini_next_sct($ini, $4, 42920) | 0; //@line 67660
 } while (($4 | 0) != 0);
 STACKTOP = sp; //@line 67669
 return $1 | 0; //@line 67670
}
function _ini_get_ram($mem, $ini, $addr0) {
 $mem = $mem | 0;
 $ini = $ini | 0;
 $addr0 = $addr0 | 0;
 var $fname = 0, $val = 0, $base = 0, $size = 0, $1 = 0, $3 = 0, $5 = 0, $28 = 0, $30 = 0, $31 = 0, $35 = 0, $48 = 0, $50 = 0, $73 = 0, $75 = 0, $76 = 0, $80 = 0, $_lcssa = 0, $_lcssa26 = 0, $89 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 67689
 STACKTOP = STACKTOP + 32 | 0; //@line 67689
 $fname = sp | 0; //@line 67690
 $val = sp + 8 | 0; //@line 67691
 $base = sp + 16 | 0; //@line 67692
 $size = sp + 24 | 0; //@line 67693
 $1 = ($addr0 | 0) != 0; //@line 67694
 if ($1) {
  HEAP32[$addr0 >> 2] = 0; //@line 67697
 }
 $3 = _ini_next_sct($ini, 0, 51096) | 0; //@line 67700
 if (($3 | 0) == 0) {
  $_0 = 0; //@line 67704
  STACKTOP = sp; //@line 67706
  return $_0 | 0; //@line 67707
 }
 L23037 : do {
  if ($1) {
   $5 = $3; //@line 67711
   while (1) {
    _ini_get_string($5, 56184, $fname, 0) | 0; //@line 67714
    if ((_ini_get_uint32($5, 49680, $base, 0) | 0) != 0) {
     _ini_get_uint32($5, 45872, $base, 0) | 0; //@line 67719
    }
    do {
     if ((_ini_get_uint32($5, 42424, $size, 0) | 0) == 0) {
      HEAP32[$size >> 2] = HEAP32[$size >> 2] << 20; //@line 67729
     } else {
      if ((_ini_get_uint32($5, 39328, $size, 0) | 0) == 0) {
       HEAP32[$size >> 2] = HEAP32[$size >> 2] << 10; //@line 67738
       break;
      } else {
       _ini_get_uint32($5, 36400, $size, 65536) | 0; //@line 67742
       break;
      }
     }
    } while (0);
    _ini_get_uint16($5, 33472, $val, 0) | 0; //@line 67747
    $28 = _pce_path_get(HEAP32[$fname >> 2] | 0) | 0; //@line 67749
    $30 = HEAP32[$size >> 2] | 0; //@line 67751
    $31 = ($28 | 0) == 0; //@line 67752
    _pce_log_tag(2, 31696, 30728, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$base >> 2], HEAP32[tempInt + 8 >> 2] = $30, HEAP32[tempInt + 16 >> 2] = $31 ? 57928 : $28, tempInt) | 0); //@line 67754
    $35 = _mem_blk_new(HEAP32[$base >> 2] | 0, HEAP32[$size >> 2] | 0, 1) | 0; //@line 67757
    if (($35 | 0) == 0) {
     $_lcssa = $28; //@line 67761
     label = 17793; //@line 67762
     break L23037;
    }
    _mem_blk_clear($35, HEAP32[$val >> 2] & 255); //@line 67767
    _mem_blk_set_readonly($35, 0); //@line 67768
    _mem_add_blk($mem, $35, 1); //@line 67769
    if ((HEAP32[$base >> 2] | 0) == 0) {
     HEAP32[$addr0 >> 2] = $35; //@line 67774
    }
    if (!$31) {
     if ((_pce_load_blk_bin($35, $28) | 0) != 0) {
      $_lcssa26 = $28; //@line 67783
      label = 17796; //@line 67784
      break L23037;
     }
    }
    _free($28); //@line 67788
    $48 = _ini_next_sct($ini, $5, 51096) | 0; //@line 67789
    if (($48 | 0) == 0) {
     $_0 = 0; //@line 67793
     break;
    } else {
     $5 = $48; //@line 67796
    }
   }
   STACKTOP = sp; //@line 67800
   return $_0 | 0; //@line 67801
  } else {
   $50 = $3; //@line 67803
   while (1) {
    _ini_get_string($50, 56184, $fname, 0) | 0; //@line 67806
    if ((_ini_get_uint32($50, 49680, $base, 0) | 0) != 0) {
     _ini_get_uint32($50, 45872, $base, 0) | 0; //@line 67811
    }
    do {
     if ((_ini_get_uint32($50, 42424, $size, 0) | 0) == 0) {
      HEAP32[$size >> 2] = HEAP32[$size >> 2] << 20; //@line 67821
     } else {
      if ((_ini_get_uint32($50, 39328, $size, 0) | 0) == 0) {
       HEAP32[$size >> 2] = HEAP32[$size >> 2] << 10; //@line 67830
       break;
      } else {
       _ini_get_uint32($50, 36400, $size, 65536) | 0; //@line 67834
       break;
      }
     }
    } while (0);
    _ini_get_uint16($50, 33472, $val, 0) | 0; //@line 67839
    $73 = _pce_path_get(HEAP32[$fname >> 2] | 0) | 0; //@line 67841
    $75 = HEAP32[$size >> 2] | 0; //@line 67843
    $76 = ($73 | 0) == 0; //@line 67844
    _pce_log_tag(2, 31696, 30728, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$base >> 2], HEAP32[tempInt + 8 >> 2] = $75, HEAP32[tempInt + 16 >> 2] = $76 ? 57928 : $73, tempInt) | 0); //@line 67846
    $80 = _mem_blk_new(HEAP32[$base >> 2] | 0, HEAP32[$size >> 2] | 0, 1) | 0; //@line 67849
    if (($80 | 0) == 0) {
     $_lcssa = $73; //@line 67853
     label = 17793; //@line 67854
     break L23037;
    }
    _mem_blk_clear($80, HEAP32[$val >> 2] & 255); //@line 67859
    _mem_blk_set_readonly($80, 0); //@line 67860
    _mem_add_blk($mem, $80, 1); //@line 67861
    if (!$76) {
     if ((_pce_load_blk_bin($80, $73) | 0) != 0) {
      $_lcssa26 = $73; //@line 67868
      label = 17796; //@line 67869
      break L23037;
     }
    }
    _free($73); //@line 67873
    $89 = _ini_next_sct($ini, $50, 51096) | 0; //@line 67874
    if (($89 | 0) == 0) {
     $_0 = 0; //@line 67878
     break;
    } else {
     $50 = $89; //@line 67881
    }
   }
   STACKTOP = sp; //@line 67885
   return $_0 | 0; //@line 67886
  }
 } while (0);
 if ((label | 0) == 17793) {
  _pce_log(0, 57104, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 67891
  _free($_lcssa); //@line 67892
  $_0 = 1; //@line 67894
  STACKTOP = sp; //@line 67896
  return $_0 | 0; //@line 67897
 } else if ((label | 0) == 17796) {
  _pce_log(0, 55920, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $_lcssa26, tempInt) | 0); //@line 67901
  _free($_lcssa26); //@line 67902
  $_0 = 1; //@line 67904
  STACKTOP = sp; //@line 67906
  return $_0 | 0; //@line 67907
 }
 return 0;
}
function _ini_get_rom($mem, $ini) {
 $mem = $mem | 0;
 $ini = $ini | 0;
 var $fname = 0, $val = 0, $base = 0, $size = 0, $1 = 0, $3 = 0, $26 = 0, $28 = 0, $29 = 0, $33 = 0, $44 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 67921
 STACKTOP = STACKTOP + 32 | 0; //@line 67921
 $fname = sp | 0; //@line 67922
 $val = sp + 8 | 0; //@line 67923
 $base = sp + 16 | 0; //@line 67924
 $size = sp + 24 | 0; //@line 67925
 $1 = _ini_next_sct($ini, 0, 55256) | 0; //@line 67926
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 67930
  STACKTOP = sp; //@line 67932
  return $_0 | 0; //@line 67933
 } else {
  $3 = $1; //@line 67935
 }
 while (1) {
  _ini_get_string($3, 56184, $fname, 0) | 0; //@line 67939
  if ((_ini_get_uint32($3, 49680, $base, 0) | 0) != 0) {
   _ini_get_uint32($3, 45872, $base, 0) | 0; //@line 67944
  }
  do {
   if ((_ini_get_uint32($3, 42424, $size, 0) | 0) == 0) {
    HEAP32[$size >> 2] = HEAP32[$size >> 2] << 20; //@line 67954
   } else {
    if ((_ini_get_uint32($3, 39328, $size, 0) | 0) == 0) {
     HEAP32[$size >> 2] = HEAP32[$size >> 2] << 10; //@line 67963
     break;
    } else {
     _ini_get_uint32($3, 36400, $size, 65536) | 0; //@line 67967
     break;
    }
   }
  } while (0);
  _ini_get_uint16($3, 33472, $val, 0) | 0; //@line 67972
  $26 = _pce_path_get(HEAP32[$fname >> 2] | 0) | 0; //@line 67974
  $28 = HEAP32[$size >> 2] | 0; //@line 67976
  $29 = ($26 | 0) != 0; //@line 67977
  _pce_log_tag(2, 54592, 30728, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = HEAP32[$base >> 2], HEAP32[tempInt + 8 >> 2] = $28, HEAP32[tempInt + 16 >> 2] = $29 ? $26 : 57928, tempInt) | 0); //@line 67979
  $33 = _mem_blk_new(HEAP32[$base >> 2] | 0, HEAP32[$size >> 2] | 0, 1) | 0; //@line 67982
  if (($33 | 0) == 0) {
   label = 17813; //@line 67986
   break;
  }
  _mem_blk_clear($33, HEAP32[$val >> 2] & 255); //@line 67991
  _mem_blk_set_readonly($33, 1); //@line 67992
  _mem_add_blk($mem, $33, 1); //@line 67993
  if ($29) {
   if ((_pce_load_blk_bin($33, $26) | 0) != 0) {
    label = 17816; //@line 68000
    break;
   }
  }
  _free($26); //@line 68004
  $44 = _ini_next_sct($ini, $3, 55256) | 0; //@line 68005
  if (($44 | 0) == 0) {
   $_0 = 0; //@line 68009
   label = 17820; //@line 68010
   break;
  } else {
   $3 = $44; //@line 68013
  }
 }
 if ((label | 0) == 17820) {
  STACKTOP = sp; //@line 68018
  return $_0 | 0; //@line 68019
 } else if ((label | 0) == 17813) {
  _pce_log(0, 57104, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 68022
  _free($26); //@line 68023
  $_0 = 1; //@line 68025
  STACKTOP = sp; //@line 68027
  return $_0 | 0; //@line 68028
 } else if ((label | 0) == 17816) {
  _pce_log(0, 53872, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $26, tempInt) | 0); //@line 68031
  _free($26); //@line 68032
  $_0 = 1; //@line 68034
  STACKTOP = sp; //@line 68036
  return $_0 | 0; //@line 68037
 }
 return 0;
}
function _ini_get_terminal($ini, $def) {
 $ini = $ini | 0;
 $def = $def | 0;
 var $scale = 0, $min_w = 0, $min_h = 0, $aspect_x = 0, $aspect_y = 0, $mouse_x = 0, $mouse_y = 0, $driver = 0, $esc = 0, $1 = 0, $cond40 = 0, $sct_043 = 0, $8 = 0, $sct_0_lcssa = 0, $sct_141 = 0, $11 = 0, $17 = 0, $sct_2 = 0, $26 = 0, $28 = 0, $30 = 0, $32 = 0, $35 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $55 = 0, $62 = 0, $trm_0_ph = 0, $68 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 68057
 STACKTOP = STACKTOP + 72 | 0; //@line 68057
 $scale = sp | 0; //@line 68058
 $min_w = sp + 8 | 0; //@line 68059
 $min_h = sp + 16 | 0; //@line 68060
 $aspect_x = sp + 24 | 0; //@line 68061
 $aspect_y = sp + 32 | 0; //@line 68062
 $mouse_x = sp + 40 | 0; //@line 68063
 $mouse_y = sp + 48 | 0; //@line 68064
 $driver = sp + 56 | 0; //@line 68065
 $esc = sp + 64 | 0; //@line 68066
 $1 = _ini_next_sct($ini, 0, 51032) | 0; //@line 68067
 _ini_get_string($1, 56176, $driver, 49672) | 0; //@line 68068
 $cond40 = ($1 | 0) == 0; //@line 68070
 L23106 : do {
  if (($def | 0) == 0) {
   L23108 : do {
    if (!$cond40) {
     $sct_141 = $1; //@line 68077
     while (1) {
      $11 = HEAP32[$driver >> 2] | 0; //@line 68080
      if ((_strcmp($11 | 0, 49672) | 0) == 0) {
       $sct_2 = $sct_141; //@line 68085
       break L23106;
      }
      if ((_strcmp($11 | 0, 51816) | 0) == 0) {
       break;
      }
      $17 = _ini_next_sct($ini, $sct_141, 51032) | 0; //@line 68093
      _ini_get_string($17, 56176, $driver, 49672) | 0; //@line 68094
      if (($17 | 0) == 0) {
       break L23108;
      } else {
       $sct_141 = $17; //@line 68100
      }
     }
     if (($sct_141 | 0) != 0) {
      $sct_2 = $sct_141; //@line 68106
      break L23106;
     }
    }
   } while (0);
   HEAP32[$driver >> 2] = 49672; //@line 68111
   $sct_2 = 0; //@line 68113
  } else {
   L23116 : do {
    if ($cond40) {
     $sct_0_lcssa = 0; //@line 68118
    } else {
     $sct_043 = $1; //@line 68120
     while (1) {
      if ((_strcmp($def | 0, HEAP32[$driver >> 2] | 0) | 0) == 0) {
       $sct_0_lcssa = $sct_043; //@line 68127
       break L23116;
      }
      $8 = _ini_next_sct($ini, $sct_043, 51032) | 0; //@line 68130
      _ini_get_string($8, 56176, $driver, 49672) | 0; //@line 68131
      if (($8 | 0) == 0) {
       $sct_0_lcssa = 0; //@line 68135
       break;
      } else {
       $sct_043 = $8; //@line 68138
      }
     }
    }
   } while (0);
   HEAP32[$driver >> 2] = $def; //@line 68144
   $sct_2 = $sct_0_lcssa; //@line 68146
  }
 } while (0);
 _ini_get_string($sct_2, 45864, $esc, 0) | 0; //@line 68150
 _ini_get_uint16($sct_2, 42408, $aspect_x, 4) | 0; //@line 68151
 _ini_get_uint16($sct_2, 39312, $aspect_y, 3) | 0; //@line 68152
 _ini_get_uint16($sct_2, 36392, $min_w, 512) | 0; //@line 68153
 _ini_get_uint16($sct_2, 33464, $min_h, 384) | 0; //@line 68154
 _ini_get_uint16($sct_2, 31672, $scale, 1) | 0; //@line 68155
 $26 = $mouse_x | 0; //@line 68156
 _ini_get_sint16($sct_2, 30704, $26, 1) | 0; //@line 68157
 $28 = $mouse_x + 4 | 0; //@line 68158
 _ini_get_sint16($sct_2, 57896, $28, 1) | 0; //@line 68159
 $30 = $mouse_y | 0; //@line 68160
 _ini_get_sint16($sct_2, 57088, $30, 1) | 0; //@line 68161
 $32 = $mouse_y + 4 | 0; //@line 68162
 _ini_get_sint16($sct_2, 55904, $32, 1) | 0; //@line 68163
 $35 = HEAP32[$esc >> 2] | 0; //@line 68165
 $38 = HEAP32[$aspect_x >> 2] | 0; //@line 68168
 $39 = HEAP32[$aspect_y >> 2] | 0; //@line 68169
 $40 = HEAP32[$min_w >> 2] | 0; //@line 68170
 $41 = HEAP32[$min_h >> 2] | 0; //@line 68171
 $42 = HEAP32[$scale >> 2] | 0; //@line 68172
 $43 = HEAP32[$26 >> 2] | 0; //@line 68173
 $44 = HEAP32[$28 >> 2] | 0; //@line 68174
 $45 = HEAP32[$30 >> 2] | 0; //@line 68175
 $46 = HEAP32[$32 >> 2] | 0; //@line 68176
 _pce_log_tag(2, 55248, 54512, (tempInt = STACKTOP, STACKTOP = STACKTOP + 88 | 0, HEAP32[tempInt >> 2] = HEAP32[$driver >> 2], HEAP32[tempInt + 8 >> 2] = ($35 | 0) != 0 ? $35 : 53864, HEAP32[tempInt + 16 >> 2] = $38, HEAP32[tempInt + 24 >> 2] = $39, HEAP32[tempInt + 32 >> 2] = $40, HEAP32[tempInt + 40 >> 2] = $41, HEAP32[tempInt + 48 >> 2] = $42, HEAP32[tempInt + 56 >> 2] = $43, HEAP32[tempInt + 64 >> 2] = $44, HEAP32[tempInt + 72 >> 2] = $45, HEAP32[tempInt + 80 >> 2] = $46, tempInt) | 0); //@line 68177
 $47 = HEAP32[$driver >> 2] | 0; //@line 68178
 L23122 : do {
  if ((_strcmp($47 | 0, 53280) | 0) == 0) {
   _pce_log(0, 52408, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 68184
  } else {
   do {
    if ((_strcmp($47 | 0, 51816) | 0) == 0) {
     $55 = _sdl_new($sct_2) | 0; //@line 68192
     if (($55 | 0) != 0) {
      $trm_0_ph = $55; //@line 68196
      break;
     }
     _pce_log(0, 51256, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 68199
     break L23122;
    } else {
     if ((_strcmp($47 | 0, 49672) | 0) != 0) {
      _pce_log(0, 50424, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $47, tempInt) | 0); //@line 68207
      break L23122;
     }
     $62 = _null_new($sct_2) | 0; //@line 68210
     if (($62 | 0) != 0) {
      $trm_0_ph = $62; //@line 68214
      break;
     }
     _pce_log(0, 50752, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 68217
     break L23122;
    }
   } while (0);
   $68 = HEAP32[$esc >> 2] | 0; //@line 68223
   if (($68 | 0) != 0) {
    _trm_set_escape_str($trm_0_ph, $68) | 0; //@line 68227
   }
   _trm_set_scale($trm_0_ph, HEAP32[$scale >> 2] | 0); //@line 68231
   _trm_set_min_size($trm_0_ph, HEAP32[$min_w >> 2] | 0, HEAP32[$min_h >> 2] | 0); //@line 68234
   _trm_set_aspect_ratio($trm_0_ph, HEAP32[$aspect_x >> 2] | 0, HEAP32[$aspect_y >> 2] | 0); //@line 68237
   _trm_set_mouse_scale($trm_0_ph, HEAP32[$26 >> 2] | 0, HEAP32[$28 >> 2] | 0, HEAP32[$30 >> 2] | 0, HEAP32[$32 >> 2] | 0); //@line 68242
   $_0 = $trm_0_ph; //@line 68244
   STACKTOP = sp; //@line 68246
   return $_0 | 0; //@line 68247
  }
 } while (0);
 _pce_log(0, 49488, (tempInt = STACKTOP, STACKTOP = STACKTOP + 1 | 0, STACKTOP = STACKTOP + 7 >> 3 << 3, HEAP32[tempInt >> 2] = 0, tempInt) | 0); //@line 68250
 $_0 = 0; //@line 68252
 STACKTOP = sp; //@line 68254
 return $_0 | 0; //@line 68255
}
function _ihex_load_fp($fp, $ext, $set) {
 $fp = $fp | 0;
 $ext = $ext | 0;
 $set = $set | 0;
 var $a1_i = 0, $a2_i = 0, $rec = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $mode_0_ph = 0, $ulba_0_ph = 0, $7 = 0, $8 = 0, $i_0_i = 0, $38 = 0, $40 = 0, $41 = 0, $43 = 0, $44 = 0, $48 = 0, $51 = 0, $52 = 0, $ck_014_i = 0, $i_013_i = 0, $55 = 0, $56 = 0, $ck_0_lcssa_i = 0, $i_014_us = 0, $66 = 0, $i_014 = 0, $94 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 68276
 STACKTOP = STACKTOP + 280 | 0; //@line 68276
 $a1_i = sp | 0; //@line 68277
 $a2_i = sp + 8 | 0; //@line 68278
 $rec = sp + 16 | 0; //@line 68279
 $1 = $rec + 1 | 0; //@line 68280
 $2 = $rec + 2 | 0; //@line 68281
 $3 = $rec | 0; //@line 68282
 $4 = $rec + 260 | 0; //@line 68283
 $5 = $rec + 4 | 0; //@line 68284
 $6 = $rec + 5 | 0; //@line 68285
 $ulba_0_ph = 0;
 $mode_0_ph = 1;
 L23141 : while (1) {
  L23143 : while (1) {
   $7 = _fgetc($fp | 0) | 0; //@line 68292
   if (($7 | 0) == 13 | ($7 | 0) == 10) {
    continue;
   } else if (($7 | 0) == (-1 | 0)) {
    $_0 = 0; //@line 68296
    label = 17883; //@line 68297
    break L23141;
   } else if (($7 | 0) != 58) {
    while (1) {
     $8 = _fgetc($fp | 0) | 0; //@line 68301
     if (($8 | 0) == (-1 | 0) | ($8 | 0) == 13 | ($8 | 0) == 10) {
      continue L23143;
     }
    }
   }
   if ((_ihex_get_hex8($fp, $1) | 0) != 0) {
    $_0 = 0; //@line 68311
    label = 17875; //@line 68312
    break L23141;
   }
   if ((_ihex_get_hex8($fp, $a1_i) | 0) != 0) {
    $_0 = 0; //@line 68319
    label = 17884; //@line 68320
    break L23141;
   }
   if ((_ihex_get_hex8($fp, $a2_i) | 0) != 0) {
    $_0 = 0; //@line 68327
    label = 17880; //@line 68328
    break L23141;
   }
   HEAP16[$2 >> 1] = (HEAPU8[$a1_i] | 0) << 8 | (HEAPU8[$a2_i] | 0); //@line 68337
   if ((_ihex_get_hex8($fp, $3) | 0) == 0) {
    $i_0_i = 0; //@line 68342
   } else {
    $_0 = 0; //@line 68344
    label = 17877; //@line 68345
    break L23141;
   }
   while (1) {
    if ($i_0_i >>> 0 >= (HEAPU8[$1] | 0) >>> 0) {
     break;
    }
    if ((_ihex_get_hex8($fp, $rec + 4 + $i_0_i | 0) | 0) == 0) {
     $i_0_i = $i_0_i + 1 | 0; //@line 68363
    } else {
     $_0 = 0; //@line 68365
     label = 17881; //@line 68366
     break L23141;
    }
   }
   if ((_ihex_get_hex8($fp, $4) | 0) != 0) {
    $_0 = 0; //@line 68374
    label = 17879; //@line 68375
    break L23141;
   }
   do {
    $38 = _fgetc($fp | 0) | 0; //@line 68379
   } while (!(($38 | 0) == (-1 | 0) | ($38 | 0) == 13 | ($38 | 0) == 10));
   $40 = HEAP8[$4] | 0; //@line 68384
   $41 = HEAP8[$1] | 0; //@line 68385
   $43 = HEAPU16[$2 >> 1] | 0; //@line 68387
   $44 = $41 & 255; //@line 68388
   $48 = HEAP8[$3] | 0; //@line 68392
   $51 = $43 + $44 + ($43 >>> 8) + ($48 & 255) & 255; //@line 68395
   $52 = $41 << 24 >> 24 == 0; //@line 68396
   if ($52) {
    $ck_0_lcssa_i = $51; //@line 68399
   } else {
    $i_013_i = 0;
    $ck_014_i = $51;
    while (1) {
     $55 = (HEAP8[$rec + 4 + $i_013_i | 0] | 0) + $ck_014_i & 255; //@line 68407
     $56 = $i_013_i + 1 | 0; //@line 68408
     if ($56 >>> 0 < $44 >>> 0) {
      $i_013_i = $56;
      $ck_014_i = $55;
     } else {
      $ck_0_lcssa_i = $55; //@line 68414
      break;
     }
    }
   }
   if ($40 << 24 >> 24 != (-$ck_0_lcssa_i & 255) << 24 >> 24) {
    $_0 = 1; //@line 68424
    label = 17885; //@line 68425
    break L23141;
   }
   if (($48 << 24 >> 24 | 0) == 4) {
    label = 17869; //@line 68429
    break;
   } else if (($48 << 24 >> 24 | 0) == 2) {
    label = 17871; //@line 68432
    break;
   } else if (($48 << 24 >> 24 | 0) == 1) {
    $_0 = 0; //@line 68435
    label = 17878; //@line 68436
    break L23141;
   } else if (($48 << 24 >> 24 | 0) != 0) {
    continue;
   }
   if ($52) {
    continue;
   }
   if ($mode_0_ph) {
    $i_014_us = 0; //@line 68446
    while (1) {
     FUNCTION_TABLE_viii[$set & 63]($ext, $i_014_us + $ulba_0_ph + $43 | 0, HEAP8[$rec + 4 + $i_014_us | 0] | 0); //@line 68453
     $66 = $i_014_us + 1 | 0; //@line 68454
     if ($66 >>> 0 < $44 >>> 0) {
      $i_014_us = $66; //@line 68458
     } else {
      continue L23143;
     }
    }
   } else {
    $i_014 = 0; //@line 68464
    while (1) {
     FUNCTION_TABLE_viii[$set & 63]($ext, ($43 + $i_014 & 65535) + $ulba_0_ph | 0, HEAP8[$rec + 4 + $i_014 | 0] | 0); //@line 68472
     $94 = $i_014 + 1 | 0; //@line 68473
     if ($94 >>> 0 < $44 >>> 0) {
      $i_014 = $94; //@line 68477
     } else {
      continue L23143;
     }
    }
   }
  }
  if ((label | 0) == 17869) {
   label = 0; //@line 68485
   if ($41 << 24 >> 24 != 2) {
    $_0 = 1; //@line 68489
    label = 17876; //@line 68490
    break;
   }
   $ulba_0_ph = ((HEAPU8[$5] | 0) << 8 | (HEAPU8[$6] | 0)) << 16;
   $mode_0_ph = 1;
   continue;
  } else if ((label | 0) == 17871) {
   label = 0; //@line 68505
   if ($41 << 24 >> 24 != 2) {
    $_0 = 1; //@line 68509
    label = 17882; //@line 68510
    break;
   }
   $ulba_0_ph = ((HEAPU8[$5] | 0) << 8 | (HEAPU8[$6] | 0)) << 4;
   $mode_0_ph = 0;
   continue;
  }
 }
 if ((label | 0) == 17879) {
  STACKTOP = sp; //@line 68527
  return $_0 | 0; //@line 68528
 } else if ((label | 0) == 17881) {
  STACKTOP = sp; //@line 68532
  return $_0 | 0; //@line 68533
 } else if ((label | 0) == 17877) {
  STACKTOP = sp; //@line 68537
  return $_0 | 0; //@line 68538
 } else if ((label | 0) == 17885) {
  STACKTOP = sp; //@line 68542
  return $_0 | 0; //@line 68543
 } else if ((label | 0) == 17882) {
  STACKTOP = sp; //@line 68547
  return $_0 | 0; //@line 68548
 } else if ((label | 0) == 17875) {
  STACKTOP = sp; //@line 68552
  return $_0 | 0; //@line 68553
 } else if ((label | 0) == 17884) {
  STACKTOP = sp; //@line 68557
  return $_0 | 0; //@line 68558
 } else if ((label | 0) == 17876) {
  STACKTOP = sp; //@line 68562
  return $_0 | 0; //@line 68563
 } else if ((label | 0) == 17880) {
  STACKTOP = sp; //@line 68567
  return $_0 | 0; //@line 68568
 } else if ((label | 0) == 17878) {
  STACKTOP = sp; //@line 68572
  return $_0 | 0; //@line 68573
 } else if ((label | 0) == 17883) {
  STACKTOP = sp; //@line 68577
  return $_0 | 0; //@line 68578
 }
 return 0;
}
function _pce_log_init() {
 HEAP32[15612] = 0; //@line 68586
 return;
}
function _ihex_get_hex8($fp, $val) {
 $fp = $fp | 0;
 $val = $val | 0;
 var $1 = 0, $29 = 0, $_0 = 0;
 HEAP8[$val] = 0; //@line 68604
 $1 = _fgetc($fp | 0) | 0; //@line 68605
 do {
  if (($1 - 48 | 0) >>> 0 < 10) {
   HEAP8[$val] = ((HEAPU8[$val] | 0) << 4 | $1 + 208) & 255; //@line 68617
  } else {
   if (($1 - 65 | 0) >>> 0 < 6) {
    HEAP8[$val] = ((HEAPU8[$val] | 0) << 4 | $1 + 201) & 255; //@line 68630
    break;
   }
   if (($1 - 97 | 0) >>> 0 < 6) {
    HEAP8[$val] = ((HEAPU8[$val] | 0) << 4 | $1 + 169) & 255; //@line 68644
    break;
   } else {
    $_0 = 1; //@line 68647
    return $_0 | 0; //@line 68650
   }
  }
 } while (0);
 $29 = _fgetc($fp | 0) | 0; //@line 68654
 if (($29 - 48 | 0) >>> 0 < 10) {
  HEAP8[$val] = ((HEAPU8[$val] | 0) << 4 | $29 + 208) & 255; //@line 68665
  $_0 = 0; //@line 68667
  return $_0 | 0; //@line 68670
 }
 if (($29 - 65 | 0) >>> 0 < 6) {
  HEAP8[$val] = ((HEAPU8[$val] | 0) << 4 | $29 + 201) & 255; //@line 68682
  $_0 = 0; //@line 68684
  return $_0 | 0; //@line 68687
 }
 if (($29 - 97 | 0) >>> 0 >= 6) {
  $_0 = 1; //@line 68693
  return $_0 | 0; //@line 68696
 }
 HEAP8[$val] = ((HEAPU8[$val] | 0) << 4 | $29 + 169) & 255; //@line 68704
 $_0 = 0; //@line 68705
 return $_0 | 0; //@line 68708
}
function _srec_load_fp($fp, $ext, $set) {
 $fp = $fp | 0;
 $ext = $ext | 0;
 $set = $set | 0;
 var $rec = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $23 = 0, $type_0_load7376_ph_i = 0, $27 = 0, $28 = 0, $v1_0_load4_ph_i_i = 0, $44 = 0, $v2_i_0_load79_ph_i = 0, $62 = 0, $63 = 0, $64 = 0, $67 = 0, $69 = 0, $i_0101_i = 0, $70 = 0, $v1_0_load4_ph_i40_i = 0, $86 = 0, $v2_i36_0_load82_ph_i = 0, $i_199_i = 0, $110 = 0, $111 = 0, $v1_0_load4_ph_i52_i = 0, $127 = 0, $v2_i48_0_load85_ph_i = 0, $146 = 0, $147 = 0, $150 = 0, $151 = 0, $v1_0_load4_ph_i64_i = 0, $167 = 0, $v2_i60_0_load86_ph_i = 0, $185 = 0, $187 = 0, $188 = 0, $190 = 0, $200 = 0, $201 = 0, $ck_017_i = 0, $i_016_i = 0, $204 = 0, $205 = 0, $ck_0_lcssa_i = 0, $210 = 0, $i_012 = 0, $214 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 68743
 STACKTOP = STACKTOP + 272 | 0; //@line 68743
 $rec = sp | 0; //@line 68744
 $1 = $rec | 0; //@line 68745
 $2 = $rec + 8 | 0; //@line 68746
 $3 = $rec + 1 | 0; //@line 68747
 $4 = $rec + 4 | 0; //@line 68748
 $5 = $rec + 268 | 0; //@line 68749
 L23213 : while (1) {
  $6 = _fgetc($fp | 0) | 0; //@line 68752
  L23215 : do {
   if (($6 | 0) == (-1 | 0)) {
    $_0 = 0; //@line 68755
    label = 17979; //@line 68756
    break L23213;
   } else if (($6 | 0) == 13 | ($6 | 0) == 10) {
    continue L23213;
   } else if (($6 | 0) == 83) {
    $8 = _fgetc($fp | 0) | 0; //@line 68761
    do {
     if (($8 - 48 | 0) >>> 0 < 10) {
      $type_0_load7376_ph_i = $8 + 208 & 255; //@line 68770
     } else {
      if (($8 - 65 | 0) >>> 0 < 6) {
       $type_0_load7376_ph_i = $8 + 201 & 255; //@line 68779
       break;
      }
      if (($8 - 97 | 0) >>> 0 >= 6) {
       break L23215;
      }
      $type_0_load7376_ph_i = $8 + 169 & 255; //@line 68790
     }
    } while (0);
    HEAP8[$1] = $type_0_load7376_ph_i; //@line 68794
    $27 = HEAP32[6336 + (($type_0_load7376_ph_i & 255) << 2) >> 2] | 0; //@line 68797
    HEAP32[$2 >> 2] = $27; //@line 68798
    $28 = _fgetc($fp | 0) | 0; //@line 68799
    do {
     if (($28 - 48 | 0) >>> 0 < 10) {
      $v1_0_load4_ph_i_i = $28 + 208 & 255; //@line 68808
     } else {
      if (($28 - 65 | 0) >>> 0 < 6) {
       $v1_0_load4_ph_i_i = $28 + 201 & 255; //@line 68817
       break;
      }
      if (($28 - 97 | 0) >>> 0 >= 6) {
       $_0 = 0; //@line 68824
       label = 17986; //@line 68825
       break L23213;
      }
      $v1_0_load4_ph_i_i = $28 + 169 & 255; //@line 68830
     }
    } while (0);
    $44 = _fgetc($fp | 0) | 0; //@line 68834
    do {
     if (($44 - 48 | 0) >>> 0 < 10) {
      $v2_i_0_load79_ph_i = $44 + 208 & 255; //@line 68843
     } else {
      if (($44 - 65 | 0) >>> 0 < 6) {
       $v2_i_0_load79_ph_i = $44 + 201 & 255; //@line 68852
       break;
      }
      if (($44 - 97 | 0) >>> 0 >= 6) {
       $_0 = 0; //@line 68859
       label = 17978; //@line 68860
       break L23213;
      }
      $v2_i_0_load79_ph_i = $44 + 169 & 255; //@line 68865
     }
    } while (0);
    $62 = $v2_i_0_load79_ph_i & 15 | $v1_0_load4_ph_i_i << 4; //@line 68871
    HEAP8[$3] = $62; //@line 68872
    $63 = $62 & 255; //@line 68873
    $64 = $27 + 1 | 0; //@line 68874
    if ($63 >>> 0 < $64 >>> 0) {
     $_0 = 0; //@line 68878
     label = 17987; //@line 68879
     break L23213;
    }
    $67 = $63 - $64 & 255; //@line 68883
    HEAP8[$3] = $67; //@line 68884
    HEAP32[$4 >> 2] = 0; //@line 68885
    $i_0101_i = 0;
    $69 = 0;
    do {
     $70 = _fgetc($fp | 0) | 0; //@line 68891
     do {
      if (($70 - 48 | 0) >>> 0 < 10) {
       $v1_0_load4_ph_i40_i = $70 + 208 & 255; //@line 68900
      } else {
       if (($70 - 65 | 0) >>> 0 < 6) {
        $v1_0_load4_ph_i40_i = $70 + 201 & 255; //@line 68909
        break;
       }
       if (($70 - 97 | 0) >>> 0 >= 6) {
        $_0 = 0; //@line 68916
        label = 17977; //@line 68917
        break L23213;
       }
       $v1_0_load4_ph_i40_i = $70 + 169 & 255; //@line 68922
      }
     } while (0);
     $86 = _fgetc($fp | 0) | 0; //@line 68926
     do {
      if (($86 - 48 | 0) >>> 0 < 10) {
       $v2_i36_0_load82_ph_i = $86 + 208 & 255; //@line 68935
      } else {
       if (($86 - 65 | 0) >>> 0 < 6) {
        $v2_i36_0_load82_ph_i = $86 + 201 & 255; //@line 68944
        break;
       }
       if (($86 - 97 | 0) >>> 0 >= 6) {
        $_0 = 0; //@line 68951
        label = 17981; //@line 68952
        break L23213;
       }
       $v2_i36_0_load82_ph_i = $86 + 169 & 255; //@line 68957
      }
     } while (0);
     $69 = ($v2_i36_0_load82_ph_i & 15 | $v1_0_load4_ph_i40_i << 4) & 255 | $69 << 8; //@line 68966
     HEAP32[$4 >> 2] = $69; //@line 68967
     $i_0101_i = $i_0101_i + 1 | 0; //@line 68968
    } while ($i_0101_i >>> 0 < $27 >>> 0);
    if ($67 << 24 >> 24 == 0) {
     $150 = 0; //@line 68980
    } else {
     $i_199_i = 0; //@line 68982
     while (1) {
      $110 = $rec + 12 + $i_199_i | 0; //@line 68985
      $111 = _fgetc($fp | 0) | 0; //@line 68986
      do {
       if (($111 - 48 | 0) >>> 0 < 10) {
        $v1_0_load4_ph_i52_i = $111 + 208 & 255; //@line 68995
       } else {
        if (($111 - 65 | 0) >>> 0 < 6) {
         $v1_0_load4_ph_i52_i = $111 + 201 & 255; //@line 69004
         break;
        }
        if (($111 - 97 | 0) >>> 0 >= 6) {
         $_0 = 0; //@line 69011
         label = 17980; //@line 69012
         break L23213;
        }
        $v1_0_load4_ph_i52_i = $111 + 169 & 255; //@line 69017
       }
      } while (0);
      $127 = _fgetc($fp | 0) | 0; //@line 69021
      do {
       if (($127 - 48 | 0) >>> 0 < 10) {
        $v2_i48_0_load85_ph_i = $127 + 208 & 255; //@line 69030
       } else {
        if (($127 - 65 | 0) >>> 0 < 6) {
         $v2_i48_0_load85_ph_i = $127 + 201 & 255; //@line 69039
         break;
        }
        if (($127 - 97 | 0) >>> 0 >= 6) {
         $_0 = 0; //@line 69046
         label = 17982; //@line 69047
         break L23213;
        }
        $v2_i48_0_load85_ph_i = $127 + 169 & 255; //@line 69052
       }
      } while (0);
      HEAP8[$110] = $v2_i48_0_load85_ph_i & 15 | $v1_0_load4_ph_i52_i << 4; //@line 69059
      $146 = $i_199_i + 1 | 0; //@line 69060
      $147 = HEAP8[$3] | 0; //@line 69061
      if ($146 >>> 0 < ($147 & 255) >>> 0) {
       $i_199_i = $146; //@line 69066
      } else {
       $150 = $147; //@line 69068
       break;
      }
     }
    }
    $151 = _fgetc($fp | 0) | 0; //@line 69074
    do {
     if (($151 - 48 | 0) >>> 0 < 10) {
      $v1_0_load4_ph_i64_i = $151 + 208 & 255; //@line 69083
     } else {
      if (($151 - 65 | 0) >>> 0 < 6) {
       $v1_0_load4_ph_i64_i = $151 + 201 & 255; //@line 69092
       break;
      }
      if (($151 - 97 | 0) >>> 0 >= 6) {
       $_0 = 0; //@line 69099
       label = 17984; //@line 69100
       break L23213;
      }
      $v1_0_load4_ph_i64_i = $151 + 169 & 255; //@line 69105
     }
    } while (0);
    $167 = _fgetc($fp | 0) | 0; //@line 69109
    do {
     if (($167 - 48 | 0) >>> 0 < 10) {
      $v2_i60_0_load86_ph_i = $167 + 208 & 255; //@line 69118
     } else {
      if (($167 - 65 | 0) >>> 0 < 6) {
       $v2_i60_0_load86_ph_i = $167 + 201 & 255; //@line 69127
       break;
      }
      if (($167 - 97 | 0) >>> 0 >= 6) {
       $_0 = 0; //@line 69134
       label = 17985; //@line 69135
       break L23213;
      }
      $v2_i60_0_load86_ph_i = $167 + 169 & 255; //@line 69140
     }
    } while (0);
    $185 = $v2_i60_0_load86_ph_i & 15 | $v1_0_load4_ph_i64_i << 4; //@line 69146
    HEAP8[$5] = $185; //@line 69147
    do {
     $187 = _fgetc($fp | 0) | 0; //@line 69150
    } while (!(($187 | 0) == (-1 | 0) | ($187 | 0) == 13 | ($187 | 0) == 10));
    $188 = $150 & 255; //@line 69155
    $190 = HEAP32[$4 >> 2] | 0; //@line 69157
    $200 = (HEAP32[$2 >> 2] | 0) + 1 + $188 + $190 + ($190 >>> 8) + ($190 >>> 16) + ($190 >>> 24) & 255; //@line 69167
    $201 = $150 << 24 >> 24 == 0; //@line 69168
    if ($201) {
     $ck_0_lcssa_i = $200; //@line 69171
    } else {
     $i_016_i = 0;
     $ck_017_i = $200;
     while (1) {
      $204 = (HEAP8[$rec + 12 + $i_016_i | 0] | 0) + $ck_017_i & 255; //@line 69179
      $205 = $i_016_i + 1 | 0; //@line 69180
      if ($205 >>> 0 < $188 >>> 0) {
       $i_016_i = $205;
       $ck_017_i = $204;
      } else {
       $ck_0_lcssa_i = $204; //@line 69186
       break;
      }
     }
    }
    if ($185 << 24 >> 24 != ~$ck_0_lcssa_i << 24 >> 24) {
     $_0 = 1; //@line 69196
     label = 17976; //@line 69197
     break L23213;
    }
    $210 = HEAP8[$1] | 0; //@line 69200
    if (($210 << 24 >> 24 | 0) == 9 | ($210 << 24 >> 24 | 0) == 8 | ($210 << 24 >> 24 | 0) == 7) {
     $_0 = 0;
     label = 17983; //@line 69203
     break L23213;
    } else if (!(($210 << 24 >> 24 | 0) == 1 | ($210 << 24 >> 24 | 0) == 2 | ($210 << 24 >> 24 | 0) == 3)) {
     continue L23213;
    }
    if ($201) {
     continue L23213;
    } else {
     $i_012 = 0; //@line 69212
    }
    while (1) {
     FUNCTION_TABLE_viii[$set & 63]($ext, $190 + $i_012 | 0, HEAP8[$rec + 12 + $i_012 | 0] | 0); //@line 69219
     $214 = $i_012 + 1 | 0; //@line 69220
     if ($214 >>> 0 < $188 >>> 0) {
      $i_012 = $214; //@line 69224
     } else {
      continue L23213;
     }
    }
   }
  } while (0);
  while (1) {
   $23 = _fgetc($fp | 0) | 0; //@line 69232
   if (($23 | 0) == (-1 | 0) | ($23 | 0) == 13 | ($23 | 0) == 10) {
    continue L23213;
   }
  }
 }
 if ((label | 0) == 17978) {
  STACKTOP = sp; //@line 69240
  return $_0 | 0; //@line 69241
 } else if ((label | 0) == 17979) {
  STACKTOP = sp; //@line 69245
  return $_0 | 0; //@line 69246
 } else if ((label | 0) == 17980) {
  STACKTOP = sp; //@line 69250
  return $_0 | 0; //@line 69251
 } else if ((label | 0) == 17984) {
  STACKTOP = sp; //@line 69255
  return $_0 | 0; //@line 69256
 } else if ((label | 0) == 17985) {
  STACKTOP = sp; //@line 69260
  return $_0 | 0; //@line 69261
 } else if ((label | 0) == 17986) {
  STACKTOP = sp; //@line 69265
  return $_0 | 0; //@line 69266
 } else if ((label | 0) == 17987) {
  STACKTOP = sp; //@line 69270
  return $_0 | 0; //@line 69271
 } else if ((label | 0) == 17981) {
  STACKTOP = sp; //@line 69275
  return $_0 | 0; //@line 69276
 } else if ((label | 0) == 17982) {
  STACKTOP = sp; //@line 69280
  return $_0 | 0; //@line 69281
 } else if ((label | 0) == 17983) {
  STACKTOP = sp; //@line 69285
  return $_0 | 0; //@line 69286
 } else if ((label | 0) == 17976) {
  STACKTOP = sp; //@line 69290
  return $_0 | 0; //@line 69291
 } else if ((label | 0) == 17977) {
  STACKTOP = sp; //@line 69295
  return $_0 | 0; //@line 69296
 }
 return 0;
}
function _pce_load_blk_bin($blk, $fname) {
 $blk = $blk | 0;
 $fname = $fname | 0;
 var $1 = 0, $_0 = 0;
 $1 = _fopen($fname | 0, 50976) | 0; //@line 69308
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 69312
  return $_0 | 0; //@line 69315
 }
 _fread(HEAP32[$blk + 44 >> 2] | 0, 1, HEAP32[$blk + 40 >> 2] | 0, $1 | 0) | 0; //@line 69321
 _fclose($1 | 0) | 0; //@line 69322
 $_0 = 0; //@line 69324
 return $_0 | 0; //@line 69327
}
function _pce_load_mem_bin($mem, $fname, $base) {
 $mem = $mem | 0;
 $fname = $fname | 0;
 $base = $base | 0;
 var $1 = 0, $4 = 0, $c_013_off0 = 0, $_01112 = 0, $8 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 69338
 _pce_log_tag(2, 56168, 42368, (tempInt = STACKTOP, STACKTOP = STACKTOP + 16 | 0, HEAP32[tempInt >> 2] = $fname, HEAP32[tempInt + 8 >> 2] = $base, tempInt) | 0); //@line 69339
 $1 = _fopen($fname | 0, 50976 | 0) | 0; //@line 69340
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 69344
  STACKTOP = sp; //@line 69346
  return $_0 | 0; //@line 69347
 }
 $4 = _fgetc($1 | 0) | 0; //@line 69349
 if (($4 | 0) != -1) {
  $_01112 = $base;
  $c_013_off0 = $4 & 255;
  while (1) {
   _mem_set_uint8_rw($mem, $_01112, $c_013_off0); //@line 69359
   $8 = _fgetc($1 | 0) | 0; //@line 69361
   if (($8 | 0) == -1) {
    break;
   } else {
    $_01112 = $_01112 + 1 | 0;
    $c_013_off0 = $8 & 255;
   }
  }
 }
 _fclose($1 | 0) | 0; //@line 69372
 $_0 = 0; //@line 69374
 STACKTOP = sp; //@line 69376
 return $_0 | 0; //@line 69377
}
function _pce_load_mem($mem, $fname, $fmt, $addr) {
 $mem = $mem | 0;
 $fname = $fname | 0;
 $fmt = $fmt | 0;
 $addr = $addr | 0;
 var $i_0 = 0, $ext_0 = 0, $8 = 0, $_sum = 0, $_024 = 0, $32 = 0, $36 = 0, $42 = 0, $46 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 69392
 if (($fname | 0) == 0) {
  $_0 = 1; //@line 69396
  STACKTOP = sp; //@line 69398
  return $_0 | 0; //@line 69399
 }
 if (($fmt | 0) == 0) {
  $ext_0 = $fname;
  $i_0 = 0;
  label = 18004; //@line 69405
 } else {
  if ((_strcmp($fmt | 0, 39304) | 0) == 0) {
   $ext_0 = $fname;
   $i_0 = 0;
   label = 18004; //@line 69412
  } else {
   $_024 = $fmt; //@line 69414
  }
 }
 do {
  if ((label | 0) == 18004) {
   while (1) {
    label = 0; //@line 69420
    $8 = HEAP8[$fname + $i_0 | 0] | 0; //@line 69424
    if (($8 << 24 >> 24 | 0) == 0) {
     break;
    } else if (($8 << 24 >> 24 | 0) == 46) {
     $_sum = $i_0 + 1 | 0; //@line 69428
     $ext_0 = $fname + $_sum | 0;
     $i_0 = $_sum;
     label = 18004; //@line 69432
     continue;
    } else {
     $ext_0 = $ext_0;
     $i_0 = $i_0 + 1 | 0;
     label = 18004; //@line 69438
     continue;
    }
   }
   if ((_strcasecmp($ext_0 | 0, 36384) | 0) == 0) {
    $_024 = 36384; //@line 69446
    break;
   }
   if ((_strcasecmp($ext_0 | 0, 33456) | 0) == 0) {
    $_024 = 36384; //@line 69453
    break;
   }
   if ((_strcasecmp($ext_0 | 0, 31664) | 0) == 0) {
    $_024 = 31664; //@line 69460
    break;
   }
   if ((_strcasecmp($ext_0 | 0, 30696) | 0) == 0) {
    $_024 = 57888; //@line 69467
    break;
   } else {
    $_0 = 1; //@line 69470
   }
   STACKTOP = sp; //@line 69473
   return $_0 | 0; //@line 69474
  }
 } while (0);
 if ((_strcmp($_024 | 0, 57888) | 0) == 0) {
  $_0 = _pce_load_mem_bin($mem, $fname, $addr) | 0; //@line 69484
  STACKTOP = sp; //@line 69486
  return $_0 | 0; //@line 69487
 }
 if ((_strcmp($_024 | 0, 36384) | 0) == 0) {
  _pce_log_tag(2, 56168, 49648, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $fname, tempInt) | 0); //@line 69493
  $32 = _fopen($fname | 0, 50976) | 0; //@line 69494
  if (($32 | 0) == 0) {
   $_0 = 1; //@line 69498
   STACKTOP = sp; //@line 69500
   return $_0 | 0; //@line 69501
  }
  $36 = _ihex_load_fp($32, $mem, 40) | 0; //@line 69504
  _fclose($32 | 0) | 0; //@line 69505
  $_0 = $36; //@line 69507
  STACKTOP = sp; //@line 69509
  return $_0 | 0; //@line 69510
 }
 if ((_strcmp($_024 | 0, 31664) | 0) != 0) {
  $_0 = 1; //@line 69516
  STACKTOP = sp; //@line 69518
  return $_0 | 0; //@line 69519
 }
 _pce_log_tag(2, 56168, 45840, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $fname, tempInt) | 0); //@line 69521
 $42 = _fopen($fname | 0, 50976) | 0; //@line 69522
 if (($42 | 0) == 0) {
  $_0 = 1; //@line 69526
  STACKTOP = sp; //@line 69528
  return $_0 | 0; //@line 69529
 }
 $46 = _srec_load_fp($42, $mem, 40) | 0; //@line 69532
 _fclose($42 | 0) | 0; //@line 69533
 $_0 = $46; //@line 69535
 STACKTOP = sp; //@line 69537
 return $_0 | 0; //@line 69538
}
function _pce_load_mem_ini($mem, $ini) {
 $mem = $mem | 0;
 $ini = $ini | 0;
 var $fmt = 0, $fname = 0, $addr = 0, $r_0_ph = 0, $sct_0_ph = 0, $sct_0 = 0, $12 = 0, $15 = 0, $r_1 = 0, sp = 0;
 sp = STACKTOP; //@line 69549
 STACKTOP = STACKTOP + 24 | 0; //@line 69549
 $fmt = sp | 0; //@line 69550
 $fname = sp + 8 | 0; //@line 69551
 $addr = sp + 16 | 0; //@line 69552
 $sct_0_ph = 0;
 $r_0_ph = 0;
 L23375 : while (1) {
  $sct_0 = $sct_0_ph; //@line 69558
  do {
   $sct_0 = _ini_next_sct($ini, $sct_0, 57048) | 0; //@line 69561
   if (($sct_0 | 0) == 0) {
    break L23375;
   }
   _ini_get_string($sct_0, 55888, $fmt, 57888) | 0; //@line 69567
   _ini_get_string($sct_0, 55240, $fname, 0) | 0; //@line 69568
   if ((_ini_get_uint32($sct_0, 54496, $addr, 0) | 0) != 0) {
    _ini_get_uint32($sct_0, 53856, $addr, 0) | 0; //@line 69573
   }
   $12 = HEAP32[$fname >> 2] | 0; //@line 69576
  } while (($12 | 0) == 0);
  $15 = _pce_path_get($12) | 0; //@line 69585
  if ((_pce_load_mem($mem, $15, HEAP32[$fmt >> 2] | 0, HEAP32[$addr >> 2] | 0) | 0) == 0) {
   $r_1 = $r_0_ph; //@line 69592
  } else {
   _pce_log(0, 53248, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $15, tempInt) | 0); //@line 69594
   $r_1 = 1; //@line 69596
  }
  _free($15); //@line 69599
  $sct_0_ph = $sct_0;
  $r_0_ph = $r_1;
 }
 STACKTOP = sp; //@line 69603
 return $r_0_ph | 0; //@line 69604
}
function _pce_log_add_fp($fp, $close, $level) {
 $fp = $fp | 0;
 $close = $close | 0;
 $level = $level | 0;
 var $1 = 0, $_0 = 0;
 $1 = HEAP32[15612] | 0; //@line 69616
 if ($1 >>> 0 > 15) {
  $_0 = 1; //@line 69620
  return $_0 | 0; //@line 69623
 }
 HEAP32[62456 + ($1 * 12 | 0) >> 2] = $fp; //@line 69626
 HEAP32[62460 + ($1 * 12 | 0) >> 2] = ($close | 0) != 0; //@line 69630
 HEAP32[62464 + ($1 * 12 | 0) >> 2] = $level; //@line 69632
 HEAP32[15612] = $1 + 1; //@line 69634
 $_0 = 0; //@line 69636
 return $_0 | 0; //@line 69639
}
function _pce_log_set_level($fp, $level) {
 $fp = $fp | 0;
 $level = $level | 0;
 var $1 = 0, $i_0 = 0, label = 0;
 $1 = HEAP32[15612] | 0; //@line 69649
 $i_0 = 0; //@line 69651
 while (1) {
  if ($i_0 >>> 0 >= $1 >>> 0) {
   label = 18049; //@line 69657
   break;
  }
  if ((HEAP32[62456 + ($i_0 * 12 | 0) >> 2] | 0) == ($fp | 0)) {
   break;
  } else {
   $i_0 = $i_0 + 1 | 0; //@line 69668
  }
 }
 if ((label | 0) == 18049) {
  return;
 }
 HEAP32[62464 + ($i_0 * 12 | 0) >> 2] = $level; //@line 69676
 return;
}
function _mon_set_cmd_fct($mon, $fct, $ext) {
 $mon = $mon | 0;
 $fct = $fct | 0;
 $ext = $ext | 0;
 HEAP32[$mon >> 2] = $ext; //@line 69691
 HEAP32[$mon + 4 >> 2] = $fct; //@line 69694
 return;
}
function _mon_set_msg_fct($mon, $fct, $ext) {
 $mon = $mon | 0;
 $fct = $fct | 0;
 $ext = $ext | 0;
 HEAP32[$mon + 8 >> 2] = $ext; //@line 69708
 HEAP32[$mon + 12 >> 2] = $fct; //@line 69711
 return;
}
function _mon_set_get_mem_fct($mon, $ext, $fct) {
 $mon = $mon | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$mon + 16 >> 2] = $ext; //@line 69725
 HEAP32[$mon + 20 >> 2] = $fct; //@line 69728
 return;
}
function _mon_set_set_mem_fct($mon, $ext, $fct) {
 $mon = $mon | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$mon + 24 >> 2] = $ext; //@line 69742
 HEAP32[$mon + 28 >> 2] = $fct; //@line 69745
 return;
}
function _mon_set_memory_mode($mon, $mode) {
 $mon = $mon | 0;
 $mode = $mode | 0;
 HEAP32[$mon + 32 >> 2] = $mode; //@line 69758
 return;
}
function _mon_set_terminate($mon, $val) {
 $mon = $mon | 0;
 $val = $val | 0;
 HEAP8[$mon + 56 | 0] = ($val | 0) != 0 | 0; //@line 69773
 return;
}
function _pce_log_add_fname($fname, $level) {
 $fname = $fname | 0;
 $level = $level | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _fopen($fname | 0, 50912) | 0; //@line 69786
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 69790
  return $_0 | 0; //@line 69793
 }
 $4 = HEAP32[15612] | 0; //@line 69795
 if ($4 >>> 0 > 15) {
  _fclose($1 | 0) | 0; //@line 69799
  $_0 = 1; //@line 69801
  return $_0 | 0; //@line 69804
 } else {
  HEAP32[62456 + ($4 * 12 | 0) >> 2] = $1; //@line 69807
  HEAP32[62460 + ($4 * 12 | 0) >> 2] = 1; //@line 69809
  HEAP32[62464 + ($4 * 12 | 0) >> 2] = $level; //@line 69811
  HEAP32[15612] = $4 + 1; //@line 69813
  $_0 = 0; //@line 69815
  return $_0 | 0; //@line 69818
 }
 return 0;
}
function _pce_log($level, $msg, varrp) {
 $level = $level | 0;
 $msg = $msg | 0;
 varrp = varrp | 0;
 var $va = 0, $1 = 0, $3 = 0, $4 = 0, $6 = 0, $i_06 = 0, $11 = 0, $12 = 0, $14 = 0, $17 = 0, $18 = 0, sp = 0;
 sp = STACKTOP; //@line 69831
 STACKTOP = STACKTOP + 16 | 0; //@line 69831
 $va = sp | 0; //@line 69832
 $1 = HEAP32[15612] | 0; //@line 69833
 if (($1 | 0) == 0) {
  STACKTOP = sp; //@line 69837
  return;
 }
 $3 = $va | 0; //@line 69840
 $4 = $va; //@line 69841
 $i_06 = 0;
 $6 = $1;
 while (1) {
  if ((HEAP32[62464 + ($i_06 * 12 | 0) >> 2] | 0) >>> 0 < $level >>> 0) {
   $17 = $6; //@line 69852
  } else {
   HEAP32[$4 >> 2] = varrp; //@line 69854
   HEAP32[$4 + 4 >> 2] = 0; //@line 69854
   $11 = 62456 + ($i_06 * 12 | 0) | 0; //@line 69855
   $12 = HEAP32[$11 >> 2] | 0; //@line 69856
   _vfprintf($12 | 0, $msg | 0, $3 | 0) | 0; //@line 69857
   $14 = HEAP32[$11 >> 2] | 0; //@line 69859
   _fflush($14 | 0) | 0; //@line 69860
   $17 = HEAP32[15612] | 0; //@line 69863
  }
  $18 = $i_06 + 1 | 0; //@line 69866
  if ($18 >>> 0 < $17 >>> 0) {
   $i_06 = $18;
   $6 = $17;
  } else {
   break;
  }
 }
 STACKTOP = sp; //@line 69875
 return;
}
function _pce_log_va($level, $msg, $va) {
 $level = $level | 0;
 $msg = $msg | 0;
 $va = $va | 0;
 var $1 = 0, $3 = 0, $i_07 = 0, $8 = 0, $9 = 0, $11 = 0, $14 = 0, $15 = 0;
 $1 = HEAP32[15612] | 0; //@line 69888
 if (($1 | 0) == 0) {
  return;
 } else {
  $i_07 = 0;
  $3 = $1;
 }
 while (1) {
  if ((HEAP32[62464 + ($i_07 * 12 | 0) >> 2] | 0) >>> 0 < $level >>> 0) {
   $14 = $3; //@line 69905
  } else {
   $8 = 62456 + ($i_07 * 12 | 0) | 0; //@line 69907
   $9 = HEAP32[$8 >> 2] | 0; //@line 69908
   _vfprintf($9 | 0, $msg | 0, $va | 0) | 0; //@line 69909
   $11 = HEAP32[$8 >> 2] | 0; //@line 69910
   _fflush($11 | 0) | 0; //@line 69911
   $14 = HEAP32[15612] | 0; //@line 69914
  }
  $15 = $i_07 + 1 | 0; //@line 69917
  if ($15 >>> 0 < $14 >>> 0) {
   $i_07 = $15;
   $3 = $14;
  } else {
   break;
  }
 }
 return;
}
function _pce_log_tag($level, $tag, $msg, varrp) {
 $level = $level | 0;
 $tag = $tag | 0;
 $msg = $msg | 0;
 varrp = varrp | 0;
 var $va = 0, $_tag = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $i_09 = 0, $12 = 0, $13 = 0, $15 = 0, $17 = 0, $20 = 0, $21 = 0, sp = 0;
 sp = STACKTOP; //@line 69940
 STACKTOP = STACKTOP + 16 | 0; //@line 69940
 $va = sp | 0; //@line 69941
 $_tag = ($tag | 0) == 0 ? 62896 : $tag; //@line 69943
 $2 = HEAP32[15612] | 0; //@line 69944
 if (($2 | 0) == 0) {
  STACKTOP = sp; //@line 69948
  return;
 }
 $4 = $va | 0; //@line 69951
 $5 = $va; //@line 69952
 $i_09 = 0;
 $7 = $2;
 while (1) {
  if ((HEAP32[62464 + ($i_09 * 12 | 0) >> 2] | 0) >>> 0 < $level >>> 0) {
   $20 = $7; //@line 69963
  } else {
   HEAP32[$5 >> 2] = varrp; //@line 69965
   HEAP32[$5 + 4 >> 2] = 0; //@line 69965
   $12 = 62456 + ($i_09 * 12 | 0) | 0; //@line 69966
   $13 = HEAP32[$12 >> 2] | 0; //@line 69967
   _fprintf($13 | 0, 49592, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $_tag, tempInt) | 0) | 0; //@line 69968
   $15 = HEAP32[$12 >> 2] | 0; //@line 69969
   _vfprintf($15 | 0, $msg | 0, $4 | 0) | 0; //@line 69970
   $17 = HEAP32[$12 >> 2] | 0; //@line 69972
   _fflush($17 | 0) | 0; //@line 69973
   $20 = HEAP32[15612] | 0; //@line 69976
  }
  $21 = $i_09 + 1 | 0; //@line 69979
  if ($21 >>> 0 < $20 >>> 0) {
   $i_09 = $21;
   $7 = $20;
  } else {
   break;
  }
 }
 STACKTOP = sp; //@line 69988
 return;
}
function _mon_init($mon) {
 $mon = $mon | 0;
 var $3 = 0, $4 = 0, $8 = 0, $9 = 0, $13 = 0, $_02227_i = 0, $_02326_i = 0, $14 = 0, $i_024_i = 0, $17 = 0, $18 = 0, $25 = 0, $26 = 0, $i_0_lcssa_i = 0, $29 = 0, $30 = 0, $31 = 0, $33 = 0;
 HEAP32[$mon + 40 >> 2] = 0; //@line 70003
 HEAP16[$mon + 44 >> 1] = 0; //@line 70005
 $3 = $mon + 48 | 0; //@line 70006
 HEAP32[$3 >> 2] = 0; //@line 70007
 $4 = $mon + 52 | 0; //@line 70008
 HEAP32[$4 >> 2] = 0; //@line 70009
 HEAP8[$mon + 56 | 0] = 0; //@line 70011
 HEAP32[$mon + 60 >> 2] = 0; //@line 70013
 _memset($mon | 0, 0, 38); //@line 70015
 $8 = _realloc(0, 120) | 0; //@line 70016
 $9 = $8; //@line 70017
 if (($8 | 0) == 0) {
  return;
 }
 HEAP32[$4 >> 2] = $9; //@line 70024
 $_02326_i = 6800;
 $_02227_i = 10;
 $13 = HEAP32[$3 >> 2] | 0;
 while (1) {
  $14 = $_02326_i | 0; //@line 70032
  L23451 : do {
   if (($13 | 0) == 0) {
    $i_0_lcssa_i = 0; //@line 70037
   } else {
    $i_024_i = $13; //@line 70039
    while (1) {
     $17 = $i_024_i - 1 | 0; //@line 70043
     $18 = $9 + ($17 * 12 | 0) | 0; //@line 70044
     if ((_strcmp(HEAP32[$14 >> 2] | 0, HEAP32[$18 >> 2] | 0) | 0) > -1) {
      $i_0_lcssa_i = $i_024_i; //@line 70051
      break L23451;
     }
     $25 = $9 + ($i_024_i * 12 | 0) | 0; //@line 70055
     $26 = $18; //@line 70056
     HEAP32[$25 >> 2] = HEAP32[$26 >> 2]; //@line 70057
     HEAP32[$25 + 4 >> 2] = HEAP32[$26 + 4 >> 2]; //@line 70057
     HEAP32[$25 + 8 >> 2] = HEAP32[$26 + 8 >> 2]; //@line 70057
     if (($17 | 0) == 0) {
      $i_0_lcssa_i = 0; //@line 70061
      break;
     } else {
      $i_024_i = $17; //@line 70064
     }
    }
   }
  } while (0);
  $29 = $9 + ($i_0_lcssa_i * 12 | 0) | 0; //@line 70071
  $30 = $_02326_i; //@line 70072
  HEAP32[$29 >> 2] = HEAP32[$30 >> 2]; //@line 70073
  HEAP32[$29 + 4 >> 2] = HEAP32[$30 + 4 >> 2]; //@line 70073
  HEAP32[$29 + 8 >> 2] = HEAP32[$30 + 8 >> 2]; //@line 70073
  $31 = $13 + 1 | 0; //@line 70074
  HEAP32[$3 >> 2] = $31; //@line 70075
  $33 = $_02227_i - 1 | 0; //@line 70077
  if (($33 | 0) == 0) {
   break;
  } else {
   $_02326_i = $_02326_i + 12 | 0;
   $_02227_i = $33;
   $13 = $31;
  }
 }
 return;
}
function _mon_cmd_add($mon, $cmd, $cnt) {
 $mon = $mon | 0;
 $cmd = $cmd | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $4 = 0, $8 = 0, $9 = 0, $14 = 0, $_02227 = 0, $_02326 = 0, $15 = 0, $i_024 = 0, $18 = 0, $19 = 0, $26 = 0, $27 = 0, $i_0_lcssa = 0, $30 = 0, $31 = 0, $32 = 0, $34 = 0, $_0 = 0;
 $1 = $mon + 52 | 0; //@line 70102
 $4 = $mon + 48 | 0; //@line 70105
 $8 = _realloc(HEAP32[$1 >> 2] | 0, ((HEAP32[$4 >> 2] | 0) + $cnt | 0) * 12 | 0) | 0; //@line 70109
 $9 = $8; //@line 70110
 if (($8 | 0) == 0) {
  $_0 = 1; //@line 70114
  return $_0 | 0; //@line 70117
 }
 HEAP32[$1 >> 2] = $9; //@line 70119
 if (($cnt | 0) == 0) {
  $_0 = 0; //@line 70123
  return $_0 | 0; //@line 70126
 }
 $_02326 = $cmd;
 $_02227 = $cnt;
 $14 = HEAP32[$4 >> 2] | 0;
 while (1) {
  $15 = $_02326 | 0; //@line 70135
  L23466 : do {
   if (($14 | 0) == 0) {
    $i_0_lcssa = 0; //@line 70140
   } else {
    $i_024 = $14; //@line 70142
    while (1) {
     $18 = $i_024 - 1 | 0; //@line 70146
     $19 = $9 + ($18 * 12 | 0) | 0; //@line 70147
     if ((_strcmp(HEAP32[$15 >> 2] | 0, HEAP32[$19 >> 2] | 0) | 0) > -1) {
      $i_0_lcssa = $i_024; //@line 70154
      break L23466;
     }
     $26 = $9 + ($i_024 * 12 | 0) | 0; //@line 70158
     $27 = $19; //@line 70159
     HEAP32[$26 >> 2] = HEAP32[$27 >> 2]; //@line 70160
     HEAP32[$26 + 4 >> 2] = HEAP32[$27 + 4 >> 2]; //@line 70160
     HEAP32[$26 + 8 >> 2] = HEAP32[$27 + 8 >> 2]; //@line 70160
     if (($18 | 0) == 0) {
      $i_0_lcssa = 0; //@line 70164
      break;
     } else {
      $i_024 = $18; //@line 70167
     }
    }
   }
  } while (0);
  $30 = $9 + ($i_0_lcssa * 12 | 0) | 0; //@line 70174
  $31 = $_02326; //@line 70175
  HEAP32[$30 >> 2] = HEAP32[$31 >> 2]; //@line 70176
  HEAP32[$30 + 4 >> 2] = HEAP32[$31 + 4 >> 2]; //@line 70176
  HEAP32[$30 + 8 >> 2] = HEAP32[$31 + 8 >> 2]; //@line 70176
  $32 = $14 + 1 | 0; //@line 70177
  HEAP32[$4 >> 2] = $32; //@line 70178
  $34 = $_02227 - 1 | 0; //@line 70180
  if (($34 | 0) == 0) {
   $_0 = 0; //@line 70184
   break;
  } else {
   $_02326 = $_02326 + 12 | 0;
   $_02227 = $34;
   $14 = $32;
  }
 }
 return $_0 | 0; //@line 70192
}
function _mon_cmd_add_bp($mon) {
 $mon = $mon | 0;
 var $1 = 0, $4 = 0, $8 = 0, $9 = 0, $_pre_i = 0, $13 = 0, $_pre3 = 0, $i_024_i = 0, $14 = 0, $15 = 0, $22 = 0, $23 = 0, $i_0_lcssa_i = 0, $26 = 0, $27 = 0, $_0_i = 0, $29 = 0, $_pre2 = 0, $i_024_i_1 = 0, $30 = 0, $31 = 0, $38 = 0, $39 = 0, $i_0_lcssa_i_1 = 0, $42 = 0, $43 = 0, $_pre1 = 0, $i_024_i_2 = 0, $45 = 0, $46 = 0, $53 = 0, $54 = 0, $i_0_lcssa_i_2 = 0, $57 = 0, $58 = 0, $_pre = 0, $i_024_i_3 = 0, $60 = 0, $61 = 0, $68 = 0, $69 = 0, $i_0_lcssa_i_3 = 0, $72 = 0, label = 0;
 $1 = $mon + 52 | 0; //@line 70211
 $4 = $mon + 48 | 0; //@line 70214
 $8 = _realloc(HEAP32[$1 >> 2] | 0, ((HEAP32[$4 >> 2] | 0) * 12 | 0) + 48 | 0) | 0; //@line 70218
 $9 = $8; //@line 70219
 if (($8 | 0) == 0) {
  $_0_i = 1; //@line 70223
  return $_0_i | 0; //@line 70226
 }
 HEAP32[$1 >> 2] = $9; //@line 70228
 $_pre_i = HEAP32[$4 >> 2] | 0; //@line 70229
 if (($_pre_i | 0) == 0) {
  HEAP32[$8 >> 2] = HEAP32[1688]; //@line 70233
  HEAP32[$8 + 4 >> 2] = HEAP32[1689]; //@line 70233
  HEAP32[$8 + 8 >> 2] = HEAP32[1690]; //@line 70233
  $13 = $_pre_i + 1 | 0; //@line 70234
  HEAP32[$4 >> 2] = $13; //@line 70235
  $29 = $13; //@line 70237
  label = 18115; //@line 70238
 } else {
  $_pre3 = HEAP32[1688] | 0; //@line 70240
  $i_024_i = $_pre_i; //@line 70242
  while (1) {
   $14 = $i_024_i - 1 | 0; //@line 70245
   $15 = $9 + ($14 * 12 | 0) | 0; //@line 70246
   if ((_strcmp($_pre3 | 0, HEAP32[$15 >> 2] | 0) | 0) > -1) {
    $i_0_lcssa_i = $i_024_i; //@line 70253
    break;
   }
   $22 = $9 + ($i_024_i * 12 | 0) | 0; //@line 70257
   $23 = $15; //@line 70258
   HEAP32[$22 >> 2] = HEAP32[$23 >> 2]; //@line 70259
   HEAP32[$22 + 4 >> 2] = HEAP32[$23 + 4 >> 2]; //@line 70259
   HEAP32[$22 + 8 >> 2] = HEAP32[$23 + 8 >> 2]; //@line 70259
   if (($14 | 0) == 0) {
    $i_0_lcssa_i = 0; //@line 70263
    break;
   } else {
    $i_024_i = $14; //@line 70266
   }
  }
  $26 = $9 + ($i_0_lcssa_i * 12 | 0) | 0; //@line 70271
  HEAP32[$26 >> 2] = HEAP32[1688]; //@line 70272
  HEAP32[$26 + 4 >> 2] = HEAP32[1689]; //@line 70272
  HEAP32[$26 + 8 >> 2] = HEAP32[1690]; //@line 70272
  $27 = $_pre_i + 1 | 0; //@line 70273
  HEAP32[$4 >> 2] = $27; //@line 70274
  if (($27 | 0) == 0) {
   $i_0_lcssa_i_1 = 0; //@line 70278
  } else {
   $29 = $27; //@line 70280
   label = 18115; //@line 70281
  }
 }
 L23483 : do {
  if ((label | 0) == 18115) {
   $_pre2 = HEAP32[1691] | 0; //@line 70287
   $i_024_i_1 = $29; //@line 70289
   while (1) {
    $30 = $i_024_i_1 - 1 | 0; //@line 70292
    $31 = $9 + ($30 * 12 | 0) | 0; //@line 70293
    if ((_strcmp($_pre2 | 0, HEAP32[$31 >> 2] | 0) | 0) > -1) {
     $i_0_lcssa_i_1 = $i_024_i_1; //@line 70300
     break L23483;
    }
    $38 = $9 + ($i_024_i_1 * 12 | 0) | 0; //@line 70304
    $39 = $31; //@line 70305
    HEAP32[$38 >> 2] = HEAP32[$39 >> 2]; //@line 70306
    HEAP32[$38 + 4 >> 2] = HEAP32[$39 + 4 >> 2]; //@line 70306
    HEAP32[$38 + 8 >> 2] = HEAP32[$39 + 8 >> 2]; //@line 70306
    if (($30 | 0) == 0) {
     $i_0_lcssa_i_1 = 0; //@line 70310
     break;
    } else {
     $i_024_i_1 = $30; //@line 70313
    }
   }
  }
 } while (0);
 $42 = $9 + ($i_0_lcssa_i_1 * 12 | 0) | 0; //@line 70320
 HEAP32[$42 >> 2] = HEAP32[1691]; //@line 70321
 HEAP32[$42 + 4 >> 2] = HEAP32[6768 >> 2]; //@line 70321
 HEAP32[$42 + 8 >> 2] = HEAP32[6772 >> 2]; //@line 70321
 $43 = $_pre_i + 2 | 0; //@line 70322
 HEAP32[$4 >> 2] = $43; //@line 70323
 L23489 : do {
  if (($43 | 0) == 0) {
   $i_0_lcssa_i_2 = 0; //@line 70328
  } else {
   $_pre1 = HEAP32[1694] | 0; //@line 70330
   $i_024_i_2 = $43; //@line 70332
   while (1) {
    $45 = $i_024_i_2 - 1 | 0; //@line 70335
    $46 = $9 + ($45 * 12 | 0) | 0; //@line 70336
    if ((_strcmp($_pre1 | 0, HEAP32[$46 >> 2] | 0) | 0) > -1) {
     $i_0_lcssa_i_2 = $i_024_i_2; //@line 70343
     break L23489;
    }
    $53 = $9 + ($i_024_i_2 * 12 | 0) | 0; //@line 70347
    $54 = $46; //@line 70348
    HEAP32[$53 >> 2] = HEAP32[$54 >> 2]; //@line 70349
    HEAP32[$53 + 4 >> 2] = HEAP32[$54 + 4 >> 2]; //@line 70349
    HEAP32[$53 + 8 >> 2] = HEAP32[$54 + 8 >> 2]; //@line 70349
    if (($45 | 0) == 0) {
     $i_0_lcssa_i_2 = 0; //@line 70353
     break;
    } else {
     $i_024_i_2 = $45; //@line 70356
    }
   }
  }
 } while (0);
 $57 = $9 + ($i_0_lcssa_i_2 * 12 | 0) | 0; //@line 70363
 HEAP32[$57 >> 2] = HEAP32[1694]; //@line 70364
 HEAP32[$57 + 4 >> 2] = HEAP32[6780 >> 2]; //@line 70364
 HEAP32[$57 + 8 >> 2] = HEAP32[6784 >> 2]; //@line 70364
 $58 = $_pre_i + 3 | 0; //@line 70365
 HEAP32[$4 >> 2] = $58; //@line 70366
 L23495 : do {
  if (($58 | 0) == 0) {
   $i_0_lcssa_i_3 = 0; //@line 70371
  } else {
   $_pre = HEAP32[1697] | 0; //@line 70373
   $i_024_i_3 = $58; //@line 70375
   while (1) {
    $60 = $i_024_i_3 - 1 | 0; //@line 70378
    $61 = $9 + ($60 * 12 | 0) | 0; //@line 70379
    if ((_strcmp($_pre | 0, HEAP32[$61 >> 2] | 0) | 0) > -1) {
     $i_0_lcssa_i_3 = $i_024_i_3; //@line 70386
     break L23495;
    }
    $68 = $9 + ($i_024_i_3 * 12 | 0) | 0; //@line 70390
    $69 = $61; //@line 70391
    HEAP32[$68 >> 2] = HEAP32[$69 >> 2]; //@line 70392
    HEAP32[$68 + 4 >> 2] = HEAP32[$69 + 4 >> 2]; //@line 70392
    HEAP32[$68 + 8 >> 2] = HEAP32[$69 + 8 >> 2]; //@line 70392
    if (($60 | 0) == 0) {
     $i_0_lcssa_i_3 = 0; //@line 70396
     break;
    } else {
     $i_024_i_3 = $60; //@line 70399
    }
   }
  }
 } while (0);
 $72 = $9 + ($i_0_lcssa_i_3 * 12 | 0) | 0; //@line 70406
 HEAP32[$72 >> 2] = HEAP32[1697]; //@line 70407
 HEAP32[$72 + 4 >> 2] = HEAP32[6792 >> 2]; //@line 70407
 HEAP32[$72 + 8 >> 2] = HEAP32[6796 >> 2]; //@line 70407
 HEAP32[$4 >> 2] = $_pre_i + 4; //@line 70409
 $_0_i = 0; //@line 70410
 return $_0_i | 0; //@line 70413
}
function _msg_is_message($msg, $val) {
 $msg = $msg | 0;
 $val = $val | 0;
 var $1 = 0, $3 = 0, $_089 = 0, $6 = 0, $_1 = 0, $8 = 0, $__1 = 0, $12 = 0, $_0 = 0, label = 0;
 $1 = HEAP8[$msg] | 0; //@line 70424
 if ($1 << 24 >> 24 == 0) {
  $_0 = 0; //@line 70428
  return $_0 | 0; //@line 70431
 } else {
  $_089 = $msg;
  $3 = $1;
 }
 while (1) {
  if ((_strcmp($_089 | 0, $val | 0) | 0) == 0) {
   $_0 = 1; //@line 70442
   label = 18137; //@line 70443
   break;
  } else {
   $_1 = $_089;
   $6 = $3;
  }
  while (1) {
   if (($6 << 24 >> 24 | 0) == 46 | ($6 << 24 >> 24 | 0) == 0) {
    break;
   }
   $8 = $_1 + 1 | 0; //@line 70454
   $_1 = $8;
   $6 = HEAP8[$8] | 0;
  }
  $__1 = $6 << 24 >> 24 == 46 ? $_1 + 1 | 0 : $_1; //@line 70461
  $12 = HEAP8[$__1] | 0; //@line 70462
  if ($12 << 24 >> 24 == 0) {
   $_0 = 0; //@line 70466
   label = 18135; //@line 70467
   break;
  } else {
   $_089 = $__1;
   $3 = $12;
  }
 }
 if ((label | 0) == 18137) {
  return $_0 | 0; //@line 70476
 } else if ((label | 0) == 18135) {
  return $_0 | 0; //@line 70481
 }
 return 0;
}
function _msg_get_uint($str, $val) {
 $str = $str | 0;
 $val = $val | 0;
 var $end_i = 0, $2 = 0, $3 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 70491
 STACKTOP = STACKTOP + 8 | 0; //@line 70491
 $end_i = sp | 0; //@line 70492
 $2 = _strtoul($str | 0, $end_i | 0, 0) | 0; //@line 70494
 $3 = HEAP32[$end_i >> 2] | 0; //@line 70495
 do {
  if (($3 | 0) == ($str | 0)) {
   $_0 = 1; //@line 70500
  } else {
   if ((HEAP8[$3] | 0) != 0) {
    $_0 = 1; //@line 70506
    break;
   }
   HEAP32[$val >> 2] = $2; //@line 70509
   $_0 = 0; //@line 70511
  }
 } while (0);
 STACKTOP = sp; //@line 70515
 return $_0 | 0; //@line 70516
}
function _msg_get_sint($str, $val) {
 $str = $str | 0;
 $val = $val | 0;
 var $end_i = 0, $2 = 0, $3 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 70525
 STACKTOP = STACKTOP + 8 | 0; //@line 70525
 $end_i = sp | 0; //@line 70526
 $2 = _strtol($str | 0, $end_i | 0, 0) | 0; //@line 70528
 $3 = HEAP32[$end_i >> 2] | 0; //@line 70529
 do {
  if (($3 | 0) == ($str | 0)) {
   $_0 = 1; //@line 70534
  } else {
   if ((HEAP8[$3] | 0) != 0) {
    $_0 = 1; //@line 70540
    break;
   }
   HEAP32[$val >> 2] = $2; //@line 70543
   $_0 = 0; //@line 70545
  }
 } while (0);
 STACKTOP = sp; //@line 70549
 return $_0 | 0; //@line 70550
}
function _msg_get_bool($str, $val) {
 $str = $str | 0;
 $val = $val | 0;
 var $end_i = 0, $16 = 0, $17 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 70561
 STACKTOP = STACKTOP + 8 | 0; //@line 70561
 $end_i = sp | 0; //@line 70562
 do {
  if (($str | 0) == 0) {
   label = 18148; //@line 70567
  } else {
   if ((HEAP8[$str] | 0) == 0) {
    label = 18148; //@line 70573
    break;
   }
   if ((_strcmp($str | 0, 50480) | 0) == 0) {
    HEAP32[$val >> 2] = 1; //@line 70580
    $_0 = 0; //@line 70582
    break;
   }
   if ((_strcmp($str | 0, 56056) | 0) == 0) {
    HEAP32[$val >> 2] = 0; //@line 70589
    $_0 = 0; //@line 70591
    break;
   }
   $16 = _strtoul($str | 0, $end_i | 0, 0) | 0; //@line 70595
   $17 = HEAP32[$end_i >> 2] | 0; //@line 70596
   if (($17 | 0) == ($str | 0)) {
    $_0 = 1; //@line 70600
    break;
   }
   if ((HEAP8[$17] | 0) != 0) {
    $_0 = 1; //@line 70607
    break;
   }
   HEAP32[$val >> 2] = ($16 | 0) != 0; //@line 70612
   $_0 = 0; //@line 70614
  }
 } while (0);
 if ((label | 0) == 18148) {
  HEAP32[$val >> 2] = 0; //@line 70618
  $_0 = 0; //@line 70620
 }
 STACKTOP = sp; //@line 70623
 return $_0 | 0; //@line 70624
}
function _msg_get_prefix_ulng($str, $val, $sep, $trim) {
 $str = $str | 0;
 $val = $val | 0;
 $sep = $sep | 0;
 $trim = $trim | 0;
 var $end_i = 0, $tmp = 0, $1 = 0, $2 = 0, $3 = 0, $5 = 0, $6 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 70636
 STACKTOP = STACKTOP + 16 | 0; //@line 70636
 $end_i = sp | 0; //@line 70637
 $tmp = sp + 8 | 0; //@line 70638
 $1 = HEAP32[$str >> 2] | 0; //@line 70639
 HEAP32[$tmp >> 2] = $1; //@line 70640
 $2 = _str_extract_alloc($1, $sep, $tmp) | 0; //@line 70641
 $3 = _str_trim($2, 49544, 49544) | 0; //@line 70642
 $5 = _strtoul($3 | 0, $end_i | 0, 0) | 0; //@line 70644
 $6 = HEAP32[$end_i >> 2] | 0; //@line 70645
 do {
  if (($6 | 0) != ($3 | 0)) {
   if ((HEAP8[$6] | 0) != 0) {
    break;
   }
   HEAP32[$val >> 2] = $5; //@line 70656
   _free($2); //@line 70657
   HEAP32[$str >> 2] = _str_ltrim(HEAP32[$tmp >> 2] | 0, $trim) | 0; //@line 70660
   $_0 = 0; //@line 70662
   STACKTOP = sp; //@line 70664
   return $_0 | 0; //@line 70665
  }
 } while (0);
 _free($2); //@line 70668
 $_0 = 1; //@line 70670
 STACKTOP = sp; //@line 70672
 return $_0 | 0; //@line 70673
}
function _msg_get_prefix_uint($str, $val, $sep, $trim) {
 $str = $str | 0;
 $val = $val | 0;
 $sep = $sep | 0;
 $trim = $trim | 0;
 var $tmp = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 70684
 STACKTOP = STACKTOP + 8 | 0; //@line 70684
 $tmp = sp | 0; //@line 70685
 if ((_msg_get_prefix_ulng($str, $tmp, $sep, $trim) | 0) != 0) {
  $_0 = 1; //@line 70690
  STACKTOP = sp; //@line 70692
  return $_0 | 0; //@line 70693
 }
 HEAP32[$val >> 2] = HEAP32[$tmp >> 2]; //@line 70696
 $_0 = 0; //@line 70698
 STACKTOP = sp; //@line 70700
 return $_0 | 0; //@line 70701
}
function _pce_path_add($dir, $atend) {
 $dir = $dir | 0;
 $atend = $atend | 0;
 var $n_0 = 0, $4 = 0, $13 = 0, $str_0 = 0, $22 = 0, $23 = 0, $28 = 0, $i_025 = 0, $32 = 0, $_0 = 0, label = 0;
 $n_0 = _strlen($dir | 0) | 0; //@line 70717
 while (1) {
  if (($n_0 | 0) == 0) {
   $str_0 = 0; //@line 70723
   break;
  }
  $4 = $n_0 - 1 | 0; //@line 70726
  if ((HEAP8[$dir + $4 | 0] | 0) == 47) {
   $n_0 = $4; //@line 70731
  } else {
   label = 18172; //@line 70733
   break;
  }
 }
 do {
  if ((label | 0) == 18172) {
   if (($n_0 | 0) == 1) {
    if ((HEAP8[$dir] | 0) == 46) {
     $str_0 = 0; //@line 70744
     break;
    }
   } else if (($n_0 | 0) == 0) {
    $str_0 = 0; //@line 70748
    break;
   }
   $13 = _malloc($n_0 + 1 | 0) | 0; //@line 70752
   if (($13 | 0) == 0) {
    $_0 = 1; //@line 70756
    return $_0 | 0; //@line 70759
   } else {
    _memcpy($13 | 0, $dir | 0, $n_0) | 0; //@line 70761
    HEAP8[$13 + $n_0 | 0] = 0; //@line 70763
    $str_0 = $13; //@line 70764
    break;
   }
  }
 } while (0);
 $22 = _realloc(HEAP32[15592] | 0, (HEAP32[15594] << 2) + 4 | 0) | 0; //@line 70775
 $23 = $22; //@line 70776
 if (($22 | 0) == 0) {
  _free($str_0); //@line 70780
  $_0 = 1; //@line 70782
  return $_0 | 0; //@line 70785
 }
 $28 = HEAP32[15594] | 0; //@line 70788
 if (($atend | 0) == 0) {
  if (($28 | 0) != 0) {
   $i_025 = $28; //@line 70794
   while (1) {
    $32 = $i_025 - 1 | 0; //@line 70797
    HEAP32[$23 + ($i_025 << 2) >> 2] = HEAP32[$23 + ($32 << 2) >> 2]; //@line 70801
    if (($32 | 0) == 0) {
     break;
    } else {
     $i_025 = $32; //@line 70807
    }
   }
  }
  HEAP32[$23 >> 2] = $str_0; //@line 70811
 } else {
  HEAP32[$23 + ($28 << 2) >> 2] = $str_0; //@line 70814
 }
 HEAP32[15594] = $28 + 1; //@line 70818
 HEAP32[15592] = $23; //@line 70819
 $_0 = 0; //@line 70821
 return $_0 | 0; //@line 70824
}
function _pce_set_fd_interactive($fd, $interactive) {
 $fd = $fd | 0;
 $interactive = $interactive | 0;
 if (!(HEAP8[6672] | 0)) {
  HEAP8[6672] = 1; //@line 70837
 }
 return;
}
function _pce_stop() {
 if (!(HEAP8[6672] | 0)) {
  HEAP8[6672] = 1; //@line 70852
 }
 return;
}
function _pce_start($brk) {
 $brk = $brk | 0;
 if (($brk | 0) != 0) {
  HEAP32[$brk >> 2] = 0; //@line 70868
 }
 if (HEAP8[6672] | 0) {
  return;
 }
 HEAP8[6672] = 1; //@line 70877
 return;
}
function _pce_path_set($dir) {
 $dir = $dir | 0;
 var $1 = 0, $7 = 0, $10 = 0, $11 = 0, $i_03_i = 0, $14 = 0, $17 = 0, $_lcssa_i = 0, $_0 = 0, $atend_0 = 0;
 $1 = HEAP8[$dir] | 0; //@line 70891
 if (($1 << 24 >> 24 | 0) == 45) {
  $atend_0 = 0;
  $_0 = $dir + 1 | 0;
 } else if (($1 << 24 >> 24 | 0) == 43) {
  $atend_0 = 1;
  $_0 = $dir + 1 | 0;
 } else if (($1 << 24 >> 24 | 0) == 61) {
  $7 = $dir + 1 | 0; //@line 70901
  $10 = HEAP32[15592] | 0; //@line 70904
  if ((HEAP32[15594] | 0) == 0) {
   $_lcssa_i = $10; //@line 70907
  } else {
   $i_03_i = 0;
   $11 = $10;
   while (1) {
    _free(HEAP32[$11 + ($i_03_i << 2) >> 2] | 0); //@line 70915
    $14 = $i_03_i + 1 | 0; //@line 70916
    $17 = HEAP32[15592] | 0; //@line 70919
    if ($14 >>> 0 < (HEAP32[15594] | 0) >>> 0) {
     $i_03_i = $14;
     $11 = $17;
    } else {
     $_lcssa_i = $17; //@line 70924
     break;
    }
   }
  }
  _free($_lcssa_i); //@line 70931
  HEAP32[15594] = 0; //@line 70932
  HEAP32[15592] = 0; //@line 70933
  $atend_0 = 1;
  $_0 = $7;
 } else {
  $atend_0 = 1;
  $_0 = $dir;
 }
 return _pce_path_add($_0, $atend_0) | 0; //@line 70943
}
function _pce_path_get($fname) {
 $fname = $fname | 0;
 var $3 = 0, $5 = 0, $i_021 = 0, $14 = 0, $17 = 0, $19 = 0, $24 = 0, $25 = 0, $26 = 0, $28 = 0, $32 = 0, $_0_i15_ph = 0, $37 = 0, $42 = 0, $_0 = 0, label = 0;
 if (($fname | 0) == 0) {
  $_0 = 0; //@line 70959
  return $_0 | 0; //@line 70962
 }
 $3 = _strlen($fname | 0) | 0; //@line 70964
 $5 = _malloc($3 + 1 | 0) | 0; //@line 70966
 if (($5 | 0) == 0) {
  $_0 = 0; //@line 70970
  return $_0 | 0; //@line 70973
 }
 _memcpy($5 | 0, $fname | 0, $3) | 0; //@line 70975
 HEAP8[$5 + $3 | 0] = 0; //@line 70977
 if ((HEAP8[$5] | 0) == 47 | (HEAP32[15594] | 0) == 0) {
  $_0 = $5; //@line 70985
  return $_0 | 0; //@line 70988
 } else {
  $i_021 = 0; //@line 70990
 }
 while (1) {
  $14 = HEAP32[(HEAP32[15592] | 0) + ($i_021 << 2) >> 2] | 0; //@line 70996
  if (($14 | 0) == 0) {
   $17 = _strlen($5 | 0) | 0; //@line 71000
   $19 = _malloc($17 + 1 | 0) | 0; //@line 71002
   if (($19 | 0) == 0) {
    label = 18216; //@line 71006
    break;
   }
   _memcpy($19 | 0, $5 | 0, $17) | 0; //@line 71009
   HEAP8[$19 + $17 | 0] = 0; //@line 71011
   $_0_i15_ph = $19; //@line 71013
  } else {
   $24 = _strlen($14 | 0) | 0; //@line 71015
   $25 = _strlen($5 | 0) | 0; //@line 71016
   $26 = $25 + $24 | 0; //@line 71017
   $28 = _malloc($26 + 2 | 0) | 0; //@line 71019
   if (($28 | 0) == 0) {
    label = 18216; //@line 71023
    break;
   }
   _memcpy($28 | 0, $14 | 0, $24) | 0; //@line 71026
   HEAP8[$28 + $24 | 0] = 47; //@line 71028
   $32 = $28 + ($24 + 1) | 0; //@line 71030
   _memcpy($32 | 0, $5 | 0, $25) | 0; //@line 71031
   HEAP8[$28 + ($26 + 1) | 0] = 0; //@line 71034
   $_0_i15_ph = $28; //@line 71036
  }
  $37 = _fopen($_0_i15_ph | 0, 50336) | 0; //@line 71039
  if (($37 | 0) != 0) {
   label = 18218; //@line 71043
   break;
  }
  _free($_0_i15_ph); //@line 71046
  $42 = $i_021 + 1 | 0; //@line 71047
  if ($42 >>> 0 < (HEAP32[15594] | 0) >>> 0) {
   $i_021 = $42; //@line 71052
  } else {
   $_0 = $5; //@line 71054
   label = 18226; //@line 71055
   break;
  }
 }
 if ((label | 0) == 18218) {
  _fclose($37 | 0) | 0; //@line 71060
  _free($5); //@line 71061
  $_0 = $_0_i15_ph; //@line 71063
  return $_0 | 0; //@line 71066
 } else if ((label | 0) == 18216) {
  _free($5); //@line 71069
  $_0 = 0; //@line 71071
  return $_0 | 0; //@line 71074
 } else if ((label | 0) == 18226) {
  return $_0 | 0; //@line 71079
 }
 return 0;
}
function _pce_path_ini($sct) {
 $sct = $sct | 0;
 var $val_0 = 0, $2 = 0, $5 = 0, $8 = 0, $14 = 0, $17 = 0, $18 = 0, $i_03_i_i = 0, $21 = 0, $24 = 0, $_lcssa_i_i = 0, $_0_i = 0, $atend_0_i = 0, $_0 = 0, label = 0;
 $val_0 = 0; //@line 71093
 while (1) {
  $2 = _ini_next_val($sct, $val_0, 56040) | 0; //@line 71096
  if (($2 | 0) == 0) {
   $_0 = 0; //@line 71100
   label = 18238; //@line 71101
   break;
  }
  $5 = _ini_val_get_str($2) | 0; //@line 71104
  if (($5 | 0) == 0) {
   $_0 = 1; //@line 71108
   label = 18240; //@line 71109
   break;
  }
  $8 = HEAP8[$5] | 0; //@line 71112
  if (($8 << 24 >> 24 | 0) == 43) {
   $atend_0_i = 1;
   $_0_i = $5 + 1 | 0;
  } else if (($8 << 24 >> 24 | 0) == 45) {
   $atend_0_i = 0;
   $_0_i = $5 + 1 | 0;
  } else if (($8 << 24 >> 24 | 0) == 61) {
   $14 = $5 + 1 | 0; //@line 71122
   $17 = HEAP32[15592] | 0; //@line 71125
   if ((HEAP32[15594] | 0) == 0) {
    $_lcssa_i_i = $17; //@line 71128
   } else {
    $i_03_i_i = 0;
    $18 = $17;
    while (1) {
     _free(HEAP32[$18 + ($i_03_i_i << 2) >> 2] | 0); //@line 71136
     $21 = $i_03_i_i + 1 | 0; //@line 71137
     $24 = HEAP32[15592] | 0; //@line 71140
     if ($21 >>> 0 < (HEAP32[15594] | 0) >>> 0) {
      $i_03_i_i = $21;
      $18 = $24;
     } else {
      $_lcssa_i_i = $24; //@line 71145
      break;
     }
    }
   }
   _free($_lcssa_i_i); //@line 71152
   HEAP32[15594] = 0; //@line 71153
   HEAP32[15592] = 0; //@line 71154
   $atend_0_i = 1;
   $_0_i = $14;
  } else {
   $atend_0_i = 1;
   $_0_i = $5;
  }
  if ((_pce_path_add($_0_i, $atend_0_i) | 0) == 0) {
   $val_0 = $2; //@line 71166
  } else {
   $_0 = 1; //@line 71168
   label = 18239; //@line 71169
   break;
  }
 }
 if ((label | 0) == 18240) {
  return $_0 | 0; //@line 71176
 } else if ((label | 0) == 18239) {
  return $_0 | 0; //@line 71181
 } else if ((label | 0) == 18238) {
  return $_0 | 0; //@line 71186
 }
 return 0;
}
function _str_cat_alloc($str1, $str2) {
 $str1 = $str1 | 0;
 $str2 = $str2 | 0;
 var $5 = 0, $10 = 0, $11 = 0, $13 = 0, $21 = 0, $_0 = 0;
 if (($str1 | 0) == 0) {
  $5 = 0; //@line 71201
 } else {
  $5 = _strlen($str1 | 0) | 0; //@line 71205
 }
 if (($str2 | 0) == 0) {
  $10 = 0; //@line 71211
 } else {
  $10 = _strlen($str2 | 0) | 0; //@line 71215
 }
 $11 = $10 + $5 | 0; //@line 71218
 $13 = _malloc($11 + 1 | 0) | 0; //@line 71220
 if (($13 | 0) == 0) {
  $_0 = 0; //@line 71224
  return $_0 | 0; //@line 71227
 }
 if (($5 | 0) != 0) {
  _memcpy($13 | 0, $str1 | 0, $5) | 0; //@line 71232
 }
 if (($10 | 0) != 0) {
  $21 = $13 + $5 | 0; //@line 71238
  _memcpy($21 | 0, $str2 | 0, $10) | 0; //@line 71239
 }
 HEAP8[$13 + $11 | 0] = 0; //@line 71243
 $_0 = $13; //@line 71245
 return $_0 | 0; //@line 71248
}
function _str_trim($str, $left, $right) {
 $str = $str | 0;
 $left = $left | 0;
 $right = $right | 0;
 var $_016 = 0, $4 = 0, $_1 = 0, $i_0 = 0, $17 = 0, $i_0_lcssa = 0, $_0 = 0;
 if (($str | 0) == 0) {
  $_0 = 0; //@line 71264
  return $_0 | 0; //@line 71267
 }
 L23666 : do {
  if (($left | 0) == 0) {
   $_1 = $str; //@line 71273
  } else {
   $_016 = $str; //@line 71275
   while (1) {
    $4 = HEAP8[$_016] | 0; //@line 71278
    if ($4 << 24 >> 24 == 0) {
     $_1 = $_016; //@line 71282
     break L23666;
    }
    if ((_strchr($left | 0, $4 << 24 >> 24 | 0) | 0) == 0) {
     $_1 = $_016; //@line 71291
     break;
    } else {
     $_016 = $_016 + 1 | 0; //@line 71294
    }
   }
  }
 } while (0);
 if (($right | 0) == 0) {
  $_0 = $_1; //@line 71303
  return $_0 | 0; //@line 71306
 }
 $i_0 = _strlen($_1 | 0) | 0; //@line 71310
 while (1) {
  if (($i_0 | 0) == 0) {
   $i_0_lcssa = 0; //@line 71316
   break;
  }
  $17 = $i_0 - 1 | 0; //@line 71319
  if ((_strchr($right | 0, HEAP8[$_1 + $17 | 0] | 0) | 0) == 0) {
   $i_0_lcssa = $i_0; //@line 71327
   break;
  } else {
   $i_0 = $17; //@line 71330
  }
 }
 HEAP8[$_1 + $i_0_lcssa | 0] = 0; //@line 71335
 $_0 = $_1; //@line 71337
 return $_0 | 0; //@line 71340
}
function _str_ltrim($str, $left) {
 $str = $str | 0;
 $left = $left | 0;
 var $_08 = 0, $4 = 0, $_0 = 0;
 L23680 : do {
  if (($str | 0) == 0) {
   $_0 = 0; //@line 71355
  } else {
   if (($left | 0) == 0) {
    $_0 = $str; //@line 71360
    break;
   } else {
    $_08 = $str; //@line 71363
   }
   while (1) {
    $4 = HEAP8[$_08] | 0; //@line 71367
    if ($4 << 24 >> 24 == 0) {
     $_0 = $_08; //@line 71371
     break L23680;
    }
    if ((_strchr($left | 0, $4 << 24 >> 24 | 0) | 0) == 0) {
     $_0 = $_08; //@line 71379
     break;
    } else {
     $_08 = $_08 + 1 | 0; //@line 71382
    }
   }
  }
 } while (0);
 return $_0 | 0; //@line 71389
}
function _str_extract_alloc($str, $sep, $rest) {
 $str = $str | 0;
 $sep = $sep | 0;
 $rest = $rest | 0;
 var $i_0 = 0, $3 = 0, $4 = 0, $9 = 0, $_pre_phi = 0, $10 = 0, $i_012_i = 0, $14 = 0, $18 = 0, $i_0_lcssa_i = 0, $_0_i = 0, $_0 = 0, label = 0;
 if (($str | 0) == 0) {
  $_0 = 0; //@line 71406
  return $_0 | 0; //@line 71409
 } else {
  $i_0 = 0; //@line 71411
 }
 while (1) {
  $3 = HEAP8[$str + $i_0 | 0] | 0; //@line 71416
  $4 = $3 << 24 >> 24 == 0; //@line 71417
  if ($4) {
   label = 18274; //@line 71420
   break;
  }
  $9 = $i_0 + 1 | 0; //@line 71426
  if ((_strchr($sep | 0, $3 << 24 >> 24 | 0) | 0) == 0) {
   $i_0 = $9; //@line 71428
  } else {
   $_pre_phi = $9; //@line 71430
   break;
  }
 }
 if ((label | 0) == 18274) {
  $_pre_phi = $i_0 + 1 | 0; //@line 71437
 }
 $10 = _malloc($_pre_phi) | 0; //@line 71440
 if (($10 | 0) == 0) {
  $_0_i = 0; //@line 71444
 } else {
  L23697 : do {
   if (($i_0 | 0) == 0) {
    $i_0_lcssa_i = 0; //@line 71450
   } else {
    $i_012_i = 0; //@line 71452
    while (1) {
     $14 = HEAP8[$str + $i_012_i | 0] | 0; //@line 71456
     if ($14 << 24 >> 24 == 0) {
      $i_0_lcssa_i = $i_012_i; //@line 71459
      break L23697;
     }
     HEAP8[$10 + $i_012_i | 0] = $14; //@line 71463
     $18 = $i_012_i + 1 | 0; //@line 71464
     if ($18 >>> 0 < $i_0 >>> 0) {
      $i_012_i = $18; //@line 71468
     } else {
      $i_0_lcssa_i = $18; //@line 71470
      break;
     }
    }
   }
  } while (0);
  HEAP8[$10 + $i_0_lcssa_i | 0] = 0; //@line 71478
  $_0_i = $10; //@line 71480
 }
 if ((HEAP32[$rest >> 2] | 0) == 0) {
  $_0 = $_0_i; //@line 71487
  return $_0 | 0; //@line 71490
 }
 HEAP32[$rest >> 2] = $str + ($4 ? $i_0 : $_pre_phi); //@line 71494
 $_0 = $_0_i; //@line 71496
 return $_0 | 0; //@line 71499
}
function _pce_usleep($usec) {
 $usec = $usec | 0;
 var $t = 0, $6 = 0, sp = 0;
 sp = STACKTOP; //@line 71507
 STACKTOP = STACKTOP + 8 | 0; //@line 71507
 $t = sp | 0; //@line 71508
 HEAP32[$t >> 2] = ($usec >>> 0) / 1e6 | 0; //@line 71511
 HEAP32[$t + 4 >> 2] = (($usec >>> 0) % 1e6 | 0) * 1e3 | 0; //@line 71515
 $6 = _nanosleep($t | 0, 0) | 0; //@line 71516
 STACKTOP = sp; //@line 71517
 return $6 | 0; //@line 71518
}
function _pce_get_interval_us($val) {
 $val = $val | 0;
 var $tv = 0, $9 = 0, $11 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 71527
 STACKTOP = STACKTOP + 8 | 0; //@line 71527
 $tv = sp | 0; //@line 71528
 if ((_gettimeofday($tv | 0, 0) | 0) != 0) {
  $_0 = 0; //@line 71533
  STACKTOP = sp; //@line 71535
  return $_0 | 0; //@line 71536
 }
 $9 = ((HEAP32[$tv >> 2] | 0) * 1e6 | 0) + (HEAP32[$tv + 4 >> 2] | 0) | 0; //@line 71543
 $11 = $9 - (HEAP32[$val >> 2] | 0) | 0; //@line 71545
 HEAP32[$val >> 2] = $9; //@line 71546
 $_0 = $11; //@line 71548
 STACKTOP = sp; //@line 71550
 return $_0 | 0; //@line 71551
}
function _ini_read_str($sct, $str) {
 $sct = $sct | 0;
 $str = $str | 0;
 var $scn = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 71560
 STACKTOP = STACKTOP + 1304 | 0; //@line 71560
 $scn = sp | 0; //@line 71561
 _scn_init($scn); //@line 71563
 _scn_set_str($scn, $str); //@line 71564
 if ((_parse_section($scn, $sct, sp + 1048 | 0) | 0) != 0) {
  _parse_error($scn, 50088, 1); //@line 71570
  _scn_free($scn); //@line 71571
  $_0 = 1; //@line 71573
  STACKTOP = sp; //@line 71575
  return $_0 | 0; //@line 71576
 }
 if ((_scn_get_chr($scn, 0) | 0) << 24 >> 24 == 0) {
  _scn_free($scn); //@line 71582
  $_0 = 0; //@line 71584
  STACKTOP = sp; //@line 71586
  return $_0 | 0; //@line 71587
 } else {
  _parse_error($scn, 50088, 1); //@line 71589
  _scn_free($scn); //@line 71590
  $_0 = 1; //@line 71592
  STACKTOP = sp; //@line 71594
  return $_0 | 0; //@line 71595
 }
 return 0;
}
function _parse_section($scn, $sct, $buf) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $buf = $buf | 0;
 var $val_i = 0, $tmp = 0, $4 = 0, $6 = 0, $7 = 0, $18 = 0, $39 = 0, $46 = 0, $done_0_i = 0, $skip_0_i = 0, $done_1_i = 0, $88 = 0, $done_2_i = 0, $skip_1_i = 0, $100 = 0, $107 = 0, $108 = 0, $name_0_i39 = 0, $115 = 0, $117 = 0, $120 = 0, $name_0_i = 0, $128 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 71620
 STACKTOP = STACKTOP + 32 | 0; //@line 71620
 $val_i = sp | 0; //@line 71621
 $tmp = sp + 16 | 0; //@line 71622
 if ((_scn_match_name($scn, $buf, 256) | 0) == 0) {
  $_0 = 0; //@line 71627
  STACKTOP = sp; //@line 71629
  return $_0 | 0; //@line 71630
 }
 $4 = $val_i + 8 | 0; //@line 71633
 $6 = $val_i + 12 | 0; //@line 71635
 $7 = $tmp + 8 | 0; //@line 71636
 L23727 : while (1) {
  if ((_strcmp($buf | 0, 31640) | 0) == 0) {
   if ((_scn_match_name($scn, $buf, 256) | 0) == 0) {
    $_0 = 1; //@line 71647
    label = 18358; //@line 71648
    break;
   }
  }
  L23732 : do {
   if ((_scn_match($scn, 30656) | 0) == 0) {
    if ((_scn_match($scn, 57016) | 0) != 0) {
     _ini_val_init($tmp, 0); //@line 71661
     if ((_ini_eval($scn, $sct, $tmp) | 0) != 0) {
      label = 18316; //@line 71666
      break L23727;
     }
     if ((HEAP32[$7 >> 2] | 0) == 0) {
      label = 18316; //@line 71673
      break L23727;
     }
     if ((_ini_get_val($sct, $buf, 0) | 0) == 0) {
      $39 = _ini_get_val($sct, $buf, 1) | 0; //@line 71680
      if (($39 | 0) == 0) {
       label = 18316; //@line 71684
       break L23727;
      }
      _ini_val_copy($39, $tmp); //@line 71687
     }
     _ini_val_free($tmp); //@line 71690
     break;
    }
    if ((_scn_match($scn, 55856) | 0) != 0) {
     $46 = _ini_get_val($sct, $buf, 1) | 0; //@line 71698
     if (($46 | 0) == 0) {
      $_0 = 1; //@line 71702
      label = 18364; //@line 71703
      break L23727;
     }
     if ((_ini_eval($scn, $sct, $46) | 0) != 0) {
      $_0 = 1; //@line 71710
      label = 18355; //@line 71711
      break L23727;
     }
     if ((HEAP32[$46 + 8 >> 2] | 0) == 0) {
      $_0 = 1; //@line 71719
      label = 18350; //@line 71720
      break L23727;
     } else {
      break;
     }
    }
    if ((_strcmp($buf | 0, 55216) | 0) != 0) {
     if ((_strcmp($buf | 0, 54472) | 0) != 0) {
      $_0 = 1; //@line 71734
      label = 18348; //@line 71735
      break L23727;
     }
     $100 = _scn_match($scn, 53816) | 0; //@line 71738
     if ((_scn_match_string($scn, $buf, 256) | 0) == 0) {
      $_0 = 1; //@line 71743
      label = 18359; //@line 71744
      break L23727;
     }
     if ((_scn_add_file($scn, $buf, 0, 1) | 0) == 0 | ($100 | 0) != 0) {
      break;
     } else {
      label = 18341; //@line 71755
      break L23727;
     }
    }
    _ini_val_init($val_i, 0); //@line 71759
    if ((_ini_eval($scn, $sct, $val_i) | 0) != 0) {
     label = 18324; //@line 71764
     break L23727;
    }
    if ((HEAP32[$4 >> 2] | 0) == 1) {
     if ((HEAP32[$6 >> 2] | 0) == 0) {
      label = 18327; //@line 71775
     } else {
      $skip_0_i = 0;
      $done_0_i = 1;
     }
    } else {
     label = 18327; //@line 71780
    }
    if ((label | 0) == 18327) {
     label = 0; //@line 71783
     $skip_0_i = 1;
     $done_0_i = 0;
    }
    _ini_val_free($val_i); //@line 71788
    if ((_parse_block($scn, $sct, $buf, $skip_0_i) | 0) == 0) {
     $done_1_i = $done_0_i; //@line 71793
    } else {
     $_0 = 1; //@line 71795
     label = 18349; //@line 71796
     break L23727;
    }
    while (1) {
     if ((_scn_match_ident($scn, 51704) | 0) == 0) {
      break L23732;
     }
     if ((_scn_match_ident($scn, 55216) | 0) == 0) {
      break;
     }
     _ini_val_init($val_i, 0); //@line 71813
     if ((_ini_eval($scn, $sct, $val_i) | 0) != 0) {
      label = 18332; //@line 71818
      break L23727;
     }
     do {
      if (($done_1_i | 0) == 0) {
       if ((HEAP32[$4 >> 2] | 0) != 1) {
        $skip_1_i = 1;
        $done_2_i = 0;
        break;
       }
       $88 = (HEAP32[$6 >> 2] | 0) == 0; //@line 71833
       $skip_1_i = $88 & 1;
       $done_2_i = $88 & 1 ^ 1;
      } else {
       $skip_1_i = 1;
       $done_2_i = $done_1_i;
      }
     } while (0);
     _ini_val_free($val_i); //@line 71845
     if ((_parse_block($scn, $sct, $buf, $skip_1_i) | 0) == 0) {
      $done_1_i = $done_2_i; //@line 71850
     } else {
      $_0 = 1; //@line 71852
      label = 18351; //@line 71853
      break L23727;
     }
    }
    if ((_parse_block($scn, $sct, $buf, $done_1_i) | 0) != 0) {
     $_0 = 1; //@line 71861
     label = 18352; //@line 71862
     break L23727;
    }
   } else {
    $18 = _ini_get_sct($sct, $buf, 1) | 0; //@line 71866
    if (($18 | 0) == 0) {
     $_0 = 1; //@line 71870
     label = 18360; //@line 71871
     break L23727;
    }
    if ((_parse_section($scn, $18, $buf) | 0) != 0) {
     $_0 = 1; //@line 71878
     label = 18353; //@line 71879
     break L23727;
    }
    if ((_scn_match($scn, 57864) | 0) == 0) {
     $_0 = 1; //@line 71886
     label = 18357; //@line 71887
     break L23727;
    }
   }
  } while (0);
  _scn_match($scn, 52288) | 0; //@line 71892
  if ((_scn_match_name($scn, $buf, 256) | 0) == 0) {
   $_0 = 0; //@line 71897
   label = 18362; //@line 71898
   break;
  }
 }
 if ((label | 0) == 18360) {
  STACKTOP = sp; //@line 71904
  return $_0 | 0; //@line 71905
 } else if ((label | 0) == 18352) {
  STACKTOP = sp; //@line 71909
  return $_0 | 0; //@line 71910
 } else if ((label | 0) == 18353) {
  STACKTOP = sp; //@line 71914
  return $_0 | 0; //@line 71915
 } else if ((label | 0) == 18332) {
  _ini_val_free($val_i); //@line 71918
  $_0 = 1; //@line 71920
  STACKTOP = sp; //@line 71922
  return $_0 | 0; //@line 71923
 } else if ((label | 0) == 18324) {
  _ini_val_free($val_i); //@line 71926
  $_0 = 1; //@line 71928
  STACKTOP = sp; //@line 71930
  return $_0 | 0; //@line 71931
 } else if ((label | 0) == 18357) {
  STACKTOP = sp; //@line 71935
  return $_0 | 0; //@line 71936
 } else if ((label | 0) == 18358) {
  STACKTOP = sp; //@line 71940
  return $_0 | 0; //@line 71941
 } else if ((label | 0) == 18359) {
  STACKTOP = sp; //@line 71945
  return $_0 | 0; //@line 71946
 } else if ((label | 0) == 18355) {
  STACKTOP = sp; //@line 71950
  return $_0 | 0; //@line 71951
 } else if ((label | 0) == 18341) {
  $107 = $scn + 1040 | 0; //@line 71954
  $108 = HEAP32[$107 >> 2] | 0; //@line 71955
  if (($108 | 0) == 0) {
   $name_0_i39 = 0; //@line 71959
  } else {
   $name_0_i39 = HEAP32[$108 + 4 >> 2] | 0; //@line 71964
  }
  $115 = $scn + 1028 | 0; //@line 71970
  $117 = (HEAP32[$115 >> 2] | 0) + 1 | 0; //@line 71972
  _fprintf(HEAP32[_stderr >> 2] | 0, 45760, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = ($name_0_i39 | 0) == 0 ? 49528 : $name_0_i39, HEAP32[tempInt + 8 >> 2] = $117, HEAP32[tempInt + 16 >> 2] = 53176, tempInt) | 0) | 0; //@line 71973
  _fputc(10, HEAP32[_stderr >> 2] | 0) | 0; //@line 71975
  $120 = HEAP32[$107 >> 2] | 0; //@line 71976
  if (($120 | 0) == 0) {
   $name_0_i = 0; //@line 71980
  } else {
   $name_0_i = HEAP32[$120 + 4 >> 2] | 0; //@line 71985
  }
  $128 = (HEAP32[$115 >> 2] | 0) + 1 | 0; //@line 71992
  _fprintf(HEAP32[_stderr >> 2] | 0, 45760, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = ($name_0_i | 0) == 0 ? 49528 : $name_0_i, HEAP32[tempInt + 8 >> 2] = $128, HEAP32[tempInt + 16 >> 2] = $buf, tempInt) | 0) | 0; //@line 71993
  _fputc(10, HEAP32[_stderr >> 2] | 0) | 0; //@line 71995
  $_0 = 1; //@line 71997
  STACKTOP = sp; //@line 71999
  return $_0 | 0; //@line 72000
 } else if ((label | 0) == 18350) {
  STACKTOP = sp; //@line 72004
  return $_0 | 0; //@line 72005
 } else if ((label | 0) == 18351) {
  STACKTOP = sp; //@line 72009
  return $_0 | 0; //@line 72010
 } else if ((label | 0) == 18348) {
  STACKTOP = sp; //@line 72014
  return $_0 | 0; //@line 72015
 } else if ((label | 0) == 18349) {
  STACKTOP = sp; //@line 72019
  return $_0 | 0; //@line 72020
 } else if ((label | 0) == 18316) {
  _ini_val_free($tmp); //@line 72023
  $_0 = 1; //@line 72025
  STACKTOP = sp; //@line 72027
  return $_0 | 0; //@line 72028
 } else if ((label | 0) == 18362) {
  STACKTOP = sp; //@line 72032
  return $_0 | 0; //@line 72033
 } else if ((label | 0) == 18364) {
  STACKTOP = sp; //@line 72037
  return $_0 | 0; //@line 72038
 }
 return 0;
}
function _parse_error($scn, $text, $src) {
 $scn = $scn | 0;
 $text = $text | 0;
 $src = $src | 0;
 var $2 = 0, $name_0 = 0, $12 = 0, $16 = 0, $i_012 = 0, $19 = 0, $24 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 72052
 $2 = HEAP32[$scn + 1040 >> 2] | 0; //@line 72054
 if (($2 | 0) == 0) {
  $name_0 = 0; //@line 72058
 } else {
  $name_0 = HEAP32[$2 + 4 >> 2] | 0; //@line 72063
 }
 $12 = (HEAP32[$scn + 1028 >> 2] | 0) + 1 | 0; //@line 72071
 _fprintf(HEAP32[_stderr >> 2] | 0, 45760, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = ($name_0 | 0) == 0 ? 49528 : $name_0, HEAP32[tempInt + 8 >> 2] = $12, HEAP32[tempInt + 16 >> 2] = $text, tempInt) | 0) | 0; //@line 72072
 L23805 : do {
  if (($src | 0) != 0) {
   $16 = HEAP32[_stderr >> 2] | 0; //@line 72077
   _fwrite(42296, 2, 1, $16 | 0) | 0; //@line 72078
   $i_012 = 0; //@line 72080
   while (1) {
    $19 = _scn_get_chr($scn, $i_012) | 0; //@line 72083
    if (($19 << 24 >> 24 | 0) == 13 | ($19 << 24 >> 24 | 0) == 10) {
     label = 18372; //@line 72085
     break;
    } else if (($19 << 24 >> 24 | 0) == 0) {
     label = 18371; //@line 72088
     break;
    }
    _fputc($19 << 24 >> 24 | 0, HEAP32[_stderr >> 2] | 0) | 0; //@line 72093
    $i_012 = $i_012 + 1 | 0; //@line 72094
    if ($i_012 >>> 0 >= 64) {
     break L23805;
    }
   }
   if ((label | 0) == 18372) {
    $24 = HEAP32[_stderr >> 2] | 0; //@line 72104
    _fwrite(36272, 4, 1, $24 | 0) | 0; //@line 72105
    break;
   } else if ((label | 0) == 18371) {
    _fwrite(39224, 5, 1, HEAP32[_stderr >> 2] | 0) | 0; //@line 72111
    break;
   }
  }
 } while (0);
 _fputc(10, HEAP32[_stderr >> 2] | 0) | 0; //@line 72118
 STACKTOP = sp; //@line 72119
 return;
}
function _ini_read_fp($sct, $fp, $fname) {
 $sct = $sct | 0;
 $fp = $fp | 0;
 $fname = $fname | 0;
 var $scn = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 72131
 STACKTOP = STACKTOP + 1304 | 0; //@line 72131
 $scn = sp | 0; //@line 72132
 _scn_init($scn); //@line 72134
 if ((_scn_add_file($scn, $fname, $fp, 0) | 0) != 0) {
  _ini_sct_del($sct); //@line 72139
  $_0 = 1; //@line 72141
  STACKTOP = sp; //@line 72143
  return $_0 | 0; //@line 72144
 }
 if ((_parse_section($scn, $sct, sp + 1048 | 0) | 0) != 0) {
  _parse_error($scn, 50088, 1); //@line 72151
  _scn_free($scn); //@line 72152
  $_0 = 1; //@line 72154
  STACKTOP = sp; //@line 72156
  return $_0 | 0; //@line 72157
 }
 if ((_scn_get_chr($scn, 0) | 0) << 24 >> 24 == 0) {
  _scn_free($scn); //@line 72163
  $_0 = 0; //@line 72165
  STACKTOP = sp; //@line 72167
  return $_0 | 0; //@line 72168
 } else {
  _parse_error($scn, 50088, 1); //@line 72170
  _scn_free($scn); //@line 72171
  $_0 = 1; //@line 72173
  STACKTOP = sp; //@line 72175
  return $_0 | 0; //@line 72176
 }
 return 0;
}
function _scn_init($scn) {
 $scn = $scn | 0;
 HEAP32[$scn >> 2] = 0; //@line 72187
 HEAP32[$scn + 1028 >> 2] = 0; //@line 72189
 HEAP32[$scn + 1032 >> 2] = 0; //@line 72191
 HEAP32[$scn + 1040 >> 2] = 0; //@line 72193
 HEAP32[$scn + 1044 >> 2] = 0; //@line 72195
 return;
}
function _scn_set_str($scn, $str) {
 $scn = $scn | 0;
 $str = $str | 0;
 HEAP32[$scn + 1044 >> 2] = $str; //@line 72208
 return;
}
function _ini_read($sct, $fname) {
 $sct = $sct | 0;
 $fname = $fname | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _fopen($fname | 0, 56008 | 0) | 0; //@line 72220
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 72224
  return $_0 | 0; //@line 72227
 }
 $4 = _ini_read_fp($sct, $1, $fname) | 0; //@line 72229
 _fclose($1 | 0) | 0; //@line 72230
 $_0 = $4; //@line 72232
 return $_0 | 0; //@line 72235
}
function _parse_block($scn, $sct, $buf, $skip) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $buf = $buf | 0;
 $skip = $skip | 0;
 var $cnt_0_ph_i = 0, $6 = 0, $12 = 0, $_0 = 0, label = 0;
 if ((_scn_match($scn, 30656) | 0) == 0) {
  $_0 = 1; //@line 72252
  return $_0 | 0; //@line 72255
 }
 if (($skip | 0) == 0) {
  if ((_parse_section($scn, $sct, $buf) | 0) != 0) {
   $_0 = 1; //@line 72264
   return $_0 | 0; //@line 72267
  }
  $_0 = (_scn_match($scn, 57864) | 0) == 0 | 0; //@line 72273
  return $_0 | 0; //@line 72276
 } else {
  $cnt_0_ph_i = 1; //@line 72278
 }
 L23845 : while (1) {
  while (1) {
   $6 = _scn_get_chr($scn, 0) | 0; //@line 72283
   if ($6 << 24 >> 24 == 0) {
    $_0 = 1; //@line 72287
    label = 18406; //@line 72288
    break L23845;
   }
   _scn_rmv_chr($scn, 1); //@line 72291
   if (($6 << 24 >> 24 | 0) == 123) {
    label = 18399; //@line 72293
    break;
   } else if (($6 << 24 >> 24 | 0) == 125) {
    label = 18400; //@line 72296
    break;
   }
  }
  if ((label | 0) == 18399) {
   label = 0; //@line 72301
   $cnt_0_ph_i = $cnt_0_ph_i + 1 | 0; //@line 72304
   continue;
  } else if ((label | 0) == 18400) {
   label = 0; //@line 72308
   $12 = $cnt_0_ph_i - 1 | 0; //@line 72309
   if (($12 | 0) == 0) {
    $_0 = 0; //@line 72313
    label = 18407; //@line 72314
    break;
   } else {
    $cnt_0_ph_i = $12; //@line 72317
    continue;
   }
  }
 }
 if ((label | 0) == 18407) {
  return $_0 | 0; //@line 72325
 } else if ((label | 0) == 18406) {
  return $_0 | 0; //@line 72330
 }
 return 0;
}
function _scn_free($scn) {
 $scn = $scn | 0;
 var $4 = 0, $_06_i = 0, $7 = 0, $13 = 0;
 if (($scn | 0) == 0) {
  return;
 }
 $4 = HEAP32[$scn + 1040 >> 2] | 0; //@line 72349
 if (($4 | 0) == 0) {
  return;
 } else {
  $_06_i = $4; //@line 72356
 }
 while (1) {
  $7 = HEAP32[$_06_i >> 2] | 0; //@line 72361
  if ((HEAP32[$_06_i + 12 >> 2] | 0) != 0) {
   $13 = HEAP32[$_06_i + 8 >> 2] | 0; //@line 72368
   _fclose($13 | 0) | 0; //@line 72369
  }
  _free(HEAP32[$_06_i + 4 >> 2] | 0); //@line 72374
  _free($_06_i); //@line 72376
  if (($7 | 0) == 0) {
   break;
  } else {
   $_06_i = $7; //@line 72382
  }
 }
 return;
}
function _scn_add_file($scn, $fname, $fp, $del) {
 $scn = $scn | 0;
 $fname = $fname | 0;
 $fp = $fp | 0;
 $del = $del | 0;
 var $1 = 0, $4 = 0, $5 = 0, $6 = 0, $9 = 0, $11 = 0, $16 = 0, $n1_0_i = 0, $25 = 0, $n1_1_i = 0, $31 = 0, $n1_2_i = 0, $35 = 0, $36 = 0, $38 = 0, $44 = 0, $_0_i29 = 0, $_06_i = 0, $55 = 0, $61 = 0, $name_035 = 0, $73 = 0, $_06_i31 = 0, $78 = 0, $84 = 0, $95 = 0, $_0 = 0, label = 0;
 $1 = _malloc(24) | 0; //@line 72409
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 72413
  return $_0 | 0; //@line 72416
 }
 $4 = $1; //@line 72418
 _memset($1 | 0, 0, 16); //@line 72419
 $5 = $scn + 1040 | 0; //@line 72420
 $6 = HEAP32[$5 >> 2] | 0; //@line 72421
 do {
  if (($6 | 0) == 0) {
   $9 = _strlen($fname | 0) | 0; //@line 72426
   $11 = _malloc($9 + 1 | 0) | 0; //@line 72428
   if (($11 | 0) == 0) {
    $_06_i = $4; //@line 72432
    label = 18433; //@line 72433
    break;
   }
   _memcpy($11 | 0, $fname | 0, $9) | 0; //@line 72436
   HEAP8[$11 + $9 | 0] = 0; //@line 72438
   $name_035 = $11; //@line 72440
  } else {
   $16 = HEAP32[$6 + 4 >> 2] | 0; //@line 72443
   L23876 : do {
    if ((HEAP8[$fname] | 0) == 47 | ($16 | 0) == 0) {
     $n1_2_i = 0; //@line 72451
    } else {
     $n1_0_i = _strlen($16 | 0) | 0; //@line 72455
     while (1) {
      if (($n1_0_i | 0) == 0) {
       $n1_1_i = 0; //@line 72461
       break;
      }
      $25 = $n1_0_i - 1 | 0; //@line 72464
      if ((HEAP8[$16 + $25 | 0] | 0) == 47) {
       $n1_0_i = $25; //@line 72469
      } else {
       $n1_1_i = $n1_0_i; //@line 72471
       break;
      }
     }
     while (1) {
      if (($n1_1_i | 0) == 0) {
       $n1_2_i = 0; //@line 72480
       break L23876;
      }
      $31 = $n1_1_i - 1 | 0; //@line 72483
      if ((HEAP8[$16 + $31 | 0] | 0) == 47) {
       $n1_2_i = $n1_1_i; //@line 72488
       break;
      } else {
       $n1_1_i = $31; //@line 72491
      }
     }
    }
   } while (0);
   $35 = _strlen($fname | 0) | 0; //@line 72497
   $36 = $35 + $n1_2_i | 0; //@line 72498
   $38 = _malloc($36 + 1 | 0) | 0; //@line 72500
   if (($38 | 0) == 0) {
    $_0_i29 = 0; //@line 72504
   } else {
    if (($n1_2_i | 0) != 0) {
     _memcpy($38 | 0, $16 | 0, $n1_2_i) | 0; //@line 72509
    }
    $44 = $38 + $n1_2_i | 0; //@line 72512
    _memcpy($44 | 0, $fname | 0, $35) | 0; //@line 72513
    HEAP8[$38 + $36 | 0] = 0; //@line 72515
    $_0_i29 = $38; //@line 72517
   }
   HEAP32[$6 + 16 >> 2] = HEAP32[$scn + 1028 >> 2]; //@line 72523
   HEAP32[(HEAP32[$5 >> 2] | 0) + 20 >> 2] = HEAP32[$scn + 1032 >> 2]; //@line 72528
   if (($_0_i29 | 0) == 0) {
    $_06_i = $4; //@line 72532
    label = 18433; //@line 72533
   } else {
    $name_035 = $_0_i29; //@line 72535
   }
  }
 } while (0);
 if ((label | 0) == 18433) {
  while (1) {
   label = 0; //@line 72541
   $55 = HEAP32[$_06_i >> 2] | 0; //@line 72544
   if ((HEAP32[$_06_i + 12 >> 2] | 0) != 0) {
    $61 = HEAP32[$_06_i + 8 >> 2] | 0; //@line 72551
    _fclose($61 | 0) | 0; //@line 72552
   }
   _free(HEAP32[$_06_i + 4 >> 2] | 0); //@line 72557
   _free($_06_i); //@line 72559
   if (($55 | 0) == 0) {
    $_0 = 1; //@line 72563
    break;
   } else {
    $_06_i = $55; //@line 72566
    label = 18433; //@line 72567
   }
  }
  return $_0 | 0; //@line 72572
 }
 HEAP32[$1 + 4 >> 2] = $name_035; //@line 72577
 do {
  if (($fp | 0) == 0) {
   $73 = _fopen($name_035 | 0, 49856) | 0; //@line 72582
   HEAP32[$1 + 8 >> 2] = $73; //@line 72585
   if (($73 | 0) == 0) {
    $_06_i31 = $4; //@line 72589
   } else {
    $95 = 0; //@line 72591
    break;
   }
   while (1) {
    $78 = HEAP32[$_06_i31 >> 2] | 0; //@line 72597
    if ((HEAP32[$_06_i31 + 12 >> 2] | 0) != 0) {
     $84 = HEAP32[$_06_i31 + 8 >> 2] | 0; //@line 72604
     _fclose($84 | 0) | 0; //@line 72605
    }
    _free(HEAP32[$_06_i31 + 4 >> 2] | 0); //@line 72610
    _free($_06_i31); //@line 72612
    if (($78 | 0) == 0) {
     $_0 = 1; //@line 72616
     break;
    } else {
     $_06_i31 = $78; //@line 72619
    }
   }
   return $_0 | 0; //@line 72624
  } else {
   HEAP32[$1 + 8 >> 2] = $fp; //@line 72628
   $95 = ($del | 0) != 0 | 0; //@line 72631
  }
 } while (0);
 HEAP32[$1 + 12 >> 2] = $95; //@line 72637
 HEAP32[$1 >> 2] = HEAP32[$5 >> 2]; //@line 72640
 HEAP32[$5 >> 2] = $4; //@line 72641
 HEAP32[$scn + 1028 >> 2] = 0; //@line 72643
 HEAP32[$scn + 1032 >> 2] = 0; //@line 72645
 $_0 = 0; //@line 72647
 return $_0 | 0; //@line 72650
}
function _scn_get_chr($scn, $idx) {
 $scn = $scn | 0;
 $idx = $idx | 0;
 var $2 = 0, $6 = 0, $9 = 0, $14 = 0, $_0 = 0;
 if ($idx >>> 0 > 255) {
  $_0 = 0; //@line 72665
  return $_0 | 0; //@line 72668
 }
 $2 = $scn | 0; //@line 72670
 L23914 : do {
  if ((HEAP32[$2 >> 2] | 0) >>> 0 <= $idx >>> 0) {
   while (1) {
    $6 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 72678
    HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $6; //@line 72681
    $9 = HEAP32[$2 >> 2] | 0; //@line 72682
    if ((HEAP32[$scn + 4 + ($9 << 2) >> 2] | 0) == 0) {
     $_0 = 0; //@line 72688
     break;
    }
    $14 = $9 + 1 | 0; //@line 72691
    HEAP32[$2 >> 2] = $14; //@line 72692
    if ($14 >>> 0 > $idx >>> 0) {
     break L23914;
    }
   }
   return $_0 | 0; //@line 72701
  }
 } while (0);
 $_0 = HEAP32[$scn + 4 + ($idx << 2) >> 2] & 255; //@line 72708
 return $_0 | 0; //@line 72711
}
function _scn_next_char($scn) {
 $scn = $scn | 0;
 var $1 = 0, $2 = 0, $4 = 0, $5 = 0, $7 = 0, $10 = 0, $15 = 0, $17 = 0, $24 = 0, $29 = 0, $36 = 0, $37 = 0, $40 = 0, $_0 = 0, label = 0;
 $1 = $scn + 1040 | 0; //@line 72724
 $2 = HEAP32[$1 >> 2] | 0; //@line 72725
 if (($2 | 0) == 0) {
  $36 = $scn + 1044 | 0; //@line 72729
  $37 = HEAP32[$36 >> 2] | 0; //@line 72730
  if (($37 | 0) == 0) {
   $_0 = 0; //@line 72734
   return $_0 | 0; //@line 72737
  }
  $40 = HEAP8[$37] | 0; //@line 72739
  if ($40 << 24 >> 24 == 0) {
   $_0 = 0; //@line 72743
   return $_0 | 0; //@line 72746
  }
  HEAP32[$36 >> 2] = $37 + 1; //@line 72749
  $_0 = $40; //@line 72751
  return $_0 | 0; //@line 72754
 }
 $4 = $scn + 1028 | 0; //@line 72756
 $5 = $scn + 1032 | 0; //@line 72757
 $7 = $2; //@line 72759
 while (1) {
  $10 = _fgetc(HEAP32[$7 + 8 >> 2] | 0) | 0; //@line 72764
  if (($10 | 0) != -1) {
   label = 18460; //@line 72768
   break;
  }
  $15 = HEAP32[$1 >> 2] | 0; //@line 72771
  if (($15 | 0) == 0) {
   $_0 = 0; //@line 72775
   label = 18470; //@line 72776
   break;
  }
  $17 = $15 | 0; //@line 72779
  HEAP32[$1 >> 2] = HEAP32[$17 >> 2]; //@line 72781
  HEAP32[$17 >> 2] = 0; //@line 72782
  if ((HEAP32[$15 + 12 >> 2] | 0) != 0) {
   $24 = HEAP32[$15 + 8 >> 2] | 0; //@line 72789
   _fclose($24 | 0) | 0; //@line 72790
  }
  _free(HEAP32[$15 + 4 >> 2] | 0); //@line 72795
  _free($15); //@line 72797
  $29 = HEAP32[$1 >> 2] | 0; //@line 72798
  if (($29 | 0) == 0) {
   $_0 = 0; //@line 72802
   label = 18473; //@line 72803
   break;
  }
  HEAP32[$4 >> 2] = HEAP32[$29 + 16 >> 2]; //@line 72808
  HEAP32[$5 >> 2] = HEAP32[$29 + 20 >> 2]; //@line 72811
  $7 = $29; //@line 72812
 }
 if ((label | 0) == 18473) {
  return $_0 | 0; //@line 72817
 } else if ((label | 0) == 18470) {
  return $_0 | 0; //@line 72822
 } else if ((label | 0) == 18460) {
  $_0 = $10 & 255; //@line 72827
  return $_0 | 0; //@line 72830
 }
 return 0;
}
function _scn_rmv_chr($scn, $cnt) {
 $scn = $scn | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $2 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $i_034 = 0, $15 = 0, $31 = 0, $i_132 = 0, $38 = 0, $i_241 = 0, $44 = 0, $60 = 0, $_lcssa40 = 0, $64 = 0, $65 = 0, $66 = 0, $_036 = 0, $68 = 0;
 $1 = $scn | 0; //@line 72849
 $2 = HEAP32[$1 >> 2] | 0; //@line 72850
 if ($2 >>> 0 > $cnt >>> 0) {
  if (($cnt | 0) == 0) {
   $i_132 = 0; //@line 72857
  } else {
   $9 = $scn + 1032 | 0; //@line 72859
   $10 = $scn + 1028 | 0; //@line 72860
   $11 = $scn + 1036 | 0; //@line 72861
   $i_034 = 0; //@line 72863
   while (1) {
    $15 = HEAP32[$scn + 4 + ($i_034 << 2) >> 2] & 255; //@line 72868
    do {
     if ($15 << 24 >> 24 != 0) {
      HEAP32[$9 >> 2] = (HEAP32[$9 >> 2] | 0) + 1; //@line 72875
      if (($15 << 24 >> 24 | 0) == 10) {
       if ((HEAP32[$11 >> 2] | 0) == 0) {
        HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 1; //@line 72883
       }
       HEAP32[$11 >> 2] = 0; //@line 72886
       break;
      } else if (($15 << 24 >> 24 | 0) == 13) {
       HEAP32[$10 >> 2] = (HEAP32[$10 >> 2] | 0) + 1; //@line 72892
       HEAP32[$11 >> 2] = 1; //@line 72893
       break;
      } else {
       HEAP32[$11 >> 2] = 0; //@line 72897
       break;
      }
     }
    } while (0);
    $31 = $i_034 + 1 | 0; //@line 72902
    if ($31 >>> 0 < $cnt >>> 0) {
     $i_034 = $31; //@line 72906
    } else {
     $i_132 = $cnt; //@line 72908
     break;
    }
   }
  }
  do {
   HEAP32[$scn + 4 + ($i_132 - $cnt << 2) >> 2] = HEAP32[$scn + 4 + ($i_132 << 2) >> 2]; //@line 72919
   $i_132 = $i_132 + 1 | 0; //@line 72920
   $38 = HEAP32[$1 >> 2] | 0; //@line 72921
  } while ($i_132 >>> 0 < $38 >>> 0);
  HEAP32[$1 >> 2] = $38 - $cnt; //@line 72931
  return;
 }
 if (($2 | 0) == 0) {
  $_lcssa40 = 0; //@line 72939
 } else {
  $5 = $scn + 1032 | 0; //@line 72941
  $6 = $scn + 1028 | 0; //@line 72942
  $7 = $scn + 1036 | 0; //@line 72943
  $i_241 = 0; //@line 72945
  while (1) {
   $44 = HEAP32[$scn + 4 + ($i_241 << 2) >> 2] & 255; //@line 72950
   do {
    if ($44 << 24 >> 24 != 0) {
     HEAP32[$5 >> 2] = (HEAP32[$5 >> 2] | 0) + 1; //@line 72957
     if (($44 << 24 >> 24 | 0) == 13) {
      HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 1; //@line 72961
      HEAP32[$7 >> 2] = 1; //@line 72962
      break;
     } else if (($44 << 24 >> 24 | 0) == 10) {
      if ((HEAP32[$7 >> 2] | 0) == 0) {
       HEAP32[$6 >> 2] = (HEAP32[$6 >> 2] | 0) + 1; //@line 72972
      }
      HEAP32[$7 >> 2] = 0; //@line 72975
      break;
     } else {
      HEAP32[$7 >> 2] = 0; //@line 72979
      break;
     }
    }
   } while (0);
   $60 = $i_241 + 1 | 0; //@line 72984
   if ($60 >>> 0 < $2 >>> 0) {
    $i_241 = $60; //@line 72988
   } else {
    $_lcssa40 = $2; //@line 72990
    break;
   }
  }
 }
 HEAP32[$1 >> 2] = 0; //@line 72996
 if (($_lcssa40 | 0) == ($cnt | 0)) {
  return;
 }
 $64 = $scn + 1032 | 0; //@line 73004
 $65 = $scn + 1028 | 0; //@line 73005
 $66 = $scn + 1036 | 0; //@line 73006
 $_036 = $cnt - $_lcssa40 | 0; //@line 73008
 do {
  $68 = _scn_next_char($scn) | 0; //@line 73011
  do {
   if ($68 << 24 >> 24 != 0) {
    HEAP32[$64 >> 2] = (HEAP32[$64 >> 2] | 0) + 1; //@line 73018
    if (($68 << 24 >> 24 | 0) == 10) {
     if ((HEAP32[$66 >> 2] | 0) == 0) {
      HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 1; //@line 73026
     }
     HEAP32[$66 >> 2] = 0; //@line 73029
     break;
    } else if (($68 << 24 >> 24 | 0) == 13) {
     HEAP32[$65 >> 2] = (HEAP32[$65 >> 2] | 0) + 1; //@line 73035
     HEAP32[$66 >> 2] = 1; //@line 73036
     break;
    } else {
     HEAP32[$66 >> 2] = 0; //@line 73040
     break;
    }
   }
  } while (0);
  $_036 = $_036 - 1 | 0; //@line 73045
 } while (($_036 | 0) != 0);
 return;
}
function _scn_match_space($scn) {
 $scn = $scn | 0;
 var $1 = 0, $2 = 0, $3 = 0, $r_0_ph = 0, $4 = 0, $r_0 = 0, $7 = 0, $10 = 0, $15 = 0, $17 = 0, $19 = 0, $22 = 0, $25 = 0, $28 = 0, $33 = 0, $36 = 0, $43 = 0, $46 = 0, $51 = 0, $60 = 0, $63 = 0, $68 = 0, $level_0_i = 0, $buf_sroa_1_0_i = 0, $77 = 0, $80 = 0, $85 = 0, $88 = 0, $or_cond8_i = 0, label = 0;
 $1 = $scn | 0; //@line 73075
 $2 = $scn + 4 | 0; //@line 73076
 $3 = $scn + 8 | 0; //@line 73077
 $r_0_ph = 0; //@line 73079
 L23999 : while (1) {
  $r_0 = $r_0_ph;
  $4 = HEAP32[$1 >> 2] | 0;
  L24001 : while (1) {
   if (($4 | 0) == 0) {
    while (1) {
     $7 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73092
     HEAP32[$scn + 4 + (HEAP32[$1 >> 2] << 2) >> 2] = $7; //@line 73095
     $10 = HEAP32[$1 >> 2] | 0; //@line 73096
     if ((HEAP32[$scn + 4 + ($10 << 2) >> 2] | 0) == 0) {
      label = 18545; //@line 73102
      break L23999;
     }
     $15 = $10 + 1 | 0; //@line 73105
     HEAP32[$1 >> 2] = $15; //@line 73106
     if (($15 | 0) != 0) {
      $17 = $15; //@line 73110
      break;
     }
    }
   } else {
    $17 = $4; //@line 73115
   }
   $19 = HEAP32[$2 >> 2] & 255; //@line 73119
   if (($19 << 24 >> 24 | 0) == 32 | ($19 << 24 >> 24 | 0) == 9 | ($19 << 24 >> 24 | 0) == 13 | ($19 << 24 >> 24 | 0) == 10) {
    label = 18519; //@line 73121
    break;
   } else if (($19 << 24 >> 24 | 0) == 35) {
    $22 = $17; //@line 73124
    while (1) {
     if (($22 | 0) == 0) {
      while (1) {
       $25 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73132
       HEAP32[$scn + 4 + (HEAP32[$1 >> 2] << 2) >> 2] = $25; //@line 73135
       $28 = HEAP32[$1 >> 2] | 0; //@line 73136
       if ((HEAP32[$scn + 4 + ($28 << 2) >> 2] | 0) == 0) {
        $r_0 = 1;
        $4 = $28;
        continue L24001;
       }
       $33 = $28 + 1 | 0; //@line 73145
       HEAP32[$1 >> 2] = $33; //@line 73146
       if (($33 | 0) != 0) {
        break;
       }
      }
     }
     $36 = HEAP32[$2 >> 2] & 255; //@line 73155
     if ($36 << 24 >> 24 == 0) {
      $r_0_ph = 1; //@line 73159
      continue L23999;
     }
     _scn_rmv_chr($scn, 1); //@line 73162
     if (($36 << 24 >> 24 | 0) == 10) {
      $r_0_ph = 1; //@line 73164
      continue L23999;
     } else if (($36 << 24 >> 24 | 0) == 13) {
      break;
     }
     $22 = HEAP32[$1 >> 2] | 0; //@line 73171
    }
    if ((HEAP32[$1 >> 2] | 0) != 0) {
     break;
    }
    while (1) {
     $43 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73181
     HEAP32[$scn + 4 + (HEAP32[$1 >> 2] << 2) >> 2] = $43; //@line 73184
     $46 = HEAP32[$1 >> 2] | 0; //@line 73185
     if ((HEAP32[$scn + 4 + ($46 << 2) >> 2] | 0) == 0) {
      $r_0 = 1;
      $4 = $46;
      continue L24001;
     }
     $51 = $46 + 1 | 0; //@line 73194
     HEAP32[$1 >> 2] = $51; //@line 73195
     if (($51 | 0) != 0) {
      break L24001;
     }
    }
   } else if (($19 << 24 >> 24 | 0) != 47) {
    label = 18546; //@line 73203
    break L23999;
   }
   if ($17 >>> 0 <= 1) {
    do {
     $60 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73211
     HEAP32[$scn + 4 + (HEAP32[$1 >> 2] << 2) >> 2] = $60; //@line 73214
     $63 = HEAP32[$1 >> 2] | 0; //@line 73215
     if ((HEAP32[$scn + 4 + ($63 << 2) >> 2] | 0) == 0) {
      label = 18548; //@line 73221
      break L23999;
     }
     $68 = $63 + 1 | 0; //@line 73224
     HEAP32[$1 >> 2] = $68; //@line 73225
    } while ($68 >>> 0 <= 1);
   }
   if ((HEAP32[$3 >> 2] & 255) << 24 >> 24 != 42) {
    label = 18547; //@line 73238
    break L23999;
   }
   _scn_rmv_chr($scn, 2); //@line 73241
   $buf_sroa_1_0_i = 0;
   $level_0_i = 0;
   while (1) {
    if ((HEAP32[$1 >> 2] | 0) == 0) {
     while (1) {
      $77 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73253
      HEAP32[$scn + 4 + (HEAP32[$1 >> 2] << 2) >> 2] = $77; //@line 73256
      $80 = HEAP32[$1 >> 2] | 0; //@line 73257
      if ((HEAP32[$scn + 4 + ($80 << 2) >> 2] | 0) == 0) {
       $r_0 = 1;
       $4 = $80;
       continue L24001;
      }
      $85 = $80 + 1 | 0; //@line 73266
      HEAP32[$1 >> 2] = $85; //@line 73267
      if (($85 | 0) != 0) {
       break;
      }
     }
    }
    $88 = HEAP32[$2 >> 2] & 255; //@line 73276
    if ($88 << 24 >> 24 == 0) {
     $r_0_ph = 1; //@line 73280
     continue L23999;
    }
    _scn_rmv_chr($scn, 1); //@line 73283
    if (!($buf_sroa_1_0_i << 24 >> 24 == 42 & $88 << 24 >> 24 == 47)) {
     $or_cond8_i = $buf_sroa_1_0_i << 24 >> 24 == 47 & $88 << 24 >> 24 == 42; //@line 73291
     $buf_sroa_1_0_i = $or_cond8_i ? 0 : $88;
     $level_0_i = ($or_cond8_i & 1) + $level_0_i | 0;
     continue;
    }
    if (($level_0_i | 0) == 0) {
     $r_0_ph = 1; //@line 73302
     continue L23999;
    }
    $buf_sroa_1_0_i = 0;
    $level_0_i = $level_0_i - 1 | 0;
   }
  }
  if ((label | 0) == 18519) {
   label = 0; //@line 73311
   _scn_rmv_chr($scn, 1); //@line 73312
   $r_0_ph = 1; //@line 73314
   continue;
  }
  if ((HEAP32[$2 >> 2] & 255) << 24 >> 24 != 10) {
   $r_0_ph = 1; //@line 73322
   continue;
  }
  _scn_rmv_chr($scn, 1); //@line 73325
  $r_0_ph = 1; //@line 73327
 }
 if ((label | 0) == 18548) {
  return $r_0 | 0; //@line 73331
 } else if ((label | 0) == 18545) {
  return $r_0 | 0; //@line 73335
 } else if ((label | 0) == 18546) {
  return $r_0 | 0; //@line 73339
 } else if ((label | 0) == 18547) {
  return $r_0 | 0; //@line 73343
 }
 return 0;
}
function _scn_match_name($scn, $str, $max) {
 $scn = $scn | 0;
 $str = $str | 0;
 $max = $max | 0;
 var $2 = 0, $6 = 0, $9 = 0, $14 = 0, $_0_i = 0, $c_051 = 0, $i_050 = 0, $22 = 0, $23 = 0, $28 = 0, $31 = 0, $36 = 0, $_0_i37 = 0, $i_1 = 0, $_0 = 0, label = 0;
 _scn_match_space($scn) | 0; //@line 73363
 $2 = $scn | 0; //@line 73364
 L24051 : do {
  if ((HEAP32[$2 >> 2] | 0) == 0) {
   while (1) {
    $6 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73372
    HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $6; //@line 73375
    $9 = HEAP32[$2 >> 2] | 0; //@line 73376
    if ((HEAP32[$scn + 4 + ($9 << 2) >> 2] | 0) == 0) {
     $_0_i = 0; //@line 73382
     break L24051;
    }
    $14 = $9 + 1 | 0; //@line 73385
    HEAP32[$2 >> 2] = $14; //@line 73386
    if (($14 | 0) != 0) {
     label = 18552; //@line 73390
     break;
    }
   }
  } else {
   label = 18552; //@line 73395
  }
 } while (0);
 if ((label | 0) == 18552) {
  $_0_i = HEAP32[$scn + 4 >> 2] & 255; //@line 73403
 }
 do {
  if (!(($_0_i - 97 & 255) < 26 | ($_0_i - 65 & 255) < 26)) {
   if (($_0_i << 24 >> 24 | 0) == 95 | ($_0_i << 24 >> 24 | 0) == 36) {
    break;
   } else {
    $_0 = 0; //@line 73417
   }
   return $_0 | 0; //@line 73421
  }
 } while (0);
 L24062 : do {
  if (($max | 0) == 0) {
   $i_1 = 0; //@line 73428
  } else {
   $i_050 = 0;
   $c_051 = $_0_i;
   L24063 : while (1) {
    $22 = $i_050 + 1 | 0; //@line 73434
    $23 = $str + $i_050 | 0; //@line 73435
    HEAP8[$23] = $c_051; //@line 73436
    L24065 : do {
     if ($22 >>> 0 > 255) {
      $_0_i37 = 0; //@line 73441
     } else {
      if ((HEAP32[$2 >> 2] | 0) >>> 0 <= $22 >>> 0) {
       do {
        $28 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73449
        HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $28; //@line 73452
        $31 = HEAP32[$2 >> 2] | 0; //@line 73453
        if ((HEAP32[$scn + 4 + ($31 << 2) >> 2] | 0) == 0) {
         $_0_i37 = 0; //@line 73459
         break L24065;
        }
        $36 = $31 + 1 | 0; //@line 73462
        HEAP32[$2 >> 2] = $36; //@line 73463
       } while ($36 >>> 0 <= $22 >>> 0);
      }
      $_0_i37 = HEAP32[$scn + 4 + ($22 << 2) >> 2] & 255; //@line 73475
     }
    } while (0);
    do {
     if (!(($_0_i37 - 97 & 255) < 26 | ($_0_i37 - 65 & 255) < 26 | $_0_i37 << 24 >> 24 == 95 | ($_0_i37 - 48 & 255) < 10)) {
      if (($_0_i37 << 24 >> 24 | 0) == 93 | ($_0_i37 << 24 >> 24 | 0) == 91 | ($_0_i37 << 24 >> 24 | 0) == 46) {
       break;
      } else if (($_0_i37 << 24 >> 24 | 0) == 45) {
       if ((HEAP8[$23] | 0) == 91 & $22 >>> 0 < $max >>> 0) {
        $i_050 = $22;
        $c_051 = $_0_i37;
        continue L24063;
       } else {
        $i_1 = $22; //@line 73504
        break L24062;
       }
      } else if (($_0_i37 << 24 >> 24 | 0) == 43) {
       if ((HEAP8[$23] | 0) == 91 & $22 >>> 0 < $max >>> 0) {
        $i_050 = $22;
        $c_051 = $_0_i37;
        continue L24063;
       } else {
        $i_1 = $22; //@line 73517
        break L24062;
       }
      } else {
       $i_1 = $22; //@line 73521
       break L24062;
      }
     }
    } while (0);
    if ($22 >>> 0 < $max >>> 0) {
     $i_050 = $22;
     $c_051 = $_0_i37;
    } else {
     $i_1 = $22; //@line 73531
     break;
    }
   }
  }
 } while (0);
 if ($i_1 >>> 0 >= $max >>> 0) {
  $_0 = 0; //@line 73541
  return $_0 | 0; //@line 73544
 }
 HEAP8[$str + $i_1 | 0] = 0; //@line 73547
 _scn_rmv_chr($scn, $i_1); //@line 73548
 $_0 = 1; //@line 73550
 return $_0 | 0; //@line 73553
}
function _scn_match_string($scn, $str, $max) {
 $scn = $scn | 0;
 $str = $str | 0;
 $max = $max | 0;
 var $2 = 0, $6 = 0, $9 = 0, $14 = 0, $j_057 = 0, $i_056 = 0, $22 = 0, $25 = 0, $28 = 0, $33 = 0, $35 = 0, $38 = 0, $40 = 0, $44 = 0, $47 = 0, $52 = 0, $54 = 0, $phitmp = 0, $66 = 0, $70 = 0, $73 = 0, $78 = 0, $80 = 0, $83 = 0, $_off_i = 0, $d_0_i = 0, $94 = 0, $98 = 0, $101 = 0, $106 = 0, $110 = 0, $_off_1_i = 0, $d_0_1_i = 0, $_0_i37 = 0, $i_1 = 0, $123 = 0, $_0 = 0, label = 0;
 _scn_match_space($scn) | 0; //@line 73578
 $2 = $scn | 0; //@line 73579
 L24085 : do {
  if ((HEAP32[$2 >> 2] | 0) == 0) {
   while (1) {
    $6 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73587
    HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $6; //@line 73590
    $9 = HEAP32[$2 >> 2] | 0; //@line 73591
    if ((HEAP32[$scn + 4 + ($9 << 2) >> 2] | 0) == 0) {
     $_0 = 0; //@line 73597
     break;
    }
    $14 = $9 + 1 | 0; //@line 73600
    HEAP32[$2 >> 2] = $14; //@line 73601
    if (($14 | 0) != 0) {
     break L24085;
    }
   }
   return $_0 | 0; //@line 73610
  }
 } while (0);
 if ((HEAP32[$scn + 4 >> 2] & 255) << 24 >> 24 != 34 | ($max | 0) == 0) {
  $_0 = 0; //@line 73621
  return $_0 | 0; //@line 73624
 } else {
  $i_056 = 1;
  $j_057 = 0;
 }
 L24093 : while (1) {
  if ($i_056 >>> 0 > 255) {
   $_0 = 1; //@line 73634
   label = 18616; //@line 73635
   break;
  }
  $22 = HEAP32[$2 >> 2] | 0; //@line 73638
  if ($22 >>> 0 > $i_056 >>> 0) {
   $35 = $22; //@line 73642
  } else {
   while (1) {
    $25 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73646
    HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $25; //@line 73649
    $28 = HEAP32[$2 >> 2] | 0; //@line 73650
    if ((HEAP32[$scn + 4 + ($28 << 2) >> 2] | 0) == 0) {
     $_0 = 1; //@line 73656
     label = 18620; //@line 73657
     break L24093;
    }
    $33 = $28 + 1 | 0; //@line 73660
    HEAP32[$2 >> 2] = $33; //@line 73661
    if ($33 >>> 0 > $i_056 >>> 0) {
     $35 = $33; //@line 73665
     break;
    }
   }
  }
  $38 = HEAP32[$scn + 4 + ($i_056 << 2) >> 2] & 255; //@line 73673
  L24101 : do {
   if (($38 << 24 >> 24 | 0) == 0) {
    $_0 = 1; //@line 73676
    label = 18626; //@line 73677
    break L24093;
   } else if (($38 << 24 >> 24 | 0) == 34) {
    label = 18614; //@line 73680
    break L24093;
   } else if (($38 << 24 >> 24 | 0) == 92) {
    $40 = $i_056 + 1 | 0; //@line 73683
    if ($40 >>> 0 > 255) {
     $i_1 = $i_056;
     $_0_i37 = 92;
     break;
    }
    if ($35 >>> 0 > $40 >>> 0) {
     $54 = $35; //@line 73693
    } else {
     while (1) {
      $44 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73697
      HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $44; //@line 73700
      $47 = HEAP32[$2 >> 2] | 0; //@line 73701
      if ((HEAP32[$scn + 4 + ($47 << 2) >> 2] | 0) == 0) {
       $i_1 = $i_056;
       $_0_i37 = 92;
       break L24101;
      }
      $52 = $47 + 1 | 0; //@line 73710
      HEAP32[$2 >> 2] = $52; //@line 73711
      if ($52 >>> 0 > $40 >>> 0) {
       $54 = $52; //@line 73715
       break;
      }
     }
    }
    $phitmp = HEAP32[$scn + 4 + ($40 << 2) >> 2] << 24 >> 24; //@line 73724
    if (($phitmp | 0) == 120) {
     $66 = $i_056 + 2 | 0; //@line 73726
     if ($66 >>> 0 > 255) {
      $_0 = 0; //@line 73730
      label = 18618; //@line 73731
      break L24093;
     }
     if ($54 >>> 0 > $66 >>> 0) {
      $80 = $54; //@line 73737
     } else {
      while (1) {
       $70 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73741
       HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $70; //@line 73744
       $73 = HEAP32[$2 >> 2] | 0; //@line 73745
       if ((HEAP32[$scn + 4 + ($73 << 2) >> 2] | 0) == 0) {
        $_0 = 0; //@line 73751
        label = 18622; //@line 73752
        break L24093;
       }
       $78 = $73 + 1 | 0; //@line 73755
       HEAP32[$2 >> 2] = $78; //@line 73756
       if ($78 >>> 0 > $66 >>> 0) {
        $80 = $78; //@line 73760
        break;
       }
      }
     }
     $83 = HEAP32[$scn + 4 + ($66 << 2) >> 2] & 255; //@line 73768
     $_off_i = $83 - 48 & 255; //@line 73769
     do {
      if (($_off_i & 255) < 10) {
       $d_0_i = $_off_i; //@line 73774
      } else {
       if (($83 - 97 & 255) < 6) {
        $d_0_i = $83 - 87 & 255; //@line 73782
        break;
       }
       if (($83 - 65 & 255) >= 6) {
        $_0 = 0; //@line 73789
        label = 18623; //@line 73790
        break L24093;
       }
       $d_0_i = $83 - 55 & 255; //@line 73794
      }
     } while (0);
     $94 = $i_056 + 3 | 0; //@line 73798
     if ($94 >>> 0 > 255) {
      $_0 = 0; //@line 73802
      label = 18617; //@line 73803
      break L24093;
     }
     if ($80 >>> 0 <= $94 >>> 0) {
      do {
       $98 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 73811
       HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $98; //@line 73814
       $101 = HEAP32[$2 >> 2] | 0; //@line 73815
       if ((HEAP32[$scn + 4 + ($101 << 2) >> 2] | 0) == 0) {
        $_0 = 0; //@line 73821
        label = 18625; //@line 73822
        break L24093;
       }
       $106 = $101 + 1 | 0; //@line 73825
       HEAP32[$2 >> 2] = $106; //@line 73826
      } while ($106 >>> 0 <= $94 >>> 0);
     }
     $110 = HEAP32[$scn + 4 + ($94 << 2) >> 2] & 255; //@line 73836
     $_off_1_i = $110 - 48 & 255; //@line 73837
     do {
      if (($_off_1_i & 255) < 10) {
       $d_0_1_i = $_off_1_i; //@line 73842
      } else {
       if (($110 - 97 & 255) < 6) {
        $d_0_1_i = $110 - 87 & 255; //@line 73850
        break;
       }
       if (($110 - 65 & 255) >= 6) {
        $_0 = 0; //@line 73857
        label = 18624; //@line 73858
        break L24093;
       }
       $d_0_1_i = $110 - 55 & 255; //@line 73862
      }
     } while (0);
     $i_1 = $94;
     $_0_i37 = $d_0_1_i + ($d_0_i << 4) & 255;
     break;
    } else if (($phitmp | 0) == 92) {
     $i_1 = $40;
     $_0_i37 = 92;
     break;
    } else if (($phitmp | 0) == 98) {
     $i_1 = $40;
     $_0_i37 = 8;
     break;
    } else if (($phitmp | 0) == 102) {
     $i_1 = $40;
     $_0_i37 = 12;
     break;
    } else if (($phitmp | 0) == 110) {
     $i_1 = $40;
     $_0_i37 = 10;
     break;
    } else if (($phitmp | 0) == 34) {
     $i_1 = $40;
     $_0_i37 = 34;
     break;
    } else if (($phitmp | 0) == 118) {
     $i_1 = $40;
     $_0_i37 = 11;
     break;
    } else if (($phitmp | 0) == 114) {
     $i_1 = $40;
     $_0_i37 = 13;
     break;
    } else if (($phitmp | 0) == 97) {
     $i_1 = $40;
     $_0_i37 = 7;
     break;
    } else {
     $i_1 = $i_056;
     $_0_i37 = 92;
     break;
    }
   } else {
    $i_1 = $i_056;
    $_0_i37 = $38;
   }
  } while (0);
  $123 = $j_057 + 1 | 0; //@line 73913
  HEAP8[$str + $j_057 | 0] = $_0_i37; //@line 73915
  if ($123 >>> 0 < $max >>> 0) {
   $i_056 = $i_1 + 1 | 0;
   $j_057 = $123;
  } else {
   $_0 = 0; //@line 73922
   label = 18627; //@line 73923
   break;
  }
 }
 if ((label | 0) == 18625) {
  return $_0 | 0; //@line 73930
 } else if ((label | 0) == 18626) {
  return $_0 | 0; //@line 73935
 } else if ((label | 0) == 18627) {
  return $_0 | 0; //@line 73940
 } else if ((label | 0) == 18618) {
  return $_0 | 0; //@line 73945
 } else if ((label | 0) == 18620) {
  return $_0 | 0; //@line 73950
 } else if ((label | 0) == 18622) {
  return $_0 | 0; //@line 73955
 } else if ((label | 0) == 18623) {
  return $_0 | 0; //@line 73960
 } else if ((label | 0) == 18624) {
  return $_0 | 0; //@line 73965
 } else if ((label | 0) == 18616) {
  return $_0 | 0; //@line 73970
 } else if ((label | 0) == 18617) {
  return $_0 | 0; //@line 73975
 } else if ((label | 0) == 18614) {
  HEAP8[$str + $j_057 | 0] = 0; //@line 73979
  _scn_rmv_chr($scn, $i_056 + 1 | 0); //@line 73981
  $_0 = 1; //@line 73983
  return $_0 | 0; //@line 73986
 }
 return 0;
}
function _scn_peek($scn, $str) {
 $scn = $scn | 0;
 $str = $str | 0;
 var $2 = 0, $cnt_0 = 0, $4 = 0, $12 = 0, $15 = 0, $20 = 0, $_0_i = 0, $_0 = 0, label = 0;
 _scn_match_space($scn) | 0; //@line 74000
 $2 = $scn | 0; //@line 74001
 $cnt_0 = 0; //@line 74003
 while (1) {
  $4 = $str + $cnt_0 | 0; //@line 74006
  if ((HEAP8[$4] | 0) == 0) {
   $_0 = 1; //@line 74011
   label = 18639; //@line 74012
   break;
  }
  L24163 : do {
   if ($cnt_0 >>> 0 > 255) {
    $_0_i = 0; //@line 74019
   } else {
    if ((HEAP32[$2 >> 2] | 0) >>> 0 <= $cnt_0 >>> 0) {
     do {
      $12 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 74027
      HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $12; //@line 74030
      $15 = HEAP32[$2 >> 2] | 0; //@line 74031
      if ((HEAP32[$scn + 4 + ($15 << 2) >> 2] | 0) == 0) {
       $_0_i = 0; //@line 74037
       break L24163;
      }
      $20 = $15 + 1 | 0; //@line 74040
      HEAP32[$2 >> 2] = $20; //@line 74041
     } while ($20 >>> 0 <= $cnt_0 >>> 0);
    }
    $_0_i = HEAP32[$scn + 4 + ($cnt_0 << 2) >> 2] & 255; //@line 74053
   }
  } while (0);
  if ($_0_i << 24 >> 24 == (HEAP8[$4] | 0)) {
   $cnt_0 = $cnt_0 + 1 | 0; //@line 74062
  } else {
   $_0 = 0; //@line 74064
   label = 18638; //@line 74065
   break;
  }
 }
 if ((label | 0) == 18638) {
  return $_0 | 0; //@line 74072
 } else if ((label | 0) == 18639) {
  return $_0 | 0; //@line 74077
 }
 return 0;
}
function _scn_match_ident($scn, $str) {
 $scn = $scn | 0;
 $str = $str | 0;
 var $2 = 0, $cnt_0 = 0, $4 = 0, $6 = 0, $11 = 0, $14 = 0, $19 = 0, $_0_i = 0, $_0 = 0, label = 0;
 _scn_match_space($scn) | 0; //@line 74092
 $2 = $scn | 0; //@line 74093
 $cnt_0 = 0; //@line 74095
 while (1) {
  $4 = $str + $cnt_0 | 0; //@line 74098
  $6 = (HEAP8[$4] | 0) == 0; //@line 74100
  L24177 : do {
   if ($cnt_0 >>> 0 > 255) {
    $_0_i = 0; //@line 74105
   } else {
    if ((HEAP32[$2 >> 2] | 0) >>> 0 <= $cnt_0 >>> 0) {
     do {
      $11 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 74113
      HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $11; //@line 74116
      $14 = HEAP32[$2 >> 2] | 0; //@line 74117
      if ((HEAP32[$scn + 4 + ($14 << 2) >> 2] | 0) == 0) {
       $_0_i = 0; //@line 74123
       break L24177;
      }
      $19 = $14 + 1 | 0; //@line 74126
      HEAP32[$2 >> 2] = $19; //@line 74127
     } while ($19 >>> 0 <= $cnt_0 >>> 0);
    }
    $_0_i = HEAP32[$scn + 4 + ($cnt_0 << 2) >> 2] & 255; //@line 74139
   }
  } while (0);
  if ($6) {
   break;
  }
  if ($_0_i << 24 >> 24 == (HEAP8[$4] | 0)) {
   $cnt_0 = $cnt_0 + 1 | 0; //@line 74152
  } else {
   $_0 = 0; //@line 74154
   label = 18653; //@line 74155
   break;
  }
 }
 if ((label | 0) == 18653) {
  return $_0 | 0; //@line 74162
 }
 if (($_0_i - 97 & 255) < 26 | ($_0_i - 65 & 255) < 26 | $_0_i << 24 >> 24 == 95 | ($_0_i - 48 & 255) < 10) {
  $_0 = 0; //@line 74176
  return $_0 | 0; //@line 74179
 }
 _scn_rmv_chr($scn, $cnt_0); //@line 74181
 $_0 = 1; //@line 74183
 return $_0 | 0; //@line 74186
}
function _scn_match($scn, $str) {
 $scn = $scn | 0;
 $str = $str | 0;
 var $2 = 0, $cnt_0 = 0, $4 = 0, $12 = 0, $15 = 0, $20 = 0, $_0_i = 0, $_0 = 0, label = 0;
 _scn_match_space($scn) | 0; //@line 74199
 $2 = $scn | 0; //@line 74200
 $cnt_0 = 0; //@line 74202
 while (1) {
  $4 = $str + $cnt_0 | 0; //@line 74205
  if ((HEAP8[$4] | 0) == 0) {
   break;
  }
  L24197 : do {
   if ($cnt_0 >>> 0 > 255) {
    $_0_i = 0; //@line 74216
   } else {
    if ((HEAP32[$2 >> 2] | 0) >>> 0 <= $cnt_0 >>> 0) {
     do {
      $12 = (_scn_next_char($scn) | 0) << 24 >> 24; //@line 74224
      HEAP32[$scn + 4 + (HEAP32[$2 >> 2] << 2) >> 2] = $12; //@line 74227
      $15 = HEAP32[$2 >> 2] | 0; //@line 74228
      if ((HEAP32[$scn + 4 + ($15 << 2) >> 2] | 0) == 0) {
       $_0_i = 0; //@line 74234
       break L24197;
      }
      $20 = $15 + 1 | 0; //@line 74237
      HEAP32[$2 >> 2] = $20; //@line 74238
     } while ($20 >>> 0 <= $cnt_0 >>> 0);
    }
    $_0_i = HEAP32[$scn + 4 + ($cnt_0 << 2) >> 2] & 255; //@line 74250
   }
  } while (0);
  if ($_0_i << 24 >> 24 == (HEAP8[$4] | 0)) {
   $cnt_0 = $cnt_0 + 1 | 0; //@line 74259
  } else {
   $_0 = 0; //@line 74261
   label = 18665; //@line 74262
   break;
  }
 }
 if ((label | 0) == 18665) {
  return $_0 | 0; //@line 74269
 }
 _scn_rmv_chr($scn, $cnt_0); //@line 74271
 $_0 = 1; //@line 74273
 return $_0 | 0; //@line 74276
}
function _ini_sct_new($name) {
 $name = $name | 0;
 var $1 = 0, $_0 = 0;
 $1 = _malloc(28) | 0; //@line 74286
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 74290
  return $_0 | 0; //@line 74293
 }
 HEAP32[$1 >> 2] = 0; //@line 74297
 HEAP32[$1 + 4 >> 2] = 0; //@line 74300
 HEAP32[$1 + 8 >> 2] = _strdup((($name | 0) == 0 ? 62864 : $name) | 0) | 0; //@line 74306
 _memset($1 + 12 | 0, 0, 16); //@line 74308
 $_0 = $1; //@line 74310
 return $_0 | 0; //@line 74313
}
function _ini_sct_del($sct) {
 $sct = $sct | 0;
 var $_06 = 0, $3 = 0;
 if (($sct | 0) == 0) {
  return;
 } else {
  $_06 = $sct; //@line 74329
 }
 while (1) {
  $3 = HEAP32[$_06 >> 2] | 0; //@line 74334
  _ini_val_del(HEAP32[$_06 + 20 >> 2] | 0); //@line 74337
  _ini_sct_del(HEAP32[$_06 + 12 >> 2] | 0); //@line 74340
  _free(HEAP32[$_06 + 8 >> 2] | 0); //@line 74343
  _free($_06); //@line 74345
  if (($3 | 0) == 0) {
   break;
  } else {
   $_06 = $3; //@line 74351
  }
 }
 return;
}
function _ini_next_sct($sct, $val, $name) {
 $sct = $sct | 0;
 $val = $val | 0;
 $name = $name | 0;
 var $_012_in = 0, $_012 = 0, $_113 = 0, $18 = 0, $_0 = 0, label = 0;
 do {
  if (($val | 0) == 0) {
   if (($sct | 0) == 0) {
    $_0 = 0; //@line 74375
    return $_0 | 0; //@line 74378
   } else {
    $_012_in = $sct + 12 | 0; //@line 74382
    break;
   }
  } else {
   $_012_in = $val | 0; //@line 74387
  }
 } while (0);
 $_012 = HEAP32[$_012_in >> 2] | 0; //@line 74391
 if (($_012 | 0) == 0) {
  $_0 = 0; //@line 74395
  return $_0 | 0; //@line 74398
 }
 if (($name | 0) == 0) {
  $_0 = $_012; //@line 74403
  return $_0 | 0; //@line 74406
 } else {
  $_113 = $_012; //@line 74408
 }
 while (1) {
  if ((_strcmp(HEAP32[$_113 + 8 >> 2] | 0, $name | 0) | 0) == 0) {
   $_0 = $_113; //@line 74418
   label = 18685; //@line 74419
   break;
  }
  $18 = HEAP32[$_113 >> 2] | 0; //@line 74423
  if (($18 | 0) == 0) {
   $_0 = 0; //@line 74427
   label = 18686; //@line 74428
   break;
  } else {
   $_113 = $18; //@line 74431
  }
 }
 if ((label | 0) == 18685) {
  return $_0 | 0; //@line 74437
 } else if ((label | 0) == 18686) {
  return $_0 | 0; //@line 74442
 }
 return 0;
}
function _ini_next_val($sct, $val, $name) {
 $sct = $sct | 0;
 $val = $val | 0;
 $name = $name | 0;
 var $_011_in = 0, $_011 = 0, $_112 = 0, $17 = 0, $_0 = 0, label = 0;
 do {
  if (($val | 0) == 0) {
   if (($sct | 0) == 0) {
    $_0 = 0; //@line 74463
    return $_0 | 0; //@line 74466
   } else {
    $_011_in = $sct + 20 | 0; //@line 74470
    break;
   }
  } else {
   $_011_in = $val | 0; //@line 74475
  }
 } while (0);
 $_011 = HEAP32[$_011_in >> 2] | 0; //@line 74479
 if (($_011 | 0) == 0 | ($name | 0) == 0) {
  $_0 = 0; //@line 74485
  return $_0 | 0; //@line 74488
 } else {
  $_112 = $_011; //@line 74490
 }
 while (1) {
  if ((_strcmp(HEAP32[$_112 + 4 >> 2] | 0, $name | 0) | 0) == 0) {
   $_0 = $_112; //@line 74500
   label = 18700; //@line 74501
   break;
  }
  $17 = HEAP32[$_112 >> 2] | 0; //@line 74505
  if (($17 | 0) == 0) {
   $_0 = 0; //@line 74509
   label = 18701; //@line 74510
   break;
  } else {
   $_112 = $17; //@line 74513
  }
 }
 if ((label | 0) == 18701) {
  return $_0 | 0; //@line 74519
 } else if ((label | 0) == 18700) {
  return $_0 | 0; //@line 74524
 }
 return 0;
}
function _ini_get_name_and_index($str, $name, $idx, $noidx, $addnew, $last) {
 $str = $str | 0;
 $name = $name | 0;
 $idx = $idx | 0;
 $noidx = $noidx | 0;
 $addnew = $addnew | 0;
 $last = $last | 0;
 var $1 = 0, $2 = 0, $s_015 = 0, $7 = 0, $9 = 0, $s_018 = 0, $_pn17 = 0, $i_016 = 0, $15 = 0, $s_0 = 0, $17 = 0, $s_0_lcssa = 0, $_pn_lcssa = 0, $i_0_lcssa = 0, $i_0_lcssa30 = 0, $_pn_lcssa29 = 0, $s_0_lcssa28 = 0, $22 = 0, $27 = 0, $28 = 0, $36 = 0, $37 = 0, $s_114 = 0, $41 = 0, $42 = 0, $43 = 0, $s_2 = 0, $48 = 0, $_0 = 0;
 $1 = HEAP32[$str >> 2] | 0; //@line 74547
 HEAP32[$idx >> 2] = 0; //@line 74548
 HEAP32[$noidx >> 2] = 1; //@line 74549
 HEAP32[$addnew >> 2] = 0; //@line 74550
 HEAP32[$last >> 2] = 0; //@line 74551
 $2 = HEAP8[$1] | 0; //@line 74552
 do {
  if (($2 - 97 & 255) >= 26) {
   if (($2 - 65 & 255) < 26 | $2 << 24 >> 24 == 95) {
    break;
   } else {
    $_0 = 1; //@line 74566
   }
   return $_0 | 0; //@line 74570
  }
 } while (0);
 HEAP8[$name] = $2; //@line 74573
 $s_015 = $1 + 1 | 0; //@line 74574
 $7 = HEAP8[$s_015] | 0; //@line 74575
 do {
  if ($7 << 24 >> 24 == 0) {
   $s_0_lcssa28 = $s_015;
   $_pn_lcssa29 = $1;
   $i_0_lcssa30 = 1;
  } else {
   $i_016 = 1;
   $_pn17 = $1;
   $s_018 = $s_015;
   $9 = $7;
   while (1) {
    if (($9 - 97 & 255) >= 26) {
     if (!(($9 - 65 & 255) < 26 | $9 << 24 >> 24 == 95 | ($9 - 48 & 255) < 10)) {
      $i_0_lcssa = $i_016;
      $_pn_lcssa = $_pn17;
      $s_0_lcssa = $s_018;
      break;
     }
    }
    $15 = $i_016 + 1 | 0; //@line 74605
    HEAP8[$name + $i_016 | 0] = $9; //@line 74607
    $s_0 = $s_018 + 1 | 0; //@line 74608
    $17 = HEAP8[$s_0] | 0; //@line 74609
    if ($17 << 24 >> 24 != 0 & $15 >>> 0 < 256) {
     $i_016 = $15;
     $_pn17 = $s_018;
     $s_018 = $s_0;
     $9 = $17;
    } else {
     $i_0_lcssa = $15;
     $_pn_lcssa = $s_018;
     $s_0_lcssa = $s_0;
     break;
    }
   }
   if ($i_0_lcssa >>> 0 > 255) {
    $_0 = 1; //@line 74627
   } else {
    $s_0_lcssa28 = $s_0_lcssa;
    $_pn_lcssa29 = $_pn_lcssa;
    $i_0_lcssa30 = $i_0_lcssa;
    break;
   }
   return $_0 | 0; //@line 74634
  }
 } while (0);
 HEAP8[$name + $i_0_lcssa30 | 0] = 0; //@line 74641
 $22 = HEAP8[$s_0_lcssa28] | 0; //@line 74642
 if (($22 << 24 >> 24 | 0) == 91) {
  $27 = $_pn_lcssa29 + 2 | 0; //@line 74644
  $28 = HEAP8[$27] | 0; //@line 74645
  if (($28 << 24 >> 24 | 0) == 43) {
   HEAP32[$addnew >> 2] = 1; //@line 74647
   $s_2 = $_pn_lcssa29 + 3 | 0; //@line 74650
  } else if (($28 << 24 >> 24 | 0) == 45) {
   HEAP32[$last >> 2] = 1; //@line 74652
   $s_2 = $_pn_lcssa29 + 3 | 0; //@line 74655
  } else {
   if (($28 - 48 & 255) >= 10) {
    $_0 = 1; //@line 74661
    return $_0 | 0; //@line 74664
   }
   $s_114 = $27;
   $37 = $28;
   $36 = HEAP32[$idx >> 2] | 0;
   while (1) {
    $41 = ($37 << 24 >> 24) - 48 + ($36 * 10 | 0) | 0; //@line 74676
    HEAP32[$idx >> 2] = $41; //@line 74677
    $42 = $s_114 + 1 | 0; //@line 74678
    $43 = HEAP8[$42] | 0; //@line 74679
    if (($43 - 48 & 255) < 10) {
     $s_114 = $42;
     $37 = $43;
     $36 = $41;
    } else {
     $s_2 = $42; //@line 74686
     break;
    }
   }
  }
  if ((HEAP8[$s_2] | 0) != 93) {
   $_0 = 1; //@line 74696
   return $_0 | 0; //@line 74699
  }
  $48 = $s_2 + 1 | 0; //@line 74701
  HEAP32[$str >> 2] = (HEAP8[$48] | 0) == 46 ? $s_2 + 2 | 0 : $48; //@line 74706
  HEAP32[$noidx >> 2] = 0; //@line 74707
  $_0 = 0; //@line 74709
  return $_0 | 0; //@line 74712
 } else if (($22 << 24 >> 24 | 0) == 0) {
  HEAP32[$str >> 2] = $s_0_lcssa28; //@line 74714
  $_0 = 0; //@line 74716
  return $_0 | 0; //@line 74719
 } else if (($22 << 24 >> 24 | 0) == 46) {
  HEAP32[$str >> 2] = $_pn_lcssa29 + 2; //@line 74722
  $_0 = 0; //@line 74724
  return $_0 | 0; //@line 74727
 } else {
  $_0 = 1; //@line 74729
  return $_0 | 0; //@line 74732
 }
 return 0;
}
function _ini_get_sct($sct, $name, $add) {
 $sct = $sct | 0;
 $name = $name | 0;
 $add = $add | 0;
 var $1 = 0, $noidx = 0, $addnew = 0, $last = 0, $index = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $_09 = 0, $simple_0 = 0, $simple_0_ = 0, $25 = 0, $27 = 0, $30 = 0, $37 = 0, $42 = 0, $_pre_phi_i = 0, $50 = 0, $sub_010_i = 0, $sub_012_i = 0, $ret_011_i = 0, $sub_0_ret_0_i = 0, $sub_0_i = 0, $ret_0_lcssa_i = 0, $60 = 0, $62 = 0, $65 = 0, $76 = 0, $_pre_phi_i_i = 0, $81 = 0, $82 = 0, $sub_017_i = 0, $sub_019_i = 0, $_01318_i = 0, $_1_i = 0, $sub_0_i12 = 0, $_013_lcssa_i = 0, $_pre_i16 = 0, $_2_i_us = 0, $97 = 0, $_0_i18_us = 0, $_2_i = 0, $110 = 0, $111 = 0, $114 = 0, $117 = 0, $_0_i18 = 0, $_1 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 74760
 STACKTOP = STACKTOP + 296 | 0; //@line 74760
 $1 = sp | 0; //@line 74761
 $noidx = sp + 8 | 0; //@line 74762
 $addnew = sp + 16 | 0; //@line 74763
 $last = sp + 24 | 0; //@line 74764
 $index = sp + 32 | 0; //@line 74765
 HEAP32[$1 >> 2] = $name; //@line 74767
 if (($sct | 0) == 0) {
  $_0 = 0; //@line 74771
  STACKTOP = sp; //@line 74773
  return $_0 | 0; //@line 74774
 }
 $3 = sp + 40 | 0; //@line 74776
 $4 = ($add | 0) == 0; //@line 74777
 $5 = ($add | 0) != 0; //@line 74778
 $simple_0 = 1;
 $_09 = $sct;
 $7 = $name;
 L24294 : while (1) {
  if ((HEAP8[$7] | 0) == 0) {
   $_0 = $_09; //@line 74789
   label = 18773; //@line 74790
   break;
  }
  if ((_ini_get_name_and_index($1, $3, $index, $noidx, $addnew, $last) | 0) != 0) {
   $_0 = 0; //@line 74797
   label = 18776; //@line 74798
   break;
  }
  $simple_0_ = (HEAP8[HEAP32[$1 >> 2] | 0] | 0) == 0 ? $simple_0 : 0; //@line 74804
  L24298 : do {
   if ((HEAP32[$addnew >> 2] | 0) == 0) {
    if (!(($simple_0_ | 0) == 0 | $4)) {
     if ((HEAP32[$noidx >> 2] | 0) != 0) {
      label = 18736; //@line 74818
      break;
     }
    }
    if ((HEAP32[$last >> 2] | 0) != 0) {
     $50 = $_09 + 12 | 0; //@line 74826
     $sub_010_i = HEAP32[$50 >> 2] | 0; //@line 74827
     if (($sub_010_i | 0) == 0) {
      $ret_0_lcssa_i = 0; //@line 74831
     } else {
      $ret_011_i = 0;
      $sub_012_i = $sub_010_i;
      while (1) {
       $sub_0_ret_0_i = (_strcmp(HEAP32[$sub_012_i + 8 >> 2] | 0, $3 | 0) | 0) == 0 ? $sub_012_i : $ret_011_i; //@line 74841
       $sub_0_i = HEAP32[$sub_012_i >> 2] | 0; //@line 74843
       if (($sub_0_i | 0) == 0) {
        $ret_0_lcssa_i = $sub_0_ret_0_i; //@line 74847
        break;
       } else {
        $ret_011_i = $sub_0_ret_0_i;
        $sub_012_i = $sub_0_i;
       }
      }
     }
     if (!($5 & ($ret_0_lcssa_i | 0) == 0)) {
      $_1 = $ret_0_lcssa_i; //@line 74859
      break;
     }
     $60 = _malloc(28) | 0; //@line 74862
     if (($60 | 0) == 0) {
      $_0 = 0; //@line 74866
      label = 18781; //@line 74867
      break L24294;
     }
     $62 = $60; //@line 74870
     HEAP32[$60 >> 2] = 0; //@line 74872
     $65 = $60 + 4 | 0; //@line 74874
     HEAP32[$65 >> 2] = 0; //@line 74875
     HEAP32[$60 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 74879
     _memset($60 + 12 | 0, 0, 16); //@line 74881
     if (($_09 | 0) == 0) {
      $_1 = $62; //@line 74885
      break;
     }
     HEAP32[$65 >> 2] = $_09; //@line 74888
     if ((HEAP32[$50 >> 2] | 0) == 0) {
      HEAP32[$50 >> 2] = $62; //@line 74893
      $_pre_phi_i_i = $_09 + 16 | 0; //@line 74896
     } else {
      $76 = $_09 + 16 | 0; //@line 74898
      HEAP32[HEAP32[$76 >> 2] >> 2] = $62; //@line 74901
      $_pre_phi_i_i = $76; //@line 74902
     }
     HEAP32[$_pre_phi_i_i >> 2] = $62; //@line 74905
     $_1 = $62; //@line 74907
     break;
    }
    $81 = HEAP32[$index >> 2] | 0; //@line 74910
    $82 = $_09 + 12 | 0; //@line 74911
    $sub_017_i = HEAP32[$82 >> 2] | 0; //@line 74912
    if (($sub_017_i | 0) == 0) {
     $_013_lcssa_i = $81; //@line 74916
    } else {
     $_01318_i = $81;
     $sub_019_i = $sub_017_i;
     while (1) {
      if ((_strcmp(HEAP32[$sub_019_i + 8 >> 2] | 0, $3 | 0) | 0) == 0) {
       if (($_01318_i | 0) == 0) {
        $_1 = $sub_019_i; //@line 74931
        break L24298;
       }
       $_1_i = $_01318_i - 1 | 0; //@line 74936
      } else {
       $_1_i = $_01318_i; //@line 74938
      }
      $sub_0_i12 = HEAP32[$sub_019_i >> 2] | 0; //@line 74942
      if (($sub_0_i12 | 0) == 0) {
       $_013_lcssa_i = $_1_i; //@line 74946
       break;
      } else {
       $_01318_i = $_1_i;
       $sub_019_i = $sub_0_i12;
      }
     }
    }
    if ($4) {
     $_0 = 0; //@line 74956
     label = 18780; //@line 74957
     break L24294;
    }
    $_pre_i16 = $_09 + 16 | 0; //@line 74961
    if (($_09 | 0) == 0) {
     $_2_i_us = $_013_lcssa_i; //@line 74963
     while (1) {
      $97 = _malloc(28) | 0; //@line 74967
      if (($97 | 0) == 0) {
       $_0_i18_us = 0; //@line 74971
      } else {
       HEAP32[$97 >> 2] = 0; //@line 74975
       HEAP32[$97 + 4 >> 2] = 0; //@line 74978
       HEAP32[$97 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 74982
       _memset($97 + 12 | 0, 0, 16); //@line 74984
       $_0_i18_us = $97; //@line 74986
      }
      if (($_2_i_us | 0) == 0) {
       $_1 = $_0_i18_us; //@line 74991
       break L24298;
      }
      if (($_0_i18_us | 0) == 0) {
       $_0 = 0; //@line 74998
       label = 18777; //@line 74999
       break L24294;
      } else {
       $_2_i_us = $_2_i_us - 1 | 0; //@line 75002
      }
     }
    } else {
     $_2_i = $_013_lcssa_i; //@line 75006
    }
    while (1) {
     $110 = ($_2_i | 0) == 0; //@line 75010
     $111 = _malloc(28) | 0; //@line 75011
     if (($111 | 0) == 0) {
      $_0_i18 = 0; //@line 75015
     } else {
      $114 = $111; //@line 75017
      HEAP32[$111 >> 2] = 0; //@line 75019
      $117 = $111 + 4 | 0; //@line 75021
      HEAP32[$117 >> 2] = 0; //@line 75022
      HEAP32[$111 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 75026
      _memset($111 + 12 | 0, 0, 16); //@line 75028
      HEAP32[$117 >> 2] = $_09; //@line 75029
      if ((HEAP32[$82 >> 2] | 0) == 0) {
       HEAP32[$82 >> 2] = $114; //@line 75034
      } else {
       HEAP32[HEAP32[$_pre_i16 >> 2] >> 2] = $114; //@line 75039
      }
      HEAP32[$_pre_i16 >> 2] = $114; //@line 75041
      $_0_i18 = $114; //@line 75043
     }
     if ($110) {
      $_1 = $_0_i18; //@line 75048
      break L24298;
     }
     if (($_0_i18 | 0) == 0) {
      $_0 = 0; //@line 75055
      label = 18778; //@line 75056
      break L24294;
     } else {
      $_2_i = $_2_i - 1 | 0; //@line 75059
     }
    }
   } else {
    label = 18736; //@line 75063
   }
  } while (0);
  do {
   if ((label | 0) == 18736) {
    label = 0; //@line 75068
    $25 = _malloc(28) | 0; //@line 75069
    if (($25 | 0) == 0) {
     $_0 = 0; //@line 75073
     label = 18775; //@line 75074
     break L24294;
    }
    $27 = $25; //@line 75077
    HEAP32[$25 >> 2] = 0; //@line 75079
    $30 = $25 + 4 | 0; //@line 75081
    HEAP32[$30 >> 2] = 0; //@line 75082
    HEAP32[$25 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 75086
    _memset($25 + 12 | 0, 0, 16); //@line 75088
    if (($_09 | 0) == 0) {
     $_1 = $27; //@line 75092
     break;
    }
    HEAP32[$30 >> 2] = $_09; //@line 75095
    $37 = $_09 + 12 | 0; //@line 75096
    if ((HEAP32[$37 >> 2] | 0) == 0) {
     HEAP32[$37 >> 2] = $27; //@line 75101
     $_pre_phi_i = $_09 + 16 | 0; //@line 75104
    } else {
     $42 = $_09 + 16 | 0; //@line 75106
     HEAP32[HEAP32[$42 >> 2] >> 2] = $27; //@line 75109
     $_pre_phi_i = $42; //@line 75110
    }
    HEAP32[$_pre_phi_i >> 2] = $27; //@line 75113
    $_1 = $27; //@line 75115
   }
  } while (0);
  if (($_1 | 0) == 0) {
   $_0 = 0; //@line 75122
   label = 18779; //@line 75123
   break;
  }
  $simple_0 = $simple_0_;
  $_09 = $_1;
  $7 = HEAP32[$1 >> 2] | 0;
 }
 if ((label | 0) == 18775) {
  STACKTOP = sp; //@line 75132
  return $_0 | 0; //@line 75133
 } else if ((label | 0) == 18776) {
  STACKTOP = sp; //@line 75137
  return $_0 | 0; //@line 75138
 } else if ((label | 0) == 18777) {
  STACKTOP = sp; //@line 75142
  return $_0 | 0; //@line 75143
 } else if ((label | 0) == 18778) {
  STACKTOP = sp; //@line 75147
  return $_0 | 0; //@line 75148
 } else if ((label | 0) == 18779) {
  STACKTOP = sp; //@line 75152
  return $_0 | 0; //@line 75153
 } else if ((label | 0) == 18780) {
  STACKTOP = sp; //@line 75157
  return $_0 | 0; //@line 75158
 } else if ((label | 0) == 18781) {
  STACKTOP = sp; //@line 75162
  return $_0 | 0; //@line 75163
 } else if ((label | 0) == 18773) {
  STACKTOP = sp; //@line 75167
  return $_0 | 0; //@line 75168
 }
 return 0;
}
function _ini_str_init($is) {
 $is = $is | 0;
 HEAP32[$is >> 2] = 0; //@line 75179
 HEAP32[$is + 4 >> 2] = 0; //@line 75181
 HEAP32[$is + 8 >> 2] = 0; //@line 75183
 return;
}
function _ini_get_val($sct, $name, $add) {
 $sct = $sct | 0;
 $name = $name | 0;
 $add = $add | 0;
 var $1 = 0, $noidx = 0, $addnew = 0, $last = 0, $index = 0, $3 = 0, $4 = 0, $5 = 0, $7 = 0, $_014 = 0, $simple_0 = 0, $18 = 0, $26 = 0, $31 = 0, $36 = 0, $_pre_phi_i = 0, $44 = 0, $val_010_i = 0, $val_012_i = 0, $ret_011_i = 0, $val_0_ret_0_i = 0, $val_0_i = 0, $ret_0_lcssa_i = 0, $54 = 0, $63 = 0, $_pre_phi_i_i = 0, $68 = 0, $69 = 0, $val_017_i = 0, $val_019_i = 0, $_01318_i = 0, $_1_i = 0, $val_0_i17 = 0, $_013_lcssa_i = 0, $_pre_i_i19 = 0, $_2_us_i = 0, $84 = 0, $_2_i = 0, $88 = 0, $89 = 0, $_0_i_i = 0, $104 = 0, $106 = 0, $109 = 0, $116 = 0, $121 = 0, $_pre_phi_i22 = 0, $129 = 0, $sub_010_i = 0, $sub_012_i = 0, $ret_011_i24 = 0, $sub_0_ret_0_i = 0, $sub_0_i = 0, $ret_0_lcssa_i26 = 0, $139 = 0, $141 = 0, $144 = 0, $155 = 0, $_pre_phi_i_i30 = 0, $160 = 0, $161 = 0, $sub_017_i = 0, $sub_019_i = 0, $_01318_i32 = 0, $_1_i34 = 0, $sub_0_i35 = 0, $_013_lcssa_i36 = 0, $_pre_i42 = 0, $_2_i38_us = 0, $176 = 0, $_0_i44_us = 0, $_2_i38 = 0, $189 = 0, $190 = 0, $193 = 0, $196 = 0, $_0_i44 = 0, $_1 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 75221
 STACKTOP = STACKTOP + 296 | 0; //@line 75221
 $1 = sp | 0; //@line 75222
 $noidx = sp + 8 | 0; //@line 75223
 $addnew = sp + 16 | 0; //@line 75224
 $last = sp + 24 | 0; //@line 75225
 $index = sp + 32 | 0; //@line 75226
 HEAP32[$1 >> 2] = $name; //@line 75228
 if (($sct | 0) == 0) {
  $_0 = 0; //@line 75232
  STACKTOP = sp; //@line 75234
  return $_0 | 0; //@line 75235
 }
 $3 = sp + 40 | 0; //@line 75237
 $4 = ($add | 0) == 0; //@line 75238
 $5 = ($add | 0) != 0; //@line 75239
 $simple_0 = 1;
 $_014 = $sct;
 $7 = $name;
 L24367 : while (1) {
  if ((HEAP8[$7] | 0) == 0) {
   $_0 = 0; //@line 75250
   label = 18881; //@line 75251
   break;
  }
  if ((_ini_get_name_and_index($1, $3, $index, $noidx, $addnew, $last) | 0) != 0) {
   $_0 = 0; //@line 75258
   label = 18874; //@line 75259
   break;
  }
  $18 = (HEAP32[$addnew >> 2] | 0) == 0; //@line 75266
  if ((HEAP8[HEAP32[$1 >> 2] | 0] | 0) == 0) {
   label = 18788; //@line 75269
   break;
  }
  L24372 : do {
   if ($18) {
    if ((HEAP32[$last >> 2] | 0) != 0) {
     $129 = $_014 + 12 | 0; //@line 75279
     $sub_010_i = HEAP32[$129 >> 2] | 0; //@line 75280
     if (($sub_010_i | 0) == 0) {
      $ret_0_lcssa_i26 = 0; //@line 75284
     } else {
      $ret_011_i24 = 0;
      $sub_012_i = $sub_010_i;
      while (1) {
       $sub_0_ret_0_i = (_strcmp(HEAP32[$sub_012_i + 8 >> 2] | 0, $3 | 0) | 0) == 0 ? $sub_012_i : $ret_011_i24; //@line 75294
       $sub_0_i = HEAP32[$sub_012_i >> 2] | 0; //@line 75296
       if (($sub_0_i | 0) == 0) {
        $ret_0_lcssa_i26 = $sub_0_ret_0_i; //@line 75300
        break;
       } else {
        $ret_011_i24 = $sub_0_ret_0_i;
        $sub_012_i = $sub_0_i;
       }
      }
     }
     if (!($5 & ($ret_0_lcssa_i26 | 0) == 0)) {
      $_1 = $ret_0_lcssa_i26; //@line 75312
      break;
     }
     $139 = _malloc(28) | 0; //@line 75315
     if (($139 | 0) == 0) {
      $_0 = 0; //@line 75319
      label = 18868; //@line 75320
      break L24367;
     }
     $141 = $139; //@line 75323
     HEAP32[$139 >> 2] = 0; //@line 75325
     $144 = $139 + 4 | 0; //@line 75327
     HEAP32[$144 >> 2] = 0; //@line 75328
     HEAP32[$139 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 75332
     _memset($139 + 12 | 0, 0, 16); //@line 75334
     if (($_014 | 0) == 0) {
      $_1 = $141; //@line 75338
      break;
     }
     HEAP32[$144 >> 2] = $_014; //@line 75341
     if ((HEAP32[$129 >> 2] | 0) == 0) {
      HEAP32[$129 >> 2] = $141; //@line 75346
      $_pre_phi_i_i30 = $_014 + 16 | 0; //@line 75349
     } else {
      $155 = $_014 + 16 | 0; //@line 75351
      HEAP32[HEAP32[$155 >> 2] >> 2] = $141; //@line 75354
      $_pre_phi_i_i30 = $155; //@line 75355
     }
     HEAP32[$_pre_phi_i_i30 >> 2] = $141; //@line 75358
     $_1 = $141; //@line 75360
     break;
    }
    $160 = HEAP32[$index >> 2] | 0; //@line 75363
    $161 = $_014 + 12 | 0; //@line 75364
    $sub_017_i = HEAP32[$161 >> 2] | 0; //@line 75365
    if (($sub_017_i | 0) == 0) {
     $_013_lcssa_i36 = $160; //@line 75369
    } else {
     $_01318_i32 = $160;
     $sub_019_i = $sub_017_i;
     while (1) {
      if ((_strcmp(HEAP32[$sub_019_i + 8 >> 2] | 0, $3 | 0) | 0) == 0) {
       if (($_01318_i32 | 0) == 0) {
        $_1 = $sub_019_i; //@line 75384
        break L24372;
       }
       $_1_i34 = $_01318_i32 - 1 | 0; //@line 75389
      } else {
       $_1_i34 = $_01318_i32; //@line 75391
      }
      $sub_0_i35 = HEAP32[$sub_019_i >> 2] | 0; //@line 75395
      if (($sub_0_i35 | 0) == 0) {
       $_013_lcssa_i36 = $_1_i34; //@line 75399
       break;
      } else {
       $_01318_i32 = $_1_i34;
       $sub_019_i = $sub_0_i35;
      }
     }
    }
    if ($4) {
     $_0 = 0; //@line 75409
     label = 18875; //@line 75410
     break L24367;
    }
    $_pre_i42 = $_014 + 16 | 0; //@line 75414
    if (($_014 | 0) == 0) {
     $_2_i38_us = $_013_lcssa_i36; //@line 75416
     while (1) {
      $176 = _malloc(28) | 0; //@line 75420
      if (($176 | 0) == 0) {
       $_0_i44_us = 0; //@line 75424
      } else {
       HEAP32[$176 >> 2] = 0; //@line 75428
       HEAP32[$176 + 4 >> 2] = 0; //@line 75431
       HEAP32[$176 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 75435
       _memset($176 + 12 | 0, 0, 16); //@line 75437
       $_0_i44_us = $176; //@line 75439
      }
      if (($_2_i38_us | 0) == 0) {
       $_1 = $_0_i44_us; //@line 75444
       break L24372;
      }
      if (($_0_i44_us | 0) == 0) {
       $_0 = 0; //@line 75451
       label = 18864; //@line 75452
       break L24367;
      } else {
       $_2_i38_us = $_2_i38_us - 1 | 0; //@line 75455
      }
     }
    } else {
     $_2_i38 = $_013_lcssa_i36; //@line 75459
    }
    while (1) {
     $189 = ($_2_i38 | 0) == 0; //@line 75463
     $190 = _malloc(28) | 0; //@line 75464
     if (($190 | 0) == 0) {
      $_0_i44 = 0; //@line 75468
     } else {
      $193 = $190; //@line 75470
      HEAP32[$190 >> 2] = 0; //@line 75472
      $196 = $190 + 4 | 0; //@line 75474
      HEAP32[$196 >> 2] = 0; //@line 75475
      HEAP32[$190 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 75479
      _memset($190 + 12 | 0, 0, 16); //@line 75481
      HEAP32[$196 >> 2] = $_014; //@line 75482
      if ((HEAP32[$161 >> 2] | 0) == 0) {
       HEAP32[$161 >> 2] = $193; //@line 75487
      } else {
       HEAP32[HEAP32[$_pre_i42 >> 2] >> 2] = $193; //@line 75492
      }
      HEAP32[$_pre_i42 >> 2] = $193; //@line 75494
      $_0_i44 = $193; //@line 75496
     }
     if ($189) {
      $_1 = $_0_i44; //@line 75501
      break L24372;
     }
     if (($_0_i44 | 0) == 0) {
      $_0 = 0; //@line 75508
      label = 18882; //@line 75509
      break L24367;
     } else {
      $_2_i38 = $_2_i38 - 1 | 0; //@line 75512
     }
    }
   } else {
    $104 = _malloc(28) | 0; //@line 75516
    if (($104 | 0) == 0) {
     $_0 = 0; //@line 75520
     label = 18873; //@line 75521
     break L24367;
    }
    $106 = $104; //@line 75524
    HEAP32[$104 >> 2] = 0; //@line 75526
    $109 = $104 + 4 | 0; //@line 75528
    HEAP32[$109 >> 2] = 0; //@line 75529
    HEAP32[$104 + 8 >> 2] = _strdup($3 | 0) | 0; //@line 75533
    _memset($104 + 12 | 0, 0, 16); //@line 75535
    if (($_014 | 0) == 0) {
     $_1 = $106; //@line 75539
     break;
    }
    HEAP32[$109 >> 2] = $_014; //@line 75542
    $116 = $_014 + 12 | 0; //@line 75543
    if ((HEAP32[$116 >> 2] | 0) == 0) {
     HEAP32[$116 >> 2] = $106; //@line 75548
     $_pre_phi_i22 = $_014 + 16 | 0; //@line 75551
    } else {
     $121 = $_014 + 16 | 0; //@line 75553
     HEAP32[HEAP32[$121 >> 2] >> 2] = $106; //@line 75556
     $_pre_phi_i22 = $121; //@line 75557
    }
    HEAP32[$_pre_phi_i22 >> 2] = $106; //@line 75560
    $_1 = $106; //@line 75562
   }
  } while (0);
  if (($_1 | 0) == 0) {
   $_0 = 0; //@line 75569
   label = 18867; //@line 75570
   break;
  }
  $simple_0 = 0;
  $_014 = $_1;
  $7 = HEAP32[$1 >> 2] | 0;
 }
 if ((label | 0) == 18788) {
  do {
   if ($18) {
    if (!(($simple_0 | 0) == 0 | $4)) {
     if ((HEAP32[$noidx >> 2] | 0) != 0) {
      break;
     }
    }
    if ((HEAP32[$last >> 2] | 0) != 0) {
     $44 = $_014 + 20 | 0; //@line 75596
     $val_010_i = HEAP32[$44 >> 2] | 0; //@line 75597
     if (($val_010_i | 0) == 0) {
      $ret_0_lcssa_i = 0; //@line 75601
     } else {
      $ret_011_i = 0;
      $val_012_i = $val_010_i;
      while (1) {
       $val_0_ret_0_i = (_strcmp(HEAP32[$val_012_i + 4 >> 2] | 0, $3 | 0) | 0) == 0 ? $val_012_i : $ret_011_i; //@line 75611
       $val_0_i = HEAP32[$val_012_i >> 2] | 0; //@line 75613
       if (($val_0_i | 0) == 0) {
        $ret_0_lcssa_i = $val_0_ret_0_i; //@line 75617
        break;
       } else {
        $ret_011_i = $val_0_ret_0_i;
        $val_012_i = $val_0_i;
       }
      }
     }
     if (!($5 & ($ret_0_lcssa_i | 0) == 0)) {
      $_0 = $ret_0_lcssa_i; //@line 75629
      STACKTOP = sp; //@line 75631
      return $_0 | 0; //@line 75632
     }
     $54 = _ini_val_new($3) | 0; //@line 75634
     if (($54 | 0) == 0) {
      $_0 = 0; //@line 75638
      STACKTOP = sp; //@line 75640
      return $_0 | 0; //@line 75641
     }
     if (($_014 | 0) == 0) {
      $_0 = $54; //@line 75646
      STACKTOP = sp; //@line 75648
      return $_0 | 0; //@line 75649
     }
     if ((HEAP32[$44 >> 2] | 0) == 0) {
      HEAP32[$44 >> 2] = $54; //@line 75655
      $_pre_phi_i_i = $_014 + 24 | 0; //@line 75658
     } else {
      $63 = $_014 + 24 | 0; //@line 75660
      HEAP32[HEAP32[$63 >> 2] >> 2] = $54; //@line 75663
      $_pre_phi_i_i = $63; //@line 75664
     }
     HEAP32[$_pre_phi_i_i >> 2] = $54; //@line 75667
     $_0 = $54; //@line 75669
     STACKTOP = sp; //@line 75671
     return $_0 | 0; //@line 75672
    }
    $68 = HEAP32[$index >> 2] | 0; //@line 75674
    $69 = $_014 + 20 | 0; //@line 75675
    $val_017_i = HEAP32[$69 >> 2] | 0; //@line 75676
    L24451 : do {
     if (($val_017_i | 0) == 0) {
      $_013_lcssa_i = $68; //@line 75681
     } else {
      $_01318_i = $68;
      $val_019_i = $val_017_i;
      while (1) {
       if ((_strcmp(HEAP32[$val_019_i + 4 >> 2] | 0, $3 | 0) | 0) == 0) {
        if (($_01318_i | 0) == 0) {
         $_0 = $val_019_i; //@line 75696
         break;
        }
        $_1_i = $_01318_i - 1 | 0; //@line 75701
       } else {
        $_1_i = $_01318_i; //@line 75703
       }
       $val_0_i17 = HEAP32[$val_019_i >> 2] | 0; //@line 75707
       if (($val_0_i17 | 0) == 0) {
        $_013_lcssa_i = $_1_i; //@line 75711
        break L24451;
       } else {
        $_01318_i = $_1_i;
        $val_019_i = $val_0_i17;
       }
      }
      STACKTOP = sp; //@line 75718
      return $_0 | 0; //@line 75719
     }
    } while (0);
    if ($4) {
     $_0 = 0; //@line 75725
     STACKTOP = sp; //@line 75727
     return $_0 | 0; //@line 75728
    }
    $_pre_i_i19 = $_014 + 24 | 0; //@line 75731
    if (($_014 | 0) == 0) {
     $_2_us_i = $_013_lcssa_i; //@line 75733
     while (1) {
      $84 = _ini_val_new($3) | 0; //@line 75737
      if (($_2_us_i | 0) == 0) {
       $_0 = $84; //@line 75740
       label = 18880; //@line 75741
       break;
      }
      if (($84 | 0) == 0) {
       $_0 = 0; //@line 75748
       label = 18876; //@line 75749
       break;
      } else {
       $_2_us_i = $_2_us_i - 1 | 0; //@line 75752
      }
     }
     if ((label | 0) == 18880) {
      STACKTOP = sp; //@line 75757
      return $_0 | 0; //@line 75758
     } else if ((label | 0) == 18876) {
      STACKTOP = sp; //@line 75762
      return $_0 | 0; //@line 75763
     }
    } else {
     $_2_i = $_013_lcssa_i; //@line 75766
    }
    while (1) {
     $88 = ($_2_i | 0) == 0; //@line 75770
     $89 = _ini_val_new($3) | 0; //@line 75771
     if (($89 | 0) == 0) {
      $_0_i_i = 0; //@line 75775
     } else {
      if ((HEAP32[$69 >> 2] | 0) == 0) {
       HEAP32[$69 >> 2] = $89; //@line 75781
      } else {
       HEAP32[HEAP32[$_pre_i_i19 >> 2] >> 2] = $89; //@line 75786
      }
      HEAP32[$_pre_i_i19 >> 2] = $89; //@line 75788
      $_0_i_i = $89; //@line 75790
     }
     if ($88) {
      $_0 = $_0_i_i; //@line 75795
      label = 18863; //@line 75796
      break;
     }
     if (($_0_i_i | 0) == 0) {
      $_0 = 0; //@line 75803
      label = 18872; //@line 75804
      break;
     } else {
      $_2_i = $_2_i - 1 | 0; //@line 75807
     }
    }
    if ((label | 0) == 18863) {
     STACKTOP = sp; //@line 75812
     return $_0 | 0; //@line 75813
    } else if ((label | 0) == 18872) {
     STACKTOP = sp; //@line 75817
     return $_0 | 0; //@line 75818
    }
   }
  } while (0);
  $26 = _ini_val_new($3) | 0; //@line 75822
  if (($26 | 0) == 0) {
   $_0 = 0; //@line 75826
   STACKTOP = sp; //@line 75828
   return $_0 | 0; //@line 75829
  }
  if (($_014 | 0) == 0) {
   $_0 = $26; //@line 75834
   STACKTOP = sp; //@line 75836
   return $_0 | 0; //@line 75837
  }
  $31 = $_014 + 20 | 0; //@line 75839
  if ((HEAP32[$31 >> 2] | 0) == 0) {
   HEAP32[$31 >> 2] = $26; //@line 75844
   $_pre_phi_i = $_014 + 24 | 0; //@line 75847
  } else {
   $36 = $_014 + 24 | 0; //@line 75849
   HEAP32[HEAP32[$36 >> 2] >> 2] = $26; //@line 75852
   $_pre_phi_i = $36; //@line 75853
  }
  HEAP32[$_pre_phi_i >> 2] = $26; //@line 75856
  $_0 = $26; //@line 75858
  STACKTOP = sp; //@line 75860
  return $_0 | 0; //@line 75861
 } else if ((label | 0) == 18864) {
  STACKTOP = sp; //@line 75865
  return $_0 | 0; //@line 75866
 } else if ((label | 0) == 18867) {
  STACKTOP = sp; //@line 75870
  return $_0 | 0; //@line 75871
 } else if ((label | 0) == 18868) {
  STACKTOP = sp; //@line 75875
  return $_0 | 0; //@line 75876
 } else if ((label | 0) == 18881) {
  STACKTOP = sp; //@line 75880
  return $_0 | 0; //@line 75881
 } else if ((label | 0) == 18882) {
  STACKTOP = sp; //@line 75885
  return $_0 | 0; //@line 75886
 } else if ((label | 0) == 18873) {
  STACKTOP = sp; //@line 75890
  return $_0 | 0; //@line 75891
 } else if ((label | 0) == 18874) {
  STACKTOP = sp; //@line 75895
  return $_0 | 0; //@line 75896
 } else if ((label | 0) == 18875) {
  STACKTOP = sp; //@line 75900
  return $_0 | 0; //@line 75901
 }
 return 0;
}
function _ini_get_uint32($sct, $name, $ret, $def) {
 $sct = $sct | 0;
 $name = $name | 0;
 $ret = $ret | 0;
 $def = $def | 0;
 var $1 = 0, $_0 = 0;
 HEAP32[$ret >> 2] = $def; //@line 75914
 $1 = _ini_get_val($sct, $name, 0) | 0; //@line 75915
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 75919
  return $_0 | 0; //@line 75922
 }
 $_0 = (_ini_val_get_uint32($1, $ret) | 0) != 0 | 0; //@line 75928
 return $_0 | 0; //@line 75931
}
function _ini_get_uint16($sct, $name, $ret, $def) {
 $sct = $sct | 0;
 $name = $name | 0;
 $ret = $ret | 0;
 $def = $def | 0;
 var $1 = 0, $_0 = 0;
 HEAP32[$ret >> 2] = $def; //@line 75943
 $1 = _ini_get_val($sct, $name, 0) | 0; //@line 75944
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 75948
  return $_0 | 0; //@line 75951
 }
 $_0 = (_ini_val_get_uint16($1, $ret) | 0) != 0 | 0; //@line 75957
 return $_0 | 0; //@line 75960
}
function _ini_get_sint16($sct, $name, $ret, $def) {
 $sct = $sct | 0;
 $name = $name | 0;
 $ret = $ret | 0;
 $def = $def | 0;
 var $1 = 0, $_0 = 0;
 HEAP32[$ret >> 2] = $def; //@line 75972
 $1 = _ini_get_val($sct, $name, 0) | 0; //@line 75973
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 75977
  return $_0 | 0; //@line 75980
 }
 $_0 = (_ini_val_get_sint16($1, $ret) | 0) != 0 | 0; //@line 75986
 return $_0 | 0; //@line 75989
}
function _ini_get_bool($sct, $name, $ret, $def) {
 $sct = $sct | 0;
 $name = $name | 0;
 $ret = $ret | 0;
 $def = $def | 0;
 var $3 = 0, $_0 = 0;
 HEAP32[$ret >> 2] = ($def | 0) != 0; //@line 76003
 $3 = _ini_get_val($sct, $name, 0) | 0; //@line 76004
 if (($3 | 0) == 0) {
  $_0 = 1; //@line 76008
  return $_0 | 0; //@line 76011
 }
 $_0 = (_ini_val_get_bool($3, $ret) | 0) != 0 | 0; //@line 76017
 return $_0 | 0; //@line 76020
}
function _ini_get_string($sct, $name, $ret, $def) {
 $sct = $sct | 0;
 $name = $name | 0;
 $ret = $ret | 0;
 $def = $def | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 HEAP32[$ret >> 2] = $def; //@line 76032
 $1 = _ini_get_val($sct, $name, 0) | 0; //@line 76033
 do {
  if (($1 | 0) == 0) {
   $_0 = 1; //@line 76038
  } else {
   $4 = _ini_val_get_str($1) | 0; //@line 76040
   if (($4 | 0) == 0) {
    $_0 = 0; //@line 76044
    break;
   }
   HEAP32[$ret >> 2] = $4; //@line 76047
   $_0 = 0; //@line 76049
  }
 } while (0);
 return $_0 | 0; //@line 76054
}
function _ini_str_add($is, $s1, $s2, $s3) {
 $is = $is | 0;
 $s1 = $s1 | 0;
 $s2 = $s2 | 0;
 $s3 = $s3 | 0;
 var $1 = 0, $5 = 0, $6 = 0, $10 = 0, $11 = 0, $15 = 0, $16 = 0, $21 = 0, $22 = 0, $23 = 0, $max_0 = 0, $31 = 0, $33 = 0, $41 = 0, $47 = 0, $50 = 0, $_sum = 0, $53 = 0, $_pre_phi46 = 0, $_pre_phi = 0, $57 = 0, $_0 = 0;
 $1 = ($s1 | 0) != 0; //@line 76072
 if ($1) {
  $5 = _strlen($s1 | 0) | 0; //@line 76077
 } else {
  $5 = 0; //@line 76079
 }
 $6 = ($s2 | 0) != 0; //@line 76082
 if ($6) {
  $10 = _strlen($s2 | 0) | 0; //@line 76087
 } else {
  $10 = 0; //@line 76089
 }
 $11 = ($s3 | 0) != 0; //@line 76092
 if ($11) {
  $15 = _strlen($s3 | 0) | 0; //@line 76097
 } else {
  $15 = 0; //@line 76099
 }
 $16 = $is | 0; //@line 76102
 $21 = $5 + 1 + $10 + $15 + (HEAP32[$16 >> 2] | 0) | 0; //@line 76107
 $22 = $is + 4 | 0; //@line 76108
 $23 = HEAP32[$22 >> 2] | 0; //@line 76109
 do {
  if ($21 >>> 0 >= $23 >>> 0) {
   $max_0 = ($23 | 0) == 0 ? 256 : $23; //@line 76117
   while (1) {
    if ($21 >>> 0 < $max_0 >>> 0) {
     break;
    } else {
     $max_0 = $max_0 << 1; //@line 76126
    }
   }
   $31 = $is + 8 | 0; //@line 76129
   $33 = _realloc(HEAP32[$31 >> 2] | 0, $max_0) | 0; //@line 76131
   if (($33 | 0) == 0) {
    $_0 = 1; //@line 76135
    return $_0 | 0; //@line 76138
   } else {
    HEAP32[$22 >> 2] = $max_0; //@line 76140
    HEAP32[$31 >> 2] = $33; //@line 76141
    break;
   }
  }
 } while (0);
 if ($1) {
  $41 = (HEAP32[$is + 8 >> 2] | 0) + (HEAP32[$16 >> 2] | 0) | 0; //@line 76152
  _memcpy($41 | 0, $s1 | 0, $5) | 0; //@line 76153
 }
 if ($6) {
  $47 = (HEAP32[$is + 8 >> 2] | 0) + ((HEAP32[$16 >> 2] | 0) + $5) | 0; //@line 76162
  _memcpy($47 | 0, $s2 | 0, $10) | 0; //@line 76163
 }
 if ($11) {
  $50 = $is + 8 | 0; //@line 76168
  $_sum = $10 + $5 | 0; //@line 76171
  $53 = (HEAP32[$50 >> 2] | 0) + ($_sum + (HEAP32[$16 >> 2] | 0)) | 0; //@line 76173
  _memcpy($53 | 0, $s3 | 0, $15) | 0; //@line 76174
  $_pre_phi = $_sum;
  $_pre_phi46 = $50;
 } else {
  $_pre_phi = $10 + $5 | 0;
  $_pre_phi46 = $is + 8 | 0;
 }
 $57 = $_pre_phi + $15 + (HEAP32[$16 >> 2] | 0) | 0; //@line 76187
 HEAP32[$16 >> 2] = $57; //@line 76188
 HEAP8[(HEAP32[$_pre_phi46 >> 2] | 0) + $57 | 0] = 0; //@line 76191
 $_0 = 0; //@line 76193
 return $_0 | 0; //@line 76196
}
function _ini_str_eval($is, $sct, $free) {
 $is = $is | 0;
 $sct = $sct | 0;
 $free = $free | 0;
 var $1 = 0, $3 = 0;
 $1 = $is + 8 | 0; //@line 76207
 $3 = _ini_read_str($sct, HEAP32[$1 >> 2] | 0) | 0; //@line 76209
 if (($free | 0) == 0) {
  return $3 | 0; //@line 76214
 }
 _free(HEAP32[$1 >> 2] | 0); //@line 76217
 return $3 | 0; //@line 76220
}
function _ini_val_init($val, $name) {
 $val = $val | 0;
 $name = $name | 0;
 var $2 = 0;
 HEAP32[$val >> 2] = 0; //@line 76231
 $2 = $val + 4 | 0; //@line 76232
 HEAP32[$2 >> 2] = 0; //@line 76233
 HEAP32[$val + 8 >> 2] = 0; //@line 76235
 if (($name | 0) == 0) {
  return;
 }
 HEAP32[$2 >> 2] = _strdup($name | 0) | 0; //@line 76243
 return;
}
function _ini_val_free($val) {
 $val = $val | 0;
 var $3 = 0;
 if (($val | 0) == 0) {
  return;
 }
 $3 = $val + 8 | 0; //@line 76261
 if ((HEAP32[$3 >> 2] | 0) == 2) {
  _free(HEAP32[$val + 12 >> 2] | 0); //@line 76268
 }
 HEAP32[$3 >> 2] = 0; //@line 76271
 _free(HEAP32[$val + 4 >> 2] | 0); //@line 76274
 return;
}
function _ini_val_set_none($val) {
 $val = $val | 0;
 var $1 = 0;
 $1 = $val + 8 | 0; //@line 76286
 if ((HEAP32[$1 >> 2] | 0) != 2) {
  HEAP32[$1 >> 2] = 0; //@line 76291
  return;
 }
 _free(HEAP32[$val + 12 >> 2] | 0); //@line 76297
 HEAP32[$1 >> 2] = 0; //@line 76299
 return;
}
function _ini_val_new($name) {
 $name = $name | 0;
 var $1 = 0, $2 = 0, $7 = 0, $_0 = 0;
 $1 = _malloc(16) | 0; //@line 76311
 $2 = $1; //@line 76312
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 76316
  return $_0 | 0; //@line 76319
 }
 HEAP32[$1 >> 2] = 0; //@line 76322
 $7 = $1 + 4 | 0; //@line 76324
 HEAP32[$7 >> 2] = 0; //@line 76325
 HEAP32[$1 + 8 >> 2] = 0; //@line 76328
 if (($name | 0) == 0) {
  $_0 = $2; //@line 76332
  return $_0 | 0; //@line 76335
 }
 HEAP32[$7 >> 2] = _strdup($name | 0) | 0; //@line 76338
 $_0 = $2; //@line 76340
 return $_0 | 0; //@line 76343
}
function _ini_val_del($val) {
 $val = $val | 0;
 var $_04 = 0, $3 = 0, $4 = 0;
 if (($val | 0) == 0) {
  return;
 } else {
  $_04 = $val; //@line 76359
 }
 while (1) {
  $3 = HEAP32[$_04 >> 2] | 0; //@line 76364
  $4 = $_04 + 8 | 0; //@line 76365
  if ((HEAP32[$4 >> 2] | 0) == 2) {
   _free(HEAP32[$_04 + 12 >> 2] | 0); //@line 76372
  }
  HEAP32[$4 >> 2] = 0; //@line 76375
  _free(HEAP32[$_04 + 4 >> 2] | 0); //@line 76378
  _free($_04); //@line 76380
  if (($3 | 0) == 0) {
   break;
  } else {
   $_04 = $3; //@line 76386
  }
 }
 return;
}
function _ini_val_get_uint32($val, $v) {
 $val = $val | 0;
 $v = $v | 0;
 var $_0 = 0;
 if ((HEAP32[$val + 8 >> 2] | 0) != 1) {
  $_0 = 1; //@line 76405
  return $_0 | 0; //@line 76408
 }
 HEAP32[$v >> 2] = HEAP32[$val + 12 >> 2]; //@line 76413
 $_0 = 0; //@line 76415
 return $_0 | 0; //@line 76418
}
function _ini_val_get_uint16($val, $v) {
 $val = $val | 0;
 $v = $v | 0;
 var $_0 = 0;
 if ((HEAP32[$val + 8 >> 2] | 0) != 1) {
  $_0 = 1; //@line 76433
  return $_0 | 0; //@line 76436
 }
 HEAP32[$v >> 2] = HEAP32[$val + 12 >> 2] & 65535; //@line 76442
 $_0 = 0; //@line 76444
 return $_0 | 0; //@line 76447
}
function _ini_val_get_sint16($val, $v) {
 $val = $val | 0;
 $v = $v | 0;
 var $7 = 0, $tmp_0_load4_ph = 0, $_0 = 0;
 if ((HEAP32[$val + 8 >> 2] | 0) != 1) {
  $_0 = 1; //@line 76463
  return $_0 | 0; //@line 76466
 }
 $7 = HEAP32[$val + 12 >> 2] | 0; //@line 76470
 if (($7 | 0) < 0) {
  $tmp_0_load4_ph = -(-$7 & 2147483647) | 0; //@line 76478
 } else {
  $tmp_0_load4_ph = $7; //@line 76480
 }
 if (($tmp_0_load4_ph + 32767 | 0) >>> 0 > 65534) {
  $_0 = 1; //@line 76487
  return $_0 | 0; //@line 76490
 }
 HEAP32[$v >> 2] = $tmp_0_load4_ph; //@line 76492
 $_0 = 0; //@line 76494
 return $_0 | 0; //@line 76497
}
function _ini_val_get_bool($val, $v) {
 $val = $val | 0;
 $v = $v | 0;
 var $_0 = 0;
 if ((HEAP32[$val + 8 >> 2] | 0) != 1) {
  $_0 = 1; //@line 76513
  return $_0 | 0; //@line 76516
 }
 HEAP32[$v >> 2] = (HEAP32[$val + 12 >> 2] | 0) != 0; //@line 76523
 $_0 = 0; //@line 76525
 return $_0 | 0; //@line 76528
}
function _ini_val_get_str($val) {
 $val = $val | 0;
 var $_0 = 0;
 if ((HEAP32[$val + 8 >> 2] | 0) != 2) {
  $_0 = 0; //@line 76542
  return $_0 | 0; //@line 76545
 }
 $_0 = HEAP32[$val + 12 >> 2] | 0; //@line 76550
 return $_0 | 0; //@line 76553
}
function _ini_val_copy($dst, $src) {
 $dst = $dst | 0;
 $src = $src | 0;
 var $2 = 0, $6 = 0, $7 = 0, $10 = 0, $15 = 0, $16 = 0, $19 = 0, $24 = 0;
 $2 = HEAP32[$src + 8 >> 2] | 0; //@line 76566
 if (($2 | 0) == 2) {
  $15 = HEAP32[$src + 12 >> 2] | 0; //@line 76569
  $16 = $dst + 8 | 0; //@line 76570
  $19 = $dst + 12 | 0; //@line 76573
  if ((HEAP32[$16 >> 2] | 0) == 2) {
   _free(HEAP32[$19 >> 2] | 0); //@line 76577
  }
  HEAP32[$16 >> 2] = 2; //@line 76580
  HEAP32[$19 >> 2] = _strdup($15 | 0) | 0; //@line 76582
  return;
 } else if (($2 | 0) == 1) {
  $6 = HEAP32[$src + 12 >> 2] | 0; //@line 76589
  $7 = $dst + 8 | 0; //@line 76590
  $10 = $dst + 12 | 0; //@line 76593
  if ((HEAP32[$7 >> 2] | 0) == 2) {
   _free(HEAP32[$10 >> 2] | 0); //@line 76597
  }
  HEAP32[$7 >> 2] = 1; //@line 76600
  HEAP32[$10 >> 2] = $6; //@line 76602
  return;
 } else {
  $24 = $dst + 8 | 0; //@line 76607
  if ((HEAP32[$24 >> 2] | 0) == 2) {
   _free(HEAP32[$dst + 12 >> 2] | 0); //@line 76614
  }
  HEAP32[$24 >> 2] = 0; //@line 76617
  return;
 }
}
function _ini_val_set_uint32($val, $v) {
 $val = $val | 0;
 $v = $v | 0;
 var $1 = 0, $4 = 0;
 $1 = $val + 8 | 0; //@line 76631
 $4 = $val + 12 | 0; //@line 76634
 if ((HEAP32[$1 >> 2] | 0) == 2) {
  _free(HEAP32[$4 >> 2] | 0); //@line 76638
 }
 HEAP32[$1 >> 2] = 1; //@line 76641
 HEAP32[$4 >> 2] = $v; //@line 76643
 return;
}
function _ini_val_set_str($val, $v) {
 $val = $val | 0;
 $v = $v | 0;
 var $1 = 0, $4 = 0;
 $1 = $val + 8 | 0; //@line 76655
 $4 = $val + 12 | 0; //@line 76658
 if ((HEAP32[$1 >> 2] | 0) == 2) {
  _free(HEAP32[$4 >> 2] | 0); //@line 76662
 }
 HEAP32[$1 >> 2] = 2; //@line 76665
 HEAP32[$4 >> 2] = _strdup($v | 0) | 0; //@line 76667
 return;
}
function _ini_eval($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2_i = 0, $v1_0_i = 0, $v2_0_i = 0, $27 = 0, $_0_i = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 76681
 STACKTOP = STACKTOP + 16 | 0; //@line 76681
 $val2_i = sp | 0; //@line 76682
 if ((_ini_eval_lor($scn, $sct, $val) | 0) != 0) {
  $_0_i = 1; //@line 76688
  STACKTOP = sp; //@line 76690
  return $_0_i | 0; //@line 76691
 }
 if ((_scn_match($scn, 49264) | 0) == 0) {
  $_0_i = 0; //@line 76697
  STACKTOP = sp; //@line 76699
  return $_0_i | 0; //@line 76700
 }
 _ini_val_init($val2_i, 0); //@line 76702
 if ((HEAP32[$val + 8 >> 2] | 0) == 1) {
  if ((HEAP32[$val + 12 >> 2] | 0) == 0) {
   label = 19018; //@line 76714
  } else {
   $v2_0_i = $val2_i;
   $v1_0_i = $val;
  }
 } else {
  label = 19018; //@line 76719
 }
 if ((label | 0) == 19018) {
  $v2_0_i = $val;
  $v1_0_i = $val2_i;
 }
 if ((_ini_eval_lor($scn, $sct, $v1_0_i) | 0) != 0) {
  _ini_val_free($val2_i); //@line 76730
  $_0_i = 1; //@line 76732
  STACKTOP = sp; //@line 76734
  return $_0_i | 0; //@line 76735
 }
 if ((_scn_match($scn, 55800) | 0) == 0) {
  _ini_val_free($val2_i); //@line 76741
  $_0_i = 1; //@line 76743
  STACKTOP = sp; //@line 76745
  return $_0_i | 0; //@line 76746
 } else {
  $27 = (_ini_eval_lor($scn, $sct, $v2_0_i) | 0) != 0; //@line 76749
  _ini_val_free($val2_i); //@line 76750
  $_0_i = $27 & 1; //@line 76753
  STACKTOP = sp; //@line 76755
  return $_0_i | 0; //@line 76756
 }
 return 0;
}
function _ini_eval_lor($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $17 = 0, $27 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 76770
 STACKTOP = STACKTOP + 16 | 0; //@line 76770
 $val2 = sp | 0; //@line 76771
 if ((_ini_eval_land($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 76776
  STACKTOP = sp; //@line 76778
  return $_0 | 0; //@line 76779
 }
 if ((_scn_match($scn, 49400) | 0) == 0) {
  $_0 = 0; //@line 76785
  STACKTOP = sp; //@line 76787
  return $_0 | 0; //@line 76788
 }
 $5 = $val + 8 | 0; //@line 76790
 $6 = $val2 + 8 | 0; //@line 76791
 $7 = $val + 12 | 0; //@line 76792
 $8 = $7; //@line 76793
 $10 = $val2 + 12 | 0; //@line 76795
 $11 = $7 | 0; //@line 76796
 while (1) {
  _ini_val_init($val2, 0); //@line 76799
  if ((_ini_eval_land($scn, $sct, $val2) | 0) != 0) {
   label = 19034; //@line 76804
   break;
  }
  $17 = HEAP32[$5 >> 2] | 0; //@line 76807
  if (!(($17 | 0) == (HEAP32[$6 >> 2] | 0) & ($17 | 0) == 1)) {
   label = 19036; //@line 76814
   break;
  }
  if ((HEAP32[$8 >> 2] | 0) == 0) {
   $27 = (HEAP32[$10 >> 2] | 0) != 0 | 0; //@line 76826
  } else {
   $27 = 1; //@line 76828
  }
  HEAP32[$11 >> 2] = $27; //@line 76831
  _ini_val_free($val2); //@line 76832
  if ((_scn_match($scn, 49400) | 0) == 0) {
   $_0 = 0; //@line 76837
   label = 19045; //@line 76838
   break;
  }
 }
 if ((label | 0) == 19034) {
  _ini_val_free($val2); //@line 76843
  $_0 = 1; //@line 76845
  STACKTOP = sp; //@line 76847
  return $_0 | 0; //@line 76848
 } else if ((label | 0) == 19036) {
  _ini_val_free($val2); //@line 76851
  $_0 = 1; //@line 76853
  STACKTOP = sp; //@line 76855
  return $_0 | 0; //@line 76856
 } else if ((label | 0) == 19045) {
  STACKTOP = sp; //@line 76860
  return $_0 | 0; //@line 76861
 }
 return 0;
}
function _ini_eval_land($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $17 = 0, $27 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 76875
 STACKTOP = STACKTOP + 16 | 0; //@line 76875
 $val2 = sp | 0; //@line 76876
 if ((_ini_eval_bor($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 76881
  STACKTOP = sp; //@line 76883
  return $_0 | 0; //@line 76884
 }
 if ((_scn_match($scn, 45704) | 0) == 0) {
  $_0 = 0; //@line 76890
  STACKTOP = sp; //@line 76892
  return $_0 | 0; //@line 76893
 }
 $5 = $val + 8 | 0; //@line 76895
 $6 = $val2 + 8 | 0; //@line 76896
 $7 = $val + 12 | 0; //@line 76897
 $8 = $7; //@line 76898
 $9 = $7 | 0; //@line 76899
 $11 = $val2 + 12 | 0; //@line 76901
 while (1) {
  _ini_val_init($val2, 0); //@line 76904
  if ((_ini_eval_bor($scn, $sct, $val2) | 0) != 0) {
   label = 19050; //@line 76909
   break;
  }
  $17 = HEAP32[$5 >> 2] | 0; //@line 76912
  if (!(($17 | 0) == (HEAP32[$6 >> 2] | 0) & ($17 | 0) == 1)) {
   label = 19052; //@line 76919
   break;
  }
  if ((HEAP32[$8 >> 2] | 0) == 0) {
   $27 = 0; //@line 76926
  } else {
   $27 = (HEAP32[$11 >> 2] | 0) != 0 | 0; //@line 76932
  }
  HEAP32[$9 >> 2] = $27; //@line 76935
  _ini_val_free($val2); //@line 76936
  if ((_scn_match($scn, 45704) | 0) == 0) {
   $_0 = 0; //@line 76941
   label = 19058; //@line 76942
   break;
  }
 }
 if ((label | 0) == 19052) {
  _ini_val_free($val2); //@line 76947
  $_0 = 1; //@line 76949
  STACKTOP = sp; //@line 76951
  return $_0 | 0; //@line 76952
 } else if ((label | 0) == 19058) {
  STACKTOP = sp; //@line 76956
  return $_0 | 0; //@line 76957
 } else if ((label | 0) == 19050) {
  _ini_val_free($val2); //@line 76960
  $_0 = 1; //@line 76962
  STACKTOP = sp; //@line 76964
  return $_0 | 0; //@line 76965
 }
 return 0;
}
function _ini_eval_bor($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $20 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 76979
 STACKTOP = STACKTOP + 16 | 0; //@line 76979
 $val2 = sp | 0; //@line 76980
 if ((_ini_eval_bxor($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 76985
  STACKTOP = sp; //@line 76987
  return $_0 | 0; //@line 76988
 }
 if ((_scn_peek($scn, 49400) | 0) != 0) {
  $_0 = 0; //@line 76994
  STACKTOP = sp; //@line 76996
  return $_0 | 0; //@line 76997
 }
 $5 = $val + 8 | 0; //@line 76999
 $6 = $val2 + 8 | 0; //@line 77000
 $7 = $val + 12 | 0; //@line 77001
 $8 = $7; //@line 77002
 $10 = $val2 + 12 | 0; //@line 77004
 $11 = $7 | 0; //@line 77005
 while (1) {
  if ((_scn_match($scn, 42216) | 0) == 0) {
   $_0 = 0; //@line 77012
   label = 19077; //@line 77013
   break;
  }
  _ini_val_init($val2, 0); //@line 77016
  if ((_ini_eval_bxor($scn, $sct, $val2) | 0) != 0) {
   label = 19067; //@line 77021
   break;
  }
  $20 = HEAP32[$5 >> 2] | 0; //@line 77024
  if (!(($20 | 0) == (HEAP32[$6 >> 2] | 0) & ($20 | 0) == 1)) {
   label = 19069; //@line 77031
   break;
  }
  HEAP32[$11 >> 2] = HEAP32[$10 >> 2] | HEAP32[$8 >> 2]; //@line 77038
  _ini_val_free($val2); //@line 77039
  if ((_scn_peek($scn, 49400) | 0) != 0) {
   $_0 = 0; //@line 77044
   label = 19073; //@line 77045
   break;
  }
 }
 if ((label | 0) == 19067) {
  _ini_val_free($val2); //@line 77050
  $_0 = 1; //@line 77052
  STACKTOP = sp; //@line 77054
  return $_0 | 0; //@line 77055
 } else if ((label | 0) == 19073) {
  STACKTOP = sp; //@line 77059
  return $_0 | 0; //@line 77060
 } else if ((label | 0) == 19069) {
  _ini_val_free($val2); //@line 77063
  $_0 = 1; //@line 77065
  STACKTOP = sp; //@line 77067
  return $_0 | 0; //@line 77068
 } else if ((label | 0) == 19077) {
  STACKTOP = sp; //@line 77072
  return $_0 | 0; //@line 77073
 }
 return 0;
}
function _ini_eval_bxor($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $20 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 77087
 STACKTOP = STACKTOP + 16 | 0; //@line 77087
 $val2 = sp | 0; //@line 77088
 if ((_ini_eval_band($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 77093
  STACKTOP = sp; //@line 77095
  return $_0 | 0; //@line 77096
 }
 if ((_scn_peek($scn, 39176) | 0) != 0) {
  $_0 = 0; //@line 77102
  STACKTOP = sp; //@line 77104
  return $_0 | 0; //@line 77105
 }
 $5 = $val + 8 | 0; //@line 77107
 $6 = $val2 + 8 | 0; //@line 77108
 $7 = $val + 12 | 0; //@line 77109
 $8 = $7; //@line 77110
 $10 = $val2 + 12 | 0; //@line 77112
 $11 = $7 | 0; //@line 77113
 while (1) {
  if ((_scn_match($scn, 36224) | 0) == 0) {
   $_0 = 0; //@line 77120
   label = 19089; //@line 77121
   break;
  }
  _ini_val_init($val2, 0); //@line 77124
  if ((_ini_eval_band($scn, $sct, $val2) | 0) != 0) {
   label = 19083; //@line 77129
   break;
  }
  $20 = HEAP32[$5 >> 2] | 0; //@line 77132
  if (!(($20 | 0) == (HEAP32[$6 >> 2] | 0) & ($20 | 0) == 1)) {
   label = 19085; //@line 77139
   break;
  }
  HEAP32[$11 >> 2] = HEAP32[$10 >> 2] ^ HEAP32[$8 >> 2]; //@line 77146
  _ini_val_free($val2); //@line 77147
  if ((_scn_peek($scn, 39176) | 0) != 0) {
   $_0 = 0; //@line 77152
   label = 19088; //@line 77153
   break;
  }
 }
 if ((label | 0) == 19088) {
  STACKTOP = sp; //@line 77159
  return $_0 | 0; //@line 77160
 } else if ((label | 0) == 19083) {
  _ini_val_free($val2); //@line 77163
  $_0 = 1; //@line 77165
  STACKTOP = sp; //@line 77167
  return $_0 | 0; //@line 77168
 } else if ((label | 0) == 19089) {
  STACKTOP = sp; //@line 77172
  return $_0 | 0; //@line 77173
 } else if ((label | 0) == 19085) {
  _ini_val_free($val2); //@line 77176
  $_0 = 1; //@line 77178
  STACKTOP = sp; //@line 77180
  return $_0 | 0; //@line 77181
 }
 return 0;
}
function _ini_eval_band($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $10 = 0, $11 = 0, $20 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 77195
 STACKTOP = STACKTOP + 16 | 0; //@line 77195
 $val2 = sp | 0; //@line 77196
 if ((_ini_eval_equ($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 77201
  STACKTOP = sp; //@line 77203
  return $_0 | 0; //@line 77204
 }
 if ((_scn_peek($scn, 45704) | 0) != 0) {
  $_0 = 0; //@line 77210
  STACKTOP = sp; //@line 77212
  return $_0 | 0; //@line 77213
 }
 $5 = $val + 8 | 0; //@line 77215
 $6 = $val2 + 8 | 0; //@line 77216
 $7 = $val + 12 | 0; //@line 77217
 $8 = $7; //@line 77218
 $10 = $val2 + 12 | 0; //@line 77220
 $11 = $7 | 0; //@line 77221
 while (1) {
  if ((_scn_match($scn, 33288) | 0) == 0) {
   $_0 = 0; //@line 77228
   label = 19108; //@line 77229
   break;
  }
  _ini_val_init($val2, 0); //@line 77232
  if ((_ini_eval_equ($scn, $sct, $val2) | 0) != 0) {
   label = 19099; //@line 77237
   break;
  }
  $20 = HEAP32[$5 >> 2] | 0; //@line 77240
  if (!(($20 | 0) == (HEAP32[$6 >> 2] | 0) & ($20 | 0) == 1)) {
   label = 19101; //@line 77247
   break;
  }
  HEAP32[$11 >> 2] = HEAP32[$10 >> 2] & HEAP32[$8 >> 2]; //@line 77254
  _ini_val_free($val2); //@line 77255
  if ((_scn_peek($scn, 45704) | 0) != 0) {
   $_0 = 0; //@line 77260
   label = 19106; //@line 77261
   break;
  }
 }
 if ((label | 0) == 19101) {
  _ini_val_free($val2); //@line 77266
  $_0 = 1; //@line 77268
  STACKTOP = sp; //@line 77270
  return $_0 | 0; //@line 77271
 } else if ((label | 0) == 19108) {
  STACKTOP = sp; //@line 77275
  return $_0 | 0; //@line 77276
 } else if ((label | 0) == 19099) {
  _ini_val_free($val2); //@line 77279
  $_0 = 1; //@line 77281
  STACKTOP = sp; //@line 77283
  return $_0 | 0; //@line 77284
 } else if ((label | 0) == 19106) {
  STACKTOP = sp; //@line 77288
  return $_0 | 0; //@line 77289
 }
 return 0;
}
function _ini_eval_equ($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $op_0 = 0, $24 = 0, $40 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 77305
 STACKTOP = STACKTOP + 16 | 0; //@line 77305
 $val2 = sp | 0; //@line 77306
 if ((_ini_eval_cmp($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 77311
  STACKTOP = sp; //@line 77313
  return $_0 | 0; //@line 77314
 }
 $3 = $val + 8 | 0; //@line 77316
 $4 = $val2 + 8 | 0; //@line 77317
 $5 = $val + 12 | 0; //@line 77318
 $6 = $5; //@line 77319
 $8 = $val2 + 12 | 0; //@line 77321
 $9 = $5 | 0; //@line 77322
 $10 = $val + 12 | 0; //@line 77323
 $11 = $val2 + 12 | 0; //@line 77324
 L24776 : while (1) {
  if ((_scn_match($scn, 31624) | 0) == 0) {
   if ((_scn_match($scn, 30640) | 0) == 0) {
    $_0 = 0; //@line 77335
    label = 19130; //@line 77336
    break;
   } else {
    $op_0 = 2; //@line 77339
   }
  } else {
   $op_0 = 1; //@line 77342
  }
  _ini_val_init($val2, 0); //@line 77345
  if ((_ini_eval_cmp($scn, $sct, $val2) | 0) != 0) {
   label = 19115; //@line 77350
   break;
  }
  do {
   if (($op_0 | 0) == 2) {
    $40 = HEAP32[$3 >> 2] | 0; //@line 77355
    if (($40 | 0) != (HEAP32[$4 >> 2] | 0)) {
     label = 19125; //@line 77360
     break L24776;
    }
    if (($40 | 0) == 1) {
     HEAP32[$9 >> 2] = (HEAP32[$6 >> 2] | 0) != (HEAP32[$8 >> 2] | 0); //@line 77369
     break;
    } else if (($40 | 0) == 2) {
     _ini_val_set_uint32($val, (_strcmp(HEAP32[$10 >> 2] | 0, HEAP32[$11 >> 2] | 0) | 0) != 0 | 0); //@line 77378
     break;
    } else {
     label = 19125; //@line 77382
     break L24776;
    }
   } else if (($op_0 | 0) == 1) {
    $24 = HEAP32[$3 >> 2] | 0; //@line 77386
    if (($24 | 0) != (HEAP32[$4 >> 2] | 0)) {
     label = 19125; //@line 77391
     break L24776;
    }
    if (($24 | 0) == 1) {
     HEAP32[$9 >> 2] = (HEAP32[$6 >> 2] | 0) == (HEAP32[$8 >> 2] | 0); //@line 77400
     break;
    } else if (($24 | 0) == 2) {
     _ini_val_set_uint32($val, (_strcmp(HEAP32[$10 >> 2] | 0, HEAP32[$11 >> 2] | 0) | 0) == 0 | 0); //@line 77409
     break;
    } else {
     label = 19125; //@line 77413
     break L24776;
    }
   } else {
    label = 19125; //@line 77417
    break L24776;
   }
  } while (0);
  _ini_val_free($val2); //@line 77421
 }
 if ((label | 0) == 19125) {
  _ini_val_free($val2); //@line 77425
  $_0 = 1; //@line 77427
  STACKTOP = sp; //@line 77429
  return $_0 | 0; //@line 77430
 } else if ((label | 0) == 19130) {
  STACKTOP = sp; //@line 77434
  return $_0 | 0; //@line 77435
 } else if ((label | 0) == 19115) {
  _ini_val_free($val2); //@line 77438
  $_0 = 1; //@line 77440
  STACKTOP = sp; //@line 77442
  return $_0 | 0; //@line 77443
 }
 return 0;
}
function _ini_eval_cmp($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $11 = 0, $op_0 = 0, $30 = 0, $44 = 0, $60 = 0, $76 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 77463
 STACKTOP = STACKTOP + 16 | 0; //@line 77463
 $val2 = sp | 0; //@line 77464
 if ((_ini_eval_shift($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 77469
  STACKTOP = sp; //@line 77471
  return $_0 | 0; //@line 77472
 }
 $3 = $val + 8 | 0; //@line 77474
 $4 = $val2 + 8 | 0; //@line 77475
 $5 = $val + 12 | 0; //@line 77476
 $6 = $5; //@line 77477
 $8 = $val2 + 12 | 0; //@line 77479
 $9 = $5 | 0; //@line 77480
 $10 = $val + 12 | 0; //@line 77481
 $11 = $val2 + 12 | 0; //@line 77482
 L24804 : while (1) {
  do {
   if ((_scn_match($scn, 57840) | 0) == 0) {
    if ((_scn_match($scn, 57e3) | 0) != 0) {
     $op_0 = 4; //@line 77494
     break;
    }
    if ((_scn_match($scn, 55840) | 0) != 0) {
     $op_0 = 1; //@line 77501
     break;
    }
    if ((_scn_match($scn, 55200) | 0) == 0) {
     $_0 = 0; //@line 77508
     label = 19163; //@line 77509
     break L24804;
    } else {
     $op_0 = 3; //@line 77512
    }
   } else {
    $op_0 = 2; //@line 77515
   }
  } while (0);
  _ini_val_init($val2, 0); //@line 77519
  if ((_ini_eval_shift($scn, $sct, $val2) | 0) != 0) {
   label = 19139; //@line 77524
   break;
  }
  do {
   if (($op_0 | 0) == 3) {
    $60 = HEAP32[$3 >> 2] | 0; //@line 77529
    if (($60 | 0) != (HEAP32[$4 >> 2] | 0)) {
     label = 19157; //@line 77534
     break L24804;
    }
    if (($60 | 0) == 1) {
     HEAP32[$9 >> 2] = (HEAP32[$6 >> 2] | 0) >>> 0 > (HEAP32[$8 >> 2] | 0) >>> 0; //@line 77543
     break;
    } else if (($60 | 0) == 2) {
     _ini_val_set_uint32($val, (_strcmp(HEAP32[$10 >> 2] | 0, HEAP32[$11 >> 2] | 0) | 0) > 0 | 0); //@line 77552
     break;
    } else {
     label = 19157; //@line 77556
     break L24804;
    }
   } else if (($op_0 | 0) == 4) {
    $76 = HEAP32[$3 >> 2] | 0; //@line 77560
    if (($76 | 0) != (HEAP32[$4 >> 2] | 0)) {
     label = 19157; //@line 77565
     break L24804;
    }
    if (($76 | 0) == 2) {
     _ini_val_set_uint32($val, (_strcmp(HEAP32[$10 >> 2] | 0, HEAP32[$11 >> 2] | 0) | 0) >>> 31 ^ 1); //@line 77574
     break;
    } else if (($76 | 0) == 1) {
     HEAP32[$9 >> 2] = (HEAP32[$6 >> 2] | 0) >>> 0 >= (HEAP32[$8 >> 2] | 0) >>> 0; //@line 77583
     break;
    } else {
     label = 19157; //@line 77587
     break L24804;
    }
   } else if (($op_0 | 0) == 2) {
    $44 = HEAP32[$3 >> 2] | 0; //@line 77591
    if (($44 | 0) != (HEAP32[$4 >> 2] | 0)) {
     label = 19157; //@line 77596
     break L24804;
    }
    if (($44 | 0) == 1) {
     HEAP32[$9 >> 2] = (HEAP32[$6 >> 2] | 0) >>> 0 <= (HEAP32[$8 >> 2] | 0) >>> 0; //@line 77605
     break;
    } else if (($44 | 0) == 2) {
     _ini_val_set_uint32($val, (_strcmp(HEAP32[$10 >> 2] | 0, HEAP32[$11 >> 2] | 0) | 0) < 1 | 0); //@line 77614
     break;
    } else {
     label = 19157; //@line 77618
     break L24804;
    }
   } else if (($op_0 | 0) == 1) {
    $30 = HEAP32[$3 >> 2] | 0; //@line 77622
    if (($30 | 0) != (HEAP32[$4 >> 2] | 0)) {
     label = 19157; //@line 77627
     break L24804;
    }
    if (($30 | 0) == 1) {
     HEAP32[$9 >> 2] = (HEAP32[$6 >> 2] | 0) >>> 0 < (HEAP32[$8 >> 2] | 0) >>> 0; //@line 77636
     break;
    } else if (($30 | 0) == 2) {
     _ini_val_set_uint32($val, (_strcmp(HEAP32[$10 >> 2] | 0, HEAP32[$11 >> 2] | 0) | 0) >>> 31); //@line 77644
     break;
    } else {
     label = 19157; //@line 77648
     break L24804;
    }
   } else {
    label = 19157; //@line 77652
    break L24804;
   }
  } while (0);
  _ini_val_free($val2); //@line 77656
 }
 if ((label | 0) == 19139) {
  _ini_val_free($val2); //@line 77660
  $_0 = 1; //@line 77662
  STACKTOP = sp; //@line 77664
  return $_0 | 0; //@line 77665
 } else if ((label | 0) == 19163) {
  STACKTOP = sp; //@line 77669
  return $_0 | 0; //@line 77670
 } else if ((label | 0) == 19157) {
  _ini_val_free($val2); //@line 77673
  $_0 = 1; //@line 77675
  STACKTOP = sp; //@line 77677
  return $_0 | 0; //@line 77678
 }
 return 0;
}
function _ini_eval_shift($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $op_0 = 0, $22 = 0, $32 = 0, $storemerge_in = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 77693
 STACKTOP = STACKTOP + 16 | 0; //@line 77693
 $val2 = sp | 0; //@line 77694
 if ((_ini_eval_add($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 77699
  STACKTOP = sp; //@line 77701
  return $_0 | 0; //@line 77702
 }
 $3 = $val + 8 | 0; //@line 77704
 $4 = $val2 + 8 | 0; //@line 77705
 $5 = $val + 12 | 0; //@line 77706
 $6 = $5; //@line 77707
 $8 = $val2 + 12 | 0; //@line 77709
 $9 = $5 | 0; //@line 77710
 while (1) {
  if ((_scn_match($scn, 54456) | 0) == 0) {
   if ((_scn_match($scn, 53808) | 0) == 0) {
    $_0 = 0; //@line 77721
    label = 19179; //@line 77722
    break;
   } else {
    $op_0 = 2; //@line 77725
   }
  } else {
   $op_0 = 1; //@line 77728
  }
  _ini_val_init($val2, 0); //@line 77731
  if ((_ini_eval_add($scn, $sct, $val2) | 0) != 0) {
   label = 19169; //@line 77736
   break;
  }
  if (($op_0 | 0) == 2) {
   $32 = HEAP32[$3 >> 2] | 0; //@line 77740
   if (!(($32 | 0) == (HEAP32[$4 >> 2] | 0) & ($32 | 0) == 1)) {
    label = 19175; //@line 77747
    break;
   }
   $storemerge_in = (HEAP32[$6 >> 2] | 0) >>> ((HEAP32[$8 >> 2] & 31) >>> 0); //@line 77755
  } else if (($op_0 | 0) == 1) {
   $22 = HEAP32[$3 >> 2] | 0; //@line 77757
   if (!(($22 | 0) == (HEAP32[$4 >> 2] | 0) & ($22 | 0) == 1)) {
    label = 19175; //@line 77764
    break;
   }
   $storemerge_in = HEAP32[$6 >> 2] << (HEAP32[$8 >> 2] & 31); //@line 77772
  } else {
   label = 19175; //@line 77774
   break;
  }
  HEAP32[$9 >> 2] = $storemerge_in; //@line 77779
  _ini_val_free($val2); //@line 77780
 }
 if ((label | 0) == 19169) {
  _ini_val_free($val2); //@line 77784
  $_0 = 1; //@line 77786
  STACKTOP = sp; //@line 77788
  return $_0 | 0; //@line 77789
 } else if ((label | 0) == 19179) {
  STACKTOP = sp; //@line 77793
  return $_0 | 0; //@line 77794
 } else if ((label | 0) == 19175) {
  _ini_val_free($val2); //@line 77797
  $_0 = 1; //@line 77799
  STACKTOP = sp; //@line 77801
  return $_0 | 0; //@line 77802
 }
 return 0;
}
function _ini_eval_add($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $9 = 0, $10 = 0, $11 = 0, $12 = 0, $op_0 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $32 = 0, $33 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $41 = 0, $49 = 0, $53 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $60 = 0, $68 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $79 = 0, $87 = 0, $90 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 77823
 STACKTOP = STACKTOP + 48 | 0; //@line 77823
 $val2 = sp + 32 | 0; //@line 77825
 if ((_ini_eval_mul($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 77830
  STACKTOP = sp; //@line 77832
  return $_0 | 0; //@line 77833
 }
 $3 = sp | 0; //@line 77835
 $4 = $val + 8 | 0; //@line 77836
 $5 = $val2 + 8 | 0; //@line 77837
 $6 = $val + 12 | 0; //@line 77838
 $7 = $6; //@line 77839
 $9 = $val2 + 12 | 0; //@line 77841
 $10 = $6 | 0; //@line 77842
 $11 = $val + 12 | 0; //@line 77843
 $12 = $val2 + 12 | 0; //@line 77844
 while (1) {
  if ((_scn_match($scn, 53168) | 0) == 0) {
   if ((_scn_match($scn, 52280) | 0) == 0) {
    $_0 = 0; //@line 77855
    label = 19220; //@line 77856
    break;
   } else {
    $op_0 = 2; //@line 77859
   }
  } else {
   $op_0 = 1; //@line 77862
  }
  _ini_val_init($val2, 0); //@line 77865
  if ((_ini_eval_mul($scn, $sct, $val2) | 0) != 0) {
   label = 19187; //@line 77870
   break;
  }
  if (($op_0 | 0) == 2) {
   $90 = HEAP32[$4 >> 2] | 0; //@line 77874
   if (!(($90 | 0) == (HEAP32[$5 >> 2] | 0) & ($90 | 0) == 1)) {
    label = 19214; //@line 77881
    break;
   }
   HEAP32[$10 >> 2] = (HEAP32[$7 >> 2] | 0) - (HEAP32[$9 >> 2] | 0); //@line 77888
   _ini_val_free($val2); //@line 77889
   continue;
  } else if (($op_0 | 0) != 1) {
   label = 19214; //@line 77893
   break;
  }
  $24 = HEAP32[$4 >> 2] | 0; //@line 77896
  $25 = HEAP32[$5 >> 2] | 0; //@line 77897
  $26 = ($24 | 0) == 1; //@line 77898
  $27 = ($25 | 0) == 1; //@line 77899
  if ($26 & $27) {
   HEAP32[$10 >> 2] = (HEAP32[$9 >> 2] | 0) + (HEAP32[$7 >> 2] | 0); //@line 77907
   _ini_val_free($val2); //@line 77908
   continue;
  }
  $32 = ($24 | 0) == 2; //@line 77911
  $33 = ($25 | 0) == 2; //@line 77912
  if ($32 & $33) {
   $35 = HEAP32[$11 >> 2] | 0; //@line 77916
   $36 = HEAP32[$12 >> 2] | 0; //@line 77917
   $37 = _strlen($35 | 0) | 0; //@line 77918
   $38 = _strlen($36 | 0) | 0; //@line 77919
   $39 = $38 + $37 | 0; //@line 77920
   $41 = _malloc($39 + 1 | 0) | 0; //@line 77922
   if (($41 | 0) == 0) {
    label = 19217; //@line 77926
    break;
   }
   if (($37 | 0) != 0) {
    _memcpy($41 | 0, $35 | 0, $37) | 0; //@line 77932
   }
   if (($38 | 0) != 0) {
    $49 = $41 + $37 | 0; //@line 77938
    _memcpy($49 | 0, $36 | 0, $38) | 0; //@line 77939
   }
   HEAP8[$41 + $39 | 0] = 0; //@line 77943
   _ini_val_set_str($val, $41); //@line 77944
   _free($41); //@line 77945
   _ini_val_free($val2); //@line 77946
   continue;
  }
  if ($32 & $27) {
   $53 = HEAP32[$9 >> 2] | 0; //@line 77952
   _sprintf($3 | 0, 51696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $53, tempInt) | 0) | 0; //@line 77953
   $55 = HEAP32[$11 >> 2] | 0; //@line 77954
   $56 = _strlen($55 | 0) | 0; //@line 77955
   $57 = _strlen($3 | 0) | 0; //@line 77956
   $58 = $57 + $56 | 0; //@line 77957
   $60 = _malloc($58 + 1 | 0) | 0; //@line 77959
   if (($60 | 0) == 0) {
    label = 19218; //@line 77963
    break;
   }
   if (($56 | 0) != 0) {
    _memcpy($60 | 0, $55 | 0, $56) | 0; //@line 77969
   }
   if (($57 | 0) != 0) {
    $68 = $60 + $56 | 0; //@line 77975
    _memcpy($68 | 0, $3 | 0, $57) | 0; //@line 77976
   }
   HEAP8[$60 + $58 | 0] = 0; //@line 77980
   _ini_val_set_str($val, $60); //@line 77981
   _free($60); //@line 77982
   _ini_val_free($val2); //@line 77983
   continue;
  }
  if (!($26 & $33)) {
   label = 19216; //@line 77989
   break;
  }
  _sprintf($3 | 0, 51696, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = HEAP32[$7 >> 2], tempInt) | 0) | 0; //@line 77993
  $74 = HEAP32[$12 >> 2] | 0; //@line 77994
  $75 = _strlen($3 | 0) | 0; //@line 77995
  $76 = _strlen($74 | 0) | 0; //@line 77996
  $77 = $76 + $75 | 0; //@line 77997
  $79 = _malloc($77 + 1 | 0) | 0; //@line 77999
  if (($79 | 0) == 0) {
   label = 19215; //@line 78003
   break;
  }
  if (($75 | 0) != 0) {
   _memcpy($79 | 0, $3 | 0, $75) | 0; //@line 78009
  }
  if (($76 | 0) != 0) {
   $87 = $79 + $75 | 0; //@line 78015
   _memcpy($87 | 0, $74 | 0, $76) | 0; //@line 78016
  }
  HEAP8[$79 + $77 | 0] = 0; //@line 78020
  _ini_val_set_str($val, $79); //@line 78021
  _free($79); //@line 78022
  _ini_val_free($val2); //@line 78023
 }
 if ((label | 0) == 19216) {
  _ini_val_free($val2); //@line 78026
  $_0 = 1; //@line 78027
  STACKTOP = sp; //@line 78029
  return $_0 | 0; //@line 78030
 } else if ((label | 0) == 19217) {
  _ini_val_free($val2); //@line 78033
  $_0 = 1; //@line 78034
  STACKTOP = sp; //@line 78036
  return $_0 | 0; //@line 78037
 } else if ((label | 0) == 19218) {
  _ini_val_free($val2); //@line 78040
  $_0 = 1; //@line 78041
  STACKTOP = sp; //@line 78043
  return $_0 | 0; //@line 78044
 } else if ((label | 0) == 19220) {
  STACKTOP = sp; //@line 78048
  return $_0 | 0; //@line 78049
 } else if ((label | 0) == 19214) {
  _ini_val_free($val2); //@line 78052
  $_0 = 1; //@line 78054
  STACKTOP = sp; //@line 78056
  return $_0 | 0; //@line 78057
 } else if ((label | 0) == 19215) {
  _ini_val_free($val2); //@line 78060
  $_0 = 1; //@line 78062
  STACKTOP = sp; //@line 78064
  return $_0 | 0; //@line 78065
 } else if ((label | 0) == 19187) {
  _ini_val_free($val2); //@line 78068
  $_0 = 1; //@line 78070
  STACKTOP = sp; //@line 78072
  return $_0 | 0; //@line 78073
 }
 return 0;
}
function _ini_eval_mul($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $val2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $op_0 = 0, $25 = 0, $34 = 0, $39 = 0, $45 = 0, $50 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 78090
 STACKTOP = STACKTOP + 16 | 0; //@line 78090
 $val2 = sp | 0; //@line 78091
 if ((_ini_eval_neg($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 78096
  STACKTOP = sp; //@line 78098
  return $_0 | 0; //@line 78099
 }
 $3 = $val + 8 | 0; //@line 78101
 $4 = $val2 + 8 | 0; //@line 78102
 $5 = $val + 12 | 0; //@line 78103
 $6 = $5; //@line 78104
 $8 = $val2 + 12 | 0; //@line 78106
 $9 = $5 | 0; //@line 78107
 L24925 : while (1) {
  do {
   if ((_scn_match($scn, 51192) | 0) == 0) {
    if ((_scn_match($scn, 50696) | 0) != 0) {
     $op_0 = 2; //@line 78119
     break;
    }
    if ((_scn_match($scn, 50392) | 0) == 0) {
     $_0 = 0; //@line 78126
     label = 19248; //@line 78127
     break L24925;
    } else {
     $op_0 = 3; //@line 78130
    }
   } else {
    $op_0 = 1; //@line 78133
   }
  } while (0);
  _ini_val_init($val2, 0); //@line 78137
  if ((_ini_eval_neg($scn, $sct, $val2) | 0) != 0) {
   label = 19234; //@line 78142
   break;
  }
  if (($op_0 | 0) == 3) {
   $45 = HEAP32[$3 >> 2] | 0; //@line 78146
   if (!(($45 | 0) == (HEAP32[$4 >> 2] | 0) & ($45 | 0) == 1)) {
    label = 19244; //@line 78153
    break;
   }
   $50 = HEAP32[$8 >> 2] | 0; //@line 78156
   if (($50 | 0) == 0) {
    label = 19244; //@line 78160
    break;
   }
   HEAP32[$9 >> 2] = ((HEAP32[$6 >> 2] | 0) >>> 0) % ($50 >>> 0) | 0; //@line 78166
  } else if (($op_0 | 0) == 2) {
   $34 = HEAP32[$3 >> 2] | 0; //@line 78169
   if (!(($34 | 0) == (HEAP32[$4 >> 2] | 0) & ($34 | 0) == 1)) {
    label = 19244; //@line 78176
    break;
   }
   $39 = HEAP32[$8 >> 2] | 0; //@line 78179
   if (($39 | 0) == 0) {
    label = 19244; //@line 78183
    break;
   }
   HEAP32[$9 >> 2] = ((HEAP32[$6 >> 2] | 0) >>> 0) / ($39 >>> 0) | 0; //@line 78189
  } else if (($op_0 | 0) == 1) {
   $25 = HEAP32[$3 >> 2] | 0; //@line 78192
   if (!(($25 | 0) == (HEAP32[$4 >> 2] | 0) & ($25 | 0) == 1)) {
    label = 19244; //@line 78199
    break;
   }
   HEAP32[$9 >> 2] = Math_imul(HEAP32[$8 >> 2] | 0, HEAP32[$6 >> 2] | 0) | 0; //@line 78206
  } else {
   label = 19244; //@line 78209
   break;
  }
  _ini_val_free($val2); //@line 78212
 }
 if ((label | 0) == 19234) {
  _ini_val_free($val2); //@line 78216
  $_0 = 1; //@line 78218
  STACKTOP = sp; //@line 78220
  return $_0 | 0; //@line 78221
 } else if ((label | 0) == 19248) {
  STACKTOP = sp; //@line 78225
  return $_0 | 0; //@line 78226
 } else if ((label | 0) == 19244) {
  _ini_val_free($val2); //@line 78229
  $_0 = 1; //@line 78231
  STACKTOP = sp; //@line 78233
  return $_0 | 0; //@line 78234
 }
 return 0;
}
function _ini_eval_neg($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $op_0 = 0, $22 = 0, $32 = 0, $39 = 0, $41 = 0, $_0 = 0;
 do {
  if ((_scn_match($scn, 53168) | 0) == 0) {
   if ((_scn_match($scn, 52280) | 0) != 0) {
    $op_0 = 2; //@line 78261
    break;
   }
   if ((_scn_match($scn, 49440) | 0) != 0) {
    $op_0 = 3; //@line 78268
    break;
   }
   $op_0 = (_scn_match($scn, 49016) | 0) == 0 ? 0 : 4; //@line 78274
  } else {
   $op_0 = 1; //@line 78276
  }
 } while (0);
 if ((_ini_eval_literal($scn, $sct, $val) | 0) != 0) {
  $_0 = 1; //@line 78284
  return $_0 | 0; //@line 78287
 }
 if (($op_0 | 0) == 1) {
  $_0 = (HEAP32[$val + 8 >> 2] | 0) != 1 | 0; //@line 78295
  return $_0 | 0; //@line 78298
 } else if (($op_0 | 0) == 2) {
  if ((HEAP32[$val + 8 >> 2] | 0) != 1) {
   $_0 = 1; //@line 78305
   return $_0 | 0; //@line 78308
  }
  $22 = $val + 12 | 0; //@line 78310
  HEAP32[$22 >> 2] = -(HEAP32[$22 >> 2] | 0); //@line 78316
  $_0 = 0; //@line 78318
  return $_0 | 0; //@line 78321
 } else if (($op_0 | 0) == 3) {
  if ((HEAP32[$val + 8 >> 2] | 0) != 1) {
   $_0 = 1; //@line 78328
   return $_0 | 0; //@line 78331
  }
  $32 = $val + 12 | 0; //@line 78333
  HEAP32[$32 >> 2] = ~HEAP32[$32 >> 2]; //@line 78339
  $_0 = 0; //@line 78341
  return $_0 | 0; //@line 78344
 } else if (($op_0 | 0) == 4) {
  $39 = HEAP32[$val + 8 >> 2] | 0; //@line 78347
  if (($39 | 0) == 1) {
   $41 = $val + 12 | 0; //@line 78349
   HEAP32[$41 >> 2] = (HEAP32[$41 >> 2] | 0) == 0; //@line 78356
   $_0 = 0; //@line 78358
   return $_0 | 0; //@line 78361
  } else if (($39 | 0) == 2) {
   _ini_val_set_uint32($val, (HEAP8[HEAP32[$val + 12 >> 2] | 0] | 0) == 0 | 0); //@line 78368
   $_0 = 0; //@line 78370
   return $_0 | 0; //@line 78373
  } else {
   $_0 = 1; //@line 78375
   return $_0 | 0; //@line 78378
  }
 } else {
  $_0 = 0; //@line 78381
  return $_0 | 0; //@line 78384
 }
 return 0;
}
function _ini_eval_literal($scn, $sct, $val) {
 $scn = $scn | 0;
 $sct = $sct | 0;
 $val = $val | 0;
 var $str = 0, $11 = 0, $42 = 0, $tmp_030 = 0, $44 = 0, $base_0_i = 0, $57 = 0, $_in_i = 0, $v_035_i = 0, $r_034_i = 0, $59 = 0, $d_0_i = 0, $75 = 0, $76 = 0, $v_1_i = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 78403
 STACKTOP = STACKTOP + 256 | 0; //@line 78403
 $str = sp | 0; //@line 78404
 if ((_scn_match($scn, 48192) | 0) != 0) {
  if ((_ini_eval($scn, $sct, $val) | 0) != 0) {
   $_0 = 1; //@line 78413
   STACKTOP = sp; //@line 78415
   return $_0 | 0; //@line 78416
  }
  _scn_match_space($scn) | 0; //@line 78418
  $_0 = (_scn_match($scn, 47848) | 0) == 0 | 0; //@line 78423
  STACKTOP = sp; //@line 78425
  return $_0 | 0; //@line 78426
 }
 $11 = $str | 0; //@line 78428
 if ((_scn_match_string($scn, $11, 256) | 0) != 0) {
  _ini_val_set_str($val, $11); //@line 78433
  $_0 = 0; //@line 78435
  STACKTOP = sp; //@line 78437
  return $_0 | 0; //@line 78438
 }
 if ((_scn_match_name($scn, $11, 256) | 0) != 0) {
  if ((_strcmp($11 | 0, 47544) | 0) == 0) {
   if ((_ini_eval_literal($scn, $sct, $val) | 0) != 0) {
    $_0 = 1; //@line 78452
    STACKTOP = sp; //@line 78454
    return $_0 | 0; //@line 78455
   }
   _ini_val_set_uint32($val, (HEAP32[$val + 8 >> 2] | 0) != 0 | 0); //@line 78461
   $_0 = 0; //@line 78463
   STACKTOP = sp; //@line 78465
   return $_0 | 0; //@line 78466
  }
  if ((_strcmp($11 | 0, 47256) | 0) == 0) {
   _ini_val_set_uint32($val, 1); //@line 78472
   $_0 = 0; //@line 78474
   STACKTOP = sp; //@line 78476
   return $_0 | 0; //@line 78477
  }
  if ((_strcmp($11 | 0, 46984) | 0) == 0) {
   _ini_val_set_uint32($val, 0); //@line 78483
   $_0 = 0; //@line 78485
   STACKTOP = sp; //@line 78487
   return $_0 | 0; //@line 78488
  }
  L25007 : do {
   if (($sct | 0) != 0) {
    $42 = $str + ((HEAP8[$11] | 0) == 36) | 0; //@line 78497
    $tmp_030 = $sct; //@line 78499
    while (1) {
     $44 = _ini_get_val($tmp_030, $42, 0) | 0; //@line 78502
     if (($44 | 0) != 0) {
      break;
     }
     $tmp_030 = HEAP32[$tmp_030 + 4 >> 2] | 0; //@line 78509
     if (($tmp_030 | 0) == 0) {
      break L25007;
     }
    }
    _ini_val_copy($val, $44); //@line 78518
    $_0 = 0; //@line 78520
    STACKTOP = sp; //@line 78522
    return $_0 | 0; //@line 78523
   }
  } while (0);
  _ini_val_set_none($val); //@line 78526
  $_0 = 0; //@line 78528
  STACKTOP = sp; //@line 78530
  return $_0 | 0; //@line 78531
 }
 if ((_scn_match($scn, 46680) | 0) == 0) {
  $base_0_i = (_scn_match($scn, 46400) | 0) == 0 ? 10 : 2; //@line 78540
 } else {
  $base_0_i = 16; //@line 78542
 }
 $57 = _scn_get_chr($scn, 0) | 0; //@line 78545
 if ($57 << 24 >> 24 == 0) {
  $_0 = 1; //@line 78549
  STACKTOP = sp; //@line 78551
  return $_0 | 0; //@line 78552
 } else {
  $r_034_i = 1;
  $v_035_i = 0;
  $_in_i = $57;
 }
 L25022 : while (1) {
  $59 = $_in_i << 24 >> 24; //@line 78560
  do {
   if (($_in_i - 48 & 255) < 10) {
    $d_0_i = $59 - 48 | 0; //@line 78568
   } else {
    if (($_in_i - 97 & 255) < 6) {
     $d_0_i = $59 - 87 | 0; //@line 78576
     break;
    }
    if (($_in_i - 65 & 255) >= 6) {
     label = 19306; //@line 78583
     break L25022;
    }
    $d_0_i = $59 - 55 | 0; //@line 78587
   }
  } while (0);
  if ($d_0_i >>> 0 >= $base_0_i >>> 0) {
   label = 19306; //@line 78594
   break;
  }
  $75 = $d_0_i + (Math_imul($v_035_i, $base_0_i) | 0) | 0; //@line 78598
  _scn_rmv_chr($scn, 1); //@line 78599
  $76 = _scn_get_chr($scn, 0) | 0; //@line 78600
  if ($76 << 24 >> 24 == 0) {
   $v_1_i = $75; //@line 78604
   break;
  } else {
   $r_034_i = 0;
   $v_035_i = $75;
   $_in_i = $76;
  }
 }
 do {
  if ((label | 0) == 19306) {
   if (($r_034_i | 0) != 0) {
    $_0 = 1; //@line 78615
    STACKTOP = sp; //@line 78617
    return $_0 | 0; //@line 78618
   }
   if (($_in_i << 24 >> 24 | 0) == 107 | ($_in_i << 24 >> 24 | 0) == 75) {
    _scn_rmv_chr($scn, 1); //@line 78621
    $v_1_i = $v_035_i << 10; //@line 78624
    break;
   } else if (($_in_i << 24 >> 24 | 0) == 109 | ($_in_i << 24 >> 24 | 0) == 77) {
    _scn_rmv_chr($scn, 1); //@line 78627
    $v_1_i = $v_035_i << 20; //@line 78630
    break;
   } else if (($_in_i << 24 >> 24 | 0) == 103 | ($_in_i << 24 >> 24 | 0) == 71) {
    _scn_rmv_chr($scn, 1); //@line 78633
    $v_1_i = $v_035_i << 30; //@line 78636
    break;
   } else {
    $v_1_i = $v_035_i; //@line 78639
    break;
   }
  }
 } while (0);
 _ini_val_set_uint32($val, $v_1_i); //@line 78645
 $_0 = 0; //@line 78647
 STACKTOP = sp; //@line 78649
 return $_0 | 0; //@line 78650
}
function _dsk_cow_get_msg($dsk, $msg, $val, $max) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 $max = $max | 0;
 return 1; //@line 78662
}
function _dsk_cow_new($dsk, $fname) {
 $dsk = $dsk | 0;
 $fname = $fname | 0;
 var $buf_i_i = 0, $1 = 0, $4 = 0, $5 = 0, $23 = 0, $26 = 0, $28 = 0, $29 = 0, $31 = 0, $35 = 0, $37 = 0, $40 = 0, $50 = 0, $56 = 0, $60 = 0, $67 = 0, $70 = 0, $73 = 0, $76 = 0, $78 = 0, $83 = 0, $102 = 0, $105 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 78687
 STACKTOP = STACKTOP + 32 | 0; //@line 78687
 $buf_i_i = sp | 0; //@line 78688
 $1 = _malloc(104) | 0; //@line 78689
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 78693
  STACKTOP = sp; //@line 78695
  return $_0 | 0; //@line 78696
 }
 $4 = $1; //@line 78698
 $5 = $dsk; //@line 78699
 _memcpy($1 | 0, $5 | 0, 68) | 0; //@line 78700
 _dsk_set_type($4, 5); //@line 78701
 HEAP32[$1 + 4 >> 2] = 478; //@line 78704
 HEAP32[$1 + 8 >> 2] = 20; //@line 78707
 HEAP32[$1 + 12 >> 2] = 64; //@line 78710
 HEAP32[$1 + 16 >> 2] = 14; //@line 78713
 HEAP32[$1 + 20 >> 2] = 54; //@line 78716
 HEAP32[$1 + 60 >> 2] = 0; //@line 78719
 HEAP32[$1 + 64 >> 2] = $1; //@line 78722
 HEAP32[$1 + 68 >> 2] = $dsk; //@line 78725
 $23 = $1 + 28 | 0; //@line 78727
 $26 = ((HEAP32[$23 >> 2] | 0) + 7 | 0) >>> 3; //@line 78730
 $28 = $1 + 100 | 0; //@line 78732
 HEAP32[$28 >> 2] = $26; //@line 78733
 $29 = _malloc($26) | 0; //@line 78734
 $31 = $1 + 96 | 0; //@line 78736
 HEAP32[$31 >> 2] = $29; //@line 78737
 if (($29 | 0) == 0) {
  _free($1); //@line 78741
  $_0 = 0; //@line 78743
  STACKTOP = sp; //@line 78745
  return $_0 | 0; //@line 78746
 }
 $35 = _fopen($fname | 0, 49184) | 0; //@line 78748
 $37 = $1 + 72 | 0; //@line 78750
 HEAP32[$37 >> 2] = $35; //@line 78751
 L25053 : do {
  if (($35 | 0) == 0) {
   $70 = _fopen($fname | 0, 55768) | 0; //@line 78756
   HEAP32[$37 >> 2] = $70; //@line 78757
   if (($70 | 0) == 0) {
    label = 19341; //@line 78761
    break;
   }
   $73 = $buf_i_i | 0; //@line 78764
   $76 = ((HEAP32[$23 >> 2] | 0) + 7 | 0) >>> 3; //@line 78767
   HEAP32[$28 >> 2] = $76; //@line 78768
   $78 = $1 + 80 | 0; //@line 78770
   HEAP32[$78 >> 2] = 20; //@line 78774
   HEAP32[$78 + 4 >> 2] = 0; //@line 78776
   $83 = $1 + 88 | 0; //@line 78782
   HEAP32[$83 >> 2] = $76 + 531 & 1073741312; //@line 78784
   HEAP32[$83 + 4 >> 2] = 0; //@line 78786
   _dsk_set_uint32_be($73, 0, 1129273120); //@line 78787
   _dsk_set_uint32_be($73, 4, 0); //@line 78788
   _dsk_set_uint32_be($73, 8, HEAP32[$23 >> 2] | 0); //@line 78790
   _dsk_set_uint32_be($73, 12, HEAP32[$78 >> 2] | 0); //@line 78797
   _dsk_set_uint32_be($73, 16, HEAP32[$83 >> 2] | 0); //@line 78804
   do {
    if ((_dsk_write(HEAP32[$37 >> 2] | 0, $73, 0, 0, 20, 0) | 0) == 0) {
     _memset(HEAP32[$31 >> 2] | 0, 0, HEAP32[$28 >> 2] | 0); //@line 78817
     if ((_dsk_write(HEAP32[$37 >> 2] | 0, HEAP32[$31 >> 2] | 0, HEAP32[$78 >> 2] | 0, HEAP32[$78 + 4 >> 2] | 0, HEAP32[$28 >> 2] | 0, 0) | 0) != 0) {
      break;
     }
     $102 = HEAP32[$37 >> 2] | 0; //@line 78833
     _fflush($102 | 0) | 0; //@line 78834
     label = 19342; //@line 78836
     break L25053;
    }
   } while (0);
   $105 = HEAP32[$37 >> 2] | 0; //@line 78840
   _fclose($105 | 0) | 0; //@line 78841
   label = 19341; //@line 78843
  } else {
   $40 = $buf_i_i | 0; //@line 78845
   do {
    if ((_dsk_read($35, $40, 0, 0, 20, 0) | 0) == 0) {
     if ((_dsk_get_uint32_be($40, 0) | 0) != 1129273120) {
      break;
     }
     if ((_dsk_get_uint32_be($40, 4) | 0) != 0) {
      break;
     }
     $50 = _dsk_get_uint32_be($40, 8) | 0; //@line 78867
     if (($50 | 0) != (HEAP32[$23 >> 2] | 0)) {
      break;
     }
     $56 = $1 + 80 | 0; //@line 78878
     HEAP32[$56 >> 2] = _dsk_get_uint32_be($40, 12) | 0; //@line 78880
     HEAP32[$56 + 4 >> 2] = 0; //@line 78882
     $60 = $1 + 88 | 0; //@line 78887
     HEAP32[$60 >> 2] = _dsk_get_uint32_be($40, 16) | 0; //@line 78889
     HEAP32[$60 + 4 >> 2] = 0; //@line 78891
     if ((_dsk_read(HEAP32[$37 >> 2] | 0, HEAP32[$31 >> 2] | 0, HEAP32[$56 >> 2] | 0, HEAP32[$56 + 4 >> 2] | 0, HEAP32[$28 >> 2] | 0, 0) | 0) == 0) {
      label = 19342; //@line 78905
      break L25053;
     }
    }
   } while (0);
   $67 = HEAP32[$37 >> 2] | 0; //@line 78910
   _fclose($67 | 0) | 0; //@line 78911
   label = 19341; //@line 78913
  }
 } while (0);
 if ((label | 0) == 19342) {
  _dsk_set_fname($4, $fname); //@line 78917
  $_0 = $4; //@line 78919
  STACKTOP = sp; //@line 78921
  return $_0 | 0; //@line 78922
 } else if ((label | 0) == 19341) {
  _free(HEAP32[$31 >> 2] | 0); //@line 78926
  _free($1); //@line 78927
  $_0 = 0; //@line 78929
  STACKTOP = sp; //@line 78931
  return $_0 | 0; //@line 78932
 }
 return 0;
}
function _dsk_cow_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 78944
 _dsk_del(HEAP32[$2 + 68 >> 2] | 0); //@line 78948
 _fclose(HEAP32[$2 + 72 >> 2] | 0) | 0; //@line 78952
 _free(HEAP32[$2 + 96 >> 2] | 0); //@line 78956
 _free($2); //@line 78957
 return;
}
function _dsk_cow_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $2 = 0, $3 = 0, $5 = 0, $7 = 0, $10$0 = 0, $11 = 0, $14$0 = 0, $16 = 0, $ofs_031$0 = 0, $ofs_031$1 = 0, $tmp_030 = 0, $_01729 = 0, $_01828 = 0, $21 = 0, $23 = 0, $24 = 0, $29 = 0, $32 = 0, $n_034_i = 0, $36 = 0, $n_037_i = 0, $m_036_i = 0, $i_035_i = 0, $i_130_i = 0, $39 = 0, $i_132_i = 0, $n_131_i = 0, $44 = 0, $45 = 0, $i_1_i = 0, $47 = 0, $i_1_lcssa_i = 0, $n_1_lcssa_i = 0, $51 = 0, $i_2_i = 0, $n_2_i = 0, $m_1_i = 0, $58 = 0, $n_0_i = 0, $_01722 = 0, $62 = 0, $63$0 = 0, $63$1 = 0, $_pre = 0, $_pre_phi40$0 = 0, $_pre_phi40$1 = 0, $_pre_phi = 0, $74$0 = 0, $_0 = 0, label = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 78984
 $3 = $dsk + 28 | 0; //@line 78985
 $5 = $2 + 68 | 0; //@line 78987
 $7 = $2 + 72 | 0; //@line 78989
 if (($n | 0) == 0) {
  $_0 = 0; //@line 78993
  return $_0 | 0; //@line 78996
 }
 $10$0 = $i; //@line 78999
 $11 = $2 + 88 | 0; //@line 79001
 $14$0 = _i64Add(HEAP32[$11 >> 2] | 0, HEAP32[$11 + 4 >> 2] | 0, $10$0 << 9 | 0 >>> 23, 0 << 9 | $10$0 >>> 23) | 0;
 $16 = $2 + 96 | 0; //@line 79010
 $_01828 = $i;
 $_01729 = $n;
 $tmp_030 = $buf;
 $ofs_031$1 = tempRet0;
 $ofs_031$0 = $14$0;
 while (1) {
  if ($_01828 >>> 0 >= (HEAP32[$3 >> 2] | 0) >>> 0) {
   $_0 = 1; //@line 79023
   label = 19370; //@line 79024
   break;
  }
  $21 = $_01828 >>> 3; //@line 79027
  $23 = 128 >>> (($_01828 & 7) >>> 0); //@line 79029
  $24 = HEAP32[$16 >> 2] | 0; //@line 79030
  $29 = (HEAPU8[$24 + $21 | 0] & $23 | 0) != 0; //@line 79035
  L25080 : do {
   if ($_01729 >>> 0 < 2) {
    $_01722 = 1; //@line 79040
   } else {
    $32 = $29 << 31 >> 31; //@line 79042
    $n_034_i = $_01729 - 1 | 0; //@line 79043
    if (($n_034_i | 0) == 0) {
     $_01722 = 1; //@line 79047
     break;
    }
    $i_035_i = $21;
    $m_036_i = $23 & 255;
    $n_037_i = $n_034_i;
    $36 = 1;
    while (1) {
     L25085 : do {
      if ($m_036_i << 24 >> 24 == 1) {
       $i_130_i = $i_035_i + 1 | 0; //@line 79062
       if ($n_037_i >>> 0 > 7) {
        $n_131_i = $n_037_i;
        $i_132_i = $i_130_i;
        $39 = $36;
        while (1) {
         if ((HEAP8[$24 + $i_132_i | 0] | 0) != $32 << 24 >> 24) {
          $m_1_i = -128;
          $n_2_i = $n_131_i;
          $i_2_i = $i_132_i;
          $51 = $39;
          break L25085;
         }
         $44 = $n_131_i - 8 | 0; //@line 79078
         $45 = $39 + 8 | 0; //@line 79079
         $i_1_i = $i_132_i + 1 | 0; //@line 79080
         if ($44 >>> 0 > 7) {
          $n_131_i = $44;
          $i_132_i = $i_1_i;
          $39 = $45;
         } else {
          $n_1_lcssa_i = $44;
          $i_1_lcssa_i = $i_1_i;
          $47 = $45;
          break;
         }
        }
       } else {
        $n_1_lcssa_i = $n_037_i;
        $i_1_lcssa_i = $i_130_i;
        $47 = $36;
       }
       if (($n_1_lcssa_i | 0) == 0) {
        $_01722 = $47; //@line 79099
        break L25080;
       } else {
        $m_1_i = -128;
        $n_2_i = $n_1_lcssa_i;
        $i_2_i = $i_1_lcssa_i;
        $51 = $47;
       }
      } else {
       $m_1_i = ($m_036_i & 255) >>> 1;
       $n_2_i = $n_037_i;
       $i_2_i = $i_035_i;
       $51 = $36;
      }
     } while (0);
     if ((HEAP8[$24 + $i_2_i | 0] & $m_1_i) << 24 >> 24 != 0 ^ $29) {
      $_01722 = $51; //@line 79120
      break L25080;
     }
     $58 = $51 + 1 | 0; //@line 79123
     $n_0_i = $n_2_i - 1 | 0; //@line 79124
     if (($n_0_i | 0) == 0) {
      $_01722 = $58; //@line 79128
      break;
     } else {
      $i_035_i = $i_2_i;
      $m_036_i = $m_1_i;
      $n_037_i = $n_0_i;
      $36 = $58;
     }
    }
   }
  } while (0);
  if ($29) {
   $62 = $_01722 << 9; //@line 79140
   $63$0 = $62; //@line 79141
   $63$1 = 0; //@line 79142
   if ((_dsk_read(HEAP32[$7 >> 2] | 0, $tmp_030, $ofs_031$0, $ofs_031$1, $63$0, $63$1) | 0) == 0) {
    $_pre_phi = $62;
    $_pre_phi40$1 = $63$1;
    $_pre_phi40$0 = $63$0;
   } else {
    $_0 = 1; //@line 79149
    label = 19373; //@line 79150
    break;
   }
  } else {
   if ((_dsk_read_lba(HEAP32[$5 >> 2] | 0, $tmp_030, $_01828, $_01722) | 0) != 0) {
    $_0 = 1; //@line 79159
    label = 19372; //@line 79160
    break;
   }
   $_pre = $_01722 << 9; //@line 79163
   $_pre_phi = $_pre;
   $_pre_phi40$1 = 0;
   $_pre_phi40$0 = $_pre;
  }
  $74$0 = _i64Add($_pre_phi40$0, $_pre_phi40$1, $ofs_031$0, $ofs_031$1) | 0;
  if (($_01729 | 0) == ($_01722 | 0)) {
   $_0 = 0; //@line 79179
   label = 19369; //@line 79180
   break;
  } else {
   $_01828 = $_01722 + $_01828 | 0;
   $_01729 = $_01729 - $_01722 | 0;
   $tmp_030 = $tmp_030 + $_pre_phi | 0;
   $ofs_031$1 = tempRet0;
   $ofs_031$0 = $74$0;
  }
 }
 if ((label | 0) == 19369) {
  return $_0 | 0; //@line 79189
 } else if ((label | 0) == 19373) {
  return $_0 | 0; //@line 79194
 } else if ((label | 0) == 19370) {
  return $_0 | 0; //@line 79199
 } else if ((label | 0) == 19372) {
  return $_0 | 0; //@line 79204
 }
 return 0;
}
function _dsk_cow_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $6 = 0, $9$0 = 0, $10 = 0, $13$0 = 0, $14 = 0, $16 = 0, $18 = 0, $20 = 0, $ofs_034$0 = 0, $ofs_034$1 = 0, $tmp_033 = 0, $_01932 = 0, $_02031 = 0, $25 = 0, $27 = 0, $28 = 0, $29 = 0, $31 = 0, $33 = 0, $36 = 0, $n_034_i = 0, $40 = 0, $n_037_i = 0, $m_036_i = 0, $i_035_i = 0, $i_130_i = 0, $43 = 0, $i_132_i = 0, $n_131_i = 0, $48 = 0, $49 = 0, $i_1_i = 0, $51 = 0, $i_1_lcssa_i = 0, $n_1_lcssa_i = 0, $55 = 0, $i_2_i = 0, $n_2_i = 0, $m_1_i = 0, $62 = 0, $n_0_i = 0, $_01925 = 0, $66 = 0, $67 = 0, $69 = 0, $71 = 0, $74 = 0, $84 = 0, $i_01_i = 0, $i_02_i = 0, $95 = 0, $97 = 0, $100$0 = 0, $100$1 = 0, $101$0 = 0, $101$1 = 0, $105 = 0, $106$0 = 0, $106$1 = 0, $113$0 = 0, $_pre_phi42 = 0, $_0 = 0, label = 0;
 if ((HEAP8[$dsk + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 79239
  return $_0 | 0; //@line 79242
 }
 $6 = HEAP32[$dsk + 64 >> 2] | 0; //@line 79245
 L25110 : do {
  if (($n | 0) == 0) {
   $_pre_phi42 = $6 + 72 | 0; //@line 79253
  } else {
   $9$0 = $i; //@line 79256
   $10 = $6 + 88 | 0; //@line 79258
   $13$0 = _i64Add(HEAP32[$10 >> 2] | 0, HEAP32[$10 + 4 >> 2] | 0, $9$0 << 9 | 0 >>> 23, 0 << 9 | $9$0 >>> 23) | 0;
   $14 = $dsk + 28 | 0; //@line 79266
   $16 = $6 + 96 | 0; //@line 79268
   $18 = $6 + 72 | 0; //@line 79270
   $20 = $6 + 80 | 0; //@line 79272
   $_02031 = $i;
   $_01932 = $n;
   $tmp_033 = $buf;
   $ofs_034$1 = tempRet0;
   $ofs_034$0 = $13$0;
   while (1) {
    if ($_02031 >>> 0 >= (HEAP32[$14 >> 2] | 0) >>> 0) {
     $_0 = 1; //@line 79285
     label = 19403; //@line 79286
     break;
    }
    $25 = $_02031 >>> 3; //@line 79289
    $27 = 128 >>> (($_02031 & 7) >>> 0); //@line 79291
    $28 = HEAP32[$16 >> 2] | 0; //@line 79292
    $29 = $28 + $25 | 0; //@line 79293
    $31 = HEAPU8[$29] | 0; //@line 79295
    $33 = ($31 & $27 | 0) != 0; //@line 79297
    L25115 : do {
     if ($_01932 >>> 0 < 2) {
      $_01925 = 1; //@line 79302
     } else {
      $36 = $33 << 31 >> 31; //@line 79304
      $n_034_i = $_01932 - 1 | 0; //@line 79305
      if (($n_034_i | 0) == 0) {
       $_01925 = 1; //@line 79309
       break;
      }
      $i_035_i = $25;
      $m_036_i = $27 & 255;
      $n_037_i = $n_034_i;
      $40 = 1;
      while (1) {
       L25120 : do {
        if ($m_036_i << 24 >> 24 == 1) {
         $i_130_i = $i_035_i + 1 | 0; //@line 79324
         if ($n_037_i >>> 0 > 7) {
          $n_131_i = $n_037_i;
          $i_132_i = $i_130_i;
          $43 = $40;
          while (1) {
           if ((HEAP8[$28 + $i_132_i | 0] | 0) != $36 << 24 >> 24) {
            $m_1_i = -128;
            $n_2_i = $n_131_i;
            $i_2_i = $i_132_i;
            $55 = $43;
            break L25120;
           }
           $48 = $n_131_i - 8 | 0; //@line 79340
           $49 = $43 + 8 | 0; //@line 79341
           $i_1_i = $i_132_i + 1 | 0; //@line 79342
           if ($48 >>> 0 > 7) {
            $n_131_i = $48;
            $i_132_i = $i_1_i;
            $43 = $49;
           } else {
            $n_1_lcssa_i = $48;
            $i_1_lcssa_i = $i_1_i;
            $51 = $49;
            break;
           }
          }
         } else {
          $n_1_lcssa_i = $n_037_i;
          $i_1_lcssa_i = $i_130_i;
          $51 = $40;
         }
         if (($n_1_lcssa_i | 0) == 0) {
          $_01925 = $51; //@line 79361
          break L25115;
         } else {
          $m_1_i = -128;
          $n_2_i = $n_1_lcssa_i;
          $i_2_i = $i_1_lcssa_i;
          $55 = $51;
         }
        } else {
         $m_1_i = ($m_036_i & 255) >>> 1;
         $n_2_i = $n_037_i;
         $i_2_i = $i_035_i;
         $55 = $40;
        }
       } while (0);
       if ((HEAP8[$28 + $i_2_i | 0] & $m_1_i) << 24 >> 24 != 0 ^ $33) {
        $_01925 = $55; //@line 79382
        break L25115;
       }
       $62 = $55 + 1 | 0; //@line 79385
       $n_0_i = $n_2_i - 1 | 0; //@line 79386
       if (($n_0_i | 0) == 0) {
        $_01925 = $62; //@line 79390
        break;
       } else {
        $i_035_i = $i_2_i;
        $m_036_i = $m_1_i;
        $n_037_i = $n_0_i;
        $40 = $62;
       }
      }
     }
    } while (0);
    if (!$33) {
     $66 = $_02031 - 1 + $_01925 | 0; //@line 79402
     $67 = $66 >>> 3; //@line 79403
     $69 = 128 >>> (($66 & 7) >>> 0); //@line 79405
     $71 = $27 + 255 | $27; //@line 79407
     $74 = $69 + 255 ^ 255 | $69; //@line 79410
     do {
      if (($25 | 0) == ($67 | 0)) {
       HEAP8[$29] = ($31 | $74 & $71) & 255; //@line 79418
      } else {
       HEAP8[$29] = ($31 | $71) & 255; //@line 79423
       $84 = (HEAP32[$16 >> 2] | 0) + $67 | 0; //@line 79425
       HEAP8[$84] = (HEAPU8[$84] | $74) & 255; //@line 79430
       $i_01_i = $25 + 1 | 0; //@line 79431
       if ($i_01_i >>> 0 < $67 >>> 0) {
        $i_02_i = $i_01_i; //@line 79435
       } else {
        break;
       }
       do {
        HEAP8[(HEAP32[$16 >> 2] | 0) + $i_02_i | 0] = -1; //@line 79443
        $i_02_i = $i_02_i + 1 | 0; //@line 79444
       } while ($i_02_i >>> 0 < $67 >>> 0);
      }
     } while (0);
     $95 = HEAP32[$18 >> 2] | 0; //@line 79457
     $97 = (HEAP32[$16 >> 2] | 0) + $25 | 0; //@line 79459
     $100$0 = _i64Add(HEAP32[$20 >> 2] | 0, HEAP32[$20 + 4 >> 2] | 0, $25, 0) | 0;
     $100$1 = tempRet0;
     $101$0 = 1 - $25 + $67 | 0; //@line 79467
     $101$1 = 0; //@line 79468
     _dsk_write($95, $97, $100$0, $100$1, $101$0, $101$1) | 0; //@line 79469
    }
    $105 = $_01925 << 9; //@line 79473
    $106$0 = $105; //@line 79474
    $106$1 = 0; //@line 79475
    if ((_dsk_write(HEAP32[$18 >> 2] | 0, $tmp_033, $ofs_034$0, $ofs_034$1, $106$0, $106$1) | 0) != 0) {
     $_0 = 1; //@line 79480
     label = 19401; //@line 79481
     break;
    }
    $113$0 = _i64Add($106$0, $106$1, $ofs_034$0, $ofs_034$1) | 0;
    if (($_01932 | 0) == ($_01925 | 0)) {
     $_pre_phi42 = $18; //@line 79491
     break L25110;
    } else {
     $_02031 = $_01925 + $_02031 | 0;
     $_01932 = $_01932 - $_01925 | 0;
     $tmp_033 = $tmp_033 + $105 | 0;
     $ofs_034$1 = tempRet0;
     $ofs_034$0 = $113$0;
    }
   }
   if ((label | 0) == 19401) {
    return $_0 | 0; //@line 79500
   } else if ((label | 0) == 19403) {
    return $_0 | 0; //@line 79505
   }
  }
 } while (0);
 _fflush(HEAP32[$_pre_phi42 >> 2] | 0) | 0; //@line 79511
 $_0 = 0; //@line 79513
 return $_0 | 0; //@line 79516
}
function _dsk_cow_set_msg($dsk, $msg, $val) {
 $dsk = $dsk | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $dsk_idx_val = 0, $5 = 0, $6 = 0, $9 = 0, $10 = 0, $12 = 0, $14 = 0, $16 = 0, $17 = 0, $n_019_i = 0, $i_018_i = 0, $r_017_i = 0, $20 = 0, $msk_013_i = 0, $blk_012_i = 0, $n_111_i = 0, $r_110_i = 0, $msk_13_i = 0, $blk_12_i = 0, $24 = 0, $25 = 0, $msk_1_lcssa_ph_i = 0, $blk_1_lcssa_ph_i = 0, $msk_26_i = 0, $k_05_i = 0, $32$0 = 0, $35$0 = 0, $ofs_032_i_i$0 = 0, $ofs_032_i_i$1 = 0, $_02731_i_i = 0, $_02830_i_i = 0, $38 = 0, $40 = 0, $41$0 = 0, $41$1 = 0, $i_029_i_i = 0, $53 = 0, $59 = 0, $67$0 = 0, $_0_i_i = 0, $r_2_i = 0, $n_2_i = 0, $74 = 0, $n_1_lcssa_i = 0, $r_1_lcssa_i = 0, $75 = 0, $82 = 0, $87 = 0, $r_0_lcssa36_i = 0, $_pre_phi32_i = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 79541
 STACKTOP = STACKTOP + 4096 | 0; //@line 79541
 if ((_strcmp($msg | 0, 49376) | 0) != 0) {
  $_0 = 1; //@line 79547
  STACKTOP = sp; //@line 79549
  return $_0 | 0; //@line 79550
 }
 $dsk_idx_val = HEAP32[$dsk + 64 >> 2] | 0; //@line 79553
 $5 = $dsk_idx_val + 100 | 0; //@line 79555
 $6 = HEAP32[$5 >> 2] | 0; //@line 79556
 do {
  if (($6 | 0) == 0) {
   $_pre_phi32_i = $dsk_idx_val + 72 | 0;
   $r_0_lcssa36_i = 0;
  } else {
   $9 = $dsk_idx_val + 96 | 0; //@line 79567
   $10 = sp | 0; //@line 79568
   $12 = $dsk_idx_val + 68 | 0; //@line 79570
   $14 = $dsk_idx_val + 88 | 0; //@line 79572
   $16 = $dsk_idx_val + 72 | 0; //@line 79574
   $r_017_i = 0;
   $i_018_i = 0;
   $n_019_i = 0;
   $17 = $6;
   while (1) {
    $20 = HEAP8[(HEAP32[$9 >> 2] | 0) + $i_018_i | 0] | 0; //@line 79584
    if ($20 << 24 >> 24 == 0) {
     $r_1_lcssa_i = $r_017_i;
     $n_1_lcssa_i = $n_019_i;
     $74 = $17;
    } else {
     $r_110_i = $r_017_i;
     $n_111_i = $n_019_i;
     $blk_012_i = $i_018_i << 3;
     $msk_013_i = $20;
     while (1) {
      if ($msk_013_i << 24 >> 24 > -1) {
       $blk_12_i = $blk_012_i;
       $msk_13_i = $msk_013_i;
       while (1) {
        $24 = $msk_13_i << 1; //@line 79605
        $25 = $blk_12_i + 1 | 0; //@line 79606
        if ($24 << 24 >> 24 > -1) {
         $blk_12_i = $25;
         $msk_13_i = $24;
        } else {
         $blk_1_lcssa_ph_i = $25;
         $msk_1_lcssa_ph_i = $24;
         break;
        }
       }
      } else {
       $blk_1_lcssa_ph_i = $blk_012_i;
       $msk_1_lcssa_ph_i = $msk_013_i;
      }
      $k_05_i = 0;
      $msk_26_i = $msk_1_lcssa_ph_i;
      do {
       $k_05_i = $k_05_i + 1 | 0; //@line 79626
       $msk_26_i = $msk_26_i << 1; //@line 79627
      } while ($msk_26_i << 24 >> 24 <= -1);
      L25166 : do {
       if (($k_05_i | 0) == 0) {
        $_0_i_i = 1; //@line 79640
       } else {
        $32$0 = $blk_1_lcssa_ph_i; //@line 79642
        $35$0 = _i64Add(HEAP32[$14 >> 2] | 0, HEAP32[$14 + 4 >> 2] | 0, $32$0 << 9 | 0 >>> 23, 0 << 9 | $32$0 >>> 23) | 0;
        $_02830_i_i = $blk_1_lcssa_ph_i;
        $_02731_i_i = $k_05_i;
        $ofs_032_i_i$1 = tempRet0;
        $ofs_032_i_i$0 = $35$0;
        while (1) {
         $38 = $_02731_i_i >>> 0 > 8 ? 8 : $_02731_i_i; //@line 79659
         $40 = $38 << 9; //@line 79661
         $41$0 = $40; //@line 79662
         $41$1 = 0; //@line 79663
         if ((_dsk_read(HEAP32[$16 >> 2] | 0, $10, $ofs_032_i_i$0, $ofs_032_i_i$1, $41$0, $41$1) | 0) != 0) {
          $_0_i_i = 0; //@line 79668
          break L25166;
         }
         if ((_dsk_write_lba(HEAP32[$12 >> 2] | 0, $10, $_02830_i_i, $38) | 0) != 0) {
          $_0_i_i = 0; //@line 79676
          break L25166;
         }
         _memset($10 | 0, 0, $40 | 0); //@line 79679
         if ((_dsk_write(HEAP32[$16 >> 2] | 0, $10, $ofs_032_i_i$0, $ofs_032_i_i$1, $41$0, $41$1) | 0) != 0) {
          $_0_i_i = 0; //@line 79685
          break L25166;
         }
         if (($38 | 0) != 0) {
          $i_029_i_i = 0; //@line 79691
          do {
           $53 = $i_029_i_i + $_02830_i_i | 0; //@line 79694
           $59 = (HEAP32[$9 >> 2] | 0) + ($53 >>> 3) | 0; //@line 79700
           HEAP8[$59] = (128 >>> (($53 & 7) >>> 0) ^ 255) & (HEAPU8[$59] | 0) & 255; //@line 79705
           $i_029_i_i = $i_029_i_i + 1 | 0; //@line 79706
          } while ($i_029_i_i >>> 0 < $38 >>> 0);
         }
         $67$0 = _i64Add($41$0, $41$1, $ofs_032_i_i$0, $ofs_032_i_i$1) | 0;
         if (($_02731_i_i | 0) == ($38 | 0)) {
          $_0_i_i = 1; //@line 79722
          break;
         } else {
          $_02830_i_i = $38 + $_02830_i_i | 0;
          $_02731_i_i = $_02731_i_i - $38 | 0;
          $ofs_032_i_i$1 = tempRet0;
          $ofs_032_i_i$0 = $67$0;
         }
        }
       }
      } while (0);
      $r_2_i = $_0_i_i ? $r_110_i : 1; //@line 79731
      $n_2_i = ($_0_i_i ? $k_05_i : 0) + $n_111_i | 0; //@line 79733
      if ($msk_26_i << 24 >> 24 == 0) {
       break;
      } else {
       $r_110_i = $r_2_i;
       $n_111_i = $n_2_i;
       $blk_012_i = $k_05_i + $blk_1_lcssa_ph_i | 0;
       $msk_013_i = $msk_26_i;
      }
     }
     $r_1_lcssa_i = $r_2_i;
     $n_1_lcssa_i = $n_2_i;
     $74 = HEAP32[$5 >> 2] | 0;
    }
    $75 = $i_018_i + 1 | 0; //@line 79750
    if ($75 >>> 0 < $74 >>> 0) {
     $r_017_i = $r_1_lcssa_i;
     $i_018_i = $75;
     $n_019_i = $n_1_lcssa_i;
     $17 = $74;
    } else {
     break;
    }
   }
   if (($n_1_lcssa_i | 0) == 0) {
    $_pre_phi32_i = $16;
    $r_0_lcssa36_i = $r_1_lcssa_i;
    break;
   }
   $82 = $dsk_idx_val + 80 | 0; //@line 79768
   if ((_dsk_write(HEAP32[$16 >> 2] | 0, HEAP32[$9 >> 2] | 0, HEAP32[$82 >> 2] | 0, HEAP32[$82 + 4 >> 2] | 0, $74, 0) | 0) == 0) {
    $87 = HEAP32[$16 >> 2] | 0; //@line 79779
    _fflush($87 | 0) | 0; //@line 79780
    $_pre_phi32_i = $16;
    $r_0_lcssa36_i = $r_1_lcssa_i;
    break;
   } else {
    $_0 = 1; //@line 79785
    STACKTOP = sp; //@line 79787
    return $_0 | 0; //@line 79788
   }
  }
 } while (0);
 _fflush(HEAP32[$_pre_phi32_i >> 2] | 0) | 0; //@line 79795
 $_0 = $r_0_lcssa36_i; //@line 79797
 STACKTOP = sp; //@line 79799
 return $_0 | 0; //@line 79800
}
function _dsk_part_add_partition($dsk, $fname, $start$0, $start$1, $blk_i, $blk_n, $ro) {
 $dsk = $dsk | 0;
 $fname = $fname | 0;
 $start$0 = $start$0 | 0;
 $start$1 = $start$1 | 0;
 $blk_i = $blk_i | 0;
 $blk_n = $blk_n | 0;
 $ro = $ro | 0;
 var $fp_0 = 0, $10 = 0, $12 = 0, $13 = 0, $15 = 0, $18 = 0, $_0 = 0;
 if (($ro | 0) == 0) {
  $fp_0 = _fopen($fname | 0, 55760) | 0; //@line 79821
 } else {
  $fp_0 = _fopen($fname | 0, 49168) | 0; //@line 79825
 }
 if (($fp_0 | 0) == 0) {
  $_0 = 1; //@line 79831
  return $_0 | 0; //@line 79834
 }
 $10 = HEAP32[$dsk + 64 >> 2] | 0; //@line 79837
 $12 = $10 + 68 | 0; //@line 79839
 $13 = HEAP32[$12 >> 2] | 0; //@line 79840
 $15 = $10 + 72 | 0; //@line 79842
 HEAP32[$15 + ($13 << 5) >> 2] = $blk_i; //@line 79844
 HEAP32[$15 + ($13 << 5) + 4 >> 2] = $blk_n; //@line 79846
 $18 = $15 + ($13 << 5) + 8 | 0; //@line 79847
 HEAP32[$18 >> 2] = $start$0; //@line 79849
 HEAP32[$18 + 4 >> 2] = $start$1; //@line 79851
 HEAP32[$15 + ($13 << 5) + 16 >> 2] = $fp_0; //@line 79853
 HEAP32[$15 + ($13 << 5) + 20 >> 2] = 1; //@line 79855
 HEAP32[$15 + ($13 << 5) + 24 >> 2] = ($ro | 0) != 0; //@line 79859
 HEAP32[$12 >> 2] = $13 + 1; //@line 79861
 $_0 = 0; //@line 79863
 return $_0 | 0; //@line 79866
}
function _dsk_part_open($c, $h, $s, $ro) {
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $ro = $ro | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _malloc(584) | 0; //@line 79879
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 79883
  return $_0 | 0; //@line 79886
 }
 $4 = $1; //@line 79888
 _dsk_init($4, $1, 0, $c, $h, $s); //@line 79889
 _dsk_set_readonly($4, $ro); //@line 79890
 HEAP32[$1 + 4 >> 2] = 386; //@line 79893
 HEAP32[$1 + 8 >> 2] = 54; //@line 79896
 HEAP32[$1 + 12 >> 2] = 50; //@line 79899
 HEAP32[$1 + 68 >> 2] = 0; //@line 79902
 $_0 = $4; //@line 79904
 return $_0 | 0; //@line 79907
}
function _null_open($nt, $w, $h) {
 $nt = $nt | 0;
 $w = $w | 0;
 $h = $h | 0;
 return 0; //@line 79918
}
function _null_close($nt) {
 $nt = $nt | 0;
 return 0; //@line 79927
}
function _null_set_msg_trm($nt, $msg, $val) {
 $nt = $nt | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 return -1 | 0; //@line 79938
}
function _null_update($vt) {
 $vt = $vt | 0;
 return;
}
function _null_check($vt) {
 $vt = $vt | 0;
 return;
}
function _pce_key_to_string($key) {
 $key = $key | 0;
 var $el_0 = 0, $3 = 0, $_0 = 0, label = 0;
 $el_0 = 7760; //@line 79967
 while (1) {
  $3 = HEAP32[$el_0 + 4 >> 2] | 0; //@line 79971
  if (($3 | 0) == 0) {
   $_0 = 0; //@line 79975
   label = 19455; //@line 79976
   break;
  }
  if ((HEAP32[$el_0 >> 2] | 0) == ($key | 0)) {
   $_0 = $3; //@line 79985
   label = 19456; //@line 79986
   break;
  } else {
   $el_0 = $el_0 + 8 | 0; //@line 79989
  }
 }
 if ((label | 0) == 19455) {
  return $_0 | 0; //@line 79995
 } else if ((label | 0) == 19456) {
  return $_0 | 0; //@line 80000
 }
 return 0;
}
function _trm_set_msg_fct($trm, $ext, $fct) {
 $trm = $trm | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$trm + 4 >> 2] = $ext; //@line 80013
 HEAP32[$trm + 8 >> 2] = $fct; //@line 80016
 return;
}
function _trm_set_key_fct($trm, $ext, $fct) {
 $trm = $trm | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$trm + 12 >> 2] = $ext; //@line 80030
 HEAP32[$trm + 16 >> 2] = $fct; //@line 80033
 return;
}
function _trm_set_mouse_fct($trm, $ext, $fct) {
 $trm = $trm | 0;
 $ext = $ext | 0;
 $fct = $fct | 0;
 HEAP32[$trm + 20 >> 2] = $ext; //@line 80047
 HEAP32[$trm + 24 >> 2] = $fct; //@line 80050
 return;
}
function _trm_set_mouse_scale($trm, $mul_x, $div_x, $mul_y, $div_y) {
 $trm = $trm | 0;
 $mul_x = $mul_x | 0;
 $div_x = $div_x | 0;
 $mul_y = $mul_y | 0;
 $div_y = $div_y | 0;
 HEAP32[$trm + 100 >> 2] = $mul_x; //@line 80066
 HEAP32[$trm + 104 >> 2] = $div_x; //@line 80068
 HEAP32[$trm + 108 >> 2] = 0; //@line 80070
 HEAP32[$trm + 112 >> 2] = $mul_y; //@line 80072
 HEAP32[$trm + 116 >> 2] = $div_y; //@line 80074
 HEAP32[$trm + 120 >> 2] = 0; //@line 80076
 return;
}
function _dsk_part_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0, $4 = 0, $5 = 0, $8 = 0, $10 = 0, $i_07 = 0, $16 = 0, $19 = 0, $20 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 80090
 $4 = $2 + 68 | 0; //@line 80092
 $5 = HEAP32[$4 >> 2] | 0; //@line 80093
 if (($5 | 0) == 0) {
  _free($2); //@line 80097
  return;
 }
 $8 = $2 + 72 | 0; //@line 80102
 $i_07 = 0;
 $10 = $5;
 while (1) {
  if ((HEAP32[$8 + ($i_07 << 5) + 20 >> 2] | 0) == 0) {
   $19 = $10; //@line 80113
  } else {
   $16 = HEAP32[$8 + ($i_07 << 5) + 16 >> 2] | 0; //@line 80116
   _fclose($16 | 0) | 0; //@line 80117
   $19 = HEAP32[$4 >> 2] | 0; //@line 80120
  }
  $20 = $i_07 + 1 | 0; //@line 80123
  if ($20 >>> 0 < $19 >>> 0) {
   $i_07 = $20;
   $10 = $19;
  } else {
   break;
  }
 }
 _free($2); //@line 80132
 return;
}
function _dsk_part_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $7 = 0, $8 = 0, $10 = 0, $dsk_idx_val = 0, $_03551 = 0, $_03650 = 0, $_03748 = 0, $14 = 0, $_pre6_i = 0, $17 = 0, $i_02_i = 0, $19 = 0, $31 = 0, $32 = 0, $pi_0_load404243 = 0, $38 = 0, $41 = 0, $44 = 0, $_037_ = 0, $46 = 0, $48$0 = 0, $50$0 = 0, $51$0 = 0, $52$0 = 0, $58 = 0, $_037_39 = 0, $60 = 0, $m_2 = 0, $cnt_0_off0 = 0, $_0 = 0, label = 0;
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 80162
  return $_0 | 0; //@line 80165
 }
 if (($n | 0) == 0) {
  $_0 = 0; //@line 80170
  return $_0 | 0; //@line 80173
 }
 $7 = $dsk + 64 | 0; //@line 80175
 $8 = HEAP32[$7 >> 2] | 0; //@line 80176
 $10 = $8 + 72 | 0; //@line 80178
 $_03748 = $n;
 $_03650 = $i;
 $_03551 = $buf;
 $dsk_idx_val = $8;
 while (1) {
  $14 = HEAP32[$dsk_idx_val + 68 >> 2] | 0; //@line 80188
  if (($14 | 0) == 0) {
   label = 19479; //@line 80192
   break;
  }
  $_pre6_i = $dsk_idx_val + 72 | 0; //@line 80196
  $i_02_i = 0;
  $17 = 0;
  while (1) {
   $19 = HEAP32[$_pre6_i + ($i_02_i << 5) >> 2] | 0; //@line 80202
   if ($19 >>> 0 > $_03650 >>> 0) {
    $31 = $19 >>> 0 < (HEAP32[$_pre6_i + ($17 << 5) >> 2] | 0) >>> 0 ? $i_02_i : $17; //@line 80211
   } else {
    if (($_03650 - $19 | 0) >>> 0 < (HEAP32[$_pre6_i + ($i_02_i << 5) + 4 >> 2] | 0) >>> 0) {
     $pi_0_load404243 = $i_02_i; //@line 80219
     break;
    } else {
     $31 = $17; //@line 80222
    }
   }
   $32 = $i_02_i + 1 | 0; //@line 80226
   if ($32 >>> 0 < $14 >>> 0) {
    $i_02_i = $32;
    $17 = $31;
   } else {
    label = 19478; //@line 80232
    break;
   }
  }
  if ((label | 0) == 19478) {
   label = 0; //@line 80237
   if ((HEAP32[$_pre6_i + ($31 << 5) >> 2] | 0) >>> 0 > $_03650 >>> 0) {
    $pi_0_load404243 = $31; //@line 80243
   } else {
    label = 19479; //@line 80245
    break;
   }
  }
  $38 = HEAP32[$10 + ($pi_0_load404243 << 5) >> 2] | 0; //@line 80251
  if ($38 >>> 0 > $_03650 >>> 0) {
   $58 = $38 - $_03650 | 0; //@line 80255
   $_037_39 = $58 >>> 0 > $_03748 >>> 0 ? $_03748 : $58; //@line 80257
   $60 = $_037_39 << 9; //@line 80258
   _memset($_03551 | 0, -2 | 0, $60 | 0); //@line 80259
   $cnt_0_off0 = $60;
   $m_2 = $_037_39;
  } else {
   $41 = $_03650 - $38 | 0; //@line 80262
   $44 = (HEAP32[$10 + ($pi_0_load404243 << 5) + 4 >> 2] | 0) - $41 | 0; //@line 80265
   $_037_ = $44 >>> 0 > $_03748 >>> 0 ? $_03748 : $44; //@line 80267
   $46 = $10 + ($pi_0_load404243 << 5) + 8 | 0; //@line 80268
   $48$0 = $41; //@line 80273
   $50$0 = _i64Add(HEAP32[$46 >> 2] | 0, HEAP32[$46 + 4 >> 2] | 0, $48$0 << 9 | 0 >>> 23, 0 << 9 | $48$0 >>> 23) | 0;
   $51$0 = $_037_; //@line 80278
   $52$0 = $51$0 << 9 | 0 >>> 23; //@line 80280
   if ((_dsk_read(HEAP32[$10 + ($pi_0_load404243 << 5) + 16 >> 2] | 0, $_03551, $50$0, tempRet0, $52$0, 0 << 9 | $51$0 >>> 23) | 0) == 0) {
    $cnt_0_off0 = $52$0;
    $m_2 = $_037_;
   } else {
    $_0 = 1; //@line 80292
    label = 19487; //@line 80293
    break;
   }
  }
  if (($_03748 | 0) == ($m_2 | 0)) {
   $_0 = 0; //@line 80302
   label = 19490; //@line 80303
   break;
  }
  $_03748 = $_03748 - $m_2 | 0;
  $_03650 = $m_2 + $_03650 | 0;
  $_03551 = $_03551 + $cnt_0_off0 | 0;
  $dsk_idx_val = HEAP32[$7 >> 2] | 0;
 }
 if ((label | 0) == 19479) {
  _memset($_03551 | 0, -2 | 0, $_03748 << 9 | 0); //@line 80315
  $_0 = 0; //@line 80317
  return $_0 | 0; //@line 80320
 } else if ((label | 0) == 19487) {
  return $_0 | 0; //@line 80325
 } else if ((label | 0) == 19490) {
  return $_0 | 0; //@line 80330
 }
 return 0;
}
function _dsk_part_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $6 = 0, $7 = 0, $9 = 0, $dsk_idx_val = 0, $_03246 = 0, $_03345 = 0, $_03444 = 0, $13 = 0, $_pre6_i = 0, $16 = 0, $i_02_i = 0, $18 = 0, $30 = 0, $31 = 0, $pi_0_load384041 = 0, $36 = 0, $43 = 0, $46 = 0, $_034_ = 0, $48 = 0, $50$0 = 0, $52$0 = 0, $53$0 = 0, $54$0 = 0, $55 = 0, $60 = 0, $63 = 0, $_034_36 = 0, $m_2 = 0, $cnt_0_off0 = 0, $_0 = 0, label = 0;
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 80359
  return $_0 | 0; //@line 80362
 }
 $6 = $dsk + 64 | 0; //@line 80364
 $7 = HEAP32[$6 >> 2] | 0; //@line 80365
 $9 = $7 + 72 | 0; //@line 80367
 if (($n | 0) == 0) {
  $_0 = 0; //@line 80371
  return $_0 | 0; //@line 80374
 } else {
  $_03444 = $n;
  $_03345 = $i;
  $_03246 = $buf;
  $dsk_idx_val = $7;
 }
 while (1) {
  $13 = HEAP32[$dsk_idx_val + 68 >> 2] | 0; //@line 80385
  if (($13 | 0) == 0) {
   $_0 = 0; //@line 80389
   label = 19510; //@line 80390
   break;
  }
  $_pre6_i = $dsk_idx_val + 72 | 0; //@line 80394
  $i_02_i = 0;
  $16 = 0;
  while (1) {
   $18 = HEAP32[$_pre6_i + ($i_02_i << 5) >> 2] | 0; //@line 80400
   if ($18 >>> 0 > $_03345 >>> 0) {
    $30 = $18 >>> 0 < (HEAP32[$_pre6_i + ($16 << 5) >> 2] | 0) >>> 0 ? $i_02_i : $16; //@line 80409
   } else {
    if (($_03345 - $18 | 0) >>> 0 < (HEAP32[$_pre6_i + ($i_02_i << 5) + 4 >> 2] | 0) >>> 0) {
     $pi_0_load384041 = $i_02_i; //@line 80417
     break;
    } else {
     $30 = $16; //@line 80420
    }
   }
   $31 = $i_02_i + 1 | 0; //@line 80424
   if ($31 >>> 0 < $13 >>> 0) {
    $i_02_i = $31;
    $16 = $30;
   } else {
    label = 19499; //@line 80430
    break;
   }
  }
  if ((label | 0) == 19499) {
   label = 0; //@line 80435
   if ((HEAP32[$_pre6_i + ($30 << 5) >> 2] | 0) >>> 0 > $_03345 >>> 0) {
    $pi_0_load384041 = $30; //@line 80441
   } else {
    $_0 = 0; //@line 80443
    label = 19508; //@line 80444
    break;
   }
  }
  $36 = HEAP32[$9 + ($pi_0_load384041 << 5) >> 2] | 0; //@line 80450
  if ($36 >>> 0 > $_03345 >>> 0) {
   $63 = $36 - $_03345 | 0; //@line 80454
   $_034_36 = $63 >>> 0 > $_03444 >>> 0 ? $_03444 : $63; //@line 80456
   $cnt_0_off0 = $_034_36 << 9;
   $m_2 = $_034_36;
  } else {
   if ((HEAP32[$9 + ($pi_0_load384041 << 5) + 24 >> 2] | 0) != 0) {
    $_0 = 1; //@line 80465
    label = 19512; //@line 80466
    break;
   }
   $43 = $_03345 - $36 | 0; //@line 80469
   $46 = (HEAP32[$9 + ($pi_0_load384041 << 5) + 4 >> 2] | 0) - $43 | 0; //@line 80472
   $_034_ = $46 >>> 0 > $_03444 >>> 0 ? $_03444 : $46; //@line 80474
   $48 = $9 + ($pi_0_load384041 << 5) + 8 | 0; //@line 80475
   $50$0 = $43; //@line 80480
   $52$0 = _i64Add(HEAP32[$48 >> 2] | 0, HEAP32[$48 + 4 >> 2] | 0, $50$0 << 9 | 0 >>> 23, 0 << 9 | $50$0 >>> 23) | 0;
   $53$0 = $_034_; //@line 80485
   $54$0 = $53$0 << 9 | 0 >>> 23; //@line 80487
   $55 = $9 + ($pi_0_load384041 << 5) + 16 | 0; //@line 80489
   if ((_dsk_write(HEAP32[$55 >> 2] | 0, $_03246, $52$0, tempRet0, $54$0, 0 << 9 | $53$0 >>> 23) | 0) != 0) {
    $_0 = 1; //@line 80495
    label = 19514; //@line 80496
    break;
   }
   $60 = HEAP32[$55 >> 2] | 0; //@line 80499
   _fflush($60 | 0) | 0; //@line 80500
   $cnt_0_off0 = $54$0;
   $m_2 = $_034_;
  }
  if (($_03444 | 0) == ($m_2 | 0)) {
   $_0 = 0; //@line 80511
   label = 19513; //@line 80512
   break;
  }
  $_03444 = $_03444 - $m_2 | 0;
  $_03345 = $m_2 + $_03345 | 0;
  $_03246 = $_03246 + $cnt_0_off0 | 0;
  $dsk_idx_val = HEAP32[$6 >> 2] | 0;
 }
 if ((label | 0) == 19510) {
  return $_0 | 0; //@line 80525
 } else if ((label | 0) == 19508) {
  return $_0 | 0; //@line 80530
 } else if ((label | 0) == 19514) {
  return $_0 | 0; //@line 80535
 } else if ((label | 0) == 19513) {
  return $_0 | 0; //@line 80540
 } else if ((label | 0) == 19512) {
  return $_0 | 0; //@line 80545
 }
 return 0;
}
function _dsk_ram_open($fname, $n, $c, $h, $s, $ro) {
 $fname = $fname | 0;
 $n = $n | 0;
 $c = $c | 0;
 $h = $h | 0;
 $s = $s | 0;
 $ro = $ro | 0;
 var $1 = 0, $4 = 0, $12 = 0, $14 = 0, $15 = 0, $17 = 0, $23 = 0, $27$0 = 0, $29 = 0, $_0 = 0;
 $1 = _malloc(72) | 0; //@line 80564
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 80568
  return $_0 | 0; //@line 80571
 }
 $4 = $1; //@line 80573
 _dsk_init($4, $1, $n, $c, $h, $s); //@line 80574
 _dsk_set_type($4, 2); //@line 80575
 _dsk_set_readonly($4, $ro); //@line 80576
 HEAP32[$1 + 4 >> 2] = 378; //@line 80579
 HEAP32[$1 + 8 >> 2] = 52; //@line 80582
 HEAP32[$1 + 12 >> 2] = 2; //@line 80585
 $12 = $1 + 28 | 0; //@line 80587
 $14 = HEAP32[$12 >> 2] << 9; //@line 80589
 $15 = _malloc($14) | 0; //@line 80590
 $17 = $1 + 68 | 0; //@line 80592
 HEAP32[$17 >> 2] = $15; //@line 80593
 if (($15 | 0) == 0) {
  _free($1); //@line 80597
  $_0 = 0; //@line 80599
  return $_0 | 0; //@line 80602
 }
 _memset($15 | 0, 0, $14 | 0); //@line 80604
 if (($fname | 0) == 0) {
  $_0 = $4; //@line 80608
  return $_0 | 0; //@line 80611
 }
 $23 = _fopen($fname | 0, 49160) | 0; //@line 80613
 do {
  if (($23 | 0) != 0) {
   $27$0 = HEAP32[$12 >> 2] | 0; //@line 80620
   $29 = _dsk_read($23, HEAP32[$17 >> 2] | 0, 0, 0, $27$0 << 9 | 0 >>> 23, 0 << 9 | $27$0 >>> 23) | 0; //@line 80626
   _fclose($23 | 0) | 0; //@line 80627
   if (($29 | 0) != 0) {
    break;
   }
   _dsk_set_fname($4, $fname); //@line 80633
   $_0 = $4; //@line 80635
   return $_0 | 0; //@line 80638
  }
 } while (0);
 _free(HEAP32[$17 >> 2] | 0); //@line 80642
 _free($1); //@line 80643
 $_0 = 0; //@line 80645
 return $_0 | 0; //@line 80648
}
function _dsk_ram_del($dsk) {
 $dsk = $dsk | 0;
 var $2 = 0;
 $2 = HEAP32[$dsk + 64 >> 2] | 0; //@line 80658
 _free(HEAP32[$2 + 68 >> 2] | 0); //@line 80662
 _free($2); //@line 80663
 return;
}
function _dsk_ram_read($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $12 = 0, $13 = 0, $_0 = 0;
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 80684
  return $_0 | 0; //@line 80687
 }
 $12 = (HEAP32[(HEAP32[$dsk + 64 >> 2] | 0) + 68 >> 2] | 0) + ($i << 9) | 0; //@line 80695
 $13 = $n << 9; //@line 80696
 _memcpy($buf | 0, $12 | 0, $13) | 0; //@line 80697
 $_0 = 0; //@line 80699
 return $_0 | 0; //@line 80702
}
function _dsk_ram_write($dsk, $buf, $i, $n) {
 $dsk = $dsk | 0;
 $buf = $buf | 0;
 $i = $i | 0;
 $n = $n | 0;
 var $16 = 0, $17 = 0, $_0 = 0;
 if ((HEAP8[$dsk + 56 | 0] | 0) != 0) {
  $_0 = 1; //@line 80720
  return $_0 | 0; //@line 80723
 }
 if (($n + $i | 0) >>> 0 > (HEAP32[$dsk + 28 >> 2] | 0) >>> 0) {
  $_0 = 1; //@line 80731
  return $_0 | 0; //@line 80734
 }
 $16 = (HEAP32[(HEAP32[$dsk + 64 >> 2] | 0) + 68 >> 2] | 0) + ($i << 9) | 0; //@line 80742
 $17 = $n << 9; //@line 80743
 _memcpy($16 | 0, $buf | 0, $17) | 0; //@line 80744
 $_0 = 0; //@line 80746
 return $_0 | 0; //@line 80749
}
function _pce_key_from_string($str) {
 $str = $str | 0;
 var $el_0 = 0, $3 = 0, $_0 = 0, label = 0;
 $el_0 = 7760; //@line 80760
 while (1) {
  $3 = HEAP32[$el_0 + 4 >> 2] | 0; //@line 80764
  if (($3 | 0) == 0) {
   $_0 = 0; //@line 80768
   label = 19547; //@line 80769
   break;
  }
  if ((_strcasecmp($3 | 0, $str | 0) | 0) == 0) {
   break;
  } else {
   $el_0 = $el_0 + 8 | 0; //@line 80779
  }
 }
 if ((label | 0) == 19547) {
  return $_0 | 0; //@line 80785
 }
 $_0 = HEAP32[$el_0 >> 2] | 0; //@line 80790
 return $_0 | 0; //@line 80793
}
function _pce_key_get_map($map, $src, $dst) {
 $map = $map | 0;
 $src = $src | 0;
 $dst = $dst | 0;
 var $val = 0, $_022 = 0, $2 = 0, $4 = 0, $i_030 = 0, $_129 = 0, $6 = 0, $7 = 0, $_2 = 0, $14 = 0, $_2_pn = 0, $_3 = 0, $_4 = 0, $el_0_i = 0, $23 = 0, $_0_i = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 80807
 STACKTOP = STACKTOP + 32 | 0; //@line 80807
 $val = sp | 0; //@line 80808
 $_022 = $map; //@line 80810
 while (1) {
  $2 = HEAP8[$_022] | 0; //@line 80813
  if (!(($2 << 24 >> 24 | 0) == 32 | ($2 << 24 >> 24 | 0) == 9)) {
   $_129 = $_022;
   $i_030 = 0;
   $4 = $2;
   break;
  }
  $_022 = $_022 + 1 | 0; //@line 80820
 }
 while (1) {
  if (($4 << 24 >> 24 | 0) == 0 | ($4 << 24 >> 24 | 0) == 61 | ($4 << 24 >> 24 | 0) == 32) {
   break;
  }
  $6 = $_129 + 1 | 0; //@line 80829
  $7 = $i_030 + 1 | 0; //@line 80830
  HEAP8[$val + $i_030 | 0] = $4; //@line 80832
  if ($7 >>> 0 >= 32) {
   $_0 = 1; //@line 80836
   label = 19567; //@line 80837
   break;
  }
  $_129 = $6;
  $i_030 = $7;
  $4 = HEAP8[$6] | 0;
 }
 if ((label | 0) == 19567) {
  STACKTOP = sp; //@line 80846
  return $_0 | 0; //@line 80847
 }
 if ($i_030 >>> 0 > 31) {
  $_0 = 1; //@line 80852
  STACKTOP = sp; //@line 80854
  return $_0 | 0; //@line 80855
 }
 HEAP8[$val + $i_030 | 0] = 0; //@line 80858
 $_2 = $_129; //@line 80860
 while (1) {
  $14 = HEAP8[$_2] | 0; //@line 80863
  if (($14 << 24 >> 24 | 0) == 61) {
   $_2_pn = $_2; //@line 80865
   label = 19559; //@line 80866
   break;
  } else if (($14 << 24 >> 24 | 0) != 32) {
   $_4 = $_2; //@line 80869
   break;
  }
  $_2 = $_2 + 1 | 0; //@line 80874
 }
 if ((label | 0) == 19559) {
  while (1) {
   label = 0; //@line 80878
   $_3 = $_2_pn + 1 | 0; //@line 80880
   if ((HEAP8[$_3] | 0) == 32) {
    $_2_pn = $_3; //@line 80885
    label = 19559; //@line 80886
   } else {
    $_4 = $_3; //@line 80888
    break;
   }
  }
 }
 HEAP32[$src >> 2] = _strtoul($val | 0, 0, 0) | 0; //@line 80896
 $el_0_i = 7760; //@line 80898
 while (1) {
  $23 = HEAP32[$el_0_i + 4 >> 2] | 0; //@line 80902
  if (($23 | 0) == 0) {
   $_0_i = 0; //@line 80906
   break;
  }
  if ((_strcasecmp($23 | 0, $_4 | 0) | 0) == 0) {
   label = 19563; //@line 80914
   break;
  } else {
   $el_0_i = $el_0_i + 8 | 0; //@line 80917
  }
 }
 if ((label | 0) == 19563) {
  $_0_i = HEAP32[$el_0_i >> 2] | 0; //@line 80924
 }
 HEAP32[$dst >> 2] = $_0_i; //@line 80927
 $_0 = 0; //@line 80929
 STACKTOP = sp; //@line 80931
 return $_0 | 0; //@line 80932
}
function _null_new($ini) {
 $ini = $ini | 0;
 var $1 = 0, $4 = 0, $_0 = 0;
 $1 = _malloc(152) | 0; //@line 80942
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 80946
  return $_0 | 0; //@line 80949
 }
 $4 = $1; //@line 80951
 _trm_init($4, $1); //@line 80952
 HEAP32[$1 + 28 >> 2] = 66; //@line 80955
 HEAP32[$1 + 32 >> 2] = 4; //@line 80958
 HEAP32[$1 + 36 >> 2] = 20; //@line 80961
 HEAP32[$1 + 40 >> 2] = 46; //@line 80964
 HEAP32[$1 + 44 >> 2] = 136; //@line 80967
 HEAP32[$1 + 48 >> 2] = 332; //@line 80970
 $_0 = $4; //@line 80972
 return $_0 | 0; //@line 80975
}
function _null_del($nt) {
 $nt = $nt | 0;
 if (($nt | 0) == 0) {
  return;
 }
 _free($nt); //@line 80991
 return;
}
function _trm_init($trm, $ext) {
 $trm = $trm | 0;
 $ext = $ext | 0;
 HEAP32[$trm >> 2] = $ext; //@line 81007
 _memset($trm + 4 | 0, 0, 28); //@line 81012
 _memset($trm + 40 | 0, 0, 16); //@line 81014
 HEAP32[$trm + 56 >> 2] = 1; //@line 81015
 _memset($trm + 60 | 0, 0, 20); //@line 81019
 HEAP32[$trm + 80 >> 2] = 1; //@line 81020
 HEAP32[$trm + 84 >> 2] = 4; //@line 81022
 HEAP32[$trm + 88 >> 2] = 3; //@line 81024
 HEAP32[$trm + 92 >> 2] = 320; //@line 81026
 HEAP32[$trm + 96 >> 2] = 240; //@line 81028
 HEAP32[$trm + 100 >> 2] = 1; //@line 81030
 HEAP32[$trm + 104 >> 2] = 1; //@line 81032
 HEAP32[$trm + 108 >> 2] = 0; //@line 81034
 HEAP32[$trm + 112 >> 2] = 1; //@line 81036
 HEAP32[$trm + 116 >> 2] = 1; //@line 81038
 _memset($trm + 120 | 0, 0, 32); //@line 81041
 return;
}
function _trm_open($trm, $w, $h) {
 $trm = $trm | 0;
 $w = $w | 0;
 $h = $h | 0;
 var $1 = 0, $6 = 0, $_0 = 0;
 $1 = $trm + 52 | 0; //@line 81055
 if ((HEAP32[$1 >> 2] | 0) != 0) {
  $_0 = 0; //@line 81060
  return $_0 | 0; //@line 81063
 }
 $6 = HEAP32[$trm + 32 >> 2] | 0; //@line 81066
 do {
  if (($6 | 0) != 0) {
   if ((FUNCTION_TABLE_iiii[$6 & 127](HEAP32[$trm >> 2] | 0, $w, $h) | 0) == 0) {
    break;
   } else {
    $_0 = 1; //@line 81079
   }
   return $_0 | 0; //@line 81083
  }
 } while (0);
 HEAP32[$1 >> 2] = 1; //@line 81086
 $_0 = 0; //@line 81088
 return $_0 | 0; //@line 81091
}
function _trm_screenshot($trm, $fname) {
 $trm = $trm | 0;
 $fname = $fname | 0;
 var $str = 0, $6 = 0, $7 = 0, $8 = 0, $_015 = 0, $13 = 0, $17 = 0, $20 = 0, $21 = 0, $25 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 81103
 STACKTOP = STACKTOP + 256 | 0; //@line 81103
 $str = sp | 0; //@line 81104
 if (($fname | 0) == 0) {
  label = 19590; //@line 81108
 } else {
  if ((HEAP8[$fname] | 0) == 0) {
   label = 19590; //@line 81114
  } else {
   $_015 = $fname; //@line 81116
  }
 }
 if ((label | 0) == 19590) {
  $6 = $str | 0; //@line 81120
  $7 = $trm + 148 | 0; //@line 81121
  $8 = HEAP32[$7 >> 2] | 0; //@line 81122
  _sprintf($6 | 0, 48496, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $8, tempInt) | 0) | 0; //@line 81123
  HEAP32[$7 >> 2] = (HEAP32[$7 >> 2] | 0) + 1; //@line 81126
  $_015 = $6; //@line 81128
 }
 $13 = _fopen($_015 | 0, 55624) | 0; //@line 81131
 if (($13 | 0) == 0) {
  $_0 = 1; //@line 81135
  STACKTOP = sp; //@line 81137
  return $_0 | 0; //@line 81138
 }
 $17 = HEAP32[$trm + 64 >> 2] | 0; //@line 81141
 $20 = HEAP32[$trm + 68 >> 2] | 0; //@line 81144
 $21 = Math_imul($17 * 3 | 0, $20) | 0; //@line 81145
 _fprintf($13 | 0, 49320, (tempInt = STACKTOP, STACKTOP = STACKTOP + 24 | 0, HEAP32[tempInt >> 2] = $17, HEAP32[tempInt + 8 >> 2] = $20, HEAP32[tempInt + 16 >> 2] = 255, tempInt) | 0) | 0; //@line 81146
 $25 = _fwrite(HEAP32[$trm + 76 >> 2] | 0, 1, $21 | 0, $13 | 0) | 0; //@line 81149
 _fclose($13 | 0) | 0; //@line 81150
 $_0 = ($25 | 0) != ($21 | 0) | 0; //@line 81154
 STACKTOP = sp; //@line 81156
 return $_0 | 0; //@line 81157
}
function _trm_set_msg_trm($trm, $msg, $val) {
 $trm = $trm | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $4 = 0, $15 = 0, $_0 = 0;
 if ((_strcmp($msg | 0, 45616) | 0) == 0) {
  $4 = _pce_key_from_string($val) | 0; //@line 81173
  if (($4 | 0) == 0) {
   $_0 = 0; //@line 81177
   return $_0 | 0; //@line 81180
  }
  HEAP32[$trm + 56 >> 2] = $4; //@line 81183
  $_0 = 0; //@line 81185
  return $_0 | 0; //@line 81188
 }
 if ((_strcmp($msg | 0, 42152) | 0) == 0) {
  _trm_screenshot($trm, $val) | 0; //@line 81194
  $_0 = 0; //@line 81196
  return $_0 | 0; //@line 81199
 }
 $15 = HEAP32[$trm + 40 >> 2] | 0; //@line 81202
 if (($15 | 0) == 0) {
  $_0 = -1; //@line 81206
  return $_0 | 0; //@line 81209
 }
 $_0 = FUNCTION_TABLE_iiii[$15 & 127](HEAP32[$trm >> 2] | 0, $msg, $val) | 0; //@line 81215
 return $_0 | 0; //@line 81218
}
function _trm_set_escape_str($trm, $str) {
 $trm = $trm | 0;
 $str = $str | 0;
 var $1 = 0, $_0 = 0;
 $1 = _pce_key_from_string($str) | 0; //@line 81228
 if (($1 | 0) == 0) {
  $_0 = 1; //@line 81232
  return $_0 | 0; //@line 81235
 }
 HEAP32[$trm + 56 >> 2] = $1; //@line 81238
 $_0 = 0; //@line 81240
 return $_0 | 0; //@line 81243
}
function _trm_set_min_size($trm, $w, $h) {
 $trm = $trm | 0;
 $w = $w | 0;
 $h = $h | 0;
 HEAP32[$trm + 92 >> 2] = $w; //@line 81255
 HEAP32[$trm + 96 >> 2] = $h; //@line 81257
 return;
}
function _trm_set_scale($trm, $v) {
 $trm = $trm | 0;
 $v = $v | 0;
 HEAP32[$trm + 80 >> 2] = ($v | 0) == 0 ? 1 : $v; //@line 81273
 HEAP32[$trm + 132 >> 2] = 0; //@line 81275
 HEAP32[$trm + 136 >> 2] = 0; //@line 81277
 HEAP32[$trm + 140 >> 2] = HEAP32[$trm + 64 >> 2]; //@line 81281
 HEAP32[$trm + 144 >> 2] = HEAP32[$trm + 68 >> 2]; //@line 81285
 return;
}
function _trm_set_aspect_ratio($trm, $x, $y) {
 $trm = $trm | 0;
 $x = $x | 0;
 $y = $y | 0;
 HEAP32[$trm + 84 >> 2] = $x; //@line 81299
 HEAP32[$trm + 88 >> 2] = $y; //@line 81301
 return;
}
function _trm_set_size($trm, $w, $h) {
 $trm = $trm | 0;
 $w = $w | 0;
 $h = $h | 0;
 var $9 = 0, $18 = 0, $19 = 0, $23 = 0, $25 = 0;
 if (($w | 0) == 0 | ($h | 0) == 0) {
  _free(HEAP32[$trm + 76 >> 2] | 0); //@line 81324
  _memset($trm + 64 | 0, 0, 16); //@line 81327
  return;
 }
 $9 = $trm + 64 | 0; //@line 81332
 do {
  if ((HEAP32[$9 >> 2] | 0) == ($w | 0)) {
   if ((HEAP32[$trm + 68 >> 2] | 0) != ($h | 0)) {
    break;
   }
   return;
  }
 } while (0);
 $18 = Math_imul($w * 3 | 0, $h) | 0; //@line 81350
 $19 = $trm + 72 | 0; //@line 81351
 do {
  if ((HEAP32[$19 >> 2] | 0) != ($18 | 0)) {
   $23 = $trm + 76 | 0; //@line 81357
   $25 = _realloc(HEAP32[$23 >> 2] | 0, $18) | 0; //@line 81359
   if (($25 | 0) == 0) {
    return;
   } else {
    HEAP32[$23 >> 2] = $25; //@line 81366
    HEAP32[$19 >> 2] = $18; //@line 81367
    break;
   }
  }
 } while (0);
 HEAP32[$9 >> 2] = $w; //@line 81373
 HEAP32[$trm + 68 >> 2] = $h; //@line 81375
 HEAP32[$trm + 132 >> 2] = 0; //@line 81377
 HEAP32[$trm + 136 >> 2] = 0; //@line 81379
 HEAP32[$trm + 140 >> 2] = $w; //@line 81381
 HEAP32[$trm + 144 >> 2] = $h; //@line 81383
 return;
}
function _trm_set_lines($trm, $buf, $y, $cnt) {
 $trm = $trm | 0;
 $buf = $buf | 0;
 $y = $y | 0;
 $cnt = $cnt | 0;
 var $1 = 0, $3 = 0, $5 = 0, $7 = 0, $dst_053 = 0, $src_052 = 0, $_051 = 0, $_04850 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $dst_0_lcssa = 0, $src_0_lcssa = 0, $_0_lcssa = 0, $_048_lcssa = 0, $_1 = 0, $tmp_0 = 0, $20 = 0, $27 = 0, $31 = 0, $32 = 0, $34 = 0, $37 = 0, $41 = 0, $43 = 0, $44 = 0, $45 = 0, label = 0;
 $1 = $trm + 64 | 0; //@line 81404
 $3 = (HEAP32[$1 >> 2] | 0) * 3 | 0; //@line 81406
 $5 = HEAP32[$trm + 76 >> 2] | 0; //@line 81408
 $7 = $5 + (Math_imul($3, $y) | 0) | 0; //@line 81410
 L25426 : do {
  if (($cnt | 0) == 0) {
   $_048_lcssa = 0;
   $_0_lcssa = $y;
   $src_0_lcssa = $buf;
   $dst_0_lcssa = $7;
  } else {
   $_04850 = $cnt;
   $_051 = $y;
   $src_052 = $buf;
   $dst_053 = $7;
   while (1) {
    if ((_memcmp($dst_053 | 0, $src_052 | 0, $3 | 0) | 0) != 0) {
     $_048_lcssa = $_04850;
     $_0_lcssa = $_051;
     $src_0_lcssa = $src_052;
     $dst_0_lcssa = $dst_053;
     break L25426;
    }
    $12 = $src_052 + $3 | 0; //@line 81430
    $13 = $dst_053 + $3 | 0; //@line 81431
    $14 = $_051 + 1 | 0; //@line 81432
    $15 = $_04850 - 1 | 0; //@line 81433
    if (($15 | 0) == 0) {
     $_048_lcssa = 0;
     $_0_lcssa = $14;
     $src_0_lcssa = $12;
     $dst_0_lcssa = $13;
     break;
    } else {
     $_04850 = $15;
     $_051 = $14;
     $src_052 = $12;
     $dst_053 = $13;
    }
   }
  }
 } while (0);
 $tmp_0 = Math_imul($_048_lcssa, $3) | 0;
 $_1 = $_048_lcssa;
 while (1) {
  if (($_1 | 0) == 0) {
   label = 19646; //@line 81458
   break;
  }
  $20 = $tmp_0 - $3 | 0; //@line 81461
  if ((_memcmp($dst_0_lcssa + $20 | 0, $src_0_lcssa + $20 | 0, $3 | 0) | 0) == 0) {
   $tmp_0 = $20;
   $_1 = $_1 - 1 | 0;
  } else {
   break;
  }
 }
 if ((label | 0) == 19646) {
  return;
 }
 $27 = Math_imul($_1, $3) | 0; //@line 81478
 _memcpy($dst_0_lcssa | 0, $src_0_lcssa | 0, $27) | 0; //@line 81479
 HEAP32[$trm + 132 >> 2] = 0; //@line 81481
 HEAP32[$trm + 140 >> 2] = HEAP32[$1 >> 2]; //@line 81484
 $31 = $trm + 144 | 0; //@line 81485
 $32 = HEAP32[$31 >> 2] | 0; //@line 81486
 $34 = $trm + 136 | 0; //@line 81488
 if (($32 | 0) == 0) {
  HEAP32[$34 >> 2] = $_0_lcssa; //@line 81491
  HEAP32[$31 >> 2] = $_1; //@line 81492
  return;
 }
 $37 = HEAP32[$34 >> 2] | 0; //@line 81497
 if ($_0_lcssa >>> 0 < $37 >>> 0) {
  $41 = $32 - $_0_lcssa + $37 | 0; //@line 81502
  HEAP32[$31 >> 2] = $41; //@line 81503
  HEAP32[$34 >> 2] = $_0_lcssa; //@line 81504
  $44 = $_0_lcssa;
  $43 = $41;
 } else {
  $44 = $37;
  $43 = $32;
 }
 $45 = $_1 + $_0_lcssa | 0; //@line 81512
 if ($45 >>> 0 <= ($43 + $44 | 0) >>> 0) {
  return;
 }
 HEAP32[$31 >> 2] = $45 - $44; //@line 81521
 return;
}
function _trm_update($trm) {
 $trm = $trm | 0;
 var $10 = 0;
 if ((HEAP32[$trm + 140 >> 2] | 0) == 0) {
  return;
 }
 if ((HEAP32[$trm + 144 >> 2] | 0) == 0) {
  return;
 }
 $10 = HEAP32[$trm + 44 >> 2] | 0; //@line 81551
 if (($10 | 0) != 0) {
  FUNCTION_TABLE_vi[$10 & 1023](HEAP32[$trm >> 2] | 0); //@line 81557
 }
 _memset($trm + 132 | 0, 0, 16); //@line 81562
 return;
}
function _trm_check($trm) {
 $trm = $trm | 0;
 var $2 = 0;
 $2 = HEAP32[$trm + 48 >> 2] | 0; //@line 81575
 if (($2 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_vi[$2 & 1023](HEAP32[$trm >> 2] | 0); //@line 81584
 return;
}
function _trm_set_msg_emu($trm, $msg, $val) {
 $trm = $trm | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $2 = 0, $_0 = 0;
 $2 = HEAP32[$trm + 8 >> 2] | 0; //@line 81599
 if (($2 | 0) == 0) {
  $_0 = 1; //@line 81603
  return $_0 | 0; //@line 81606
 }
 $_0 = FUNCTION_TABLE_iiii[$2 & 127](HEAP32[$trm + 4 >> 2] | 0, $msg, $val) | 0; //@line 81612
 return $_0 | 0; //@line 81615
}
function _trm_set_key($trm, $event, $key) {
 $trm = $trm | 0;
 $event = $event | 0;
 $key = $key | 0;
 var $4 = 0, $5 = 0, $6 = 0, $8 = 0, $9 = 0, $10 = 0, $17 = 0, $19 = 0, $24 = 0, $25 = 0, $28 = 0, $_pre37 = 0, $33 = 0, $36 = 0, $43 = 0, $48 = 0, $52 = 0, $54 = 0, $57 = 0, $58 = 0;
 do {
  if (($event | 0) == 1) {
   $4 = (HEAP32[$trm + 56 >> 2] | 0) == ($key | 0); //@line 81636
   $5 = $trm + 60 | 0; //@line 81637
   $6 = HEAP32[$5 >> 2] | 0; //@line 81638
   if ($4) {
    $8 = $6 ^ 1; //@line 81641
    HEAP32[$5 >> 2] = $8; //@line 81642
    $9 = $8; //@line 81644
   } else {
    $9 = $6; //@line 81646
   }
   $10 = $trm + 60 | 0; //@line 81649
   if (($9 & 1 | 0) != 0) {
    if ($4) {
     return;
    }
    _trm_set_key_emu($trm, 3, $key); //@line 81659
    return;
   }
   do {
    if (($key | 0) == 75) {
     $17 = $9 | 4; //@line 81666
     HEAP32[$10 >> 2] = $17; //@line 81667
     $43 = $17; //@line 81669
    } else if (($key | 0) == 71) {
     $19 = $9 | 8; //@line 81671
     HEAP32[$10 >> 2] = $19; //@line 81672
     $43 = $19; //@line 81674
    } else if (($key | 0) == 16) {
     if (($9 & 12 | 0) != 0) {
      $43 = $9; //@line 81680
      break;
     }
     $24 = $trm + 40 | 0; //@line 81683
     $25 = HEAP32[$24 >> 2] | 0; //@line 81684
     do {
      if (($25 | 0) != 0) {
       $28 = HEAP32[$trm >> 2] | 0; //@line 81690
       FUNCTION_TABLE_iiii[$25 & 127]($28, 39120, 62840) | 0; //@line 81691
       $_pre37 = HEAP32[$24 >> 2] | 0; //@line 81692
       if (($_pre37 | 0) == 0) {
        break;
       }
       $33 = HEAP32[$trm >> 2] | 0; //@line 81699
       FUNCTION_TABLE_iiii[$_pre37 & 127]($33, 33232, 31608) | 0; //@line 81700
      }
     } while (0);
     $36 = HEAP32[$trm + 8 >> 2] | 0; //@line 81705
     if (($36 | 0) == 0) {
      return;
     }
     FUNCTION_TABLE_iiii[$36 & 127](HEAP32[$trm + 4 >> 2] | 0, 30616, 57824) | 0; //@line 81714
     return;
    } else {
     $43 = $9; //@line 81719
    }
   } while (0);
   if (($43 & 12 | 0) != 12) {
    break;
   }
   $48 = HEAP32[$trm + 40 >> 2] | 0; //@line 81730
   if (($48 | 0) == 0) {
    $54 = $43; //@line 81734
   } else {
    $52 = HEAP32[$trm >> 2] | 0; //@line 81737
    FUNCTION_TABLE_iiii[$48 & 127]($52, 39120, 62840) | 0; //@line 81738
    $54 = HEAP32[$10 >> 2] | 0; //@line 81741
   }
   HEAP32[$10 >> 2] = $54 & -13; //@line 81745
  } else if (($event | 0) == 2) {
   $57 = $trm + 60 | 0; //@line 81748
   $58 = HEAP32[$57 >> 2] | 0; //@line 81749
   if (($58 & 1 | 0) == 0) {
    if (($key | 0) == 75) {
     HEAP32[$57 >> 2] = $58 & -5; //@line 81756
     break;
    } else if (($key | 0) == 71) {
     HEAP32[$57 >> 2] = $58 & -9; //@line 81761
     break;
    } else if (($key | 0) == 16) {
     return;
    } else {
     break;
    }
   } else {
    if ((HEAP32[$trm + 56 >> 2] | 0) == ($key | 0)) {
     return;
    }
    HEAP32[$57 >> 2] = $58 & -2; //@line 81780
    return;
   }
  }
 } while (0);
 _trm_set_key_emu($trm, $event, $key); //@line 81787
 return;
}
function _trm_set_key_emu($trm, $event, $key) {
 $trm = $trm | 0;
 $event = $event | 0;
 $key = $key | 0;
 var $5 = 0, $13 = 0, $21 = 0, $29 = 0, $37 = 0, $45 = 0, $53 = 0, $61 = 0, $69 = 0, $73 = 0, $77 = 0, $85 = 0, $92 = 0, $93 = 0, $95 = 0, $96 = 0, $_pre_i = 0, $100 = 0, $103 = 0, $111 = 0, $118 = 0, $119 = 0, $121 = 0, $122 = 0, $_pre68_i = 0, $126 = 0, $129 = 0, $137 = 0, $146 = 0, $148 = 0, $160 = 0, $161 = 0, $164 = 0, $177 = 0, $185 = 0, $192 = 0;
 do {
  if (($event | 0) == 3) {
   if (($key | 0) == 25) {
    $69 = HEAP32[$trm + 8 >> 2] | 0; //@line 81826
    if (($69 | 0) == 0) {
     return;
    }
    $73 = HEAP32[$trm + 4 >> 2] | 0; //@line 81834
    FUNCTION_TABLE_iiii[$69 & 127]($73, 56976, 51672) | 0; //@line 81835
    return;
   } else if (($key | 0) == 106 | ($key | 0) == 90) {
    $177 = HEAP32[$trm + 8 >> 2] | 0; //@line 81841
    if (($177 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$177 & 127](HEAP32[$trm + 4 >> 2] | 0, 48608, 48176) | 0; //@line 81850
    return;
   } else if (($key | 0) == 20) {
    $29 = HEAP32[$trm + 8 >> 2] | 0; //@line 81856
    if (($29 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$29 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 55176) | 0; //@line 81865
    return;
   } else if (($key | 0) == 35) {
    $137 = HEAP32[$trm + 8 >> 2] | 0; //@line 81871
    if (($137 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$137 & 127](HEAP32[$trm + 4 >> 2] | 0, 48992, 57824) | 0; //@line 81880
    return;
   } else if (($key | 0) == 47) {
    _trm_screenshot($trm, 0) | 0; //@line 81885
    return;
   } else if (($key | 0) == 105 | ($key | 0) == 87) {
    $146 = $trm + 80 | 0; //@line 81890
    $148 = (HEAP32[$146 >> 2] | 0) + 1 | 0; //@line 81892
    HEAP32[$146 >> 2] = ($148 | 0) == 0 ? 1 : $148; //@line 81895
    HEAP32[$trm + 132 >> 2] = 0; //@line 81897
    HEAP32[$trm + 136 >> 2] = 0; //@line 81899
    HEAP32[$trm + 140 >> 2] = HEAP32[$trm + 64 >> 2]; //@line 81903
    HEAP32[$trm + 144 >> 2] = HEAP32[$trm + 68 >> 2]; //@line 81907
    return;
   } else if (($key | 0) == 107 | ($key | 0) == 94) {
    $160 = $trm + 80 | 0; //@line 81912
    $161 = HEAP32[$160 >> 2] | 0; //@line 81913
    if ($161 >>> 0 <= 1) {
     return;
    }
    $164 = $161 - 1 | 0; //@line 81920
    HEAP32[$160 >> 2] = ($164 | 0) == 0 ? 1 : $164; //@line 81923
    HEAP32[$trm + 132 >> 2] = 0; //@line 81925
    HEAP32[$trm + 136 >> 2] = 0; //@line 81927
    HEAP32[$trm + 140 >> 2] = HEAP32[$trm + 64 >> 2]; //@line 81931
    HEAP32[$trm + 144 >> 2] = HEAP32[$trm + 68 >> 2]; //@line 81935
    return;
   } else if (($key | 0) == 65) {
    $92 = $trm + 40 | 0; //@line 81940
    $93 = HEAP32[$92 >> 2] | 0; //@line 81941
    do {
     if (($93 | 0) != 0) {
      $95 = $trm | 0; //@line 81946
      $96 = HEAP32[$95 >> 2] | 0; //@line 81947
      FUNCTION_TABLE_iiii[$93 & 127]($96, 39120, 62840) | 0; //@line 81948
      $_pre_i = HEAP32[$92 >> 2] | 0; //@line 81949
      if (($_pre_i | 0) == 0) {
       break;
      }
      $100 = HEAP32[$95 >> 2] | 0; //@line 81955
      FUNCTION_TABLE_iiii[$_pre_i & 127]($100, 33232, 31608) | 0; //@line 81956
     }
    } while (0);
    $103 = HEAP32[$trm + 8 >> 2] | 0; //@line 81961
    if (($103 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$103 & 127](HEAP32[$trm + 4 >> 2] | 0, 50368, 57824) | 0; //@line 81970
    return;
   } else if (($key | 0) == 18) {
    $13 = HEAP32[$trm + 8 >> 2] | 0; //@line 81976
    if (($13 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$13 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 57824) | 0; //@line 81985
    return;
   } else if (($key | 0) == 32) {
    $118 = $trm + 40 | 0; //@line 81990
    $119 = HEAP32[$118 >> 2] | 0; //@line 81991
    do {
     if (($119 | 0) != 0) {
      $121 = $trm | 0; //@line 81996
      $122 = HEAP32[$121 >> 2] | 0; //@line 81997
      FUNCTION_TABLE_iiii[$119 & 127]($122, 39120, 62840) | 0; //@line 81998
      $_pre68_i = HEAP32[$118 >> 2] | 0; //@line 81999
      if (($_pre68_i | 0) == 0) {
       break;
      }
      $126 = HEAP32[$121 >> 2] | 0; //@line 82005
      FUNCTION_TABLE_iiii[$_pre68_i & 127]($126, 33232, 31608) | 0; //@line 82006
     }
    } while (0);
    $129 = HEAP32[$trm + 8 >> 2] | 0; //@line 82011
    if (($129 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$129 & 127](HEAP32[$trm + 4 >> 2] | 0, 30616, 57824) | 0; //@line 82020
    return;
   } else if (($key | 0) == 24) {
    $61 = HEAP32[$trm + 8 >> 2] | 0; //@line 82026
    if (($61 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$61 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 52264) | 0; //@line 82035
    return;
   } else if (($key | 0) == 41) {
    $111 = HEAP32[$trm + 8 >> 2] | 0; //@line 82041
    if (($111 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$111 & 127](HEAP32[$trm + 4 >> 2] | 0, 49408, 62840) | 0; //@line 82050
    return;
   } else if (($key | 0) == 108 | ($key | 0) == 92) {
    $185 = HEAP32[$trm + 8 >> 2] | 0; //@line 82056
    if (($185 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$185 & 127](HEAP32[$trm + 4 >> 2] | 0, 48608, 47832) | 0; //@line 82065
    return;
   } else if (($key | 0) == 50) {
    $85 = HEAP32[$trm + 40 >> 2] | 0; //@line 82071
    if (($85 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$85 & 127](HEAP32[$trm >> 2] | 0, 50672, 62840) | 0; //@line 82080
    return;
   } else if (($key | 0) == 49) {
    $77 = HEAP32[$trm + 40 >> 2] | 0; //@line 82086
    if (($77 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$77 & 127](HEAP32[$trm >> 2] | 0, 51160, 62840) | 0; //@line 82095
    return;
   } else if (($key | 0) == 23) {
    $53 = HEAP32[$trm + 8 >> 2] | 0; //@line 82101
    if (($53 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$53 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 53152) | 0; //@line 82110
    return;
   } else if (($key | 0) == 22) {
    $45 = HEAP32[$trm + 8 >> 2] | 0; //@line 82116
    if (($45 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$45 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 53784) | 0; //@line 82125
    return;
   } else if (($key | 0) == 21) {
    $37 = HEAP32[$trm + 8 >> 2] | 0; //@line 82131
    if (($37 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$37 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 54440) | 0; //@line 82140
    return;
   } else if (($key | 0) == 27) {
    $5 = HEAP32[$trm + 8 >> 2] | 0; //@line 82146
    if (($5 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$5 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 31608) | 0; //@line 82155
    return;
   } else if (($key | 0) == 19) {
    $21 = HEAP32[$trm + 8 >> 2] | 0; //@line 82161
    if (($21 | 0) == 0) {
     return;
    }
    FUNCTION_TABLE_iiii[$21 & 127](HEAP32[$trm + 4 >> 2] | 0, 56976, 55824) | 0; //@line 82170
    return;
   } else {
    break;
   }
  }
 } while (0);
 $192 = HEAP32[$trm + 16 >> 2] | 0; //@line 82180
 if (($192 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viii[$192 & 63](HEAP32[$trm + 12 >> 2] | 0, $event, $key); //@line 82189
 return;
}
function _trm_set_mouse($trm, $dx, $dy, $but) {
 $trm = $trm | 0;
 $dx = $dx | 0;
 $dy = $dy | 0;
 $but = $but | 0;
 var $3 = 0, $4 = 0, $6 = 0, $8 = 0, $9 = 0, $14 = 0, $15 = 0, $17 = 0, $19 = 0, $20 = 0, $24 = 0;
 $3 = Math_imul(HEAP32[$trm + 100 >> 2] | 0, $dx) | 0; //@line 82209
 $4 = $trm + 108 | 0; //@line 82210
 $6 = $3 + (HEAP32[$4 >> 2] | 0) | 0; //@line 82212
 $8 = HEAP32[$trm + 104 >> 2] | 0; //@line 82214
 $9 = ($6 | 0) / ($8 | 0) | 0; //@line 82215
 HEAP32[$4 >> 2] = $6 - (Math_imul($9, $8) | 0); //@line 82218
 $14 = Math_imul(HEAP32[$trm + 112 >> 2] | 0, $dy) | 0; //@line 82221
 $15 = $trm + 120 | 0; //@line 82222
 $17 = $14 + (HEAP32[$15 >> 2] | 0) | 0; //@line 82224
 $19 = HEAP32[$trm + 116 >> 2] | 0; //@line 82226
 $20 = ($17 | 0) / ($19 | 0) | 0; //@line 82227
 HEAP32[$15 >> 2] = $17 - (Math_imul($20, $19) | 0); //@line 82230
 $24 = HEAP32[$trm + 24 >> 2] | 0; //@line 82232
 if (($24 | 0) == 0) {
  return;
 }
 FUNCTION_TABLE_viiii[$24 & 7](HEAP32[$trm + 20 >> 2] | 0, $9, $20, $but); //@line 82241
 return;
}
function _trm_get_scale($trm, $w, $h, $fx, $fy) {
 $trm = $trm | 0;
 $w = $w | 0;
 $h = $h | 0;
 $fx = $fx | 0;
 $fy = $fy | 0;
 var $2 = 0, $3 = 0, $f_0 = 0, $8 = 0, $12 = 0, $14 = 0, $17 = 0, $18 = 0, $19 = 0, $22 = 0, $23 = 0, $27 = 0, $28 = 0, $30 = 0, $32 = 0, $33 = 0, $35 = 0, $37 = 0, $38 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $_lcssa = 0, $w2_0_lcssa = 0, $53 = 0;
 $2 = HEAP32[$trm + 92 >> 2] | 0; //@line 82264
 $3 = $trm + 96 | 0; //@line 82265
 $f_0 = 1; //@line 82267
 while (1) {
  if ((Math_imul($f_0, $w) | 0) >>> 0 >= $2 >>> 0) {
   break;
  }
  $8 = Math_imul($f_0, $h) | 0; //@line 82276
  if ($8 >>> 0 < (HEAP32[$3 >> 2] | 0) >>> 0) {
   $f_0 = $f_0 + 1 | 0; //@line 82281
  } else {
   break;
  }
 }
 $12 = $trm + 80 | 0; //@line 82286
 $14 = $f_0 - 1 | 0; //@line 82288
 HEAP32[$fx >> 2] = $14 + (HEAP32[$12 >> 2] | 0); //@line 82290
 $17 = $14 + (HEAP32[$12 >> 2] | 0) | 0; //@line 82292
 HEAP32[$fy >> 2] = $17; //@line 82293
 $18 = $trm + 84 | 0; //@line 82294
 $19 = HEAP32[$18 >> 2] | 0; //@line 82295
 if (($19 | 0) == 0) {
  return;
 }
 $22 = $trm + 88 | 0; //@line 82302
 $23 = HEAP32[$22 >> 2] | 0; //@line 82303
 if (($23 | 0) == 0) {
  return;
 }
 $27 = Math_imul(HEAP32[$fx >> 2] | 0, $w) | 0; //@line 82311
 $28 = Math_imul($17, $h) | 0; //@line 82312
 $30 = ((Math_imul($28, $19) | 0) >>> 0) / ($23 >>> 0) | 0; //@line 82314
 $32 = ((Math_imul($27, $23) | 0) >>> 0) / ($19 >>> 0) | 0; //@line 82316
 $33 = $28 + $h | 0; //@line 82317
 if ($33 >>> 0 <= $32 >>> 0) {
  $38 = $33;
  $37 = $17;
  do {
   $37 = $37 + 1 | 0; //@line 82325
   $38 = $38 + $h | 0; //@line 82326
  } while ($38 >>> 0 <= $32 >>> 0);
  HEAP32[$fy >> 2] = $37; //@line 82335
 }
 $35 = $27 + $w | 0; //@line 82338
 if ($35 >>> 0 > $30 >>> 0) {
  $w2_0_lcssa = $27;
  $_lcssa = $35;
 } else {
  $44 = $35;
  $43 = HEAP32[$fx >> 2] | 0;
  while (1) {
   $45 = $43 + 1 | 0; //@line 82350
   $46 = $44 + $w | 0; //@line 82351
   if ($46 >>> 0 > $30 >>> 0) {
    break;
   } else {
    $44 = $46;
    $43 = $45;
   }
  }
  HEAP32[$fx >> 2] = $45; //@line 82360
  $w2_0_lcssa = $44;
  $_lcssa = $46;
 }
 if ($w2_0_lcssa >>> 0 >= $30 >>> 0) {
  return;
 }
 $53 = Math_imul(HEAP32[$22 >> 2] | 0, $_lcssa - $30 | 0) | 0; //@line 82374
 if ($53 >>> 0 >= (Math_imul(HEAP32[$18 >> 2] | 0, $30 - $w2_0_lcssa | 0) | 0) >>> 0) {
  return;
 }
 HEAP32[$fx >> 2] = (HEAP32[$fx >> 2] | 0) + 1; //@line 82386
 return;
}
function _trm_scale($trm, $src, $w, $h, $fx, $fy) {
 $trm = $trm | 0;
 $src = $src | 0;
 $w = $w | 0;
 $h = $h | 0;
 $fx = $fx | 0;
 $fy = $fy | 0;
 var $1 = 0, $4 = 0, $7 = 0, $8 = 0, $11 = 0, $12 = 0, $14 = 0, $_0_i31 = 0, $19 = 0, $22 = 0, $25 = 0, $_023_us_pn_i = 0, $i_019_us_i = 0, $_121_us_i = 0, $28 = 0, $y_024_us_i = 0, $_023_us_i = 0, $_01722_us_i = 0, $y_024_i = 0, $_023_i = 0, $_01722_i = 0, $31 = 0, $36 = 0, $39 = 0, $40 = 0, $41 = 0, $scevgep61_sum_i = 0, $_2_lcssa_us_i = 0, $43 = 0, $_233_us_i = 0, $i_032_us_i = 0, $45 = 0, $47 = 0, $x_030_us_i26 = 0, $_129_us_i27 = 0, $_12728_us_i = 0, $51 = 0, $54 = 0, $65 = 0, $scevgep_i28 = 0, $scevgep61_i = 0, $y_038_us_i = 0, $_037_us_i = 0, $_02636_us_i = 0, $67 = 0, $_233_us45_i = 0, $i_032_us46_i = 0, $70 = 0, $72 = 0, $y_038_us41_i = 0, $75 = 0, $76 = 0, $78 = 0, $79 = 0, $80 = 0, $81 = 0, $84 = 0, $85 = 0, $86 = 0, $y_040_i = 0, $_039_i = 0, $_02238_i = 0, $89 = 0, $_225_us_i = 0, $i_024_us_i = 0, $98 = 0, $x_030_us_i = 0, $_129_us_i = 0, $_12327_us_i = 0, $100 = 0, $101 = 0, $split31_i = 0, $_1_lcssa_i = 0, $_123_lcssa_i = 0, $_334_i = 0, $j_033_i = 0, $102 = 0, $104 = 0, $_3_lcssa_i = 0, $107 = 0, $_0 = 0;
 $1 = ($fx | 0) == 1; //@line 82420
 if ($1 & ($fy | 0) == 1) {
  $_0 = $src; //@line 82425
  return $_0 | 0; //@line 82428
 }
 $4 = Math_imul($fx, $w) | 0; //@line 82430
 $7 = Math_imul(Math_imul($h * 3 | 0, $4) | 0, $fy) | 0; //@line 82433
 $8 = $trm + 124 | 0; //@line 82434
 $11 = $trm + 128 | 0; //@line 82437
 $12 = HEAP32[$11 >> 2] | 0; //@line 82438
 do {
  if ($7 >>> 0 > (HEAP32[$8 >> 2] | 0) >>> 0) {
   $14 = _realloc($12, $7) | 0; //@line 82442
   if (($14 | 0) == 0) {
    $_0 = 0; //@line 82446
    return $_0 | 0; //@line 82449
   } else {
    HEAP32[$11 >> 2] = $14; //@line 82451
    HEAP32[$8 >> 2] = $7; //@line 82452
    $_0_i31 = $14; //@line 82454
    break;
   }
  } else {
   if (($12 | 0) == 0) {
    $_0 = 0; //@line 82461
   } else {
    $_0_i31 = $12; //@line 82463
    break;
   }
   return $_0 | 0; //@line 82468
  }
 } while (0);
 if ($1) {
  $19 = $w * 3 | 0; //@line 82474
  if (($h | 0) == 0) {
   $_0 = $_0_i31; //@line 82478
   return $_0 | 0; //@line 82481
  }
  if ($fy >>> 0 <= 1) {
   $_01722_i = $src;
   $_023_i = $_0_i31;
   $y_024_i = 0;
   while (1) {
    _memcpy($_023_i | 0, $_01722_i | 0, $19) | 0; //@line 82490
    $31 = $y_024_i + 1 | 0; //@line 82493
    if ($31 >>> 0 < $h >>> 0) {
     $_01722_i = $_01722_i + $19 | 0;
     $_023_i = $_023_i + $19 | 0;
     $y_024_i = $31;
    } else {
     $_0 = $_0_i31; //@line 82499
     break;
    }
   }
   return $_0 | 0; //@line 82505
  }
  $22 = Math_imul($19, $fy) | 0; //@line 82507
  $_01722_us_i = $src;
  $_023_us_i = $_0_i31;
  $y_024_us_i = 0;
  while (1) {
   _memcpy($_023_us_i | 0, $_01722_us_i | 0, $19) | 0; //@line 82514
   $i_019_us_i = 1;
   $_023_us_pn_i = $_023_us_i;
   while (1) {
    $_121_us_i = $_023_us_pn_i + $19 | 0; //@line 82520
    _memcpy($_121_us_i | 0, $_023_us_pn_i | 0, $19) | 0; //@line 82521
    $28 = $i_019_us_i + 1 | 0; //@line 82522
    if ($28 >>> 0 < $fy >>> 0) {
     $i_019_us_i = $28;
     $_023_us_pn_i = $_121_us_i;
    } else {
     break;
    }
   }
   $25 = $y_024_us_i + 1 | 0; //@line 82533
   if ($25 >>> 0 < $h >>> 0) {
    $_01722_us_i = $_01722_us_i + $19 | 0;
    $_023_us_i = $_023_us_i + $22 | 0;
    $y_024_us_i = $25;
   } else {
    $_0 = $_0_i31; //@line 82539
    break;
   }
  }
  return $_0 | 0; //@line 82545
 }
 if (($fx | 0) != 2) {
  $75 = $w * 3 | 0; //@line 82550
  $76 = Math_imul($75, $fx) | 0; //@line 82551
  if (($h | 0) == 0) {
   $_0 = $_0_i31; //@line 82555
   return $_0 | 0; //@line 82558
  }
  $78 = ($w | 0) == 0; //@line 82560
  $79 = ($fx | 0) == 0; //@line 82561
  $80 = $fy >>> 0 > 1; //@line 82562
  $81 = -$76 | 0; //@line 82563
  $84 = Math_imul(($fy * 3 | 0) - 3 | 0, $4) | 0; //@line 82566
  $85 = $fx * 3 | 0; //@line 82567
  $86 = $4 * 3 | 0; //@line 82568
  $_02238_i = $src;
  $_039_i = $_0_i31;
  $y_040_i = 0;
  while (1) {
   if ($78) {
    $_123_lcssa_i = $_02238_i;
    $_1_lcssa_i = $_039_i;
   } else {
    if ($79) {
     $split31_i = $_039_i; //@line 82580
    } else {
     $_12327_us_i = $_02238_i;
     $_129_us_i = $_039_i;
     $x_030_us_i = 0;
     while (1) {
      $100 = $_12327_us_i + 1 | 0; //@line 82587
      $101 = $_12327_us_i + 2 | 0; //@line 82588
      $i_024_us_i = 0;
      $_225_us_i = $_129_us_i;
      while (1) {
       HEAP8[$_225_us_i] = HEAP8[$_12327_us_i] | 0; //@line 82595
       HEAP8[$_225_us_i + 1 | 0] = HEAP8[$100] | 0; //@line 82598
       HEAP8[$_225_us_i + 2 | 0] = HEAP8[$101] | 0; //@line 82601
       $98 = $i_024_us_i + 1 | 0; //@line 82603
       if ($98 >>> 0 < $fx >>> 0) {
        $i_024_us_i = $98;
        $_225_us_i = $_225_us_i + 3 | 0;
       } else {
        break;
       }
      }
      $89 = $x_030_us_i + 1 | 0; //@line 82614
      if ($89 >>> 0 < $w >>> 0) {
       $_12327_us_i = $_12327_us_i + 3 | 0;
       $_129_us_i = $_129_us_i + $85 | 0;
       $x_030_us_i = $89;
      } else {
       break;
      }
     }
     $split31_i = $_039_i + $86 | 0; //@line 82624
    }
    $_123_lcssa_i = $_02238_i + $75 | 0;
    $_1_lcssa_i = $split31_i;
   }
   if ($80) {
    $j_033_i = 1;
    $_334_i = $_1_lcssa_i;
    while (1) {
     $102 = $_334_i + $81 | 0; //@line 82639
     _memcpy($_334_i | 0, $102 | 0, $76) | 0; //@line 82640
     $104 = $j_033_i + 1 | 0; //@line 82642
     if ($104 >>> 0 < $fy >>> 0) {
      $j_033_i = $104;
      $_334_i = $_334_i + $76 | 0;
     } else {
      break;
     }
    }
    $_3_lcssa_i = $_1_lcssa_i + $84 | 0; //@line 82653
   } else {
    $_3_lcssa_i = $_1_lcssa_i; //@line 82655
   }
   $107 = $y_040_i + 1 | 0; //@line 82658
   if ($107 >>> 0 < $h >>> 0) {
    $_02238_i = $_123_lcssa_i;
    $_039_i = $_3_lcssa_i;
    $y_040_i = $107;
   } else {
    $_0 = $_0_i31; //@line 82664
    break;
   }
  }
  return $_0 | 0; //@line 82670
 }
 $36 = $w * 6 | 0; //@line 82672
 if (($h | 0) == 0) {
  $_0 = $_0_i31; //@line 82676
  return $_0 | 0; //@line 82679
 }
 $39 = $fy >>> 0 > 1; //@line 82682
 $40 = -$36 | 0; //@line 82683
 if (($w | 0) == 0) {
  if ($39) {
   $y_038_us41_i = 0; //@line 82686
  } else {
   $_0 = $_0_i31; //@line 82688
   return $_0 | 0; //@line 82691
  }
  while (1) {
   $i_032_us46_i = 1;
   $_233_us45_i = $_0_i31;
   while (1) {
    $70 = $_233_us45_i + $40 | 0; //@line 82700
    _memcpy($_233_us45_i | 0, $70 | 0, $36) | 0; //@line 82701
    $72 = $i_032_us46_i + 1 | 0; //@line 82703
    if ($72 >>> 0 < $fy >>> 0) {
     $i_032_us46_i = $72;
     $_233_us45_i = $_233_us45_i + $36 | 0;
    } else {
     break;
    }
   }
   $67 = $y_038_us41_i + 1 | 0; //@line 82712
   if ($67 >>> 0 < $h >>> 0) {
    $y_038_us41_i = $67; //@line 82716
   } else {
    $_0 = $_0_i31; //@line 82718
    break;
   }
  }
  return $_0 | 0; //@line 82724
 }
 $41 = $w * 3 | 0; //@line 82726
 $scevgep61_sum_i = Math_imul($36, $fy) | 0; //@line 82727
 $_02636_us_i = $src;
 $_037_us_i = $_0_i31;
 $y_038_us_i = 0;
 while (1) {
  $_12728_us_i = $_02636_us_i;
  $_129_us_i27 = $_037_us_i;
  $x_030_us_i26 = 0;
  while (1) {
   HEAP8[$_129_us_i27] = HEAP8[$_12728_us_i] | 0; //@line 82741
   $51 = $_12728_us_i + 1 | 0; //@line 82742
   HEAP8[$_129_us_i27 + 1 | 0] = HEAP8[$51] | 0; //@line 82745
   $54 = $_12728_us_i + 2 | 0; //@line 82746
   HEAP8[$_129_us_i27 + 2 | 0] = HEAP8[$54] | 0; //@line 82749
   HEAP8[$_129_us_i27 + 3 | 0] = HEAP8[$_12728_us_i] | 0; //@line 82752
   HEAP8[$_129_us_i27 + 4 | 0] = HEAP8[$51] | 0; //@line 82755
   HEAP8[$_129_us_i27 + 5 | 0] = HEAP8[$54] | 0; //@line 82758
   $65 = $x_030_us_i26 + 1 | 0; //@line 82761
   if ($65 >>> 0 < $w >>> 0) {
    $_12728_us_i = $_12728_us_i + 3 | 0;
    $_129_us_i27 = $_129_us_i27 + 6 | 0;
    $x_030_us_i26 = $65;
   } else {
    break;
   }
  }
  $scevgep_i28 = $_02636_us_i + $41 | 0; //@line 82770
  $scevgep61_i = $_037_us_i + $36 | 0; //@line 82771
  if ($39) {
   $i_032_us_i = 1;
   $_233_us_i = $scevgep61_i;
   while (1) {
    $45 = $_233_us_i + $40 | 0; //@line 82778
    _memcpy($_233_us_i | 0, $45 | 0, $36) | 0; //@line 82779
    $47 = $i_032_us_i + 1 | 0; //@line 82781
    if ($47 >>> 0 < $fy >>> 0) {
     $i_032_us_i = $47;
     $_233_us_i = $_233_us_i + $36 | 0;
    } else {
     break;
    }
   }
   $_2_lcssa_us_i = $_037_us_i + $scevgep61_sum_i | 0; //@line 82792
  } else {
   $_2_lcssa_us_i = $scevgep61_i; //@line 82794
  }
  $43 = $y_038_us_i + 1 | 0; //@line 82797
  if ($43 >>> 0 < $h >>> 0) {
   $_02636_us_i = $scevgep_i28;
   $_037_us_i = $_2_lcssa_us_i;
   $y_038_us_i = $43;
  } else {
   $_0 = $_0_i31; //@line 82803
   break;
  }
 }
 return $_0 | 0; //@line 82809
}
function _sdl_new($sct) {
 $sct = $sct | 0;
 var $sdlkey_i_i = 0, $pcekey_i_i = 0, $fs_i = 0, $rep_i = 0, $1 = 0, $6 = 0, $26 = 0, $28 = 0, $46 = 0, $48 = 0, $49 = 0, $50 = 0, $52 = 0, $54 = 0, $_pre_i_pre_i = 0, $55 = 0, $58 = 0, $59 = 0, $60$1 = 0, $61 = 0, $65 = 0, $67 = 0, $68 = 0, $70 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $i_0_i_i_i = 0, $93 = 0, $94 = 0, $97 = 0, $_0 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 82831
 STACKTOP = STACKTOP + 32 | 0; //@line 82831
 $sdlkey_i_i = sp | 0; //@line 82832
 $pcekey_i_i = sp + 8 | 0; //@line 82833
 $fs_i = sp + 16 | 0; //@line 82834
 $rep_i = sp + 24 | 0; //@line 82835
 $1 = _malloc(208) | 0; //@line 82836
 if (($1 | 0) == 0) {
  $_0 = 0; //@line 82840
  STACKTOP = sp; //@line 82842
  return $_0 | 0; //@line 82843
 }
 $6 = $1; //@line 82847
 _trm_init($6, $1); //@line 82848
 HEAP32[$1 + 28 >> 2] = 56; //@line 82851
 HEAP32[$1 + 32 >> 2] = 52; //@line 82854
 HEAP32[$1 + 36 >> 2] = 6; //@line 82857
 HEAP32[$1 + 40 >> 2] = 28; //@line 82860
 HEAP32[$1 + 44 >> 2] = 330; //@line 82863
 HEAP32[$1 + 48 >> 2] = 364; //@line 82866
 _memset($1 + 152 | 0, 0, 16); //@line 82868
 _ini_get_bool($sct, 48296, $fs_i, 0) | 0; //@line 82869
 HEAP8[$1 + 168 | 0] = (HEAP32[$fs_i >> 2] | 0) != 0 | 0; //@line 82874
 $26 = $1 + 180 | 0; //@line 82876
 _ini_get_uint16($sct, 55592, $26, 0) | 0; //@line 82877
 $28 = HEAP32[$26 >> 2] | 0; //@line 82878
 HEAP32[$1 + 184 >> 2] = $28; //@line 82881
 HEAP32[$1 + 188 >> 2] = $28; //@line 82884
 HEAP32[$1 + 192 >> 2] = $28; //@line 82887
 HEAP8[$1 + 196 | 0] = 0; //@line 82889
 HEAP32[$1 + 172 >> 2] = 0; //@line 82892
 HEAP32[$1 + 176 >> 2] = 0; //@line 82895
 _ini_get_bool($sct, 49272, $rep_i, 0) | 0; //@line 82896
 HEAP8[$1 + 197 | 0] = (HEAP32[$rep_i >> 2] | 0) != 0 | 0; //@line 82901
 $46 = $1 + 200 | 0; //@line 82903
 HEAP32[$46 >> 2] = 0; //@line 82904
 $48 = $1 + 204 | 0; //@line 82906
 $49 = _malloc(888) | 0; //@line 82907
 $50 = $49; //@line 82908
 HEAP32[$48 >> 2] = $50; //@line 82909
 if (($49 | 0) != 0) {
  $52 = $49; //@line 82913
  HEAP32[$52 >> 2] = 27; //@line 82917
  HEAP32[$52 + 4 >> 2] = 1; //@line 82919
  $54 = $49 + 8 | 0; //@line 82921
  HEAP32[$54 >> 2] = 1082; //@line 82925
  HEAP32[$54 + 4 >> 2] = 2; //@line 82927
  $55 = 2;
  $_pre_i_pre_i = $50;
  while (1) {
   $58 = 9952 + ($55 << 3) | 0; //@line 82935
   $59 = $_pre_i_pre_i + ($55 << 3) | 0; //@line 82936
   $60$1 = HEAP32[$58 + 4 >> 2] | 0; //@line 82940
   HEAP32[$59 >> 2] = HEAP32[$58 >> 2]; //@line 82942
   HEAP32[$59 + 4 >> 2] = $60$1; //@line 82944
   $61 = $55 + 1 | 0; //@line 82945
   if ($61 >>> 0 >= 111) {
    break;
   }
   $55 = $61;
   $_pre_i_pre_i = HEAP32[$48 >> 2] | 0;
  }
  HEAP32[$46 >> 2] = 111; //@line 82955
 }
 $65 = _ini_next_val($sct, 0, 45584) | 0; //@line 82960
 if (($65 | 0) == 0) {
  $_0 = $6; //@line 82964
  STACKTOP = sp; //@line 82966
  return $_0 | 0; //@line 82967
 } else {
  $67 = $65; //@line 82969
 }
 while (1) {
  $68 = _ini_val_get_str($67) | 0; //@line 82973
  do {
   if (($68 | 0) != 0) {
    if ((_pce_key_get_map($68, $sdlkey_i_i, $pcekey_i_i) | 0) != 0) {
     break;
    }
    $76 = HEAP32[$sdlkey_i_i >> 2] | 0; //@line 82984
    $77 = HEAP32[$pcekey_i_i >> 2] | 0; //@line 82985
    $78 = HEAP32[$46 >> 2] | 0; //@line 82986
    $79 = HEAP32[$48 >> 2] | 0; //@line 82987
    $i_0_i_i_i = 0; //@line 82989
    while (1) {
     if ($i_0_i_i_i >>> 0 >= $78 >>> 0) {
      break;
     }
     if ((HEAP32[$79 + ($i_0_i_i_i << 3) >> 2] | 0) == ($76 | 0)) {
      label = 19882; //@line 83003
      break;
     } else {
      $i_0_i_i_i = $i_0_i_i_i + 1 | 0; //@line 83006
     }
    }
    if ((label | 0) == 19882) {
     label = 0; //@line 83010
     HEAP32[$79 + ($i_0_i_i_i << 3) + 4 >> 2] = $77; //@line 83012
     break;
    }
    $93 = _realloc($79, ($78 << 3) + 8 | 0) | 0; //@line 83019
    $94 = $93; //@line 83020
    if (($93 | 0) == 0) {
     break;
    }
    $97 = HEAP32[$46 >> 2] | 0; //@line 83026
    HEAP32[$94 + ($97 << 3) >> 2] = $76; //@line 83028
    HEAP32[$94 + ($97 << 3) + 4 >> 2] = $77; //@line 83030
    HEAP32[$48 >> 2] = $94; //@line 83031
    HEAP32[$46 >> 2] = $97 + 1; //@line 83033
   }
  } while (0);
  $70 = _ini_next_val($sct, $67, 45584) | 0; //@line 83037
  if (($70 | 0) == 0) {
   $_0 = $6; //@line 83041
   break;
  } else {
   $67 = $70; //@line 83044
  }
 }
 STACKTOP = sp; //@line 83048
 return $_0 | 0; //@line 83049
}
function _sdl_del($sdl) {
 $sdl = $sdl | 0;
 _free($sdl); //@line 83059
 return;
}
function _sdl_open($sdl, $w, $h) {
 $sdl = $sdl | 0;
 $w = $w | 0;
 $h = $h | 0;
 var $fx = 0, $fy = 0, $or_cond = 0, $_016 = 0, $_015 = 0, $8 = 0, $13 = 0, $29 = 0, $32 = 0, $_0 = 0, sp = 0;
 sp = STACKTOP; //@line 83075
 STACKTOP = STACKTOP + 16 | 0; //@line 83075
 $fx = sp | 0; //@line 83076
 $fy = sp + 8 | 0; //@line 83077
 $or_cond = ($w | 0) == 0 | ($h | 0) == 0; //@line 83080
 $_016 = $or_cond ? 480 : $h; //@line 83081
 $_015 = $or_cond ? 640 : $w; //@line 83082
 _trm_get_scale($sdl | 0, $_015, $_016, $fx, $fy); //@line 83084
 $8 = (HEAP32[$sdl + 188 >> 2] | 0) + (HEAP32[$sdl + 180 >> 2] | 0) | 0; //@line 83089
 $13 = (HEAP32[$sdl + 192 >> 2] | 0) + (HEAP32[$sdl + 184 >> 2] | 0) | 0; //@line 83094
 do {
  if ((_SDL_WasInit(32) | 0) == 0) {
   if ((_SDL_InitSubSystem(32) | 0) < 0) {
    $_0 = 1; //@line 83104
   } else {
    break;
   }
   STACKTOP = sp; //@line 83109
   return $_0 | 0; //@line 83110
  }
 } while (0);
 HEAP32[$sdl + 172 >> 2] = HEAPU8[(HEAP32[(_SDL_GetVideoInfo() | 0) + 8 >> 2] | 0) + 9 | 0] | 0; //@line 83120
 HEAP32[$sdl + 176 >> 2] = 0; //@line 83122
 _SDL_WM_SetCaption(52256, 52256); //@line 83123
 _SDL_EnableKeyRepeat(500, 30) | 0; //@line 83124
 $29;
 $32 = $8 + (Math_imul(HEAP32[$fx >> 2] | 0, $_015) | 0) | 0; //@line 83128
 _sdl_set_window_size($sdl, $32, $13 + (Math_imul(HEAP32[$fy >> 2] | 0, $_016) | 0) | 0) | 0; //@line 83132
 $_0 = 0; //@line 83134
 STACKTOP = sp; //@line 83136
 return $_0 | 0; //@line 83137
}
function _sdl_close($sdl) {
 $sdl = $sdl | 0;
 var $3 = 0, $4 = 0, $5 = 0;
 HEAP8[$sdl + 196 | 0] = 0; //@line 83147
 _SDL_ShowCursor(1) | 0; //@line 83148
 $3;
 $4 = $sdl + 152 | 0; //@line 83150
 $5 = HEAP32[$4 >> 2] | 0; //@line 83151
 if (($5 | 0) == 0) {
  return 0; //@line 83156
 }
 _SDL_FreeSurface($5 | 0); //@line 83158
 HEAP32[$4 >> 2] = 0; //@line 83159
 return 0; //@line 83162
}
function _sdl_set_msg_trm($sdl, $msg, $val) {
 $sdl = $sdl | 0;
 $msg = $msg | 0;
 $val = $val | 0;
 var $_val = 0, $7 = 0, $14 = 0, $23 = 0, $39 = 0, $41 = 0, $43 = 0, $54 = 0, $55 = 0, $60 = 0, $_0 = 0;
 $_val = ($val | 0) == 0 ? 62832 : $val; //@line 83180
 if ((_strcmp($msg | 0, 57808) | 0) == 0) {
  HEAP8[$sdl + 196 | 0] = 1; //@line 83186
  _SDL_ShowCursor(0) | 0; //@line 83187
  $7;
  $_0 = 0; //@line 83190
  return $_0 | 0; //@line 83193
 }
 if ((_strcmp($msg | 0, 56960) | 0) == 0) {
  HEAP8[$sdl + 196 | 0] = 0; //@line 83200
  _SDL_ShowCursor(1) | 0; //@line 83201
  $14;
  $_0 = 0; //@line 83204
  return $_0 | 0; //@line 83207
 }
 if ((_strcmp($msg | 0, 55808) | 0) == 0) {
  _SDL_WM_SetCaption($_val | 0, $_val | 0); //@line 83213
  $_0 = 0; //@line 83215
  return $_0 | 0; //@line 83218
 }
 if ((_strcmp($msg | 0, 55152) | 0) == 0) {
  $23 = _strtoul($_val | 0, 0, 0) | 0; //@line 83224
  HEAP32[$sdl + 180 >> 2] = $23; //@line 83226
  HEAP32[$sdl + 188 >> 2] = $23; //@line 83228
  _sdl_update($sdl); //@line 83229
  $_0 = 0; //@line 83231
  return $_0 | 0; //@line 83234
 }
 if ((_strcmp($msg | 0, 54416) | 0) == 0) {
  HEAP32[$sdl + 184 >> 2] = _strtoul($_val | 0, 0, 0) | 0; //@line 83242
  HEAP32[$sdl + 192 >> 2] = HEAP32[$sdl + 180 >> 2]; //@line 83246
  _sdl_update($sdl); //@line 83247
  $_0 = 0; //@line 83249
  return $_0 | 0; //@line 83252
 }
 if ((_strcmp($msg | 0, 53760) | 0) == 0) {
  $39 = $sdl + 168 | 0; //@line 83258
  $41 = (HEAP8[$39] | 0) == 0; //@line 83260
  $43 = HEAP32[$sdl + 152 >> 2] | 0; //@line 83262
  if (($43 | 0) != 0) {
   _SDL_WM_ToggleFullScreen($43 | 0) | 0; //@line 83266
  }
  HEAP8[$39] = $41 & 1; //@line 83270
  $_0 = 0; //@line 83272
  return $_0 | 0; //@line 83275
 }
 if ((_strcmp($msg | 0, 53136) | 0) != 0) {
  $_0 = -1; //@line 83281
  return $_0 | 0; //@line 83284
 }
 $54 = (_strtol($_val | 0, 0, 0) | 0) != 0; //@line 83287
 $55 = $sdl + 168 | 0; //@line 83288
 if (!($54 ^ (HEAP8[$55] | 0) != 0)) {
  $_0 = 0; //@line 83294
  return $_0 | 0; //@line 83297
 }
 $60 = HEAP32[$sdl + 152 >> 2] | 0; //@line 83300
 if (($60 | 0) != 0) {
  _SDL_WM_ToggleFullScreen($60 | 0) | 0; //@line 83304
 }
 HEAP8[$55] = $54 & 1; //@line 83308
 $_0 = 0; //@line 83310
 return $_0 | 0; //@line 83313
}
function _sdl_update($sdl) {
 $sdl = $sdl | 0;
 var $dst = 0, $fx = 0, $fy = 0, $1 = 0, $2 = 0, $4 = 0, $8 = 0, $11 = 0, $12 = 0, $16 = 0, $33 = 0, $34 = 0, $37 = 0, $38 = 0, $41 = 0, $44 = 0, $47 = 0, $53 = 0, $62 = 0, $67 = 0, sp = 0;
 sp = STACKTOP; //@line 83329
 STACKTOP = STACKTOP + 32 | 0; //@line 83329
 $dst = sp | 0; //@line 83330
 $fx = sp + 16 | 0; //@line 83331
 $fy = sp + 24 | 0; //@line 83332
 $1 = $sdl | 0; //@line 83333
 $2 = $sdl + 64 | 0; //@line 83334
 $4 = $sdl + 68 | 0; //@line 83336
 _trm_get_scale($1, HEAP32[$2 >> 2] | 0, HEAP32[$4 >> 2] | 0, $fx, $fy); //@line 83338
 $8 = Math_imul(HEAP32[$2 >> 2] | 0, HEAP32[$fx >> 2] | 0) | 0; //@line 83341
 $11 = Math_imul(HEAP32[$4 >> 2] | 0, HEAP32[$fy >> 2] | 0) | 0; //@line 83344
 $12 = $sdl + 180 | 0; //@line 83345
 $16 = $sdl + 184 | 0; //@line 83349
 if ((_sdl_set_window_size($sdl, (HEAP32[$12 >> 2] | 0) + $8 + (HEAP32[$sdl + 188 >> 2] | 0) | 0, (HEAP32[$16 >> 2] | 0) + $11 + (HEAP32[$sdl + 192 >> 2] | 0) | 0) | 0) != 0) {
  STACKTOP = sp; //@line 83361
  return;
 }
 $33 = _trm_scale($1, HEAP32[$sdl + 76 >> 2] | 0, HEAP32[$2 >> 2] | 0, HEAP32[$4 >> 2] | 0, HEAP32[$fx >> 2] | 0, HEAP32[$fy >> 2] | 0) | 0; //@line 83370
 $34 = HEAP32[$fx >> 2] | 0; //@line 83371
 $37 = Math_imul(HEAP32[$sdl + 132 >> 2] | 0, $34) | 0; //@line 83374
 $38 = HEAP32[$fy >> 2] | 0; //@line 83375
 $41 = Math_imul(HEAP32[$sdl + 136 >> 2] | 0, $38) | 0; //@line 83378
 $44 = Math_imul(HEAP32[$sdl + 140 >> 2] | 0, $34) | 0; //@line 83381
 $47 = Math_imul(HEAP32[$sdl + 144 >> 2] | 0, $38) | 0; //@line 83384
 $53 = _SDL_CreateRGBSurfaceFrom($33 + (((Math_imul($41, $8) | 0) + $37 | 0) * 3 | 0) | 0, $44 | 0, $47 | 0, 24, $8 * 3 | 0 | 0, 255, 65280, 16711680, 0) | 0; //@line 83390
 HEAP32[$dst >> 2] = (HEAP32[$12 >> 2] | 0) + $37; //@line 83394
 HEAP32[$dst + 4 >> 2] = (HEAP32[$16 >> 2] | 0) + $41; //@line 83398
 if (($53 | 0) == 0) {
  STACKTOP = sp; //@line 83402
  return;
 }
 $62 = $sdl + 152 | 0; //@line 83405
 if ((_SDL_UpperBlit($53 | 0, 0, HEAP32[$62 >> 2] | 0, $dst | 0) | 0) != 0) {
  $67 = HEAP32[_stderr >> 2] | 0; //@line 83411
  _fwrite(31568, 16, 1, $67 | 0) | 0; //@line 83412
 }
 _SDL_FreeSurface($53 | 0); //@line 83415
 _SDL_Flip(HEAP32[$62 >> 2] | 0) | 0; //@line 83417
 STACKTOP = sp; //@line 83419
 return;
}
function _sdl_check($sdl) {
 $sdl = $sdl | 0;
 var $evt = 0, $3 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $16 = 0, $17 = 0, $18 = 0, $20 = 0, $22 = 0, $i_019 = 0, $24 = 0, $26 = 0, $33 = 0, $37 = 0, $46 = 0, $i_0_i_i = 0, $49 = 0, $52 = 0, $58 = 0, $61 = 0, $62 = 0, $68 = 0, $69 = 0, $i_0_i_i8 = 0, $73 = 0, $79 = 0, $86 = 0, $87 = 0, $_0_i = 0, $93 = 0, $101 = 0, $102 = 0, $_0_i14 = 0, $109 = 0, $114 = 0, $120 = 0, $121 = 0, $129 = 0, $130 = 0, $136 = 0, label = 0, sp = 0;
 sp = STACKTOP; //@line 83443
 STACKTOP = STACKTOP + 48 | 0; //@line 83443
 $evt = sp | 0; //@line 83444
 if ((_SDL_PollEvent($evt | 0) | 0) == 0) {
  STACKTOP = sp; //@line 83449
  return;
 }
 $3 = $evt | 0; //@line 83452
 $5 = $evt + 16 | 0; //@line 83454
 $6 = $sdl + 200 | 0; //@line 83455
 $7 = $sdl + 204 | 0; //@line 83456
 $8 = $sdl + 197 | 0; //@line 83457
 $9 = $sdl | 0; //@line 83458
 $11 = $evt + 20 | 0; //@line 83460
 $12 = $sdl + 196 | 0; //@line 83461
 $13 = $sdl + 168 | 0; //@line 83462
 $14 = $sdl + 152 | 0; //@line 83463
 $16 = $evt + 8 | 0; //@line 83465
 $17 = $sdl + 164 | 0; //@line 83466
 $18 = $sdl + 24 | 0; //@line 83467
 $20 = $evt + 20 | 0; //@line 83469
 $22 = $evt + 24 | 0; //@line 83471
 $i_019 = 0; //@line 83473
 do {
  $24 = HEAP32[$3 >> 2] | 0; //@line 83476
  L25832 : do {
   if (($24 | 0) == 769) {
    $68 = HEAP32[$5 >> 2] | 0; //@line 83479
    $69 = HEAP32[$6 >> 2] | 0; //@line 83480
    $i_0_i_i8 = 0; //@line 83482
    while (1) {
     if ($i_0_i_i8 >>> 0 >= $69 >>> 0) {
      break L25832;
     }
     $73 = HEAP32[$7 >> 2] | 0; //@line 83490
     if ((HEAP32[$73 + ($i_0_i_i8 << 3) >> 2] | 0) == ($68 | 0)) {
      break;
     } else {
      $i_0_i_i8 = $i_0_i_i8 + 1 | 0; //@line 83499
     }
    }
    $79 = HEAP32[$73 + ($i_0_i_i8 << 3) + 4 >> 2] | 0; //@line 83503
    if (($68 | 0) == 1094 | ($79 | 0) == 0) {
     break;
    }
    if (($68 | 0) == 1107) {
     _trm_set_key($9, 1, $79); //@line 83514
    }
    _trm_set_key($9, 2, $79); //@line 83517
   } else if (($24 | 0) == 1025) {
    $86 = HEAP8[$16] | 0; //@line 83520
    $87 = $86 & 255; //@line 83521
    if (($87 | 0) == 2) {
     $_0_i = 2; //@line 83523
    } else if (($87 | 0) == 0) {
     break;
    } else {
     $_0_i = $86 << 24 >> 24 == 3 ? 1 : $87 - 1 | 0; //@line 83531
    }
    $93 = HEAP32[$17 >> 2] | 1 << $_0_i; //@line 83536
    HEAP32[$17 >> 2] = $93; //@line 83537
    if ((HEAP8[$12] | 0) == 0) {
     break;
    }
    if ((HEAP32[$18 >> 2] | 0) == 0) {
     break;
    }
    _trm_set_mouse($9, 0, 0, $93); //@line 83550
   } else if (($24 | 0) == 1024) {
    $120 = HEAP32[$20 >> 2] | 0; //@line 83553
    $121 = HEAP32[$22 >> 2] | 0; //@line 83554
    if ((HEAP8[$12] | 0) == 0) {
     break;
    }
    if ((HEAP32[$18 >> 2] | 0) == 0) {
     break;
    }
    $129 = (_SDL_GetMouseState(0, 0) | 0) & 255; //@line 83568
    $130 = $129 & 1; //@line 83569
    _trm_set_mouse($9, $120, $121, ($129 & 4 | 0) == 0 ? $130 : $130 | 2); //@line 83574
   } else if (($24 | 0) == 1026) {
    $101 = HEAP8[$16] | 0; //@line 83577
    $102 = $101 & 255; //@line 83578
    if (($102 | 0) == 2) {
     $_0_i14 = 2; //@line 83580
    } else if (($102 | 0) == 0) {
     break;
    } else {
     $_0_i14 = $101 << 24 >> 24 == 3 ? 1 : $102 - 1 | 0; //@line 83588
    }
    $109 = HEAP32[$17 >> 2] & ~(1 << $_0_i14); //@line 83594
    HEAP32[$17 >> 2] = $109; //@line 83595
    if ((HEAP8[$12] | 0) == 0) {
     HEAP8[$12] = 1; //@line 83600
     _SDL_ShowCursor(0) | 0; //@line 83601
     $114;
     break;
    }
    if ((HEAP32[$18 >> 2] | 0) == 0) {
     break;
    }
    _trm_set_mouse($9, 0, 0, $109); //@line 83612
   } else if (($24 | 0) == 256) {
    HEAP8[$12] = 0; //@line 83615
    _SDL_ShowCursor(1) | 0; //@line 83616
    $136;
    _trm_set_msg_emu($9, 42112, 39096) | 0; //@line 83618
   } else if (($24 | 0) == 768) {
    $26 = HEAP32[$5 >> 2] | 0; //@line 83621
    if (($26 | 0) == 96) {
     label = 19943; //@line 83623
    } else if (($26 | 0) == 1094) {
     _trm_screenshot($9, 0) | 0; //@line 83625
     break;
    }
    do {
     if ((label | 0) == 19943) {
      label = 0; //@line 83631
      if ((HEAP16[$11 >> 1] & 64) == 0) {
       break;
      }
      HEAP8[$12] = 0; //@line 83639
      _SDL_ShowCursor(1) | 0; //@line 83640
      $33;
      if ((HEAP8[$13] | 0) != 0) {
       $37 = HEAP32[$14 >> 2] | 0; //@line 83646
       if (($37 | 0) != 0) {
        _SDL_WM_ToggleFullScreen($37 | 0) | 0; //@line 83650
       }
       HEAP8[$13] = 0; //@line 83653
      }
      _trm_set_msg_emu($9, 36160, 39096) | 0; //@line 83656
      break L25832;
     }
    } while (0);
    $46 = HEAP32[$6 >> 2] | 0; //@line 83661
    $i_0_i_i = 0; //@line 83663
    while (1) {
     if ($i_0_i_i >>> 0 >= $46 >>> 0) {
      label = 19952; //@line 83669
      break;
     }
     $52 = HEAP32[$7 >> 2] | 0; //@line 83672
     if ((HEAP32[$52 + ($i_0_i_i << 3) >> 2] | 0) == ($26 | 0)) {
      break;
     } else {
      $i_0_i_i = $i_0_i_i + 1 | 0; //@line 83681
     }
    }
    if ((label | 0) == 19952) {
     label = 0; //@line 83685
     $49 = HEAP32[_stderr >> 2] | 0; //@line 83686
     _fprintf($49 | 0, 33192, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $26, tempInt) | 0) | 0; //@line 83687
     break;
    }
    $58 = HEAP32[$52 + ($i_0_i_i << 3) + 4 >> 2] | 0; //@line 83692
    $61 = ($58 | 0) == 0; //@line 83695
    if ((HEAP8[$8] | 0) != 0 | $61) {
     $62 = HEAP32[_stderr >> 2] | 0; //@line 83699
     _fprintf($62 | 0, 33192, (tempInt = STACKTOP, STACKTOP = STACKTOP + 8 | 0, HEAP32[tempInt >> 2] = $26, tempInt) | 0) | 0; //@line 83700
     if ($61) {
      break;
     }
    }
    _trm_set_key($9, 1, $58); //@line 83706
    if (($26 | 0) != 1107) {
     break;
    }
    _trm_set_key($9, 2, $58); //@line 83712
   }
  } while (0);
  $i_019 = $i_019 + 1 | 0; //@line 83716
 } while ((_SDL_PollEvent($evt | 0) | 0) != 0 & $i_019 >>> 0 < 8);
 STACKTOP = sp; //@line 83728
 return;
}
function _sdl_set_window_size($sdl, $w, $h) {
 $sdl = $sdl | 0;
 $w = $w | 0;
 $h = $h | 0;
 var $1 = 0, $2 = 0, $_ = 0, $18 = 0, $20 = 0, $23 = 0, $26 = 0, $28 = 0, $_0 = 0, label = 0;
 $1 = $sdl + 152 | 0; //@line 83743
 $2 = HEAP32[$1 >> 2] | 0; //@line 83744
 if (($2 | 0) != 0) {
  do {
   if ((HEAP32[$sdl + 156 >> 2] | 0) == ($w | 0)) {
    if ((HEAP32[$sdl + 160 >> 2] | 0) == ($h | 0)) {
     $_0 = 0; //@line 83759
    } else {
     break;
    }
    return $_0 | 0; //@line 83765
   }
  } while (0);
  _SDL_FreeSurface($2 | 0); //@line 83768
 }
 HEAP32[$1 >> 2] = 0; //@line 83771
 $_ = (HEAP8[$sdl + 168 | 0] | 0) == 0 ? 134217729 : 142606337; //@line 83775
 $18 = HEAP32[$sdl + 172 >> 2] | 0; //@line 83777
 if (($18 | 0) == 4) {
  $23 = _SDL_SetVideoMode($w | 0, $h | 0, 32, $_ | 0) | 0; //@line 83779
  HEAP32[$1 >> 2] = $23; //@line 83780
  HEAP32[$sdl + 176 >> 2] = 4; //@line 83782
  $26 = $23; //@line 83784
  label = 19991; //@line 83785
 } else if (($18 | 0) == 2) {
  $20 = _SDL_SetVideoMode($w | 0, $h | 0, 16, $_ | 0) | 0; //@line 83787
  HEAP32[$1 >> 2] = $20; //@line 83788
  HEAP32[$sdl + 176 >> 2] = 2; //@line 83790
  $26 = $20; //@line 83792
  label = 19991; //@line 83793
 } else {
  label = 19992; //@line 83795
 }
 if ((label | 0) == 19991) {
  if (($26 | 0) == 0) {
   label = 19992; //@line 83802
  }
 }
 do {
  if ((label | 0) == 19992) {
   $28 = _SDL_SetVideoMode($w | 0, $h | 0, 16, $_ | 0) | 0; //@line 83807
   HEAP32[$1 >> 2] = $28; //@line 83808
   HEAP32[$sdl + 176 >> 2] = 2; //@line 83810
   if (($28 | 0) == 0) {
    $_0 = 1; //@line 83814
   } else {
    break;
   }
   return $_0 | 0; //@line 83820
  }
 } while (0);
 HEAP32[$sdl + 156 >> 2] = $w; //@line 83824
 HEAP32[$sdl + 160 >> 2] = $h; //@line 83826
 $_0 = 0; //@line 83828
 return $_0 | 0; //@line 83831
}
function _malloc($bytes) {
 $bytes = $bytes | 0;
 var $8 = 0, $9 = 0, $10 = 0, $11 = 0, $17 = 0, $18 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $35 = 0, $40 = 0, $45 = 0, $56 = 0, $59 = 0, $62 = 0, $64 = 0, $65 = 0, $67 = 0, $69 = 0, $71 = 0, $73 = 0, $75 = 0, $77 = 0, $79 = 0, $82 = 0, $83 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $100 = 0, $105 = 0, $106 = 0, $109 = 0, $111 = 0, $117 = 0, $120 = 0, $121 = 0, $122 = 0, $124 = 0, $125 = 0, $126 = 0, $132 = 0, $133 = 0, $_pre_phi = 0, $F4_0 = 0, $145 = 0, $150 = 0, $152 = 0, $153 = 0, $155 = 0, $157 = 0, $159 = 0, $161 = 0, $163 = 0, $165 = 0, $167 = 0, $172 = 0, $rsize_0_i = 0, $v_0_i = 0, $t_0_i = 0, $179 = 0, $183 = 0, $185 = 0, $189 = 0, $190 = 0, $192 = 0, $193 = 0, $196 = 0, $197 = 0, $201 = 0, $203 = 0, $207 = 0, $211 = 0, $215 = 0, $220 = 0, $221 = 0, $224 = 0, $225 = 0, $RP_0_i = 0, $R_0_i = 0, $227 = 0, $228 = 0, $231 = 0, $232 = 0, $R_1_i = 0, $242 = 0, $244 = 0, $258 = 0, $274 = 0, $286 = 0, $300 = 0, $304 = 0, $315 = 0, $318 = 0, $319 = 0, $320 = 0, $322 = 0, $323 = 0, $324 = 0, $330 = 0, $331 = 0, $_pre_phi_i = 0, $F1_0_i = 0, $342 = 0, $348 = 0, $349 = 0, $350 = 0, $353 = 0, $354 = 0, $361 = 0, $362 = 0, $365 = 0, $367 = 0, $370 = 0, $375 = 0, $idx_0_i = 0, $383 = 0, $391 = 0, $rst_0_i = 0, $sizebits_0_i = 0, $t_0_i116 = 0, $rsize_0_i117 = 0, $v_0_i118 = 0, $396 = 0, $397 = 0, $rsize_1_i = 0, $v_1_i = 0, $403 = 0, $406 = 0, $rst_1_i = 0, $t_1_i = 0, $rsize_2_i = 0, $v_2_i = 0, $414 = 0, $417 = 0, $422 = 0, $424 = 0, $425 = 0, $427 = 0, $429 = 0, $431 = 0, $433 = 0, $435 = 0, $437 = 0, $439 = 0, $t_2_ph_i = 0, $v_330_i = 0, $rsize_329_i = 0, $t_228_i = 0, $449 = 0, $450 = 0, $_rsize_3_i = 0, $t_2_v_3_i = 0, $452 = 0, $455 = 0, $v_3_lcssa_i = 0, $rsize_3_lcssa_i = 0, $463 = 0, $464 = 0, $467 = 0, $468 = 0, $472 = 0, $474 = 0, $478 = 0, $482 = 0, $486 = 0, $491 = 0, $492 = 0, $495 = 0, $496 = 0, $RP_0_i119 = 0, $R_0_i120 = 0, $498 = 0, $499 = 0, $502 = 0, $503 = 0, $R_1_i122 = 0, $513 = 0, $515 = 0, $529 = 0, $545 = 0, $557 = 0, $571 = 0, $575 = 0, $586 = 0, $589 = 0, $591 = 0, $592 = 0, $593 = 0, $599 = 0, $600 = 0, $_pre_phi_i128 = 0, $F5_0_i = 0, $612 = 0, $613 = 0, $620 = 0, $621 = 0, $624 = 0, $626 = 0, $629 = 0, $634 = 0, $I7_0_i = 0, $641 = 0, $648 = 0, $649 = 0, $668 = 0, $T_0_i = 0, $K12_0_i = 0, $677 = 0, $678 = 0, $694 = 0, $695 = 0, $697 = 0, $711 = 0, $nb_0 = 0, $714 = 0, $717 = 0, $718 = 0, $721 = 0, $736 = 0, $743 = 0, $746 = 0, $747 = 0, $748 = 0, $762 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $779 = 0, $782 = 0, $783 = 0, $791 = 0, $794 = 0, $sp_0_i_i = 0, $796 = 0, $797 = 0, $800 = 0, $806 = 0, $809 = 0, $812 = 0, $813 = 0, $814 = 0, $ssize_0_i = 0, $824 = 0, $825 = 0, $829 = 0, $835 = 0, $836 = 0, $840 = 0, $843 = 0, $847 = 0, $ssize_1_i = 0, $br_0_i = 0, $tsize_0_i = 0, $tbase_0_i = 0, $849 = 0, $856 = 0, $860 = 0, $ssize_2_i = 0, $tsize_0303639_i = 0, $tsize_1_i = 0, $876 = 0, $877 = 0, $881 = 0, $883 = 0, $_tbase_1_i = 0, $tbase_245_i = 0, $tsize_244_i = 0, $886 = 0, $890 = 0, $893 = 0, $i_02_i_i = 0, $899 = 0, $901 = 0, $908 = 0, $914 = 0, $917 = 0, $sp_067_i = 0, $925 = 0, $926 = 0, $927 = 0, $932 = 0, $939 = 0, $944 = 0, $946 = 0, $947 = 0, $949 = 0, $955 = 0, $958 = 0, $968 = 0, $sp_160_i = 0, $970 = 0, $975 = 0, $982 = 0, $986 = 0, $993 = 0, $996 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $_sum_i21_i = 0, $1009 = 0, $1010 = 0, $1011 = 0, $1019 = 0, $1028 = 0, $_sum2_i23_i = 0, $1037 = 0, $1041 = 0, $1042 = 0, $1047 = 0, $1050 = 0, $1053 = 0, $1076 = 0, $_pre_phi57_i_i = 0, $1081 = 0, $1084 = 0, $1087 = 0, $1092 = 0, $1097 = 0, $1101 = 0, $_sum67_i_i = 0, $1107 = 0, $1108 = 0, $1112 = 0, $1113 = 0, $RP_0_i_i = 0, $R_0_i_i = 0, $1115 = 0, $1116 = 0, $1119 = 0, $1120 = 0, $R_1_i_i = 0, $1132 = 0, $1134 = 0, $1148 = 0, $_sum3233_i_i = 0, $1165 = 0, $1178 = 0, $qsize_0_i_i = 0, $oldfirst_0_i_i = 0, $1194 = 0, $1202 = 0, $1205 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $1215 = 0, $1216 = 0, $_pre_phi_i25_i = 0, $F4_0_i_i = 0, $1228 = 0, $1229 = 0, $1236 = 0, $1237 = 0, $1240 = 0, $1242 = 0, $1245 = 0, $1250 = 0, $I7_0_i_i = 0, $1257 = 0, $1264 = 0, $1265 = 0, $1284 = 0, $T_0_i27_i = 0, $K8_0_i_i = 0, $1293 = 0, $1294 = 0, $1310 = 0, $1311 = 0, $1313 = 0, $1327 = 0, $sp_0_i_i_i = 0, $1330 = 0, $1334 = 0, $1335 = 0, $1341 = 0, $1348 = 0, $1349 = 0, $1353 = 0, $1354 = 0, $1358 = 0, $1364 = 0, $1367 = 0, $1377 = 0, $1380 = 0, $1381 = 0, $1389 = 0, $1392 = 0, $1398 = 0, $1401 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1411 = 0, $1412 = 0, $_pre_phi_i_i = 0, $F_0_i_i = 0, $1422 = 0, $1423 = 0, $1430 = 0, $1431 = 0, $1434 = 0, $1436 = 0, $1439 = 0, $1444 = 0, $I1_0_i_i = 0, $1451 = 0, $1455 = 0, $1456 = 0, $1471 = 0, $T_0_i_i = 0, $K2_0_i_i = 0, $1480 = 0, $1481 = 0, $1494 = 0, $1495 = 0, $1497 = 0, $1507 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $mem_0 = 0, label = 0;
 do {
  if ($bytes >>> 0 < 245) {
   if ($bytes >>> 0 < 11) {
    $8 = 16; //@line 84024
   } else {
    $8 = $bytes + 11 & -8; //@line 84028
   }
   $9 = $8 >>> 3; //@line 84031
   $10 = HEAP32[15730] | 0; //@line 84032
   $11 = $10 >>> ($9 >>> 0); //@line 84033
   if (($11 & 3 | 0) != 0) {
    $17 = ($11 & 1 ^ 1) + $9 | 0; //@line 84039
    $18 = $17 << 1; //@line 84040
    $20 = 62960 + ($18 << 2) | 0; //@line 84042
    $21 = 62960 + ($18 + 2 << 2) | 0; //@line 84044
    $22 = HEAP32[$21 >> 2] | 0; //@line 84045
    $23 = $22 + 8 | 0; //@line 84046
    $24 = HEAP32[$23 >> 2] | 0; //@line 84047
    do {
     if (($20 | 0) == ($24 | 0)) {
      HEAP32[15730] = $10 & ~(1 << $17); //@line 84054
     } else {
      if ($24 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
       _abort(); //@line 84060
       return 0; //@line 84060
      }
      $35 = $24 + 12 | 0; //@line 84063
      if ((HEAP32[$35 >> 2] | 0) == ($22 | 0)) {
       HEAP32[$35 >> 2] = $20; //@line 84067
       HEAP32[$21 >> 2] = $24; //@line 84068
       break;
      } else {
       _abort(); //@line 84071
       return 0; //@line 84071
      }
     }
    } while (0);
    $40 = $17 << 3; //@line 84076
    HEAP32[$22 + 4 >> 2] = $40 | 3; //@line 84079
    $45 = $22 + ($40 | 4) | 0; //@line 84083
    HEAP32[$45 >> 2] = HEAP32[$45 >> 2] | 1; //@line 84086
    $mem_0 = $23; //@line 84088
    return $mem_0 | 0; //@line 84091
   }
   if ($8 >>> 0 <= (HEAP32[15732] | 0) >>> 0) {
    $nb_0 = $8; //@line 84096
    break;
   }
   if (($11 | 0) != 0) {
    $56 = 2 << $9; //@line 84102
    $59 = $11 << $9 & ($56 | -$56); //@line 84105
    $62 = ($59 & -$59) - 1 | 0; //@line 84108
    $64 = $62 >>> 12 & 16; //@line 84110
    $65 = $62 >>> ($64 >>> 0); //@line 84111
    $67 = $65 >>> 5 & 8; //@line 84113
    $69 = $65 >>> ($67 >>> 0); //@line 84115
    $71 = $69 >>> 2 & 4; //@line 84117
    $73 = $69 >>> ($71 >>> 0); //@line 84119
    $75 = $73 >>> 1 & 2; //@line 84121
    $77 = $73 >>> ($75 >>> 0); //@line 84123
    $79 = $77 >>> 1 & 1; //@line 84125
    $82 = ($67 | $64 | $71 | $75 | $79) + ($77 >>> ($79 >>> 0)) | 0; //@line 84128
    $83 = $82 << 1; //@line 84129
    $85 = 62960 + ($83 << 2) | 0; //@line 84131
    $86 = 62960 + ($83 + 2 << 2) | 0; //@line 84133
    $87 = HEAP32[$86 >> 2] | 0; //@line 84134
    $88 = $87 + 8 | 0; //@line 84135
    $89 = HEAP32[$88 >> 2] | 0; //@line 84136
    do {
     if (($85 | 0) == ($89 | 0)) {
      HEAP32[15730] = $10 & ~(1 << $82); //@line 84143
     } else {
      if ($89 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
       _abort(); //@line 84149
       return 0; //@line 84149
      }
      $100 = $89 + 12 | 0; //@line 84152
      if ((HEAP32[$100 >> 2] | 0) == ($87 | 0)) {
       HEAP32[$100 >> 2] = $85; //@line 84156
       HEAP32[$86 >> 2] = $89; //@line 84157
       break;
      } else {
       _abort(); //@line 84160
       return 0; //@line 84160
      }
     }
    } while (0);
    $105 = $82 << 3; //@line 84165
    $106 = $105 - $8 | 0; //@line 84166
    HEAP32[$87 + 4 >> 2] = $8 | 3; //@line 84169
    $109 = $87; //@line 84170
    $111 = $109 + $8 | 0; //@line 84172
    HEAP32[$109 + ($8 | 4) >> 2] = $106 | 1; //@line 84177
    HEAP32[$109 + $105 >> 2] = $106; //@line 84180
    $117 = HEAP32[15732] | 0; //@line 84181
    if (($117 | 0) != 0) {
     $120 = HEAP32[15735] | 0; //@line 84184
     $121 = $117 >>> 3; //@line 84185
     $122 = $121 << 1; //@line 84186
     $124 = 62960 + ($122 << 2) | 0; //@line 84188
     $125 = HEAP32[15730] | 0; //@line 84189
     $126 = 1 << $121; //@line 84190
     do {
      if (($125 & $126 | 0) == 0) {
       HEAP32[15730] = $125 | $126; //@line 84196
       $F4_0 = $124;
       $_pre_phi = 62960 + ($122 + 2 << 2) | 0;
      } else {
       $132 = 62960 + ($122 + 2 << 2) | 0; //@line 84202
       $133 = HEAP32[$132 >> 2] | 0; //@line 84203
       if ($133 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
        $F4_0 = $133;
        $_pre_phi = $132;
        break;
       }
       _abort(); //@line 84211
       return 0; //@line 84211
      }
     } while (0);
     HEAP32[$_pre_phi >> 2] = $120; //@line 84217
     HEAP32[$F4_0 + 12 >> 2] = $120; //@line 84219
     HEAP32[$120 + 8 >> 2] = $F4_0; //@line 84221
     HEAP32[$120 + 12 >> 2] = $124; //@line 84223
    }
    HEAP32[15732] = $106; //@line 84225
    HEAP32[15735] = $111; //@line 84226
    $mem_0 = $88; //@line 84228
    return $mem_0 | 0; //@line 84231
   }
   $145 = HEAP32[15731] | 0; //@line 84233
   if (($145 | 0) == 0) {
    $nb_0 = $8; //@line 84236
    break;
   }
   $150 = ($145 & -$145) - 1 | 0; //@line 84241
   $152 = $150 >>> 12 & 16; //@line 84243
   $153 = $150 >>> ($152 >>> 0); //@line 84244
   $155 = $153 >>> 5 & 8; //@line 84246
   $157 = $153 >>> ($155 >>> 0); //@line 84248
   $159 = $157 >>> 2 & 4; //@line 84250
   $161 = $157 >>> ($159 >>> 0); //@line 84252
   $163 = $161 >>> 1 & 2; //@line 84254
   $165 = $161 >>> ($163 >>> 0); //@line 84256
   $167 = $165 >>> 1 & 1; //@line 84258
   $172 = HEAP32[63224 + (($155 | $152 | $159 | $163 | $167) + ($165 >>> ($167 >>> 0)) << 2) >> 2] | 0; //@line 84263
   $t_0_i = $172;
   $v_0_i = $172;
   $rsize_0_i = (HEAP32[$172 + 4 >> 2] & -8) - $8 | 0;
   while (1) {
    $179 = HEAP32[$t_0_i + 16 >> 2] | 0; //@line 84274
    if (($179 | 0) == 0) {
     $183 = HEAP32[$t_0_i + 20 >> 2] | 0; //@line 84278
     if (($183 | 0) == 0) {
      break;
     } else {
      $185 = $183; //@line 84283
     }
    } else {
     $185 = $179; //@line 84286
    }
    $189 = (HEAP32[$185 + 4 >> 2] & -8) - $8 | 0; //@line 84292
    $190 = $189 >>> 0 < $rsize_0_i >>> 0; //@line 84293
    $t_0_i = $185;
    $v_0_i = $190 ? $185 : $v_0_i;
    $rsize_0_i = $190 ? $189 : $rsize_0_i;
   }
   $192 = $v_0_i; //@line 84298
   $193 = HEAP32[15734] | 0; //@line 84299
   if ($192 >>> 0 < $193 >>> 0) {
    _abort(); //@line 84302
    return 0; //@line 84302
   }
   $196 = $192 + $8 | 0; //@line 84305
   $197 = $196; //@line 84306
   if ($192 >>> 0 >= $196 >>> 0) {
    _abort(); //@line 84309
    return 0; //@line 84309
   }
   $201 = HEAP32[$v_0_i + 24 >> 2] | 0; //@line 84313
   $203 = HEAP32[$v_0_i + 12 >> 2] | 0; //@line 84315
   do {
    if (($203 | 0) == ($v_0_i | 0)) {
     $220 = $v_0_i + 20 | 0; //@line 84319
     $221 = HEAP32[$220 >> 2] | 0; //@line 84320
     if (($221 | 0) == 0) {
      $224 = $v_0_i + 16 | 0; //@line 84323
      $225 = HEAP32[$224 >> 2] | 0; //@line 84324
      if (($225 | 0) == 0) {
       $R_1_i = 0; //@line 84327
       break;
      } else {
       $R_0_i = $225;
       $RP_0_i = $224;
      }
     } else {
      $R_0_i = $221;
      $RP_0_i = $220;
     }
     while (1) {
      $227 = $R_0_i + 20 | 0; //@line 84338
      $228 = HEAP32[$227 >> 2] | 0; //@line 84339
      if (($228 | 0) != 0) {
       $R_0_i = $228;
       $RP_0_i = $227;
       continue;
      }
      $231 = $R_0_i + 16 | 0; //@line 84345
      $232 = HEAP32[$231 >> 2] | 0; //@line 84346
      if (($232 | 0) == 0) {
       break;
      } else {
       $R_0_i = $232;
       $RP_0_i = $231;
      }
     }
     if ($RP_0_i >>> 0 < $193 >>> 0) {
      _abort(); //@line 84357
      return 0; //@line 84357
     } else {
      HEAP32[$RP_0_i >> 2] = 0; //@line 84360
      $R_1_i = $R_0_i; //@line 84361
      break;
     }
    } else {
     $207 = HEAP32[$v_0_i + 8 >> 2] | 0; //@line 84366
     if ($207 >>> 0 < $193 >>> 0) {
      _abort(); //@line 84370
      return 0; //@line 84370
     }
     $211 = $207 + 12 | 0; //@line 84373
     if ((HEAP32[$211 >> 2] | 0) != ($v_0_i | 0)) {
      _abort(); //@line 84377
      return 0; //@line 84377
     }
     $215 = $203 + 8 | 0; //@line 84380
     if ((HEAP32[$215 >> 2] | 0) == ($v_0_i | 0)) {
      HEAP32[$211 >> 2] = $203; //@line 84384
      HEAP32[$215 >> 2] = $207; //@line 84385
      $R_1_i = $203; //@line 84386
      break;
     } else {
      _abort(); //@line 84389
      return 0; //@line 84389
     }
    }
   } while (0);
   L25981 : do {
    if (($201 | 0) != 0) {
     $242 = $v_0_i + 28 | 0; //@line 84398
     $244 = 63224 + (HEAP32[$242 >> 2] << 2) | 0; //@line 84400
     do {
      if (($v_0_i | 0) == (HEAP32[$244 >> 2] | 0)) {
       HEAP32[$244 >> 2] = $R_1_i; //@line 84405
       if (($R_1_i | 0) != 0) {
        break;
       }
       HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$242 >> 2]); //@line 84415
       break L25981;
      } else {
       if ($201 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 84422
        return 0; //@line 84422
       }
       $258 = $201 + 16 | 0; //@line 84425
       if ((HEAP32[$258 >> 2] | 0) == ($v_0_i | 0)) {
        HEAP32[$258 >> 2] = $R_1_i; //@line 84429
       } else {
        HEAP32[$201 + 20 >> 2] = $R_1_i; //@line 84432
       }
       if (($R_1_i | 0) == 0) {
        break L25981;
       }
      }
     } while (0);
     if ($R_1_i >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 84444
      return 0; //@line 84444
     }
     HEAP32[$R_1_i + 24 >> 2] = $201; //@line 84448
     $274 = HEAP32[$v_0_i + 16 >> 2] | 0; //@line 84450
     do {
      if (($274 | 0) != 0) {
       if ($274 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 84458
        return 0; //@line 84458
       } else {
        HEAP32[$R_1_i + 16 >> 2] = $274; //@line 84462
        HEAP32[$274 + 24 >> 2] = $R_1_i; //@line 84464
        break;
       }
      }
     } while (0);
     $286 = HEAP32[$v_0_i + 20 >> 2] | 0; //@line 84470
     if (($286 | 0) == 0) {
      break;
     }
     if ($286 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 84479
      return 0; //@line 84479
     } else {
      HEAP32[$R_1_i + 20 >> 2] = $286; //@line 84483
      HEAP32[$286 + 24 >> 2] = $R_1_i; //@line 84485
      break;
     }
    }
   } while (0);
   if ($rsize_0_i >>> 0 < 16) {
    $300 = $rsize_0_i + $8 | 0; //@line 84492
    HEAP32[$v_0_i + 4 >> 2] = $300 | 3; //@line 84495
    $304 = $192 + ($300 + 4) | 0; //@line 84498
    HEAP32[$304 >> 2] = HEAP32[$304 >> 2] | 1; //@line 84501
   } else {
    HEAP32[$v_0_i + 4 >> 2] = $8 | 3; //@line 84505
    HEAP32[$192 + ($8 | 4) >> 2] = $rsize_0_i | 1; //@line 84510
    HEAP32[$192 + ($rsize_0_i + $8) >> 2] = $rsize_0_i; //@line 84514
    $315 = HEAP32[15732] | 0; //@line 84515
    if (($315 | 0) != 0) {
     $318 = HEAP32[15735] | 0; //@line 84518
     $319 = $315 >>> 3; //@line 84519
     $320 = $319 << 1; //@line 84520
     $322 = 62960 + ($320 << 2) | 0; //@line 84522
     $323 = HEAP32[15730] | 0; //@line 84523
     $324 = 1 << $319; //@line 84524
     do {
      if (($323 & $324 | 0) == 0) {
       HEAP32[15730] = $323 | $324; //@line 84530
       $F1_0_i = $322;
       $_pre_phi_i = 62960 + ($320 + 2 << 2) | 0;
      } else {
       $330 = 62960 + ($320 + 2 << 2) | 0; //@line 84536
       $331 = HEAP32[$330 >> 2] | 0; //@line 84537
       if ($331 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
        $F1_0_i = $331;
        $_pre_phi_i = $330;
        break;
       }
       _abort(); //@line 84545
       return 0; //@line 84545
      }
     } while (0);
     HEAP32[$_pre_phi_i >> 2] = $318; //@line 84551
     HEAP32[$F1_0_i + 12 >> 2] = $318; //@line 84553
     HEAP32[$318 + 8 >> 2] = $F1_0_i; //@line 84555
     HEAP32[$318 + 12 >> 2] = $322; //@line 84557
    }
    HEAP32[15732] = $rsize_0_i; //@line 84559
    HEAP32[15735] = $197; //@line 84560
   }
   $342 = $v_0_i + 8 | 0; //@line 84562
   if (($342 | 0) == 0) {
    $nb_0 = $8; //@line 84566
    break;
   } else {
    $mem_0 = $342; //@line 84569
   }
   return $mem_0 | 0; //@line 84573
  } else {
   if ($bytes >>> 0 > 4294967231) {
    $nb_0 = -1; //@line 84577
    break;
   }
   $348 = $bytes + 11 | 0; //@line 84580
   $349 = $348 & -8; //@line 84581
   $350 = HEAP32[15731] | 0; //@line 84582
   if (($350 | 0) == 0) {
    $nb_0 = $349; //@line 84585
    break;
   }
   $353 = -$349 | 0; //@line 84588
   $354 = $348 >>> 8; //@line 84589
   do {
    if (($354 | 0) == 0) {
     $idx_0_i = 0; //@line 84593
    } else {
     if ($349 >>> 0 > 16777215) {
      $idx_0_i = 31; //@line 84597
      break;
     }
     $361 = ($354 + 1048320 | 0) >>> 16 & 8; //@line 84602
     $362 = $354 << $361; //@line 84603
     $365 = ($362 + 520192 | 0) >>> 16 & 4; //@line 84606
     $367 = $362 << $365; //@line 84608
     $370 = ($367 + 245760 | 0) >>> 16 & 2; //@line 84611
     $375 = 14 - ($365 | $361 | $370) + ($367 << $370 >>> 15) | 0; //@line 84616
     $idx_0_i = $349 >>> (($375 + 7 | 0) >>> 0) & 1 | $375 << 1; //@line 84622
    }
   } while (0);
   $383 = HEAP32[63224 + ($idx_0_i << 2) >> 2] | 0; //@line 84627
   L26029 : do {
    if (($383 | 0) == 0) {
     $v_2_i = 0;
     $rsize_2_i = $353;
     $t_1_i = 0;
    } else {
     if (($idx_0_i | 0) == 31) {
      $391 = 0; //@line 84635
     } else {
      $391 = 25 - ($idx_0_i >>> 1) | 0; //@line 84639
     }
     $v_0_i118 = 0;
     $rsize_0_i117 = $353;
     $t_0_i116 = $383;
     $sizebits_0_i = $349 << $391;
     $rst_0_i = 0;
     while (1) {
      $396 = HEAP32[$t_0_i116 + 4 >> 2] & -8; //@line 84652
      $397 = $396 - $349 | 0; //@line 84653
      if ($397 >>> 0 < $rsize_0_i117 >>> 0) {
       if (($396 | 0) == ($349 | 0)) {
        $v_2_i = $t_0_i116;
        $rsize_2_i = $397;
        $t_1_i = $t_0_i116;
        break L26029;
       } else {
        $v_1_i = $t_0_i116;
        $rsize_1_i = $397;
       }
      } else {
       $v_1_i = $v_0_i118;
       $rsize_1_i = $rsize_0_i117;
      }
      $403 = HEAP32[$t_0_i116 + 20 >> 2] | 0; //@line 84669
      $406 = HEAP32[$t_0_i116 + 16 + ($sizebits_0_i >>> 31 << 2) >> 2] | 0; //@line 84672
      $rst_1_i = ($403 | 0) == 0 | ($403 | 0) == ($406 | 0) ? $rst_0_i : $403; //@line 84676
      if (($406 | 0) == 0) {
       $v_2_i = $v_1_i;
       $rsize_2_i = $rsize_1_i;
       $t_1_i = $rst_1_i;
       break;
      } else {
       $v_0_i118 = $v_1_i;
       $rsize_0_i117 = $rsize_1_i;
       $t_0_i116 = $406;
       $sizebits_0_i = $sizebits_0_i << 1;
       $rst_0_i = $rst_1_i;
      }
     }
    }
   } while (0);
   if (($t_1_i | 0) == 0 & ($v_2_i | 0) == 0) {
    $414 = 2 << $idx_0_i; //@line 84695
    $417 = $350 & ($414 | -$414); //@line 84698
    if (($417 | 0) == 0) {
     $nb_0 = $349; //@line 84701
     break;
    }
    $422 = ($417 & -$417) - 1 | 0; //@line 84706
    $424 = $422 >>> 12 & 16; //@line 84708
    $425 = $422 >>> ($424 >>> 0); //@line 84709
    $427 = $425 >>> 5 & 8; //@line 84711
    $429 = $425 >>> ($427 >>> 0); //@line 84713
    $431 = $429 >>> 2 & 4; //@line 84715
    $433 = $429 >>> ($431 >>> 0); //@line 84717
    $435 = $433 >>> 1 & 2; //@line 84719
    $437 = $433 >>> ($435 >>> 0); //@line 84721
    $439 = $437 >>> 1 & 1; //@line 84723
    $t_2_ph_i = HEAP32[63224 + (($427 | $424 | $431 | $435 | $439) + ($437 >>> ($439 >>> 0)) << 2) >> 2] | 0; //@line 84729
   } else {
    $t_2_ph_i = $t_1_i; //@line 84731
   }
   if (($t_2_ph_i | 0) == 0) {
    $rsize_3_lcssa_i = $rsize_2_i;
    $v_3_lcssa_i = $v_2_i;
   } else {
    $t_228_i = $t_2_ph_i;
    $rsize_329_i = $rsize_2_i;
    $v_330_i = $v_2_i;
    while (1) {
     $449 = (HEAP32[$t_228_i + 4 >> 2] & -8) - $349 | 0; //@line 84746
     $450 = $449 >>> 0 < $rsize_329_i >>> 0; //@line 84747
     $_rsize_3_i = $450 ? $449 : $rsize_329_i; //@line 84748
     $t_2_v_3_i = $450 ? $t_228_i : $v_330_i; //@line 84749
     $452 = HEAP32[$t_228_i + 16 >> 2] | 0; //@line 84751
     if (($452 | 0) != 0) {
      $t_228_i = $452;
      $rsize_329_i = $_rsize_3_i;
      $v_330_i = $t_2_v_3_i;
      continue;
     }
     $455 = HEAP32[$t_228_i + 20 >> 2] | 0; //@line 84758
     if (($455 | 0) == 0) {
      $rsize_3_lcssa_i = $_rsize_3_i;
      $v_3_lcssa_i = $t_2_v_3_i;
      break;
     } else {
      $t_228_i = $455;
      $rsize_329_i = $_rsize_3_i;
      $v_330_i = $t_2_v_3_i;
     }
    }
   }
   if (($v_3_lcssa_i | 0) == 0) {
    $nb_0 = $349; //@line 84772
    break;
   }
   if ($rsize_3_lcssa_i >>> 0 >= ((HEAP32[15732] | 0) - $349 | 0) >>> 0) {
    $nb_0 = $349; //@line 84779
    break;
   }
   $463 = $v_3_lcssa_i; //@line 84782
   $464 = HEAP32[15734] | 0; //@line 84783
   if ($463 >>> 0 < $464 >>> 0) {
    _abort(); //@line 84786
    return 0; //@line 84786
   }
   $467 = $463 + $349 | 0; //@line 84789
   $468 = $467; //@line 84790
   if ($463 >>> 0 >= $467 >>> 0) {
    _abort(); //@line 84793
    return 0; //@line 84793
   }
   $472 = HEAP32[$v_3_lcssa_i + 24 >> 2] | 0; //@line 84797
   $474 = HEAP32[$v_3_lcssa_i + 12 >> 2] | 0; //@line 84799
   do {
    if (($474 | 0) == ($v_3_lcssa_i | 0)) {
     $491 = $v_3_lcssa_i + 20 | 0; //@line 84803
     $492 = HEAP32[$491 >> 2] | 0; //@line 84804
     if (($492 | 0) == 0) {
      $495 = $v_3_lcssa_i + 16 | 0; //@line 84807
      $496 = HEAP32[$495 >> 2] | 0; //@line 84808
      if (($496 | 0) == 0) {
       $R_1_i122 = 0; //@line 84811
       break;
      } else {
       $R_0_i120 = $496;
       $RP_0_i119 = $495;
      }
     } else {
      $R_0_i120 = $492;
      $RP_0_i119 = $491;
     }
     while (1) {
      $498 = $R_0_i120 + 20 | 0; //@line 84822
      $499 = HEAP32[$498 >> 2] | 0; //@line 84823
      if (($499 | 0) != 0) {
       $R_0_i120 = $499;
       $RP_0_i119 = $498;
       continue;
      }
      $502 = $R_0_i120 + 16 | 0; //@line 84829
      $503 = HEAP32[$502 >> 2] | 0; //@line 84830
      if (($503 | 0) == 0) {
       break;
      } else {
       $R_0_i120 = $503;
       $RP_0_i119 = $502;
      }
     }
     if ($RP_0_i119 >>> 0 < $464 >>> 0) {
      _abort(); //@line 84841
      return 0; //@line 84841
     } else {
      HEAP32[$RP_0_i119 >> 2] = 0; //@line 84844
      $R_1_i122 = $R_0_i120; //@line 84845
      break;
     }
    } else {
     $478 = HEAP32[$v_3_lcssa_i + 8 >> 2] | 0; //@line 84850
     if ($478 >>> 0 < $464 >>> 0) {
      _abort(); //@line 84854
      return 0; //@line 84854
     }
     $482 = $478 + 12 | 0; //@line 84857
     if ((HEAP32[$482 >> 2] | 0) != ($v_3_lcssa_i | 0)) {
      _abort(); //@line 84861
      return 0; //@line 84861
     }
     $486 = $474 + 8 | 0; //@line 84864
     if ((HEAP32[$486 >> 2] | 0) == ($v_3_lcssa_i | 0)) {
      HEAP32[$482 >> 2] = $474; //@line 84868
      HEAP32[$486 >> 2] = $478; //@line 84869
      $R_1_i122 = $474; //@line 84870
      break;
     } else {
      _abort(); //@line 84873
      return 0; //@line 84873
     }
    }
   } while (0);
   L26079 : do {
    if (($472 | 0) != 0) {
     $513 = $v_3_lcssa_i + 28 | 0; //@line 84882
     $515 = 63224 + (HEAP32[$513 >> 2] << 2) | 0; //@line 84884
     do {
      if (($v_3_lcssa_i | 0) == (HEAP32[$515 >> 2] | 0)) {
       HEAP32[$515 >> 2] = $R_1_i122; //@line 84889
       if (($R_1_i122 | 0) != 0) {
        break;
       }
       HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$513 >> 2]); //@line 84899
       break L26079;
      } else {
       if ($472 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 84906
        return 0; //@line 84906
       }
       $529 = $472 + 16 | 0; //@line 84909
       if ((HEAP32[$529 >> 2] | 0) == ($v_3_lcssa_i | 0)) {
        HEAP32[$529 >> 2] = $R_1_i122; //@line 84913
       } else {
        HEAP32[$472 + 20 >> 2] = $R_1_i122; //@line 84916
       }
       if (($R_1_i122 | 0) == 0) {
        break L26079;
       }
      }
     } while (0);
     if ($R_1_i122 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 84928
      return 0; //@line 84928
     }
     HEAP32[$R_1_i122 + 24 >> 2] = $472; //@line 84932
     $545 = HEAP32[$v_3_lcssa_i + 16 >> 2] | 0; //@line 84934
     do {
      if (($545 | 0) != 0) {
       if ($545 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 84942
        return 0; //@line 84942
       } else {
        HEAP32[$R_1_i122 + 16 >> 2] = $545; //@line 84946
        HEAP32[$545 + 24 >> 2] = $R_1_i122; //@line 84948
        break;
       }
      }
     } while (0);
     $557 = HEAP32[$v_3_lcssa_i + 20 >> 2] | 0; //@line 84954
     if (($557 | 0) == 0) {
      break;
     }
     if ($557 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 84963
      return 0; //@line 84963
     } else {
      HEAP32[$R_1_i122 + 20 >> 2] = $557; //@line 84967
      HEAP32[$557 + 24 >> 2] = $R_1_i122; //@line 84969
      break;
     }
    }
   } while (0);
   do {
    if ($rsize_3_lcssa_i >>> 0 < 16) {
     $571 = $rsize_3_lcssa_i + $349 | 0; //@line 84977
     HEAP32[$v_3_lcssa_i + 4 >> 2] = $571 | 3; //@line 84980
     $575 = $463 + ($571 + 4) | 0; //@line 84983
     HEAP32[$575 >> 2] = HEAP32[$575 >> 2] | 1; //@line 84986
    } else {
     HEAP32[$v_3_lcssa_i + 4 >> 2] = $349 | 3; //@line 84990
     HEAP32[$463 + ($349 | 4) >> 2] = $rsize_3_lcssa_i | 1; //@line 84995
     HEAP32[$463 + ($rsize_3_lcssa_i + $349) >> 2] = $rsize_3_lcssa_i; //@line 84999
     $586 = $rsize_3_lcssa_i >>> 3; //@line 85000
     if ($rsize_3_lcssa_i >>> 0 < 256) {
      $589 = $586 << 1; //@line 85003
      $591 = 62960 + ($589 << 2) | 0; //@line 85005
      $592 = HEAP32[15730] | 0; //@line 85006
      $593 = 1 << $586; //@line 85007
      do {
       if (($592 & $593 | 0) == 0) {
        HEAP32[15730] = $592 | $593; //@line 85013
        $F5_0_i = $591;
        $_pre_phi_i128 = 62960 + ($589 + 2 << 2) | 0;
       } else {
        $599 = 62960 + ($589 + 2 << 2) | 0; //@line 85019
        $600 = HEAP32[$599 >> 2] | 0; //@line 85020
        if ($600 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
         $F5_0_i = $600;
         $_pre_phi_i128 = $599;
         break;
        }
        _abort(); //@line 85028
        return 0; //@line 85028
       }
      } while (0);
      HEAP32[$_pre_phi_i128 >> 2] = $468; //@line 85034
      HEAP32[$F5_0_i + 12 >> 2] = $468; //@line 85036
      HEAP32[$463 + ($349 + 8) >> 2] = $F5_0_i; //@line 85040
      HEAP32[$463 + ($349 + 12) >> 2] = $591; //@line 85044
      break;
     }
     $612 = $467; //@line 85047
     $613 = $rsize_3_lcssa_i >>> 8; //@line 85048
     do {
      if (($613 | 0) == 0) {
       $I7_0_i = 0; //@line 85052
      } else {
       if ($rsize_3_lcssa_i >>> 0 > 16777215) {
        $I7_0_i = 31; //@line 85056
        break;
       }
       $620 = ($613 + 1048320 | 0) >>> 16 & 8; //@line 85061
       $621 = $613 << $620; //@line 85062
       $624 = ($621 + 520192 | 0) >>> 16 & 4; //@line 85065
       $626 = $621 << $624; //@line 85067
       $629 = ($626 + 245760 | 0) >>> 16 & 2; //@line 85070
       $634 = 14 - ($624 | $620 | $629) + ($626 << $629 >>> 15) | 0; //@line 85075
       $I7_0_i = $rsize_3_lcssa_i >>> (($634 + 7 | 0) >>> 0) & 1 | $634 << 1; //@line 85081
      }
     } while (0);
     $641 = 63224 + ($I7_0_i << 2) | 0; //@line 85085
     HEAP32[$463 + ($349 + 28) >> 2] = $I7_0_i; //@line 85089
     HEAP32[$463 + ($349 + 20) >> 2] = 0; //@line 85095
     HEAP32[$463 + ($349 + 16) >> 2] = 0; //@line 85097
     $648 = HEAP32[15731] | 0; //@line 85098
     $649 = 1 << $I7_0_i; //@line 85099
     if (($648 & $649 | 0) == 0) {
      HEAP32[15731] = $648 | $649; //@line 85104
      HEAP32[$641 >> 2] = $612; //@line 85105
      HEAP32[$463 + ($349 + 24) >> 2] = $641; //@line 85110
      HEAP32[$463 + ($349 + 12) >> 2] = $612; //@line 85114
      HEAP32[$463 + ($349 + 8) >> 2] = $612; //@line 85118
      break;
     }
     if (($I7_0_i | 0) == 31) {
      $668 = 0; //@line 85124
     } else {
      $668 = 25 - ($I7_0_i >>> 1) | 0; //@line 85128
     }
     $K12_0_i = $rsize_3_lcssa_i << $668;
     $T_0_i = HEAP32[$641 >> 2] | 0;
     while (1) {
      if ((HEAP32[$T_0_i + 4 >> 2] & -8 | 0) == ($rsize_3_lcssa_i | 0)) {
       break;
      }
      $677 = $T_0_i + 16 + ($K12_0_i >>> 31 << 2) | 0; //@line 85144
      $678 = HEAP32[$677 >> 2] | 0; //@line 85145
      if (($678 | 0) == 0) {
       label = 20148; //@line 85149
       break;
      } else {
       $K12_0_i = $K12_0_i << 1;
       $T_0_i = $678;
      }
     }
     if ((label | 0) == 20148) {
      if ($677 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
       _abort(); //@line 85160
       return 0; //@line 85160
      } else {
       HEAP32[$677 >> 2] = $612; //@line 85163
       HEAP32[$463 + ($349 + 24) >> 2] = $T_0_i; //@line 85167
       HEAP32[$463 + ($349 + 12) >> 2] = $612; //@line 85171
       HEAP32[$463 + ($349 + 8) >> 2] = $612; //@line 85175
       break;
      }
     }
     $694 = $T_0_i + 8 | 0; //@line 85179
     $695 = HEAP32[$694 >> 2] | 0; //@line 85180
     $697 = HEAP32[15734] | 0; //@line 85182
     if ($T_0_i >>> 0 < $697 >>> 0) {
      _abort(); //@line 85185
      return 0; //@line 85185
     }
     if ($695 >>> 0 < $697 >>> 0) {
      _abort(); //@line 85191
      return 0; //@line 85191
     } else {
      HEAP32[$695 + 12 >> 2] = $612; //@line 85195
      HEAP32[$694 >> 2] = $612; //@line 85196
      HEAP32[$463 + ($349 + 8) >> 2] = $695; //@line 85200
      HEAP32[$463 + ($349 + 12) >> 2] = $T_0_i; //@line 85204
      HEAP32[$463 + ($349 + 24) >> 2] = 0; //@line 85208
      break;
     }
    }
   } while (0);
   $711 = $v_3_lcssa_i + 8 | 0; //@line 85213
   if (($711 | 0) == 0) {
    $nb_0 = $349; //@line 85217
    break;
   } else {
    $mem_0 = $711; //@line 85220
   }
   return $mem_0 | 0; //@line 85224
  }
 } while (0);
 $714 = HEAP32[15732] | 0; //@line 85228
 if ($nb_0 >>> 0 <= $714 >>> 0) {
  $717 = $714 - $nb_0 | 0; //@line 85231
  $718 = HEAP32[15735] | 0; //@line 85232
  if ($717 >>> 0 > 15) {
   $721 = $718; //@line 85235
   HEAP32[15735] = $721 + $nb_0; //@line 85238
   HEAP32[15732] = $717; //@line 85239
   HEAP32[$721 + ($nb_0 + 4) >> 2] = $717 | 1; //@line 85244
   HEAP32[$721 + $714 >> 2] = $717; //@line 85247
   HEAP32[$718 + 4 >> 2] = $nb_0 | 3; //@line 85250
  } else {
   HEAP32[15732] = 0; //@line 85252
   HEAP32[15735] = 0; //@line 85253
   HEAP32[$718 + 4 >> 2] = $714 | 3; //@line 85256
   $736 = $718 + ($714 + 4) | 0; //@line 85260
   HEAP32[$736 >> 2] = HEAP32[$736 >> 2] | 1; //@line 85263
  }
  $mem_0 = $718 + 8 | 0; //@line 85267
  return $mem_0 | 0; //@line 85270
 }
 $743 = HEAP32[15733] | 0; //@line 85272
 if ($nb_0 >>> 0 < $743 >>> 0) {
  $746 = $743 - $nb_0 | 0; //@line 85275
  HEAP32[15733] = $746; //@line 85276
  $747 = HEAP32[15736] | 0; //@line 85277
  $748 = $747; //@line 85278
  HEAP32[15736] = $748 + $nb_0; //@line 85281
  HEAP32[$748 + ($nb_0 + 4) >> 2] = $746 | 1; //@line 85286
  HEAP32[$747 + 4 >> 2] = $nb_0 | 3; //@line 85289
  $mem_0 = $747 + 8 | 0; //@line 85292
  return $mem_0 | 0; //@line 85295
 }
 do {
  if ((HEAP32[15676] | 0) == 0) {
   $762 = _sysconf(8) | 0; //@line 85301
   if (($762 - 1 & $762 | 0) == 0) {
    HEAP32[15678] = $762; //@line 85306
    HEAP32[15677] = $762; //@line 85307
    HEAP32[15679] = -1; //@line 85308
    HEAP32[15680] = 2097152; //@line 85309
    HEAP32[15681] = 0; //@line 85310
    HEAP32[15841] = 0; //@line 85311
    HEAP32[15676] = (_time(0) | 0) & -16 ^ 1431655768; //@line 85315
    break;
   } else {
    _abort(); //@line 85318
    return 0; //@line 85318
   }
  }
 } while (0);
 $771 = $nb_0 + 48 | 0; //@line 85323
 $772 = HEAP32[15678] | 0; //@line 85324
 $773 = $nb_0 + 47 | 0; //@line 85325
 $774 = $772 + $773 | 0; //@line 85326
 $775 = -$772 | 0; //@line 85327
 $776 = $774 & $775; //@line 85328
 if ($776 >>> 0 <= $nb_0 >>> 0) {
  $mem_0 = 0; //@line 85331
  return $mem_0 | 0; //@line 85334
 }
 $779 = HEAP32[15840] | 0; //@line 85336
 do {
  if (($779 | 0) != 0) {
   $782 = HEAP32[15838] | 0; //@line 85340
   $783 = $782 + $776 | 0; //@line 85341
   if ($783 >>> 0 <= $782 >>> 0 | $783 >>> 0 > $779 >>> 0) {
    $mem_0 = 0; //@line 85346
   } else {
    break;
   }
   return $mem_0 | 0; //@line 85352
  }
 } while (0);
 L26171 : do {
  if ((HEAP32[15841] & 4 | 0) == 0) {
   $791 = HEAP32[15736] | 0; //@line 85360
   L26173 : do {
    if (($791 | 0) == 0) {
     label = 20178; //@line 85364
    } else {
     $794 = $791; //@line 85366
     $sp_0_i_i = 63368; //@line 85367
     while (1) {
      $796 = $sp_0_i_i | 0; //@line 85370
      $797 = HEAP32[$796 >> 2] | 0; //@line 85371
      if ($797 >>> 0 <= $794 >>> 0) {
       $800 = $sp_0_i_i + 4 | 0; //@line 85374
       if (($797 + (HEAP32[$800 >> 2] | 0) | 0) >>> 0 > $794 >>> 0) {
        break;
       }
      }
      $806 = HEAP32[$sp_0_i_i + 8 >> 2] | 0; //@line 85383
      if (($806 | 0) == 0) {
       label = 20178; //@line 85386
       break L26173;
      } else {
       $sp_0_i_i = $806; //@line 85389
      }
     }
     if (($sp_0_i_i | 0) == 0) {
      label = 20178; //@line 85394
      break;
     }
     $840 = $774 - (HEAP32[15733] | 0) & $775; //@line 85399
     if ($840 >>> 0 >= 2147483647) {
      $tsize_0303639_i = 0; //@line 85402
      break;
     }
     $843 = _sbrk($840 | 0) | 0; //@line 85405
     $847 = ($843 | 0) == ((HEAP32[$796 >> 2] | 0) + (HEAP32[$800 >> 2] | 0) | 0); //@line 85409
     $tbase_0_i = $847 ? $843 : -1;
     $tsize_0_i = $847 ? $840 : 0;
     $br_0_i = $843;
     $ssize_1_i = $840;
     label = 20187; //@line 85413
    }
   } while (0);
   do {
    if ((label | 0) == 20178) {
     $809 = _sbrk(0) | 0; //@line 85418
     if (($809 | 0) == -1) {
      $tsize_0303639_i = 0; //@line 85421
      break;
     }
     $812 = $809; //@line 85424
     $813 = HEAP32[15677] | 0; //@line 85425
     $814 = $813 - 1 | 0; //@line 85426
     if (($814 & $812 | 0) == 0) {
      $ssize_0_i = $776; //@line 85430
     } else {
      $ssize_0_i = $776 - $812 + ($814 + $812 & -$813) | 0; //@line 85437
     }
     $824 = HEAP32[15838] | 0; //@line 85440
     $825 = $824 + $ssize_0_i | 0; //@line 85441
     if (!($ssize_0_i >>> 0 > $nb_0 >>> 0 & $ssize_0_i >>> 0 < 2147483647)) {
      $tsize_0303639_i = 0; //@line 85446
      break;
     }
     $829 = HEAP32[15840] | 0; //@line 85449
     if (($829 | 0) != 0) {
      if ($825 >>> 0 <= $824 >>> 0 | $825 >>> 0 > $829 >>> 0) {
       $tsize_0303639_i = 0; //@line 85456
       break;
      }
     }
     $835 = _sbrk($ssize_0_i | 0) | 0; //@line 85460
     $836 = ($835 | 0) == ($809 | 0); //@line 85461
     $tbase_0_i = $836 ? $809 : -1;
     $tsize_0_i = $836 ? $ssize_0_i : 0;
     $br_0_i = $835;
     $ssize_1_i = $ssize_0_i;
     label = 20187; //@line 85465
    }
   } while (0);
   L26193 : do {
    if ((label | 0) == 20187) {
     $849 = -$ssize_1_i | 0; //@line 85474
     if (($tbase_0_i | 0) != -1) {
      $tsize_244_i = $tsize_0_i;
      $tbase_245_i = $tbase_0_i;
      label = 20198; //@line 85478
      break L26171;
     }
     do {
      if (($br_0_i | 0) != -1 & $ssize_1_i >>> 0 < 2147483647 & $ssize_1_i >>> 0 < $771 >>> 0) {
       $856 = HEAP32[15678] | 0; //@line 85488
       $860 = $773 - $ssize_1_i + $856 & -$856; //@line 85492
       if ($860 >>> 0 >= 2147483647) {
        $ssize_2_i = $ssize_1_i; //@line 85495
        break;
       }
       if ((_sbrk($860 | 0) | 0) == -1) {
        _sbrk($849 | 0) | 0; //@line 85501
        $tsize_0303639_i = $tsize_0_i; //@line 85502
        break L26193;
       } else {
        $ssize_2_i = $860 + $ssize_1_i | 0; //@line 85506
        break;
       }
      } else {
       $ssize_2_i = $ssize_1_i; //@line 85510
      }
     } while (0);
     if (($br_0_i | 0) == -1) {
      $tsize_0303639_i = $tsize_0_i; //@line 85516
     } else {
      $tsize_244_i = $ssize_2_i;
      $tbase_245_i = $br_0_i;
      label = 20198; //@line 85519
      break L26171;
     }
    }
   } while (0);
   HEAP32[15841] = HEAP32[15841] | 4; //@line 85527
   $tsize_1_i = $tsize_0303639_i; //@line 85528
   label = 20195; //@line 85529
  } else {
   $tsize_1_i = 0; //@line 85531
   label = 20195; //@line 85532
  }
 } while (0);
 do {
  if ((label | 0) == 20195) {
   if ($776 >>> 0 >= 2147483647) {
    break;
   }
   $876 = _sbrk($776 | 0) | 0; //@line 85542
   $877 = _sbrk(0) | 0; //@line 85543
   if (!(($877 | 0) != -1 & ($876 | 0) != -1 & $876 >>> 0 < $877 >>> 0)) {
    break;
   }
   $881 = $877 - $876 | 0; //@line 85554
   $883 = $881 >>> 0 > ($nb_0 + 40 | 0) >>> 0; //@line 85556
   $_tbase_1_i = $883 ? $876 : -1; //@line 85558
   if (($_tbase_1_i | 0) != -1) {
    $tsize_244_i = $883 ? $881 : $tsize_1_i;
    $tbase_245_i = $_tbase_1_i;
    label = 20198; //@line 85562
   }
  }
 } while (0);
 do {
  if ((label | 0) == 20198) {
   $886 = (HEAP32[15838] | 0) + $tsize_244_i | 0; //@line 85571
   HEAP32[15838] = $886; //@line 85572
   if ($886 >>> 0 > (HEAP32[15839] | 0) >>> 0) {
    HEAP32[15839] = $886; //@line 85576
   }
   $890 = HEAP32[15736] | 0; //@line 85578
   L26213 : do {
    if (($890 | 0) == 0) {
     $893 = HEAP32[15734] | 0; //@line 85582
     if (($893 | 0) == 0 | $tbase_245_i >>> 0 < $893 >>> 0) {
      HEAP32[15734] = $tbase_245_i; //@line 85587
     }
     HEAP32[15842] = $tbase_245_i; //@line 85589
     HEAP32[15843] = $tsize_244_i; //@line 85590
     HEAP32[15845] = 0; //@line 85591
     HEAP32[15739] = HEAP32[15676]; //@line 85593
     HEAP32[15738] = -1; //@line 85594
     $i_02_i_i = 0; //@line 85595
     do {
      $899 = $i_02_i_i << 1; //@line 85598
      $901 = 62960 + ($899 << 2) | 0; //@line 85600
      HEAP32[62960 + ($899 + 3 << 2) >> 2] = $901; //@line 85603
      HEAP32[62960 + ($899 + 2 << 2) >> 2] = $901; //@line 85606
      $i_02_i_i = $i_02_i_i + 1 | 0; //@line 85607
     } while ($i_02_i_i >>> 0 < 32);
     $908 = $tbase_245_i + 8 | 0; //@line 85617
     if (($908 & 7 | 0) == 0) {
      $914 = 0; //@line 85621
     } else {
      $914 = -$908 & 7; //@line 85625
     }
     $917 = $tsize_244_i - 40 - $914 | 0; //@line 85630
     HEAP32[15736] = $tbase_245_i + $914; //@line 85631
     HEAP32[15733] = $917; //@line 85632
     HEAP32[$tbase_245_i + ($914 + 4) >> 2] = $917 | 1; //@line 85637
     HEAP32[$tbase_245_i + ($tsize_244_i - 36) >> 2] = 40; //@line 85641
     HEAP32[15737] = HEAP32[15680]; //@line 85643
    } else {
     $sp_067_i = 63368; //@line 85645
     while (1) {
      $925 = HEAP32[$sp_067_i >> 2] | 0; //@line 85649
      $926 = $sp_067_i + 4 | 0; //@line 85650
      $927 = HEAP32[$926 >> 2] | 0; //@line 85651
      if (($tbase_245_i | 0) == ($925 + $927 | 0)) {
       label = 20210; //@line 85655
       break;
      }
      $932 = HEAP32[$sp_067_i + 8 >> 2] | 0; //@line 85659
      if (($932 | 0) == 0) {
       break;
      } else {
       $sp_067_i = $932; //@line 85664
      }
     }
     do {
      if ((label | 0) == 20210) {
       if ((HEAP32[$sp_067_i + 12 >> 2] & 8 | 0) != 0) {
        break;
       }
       $939 = $890; //@line 85676
       if (!($939 >>> 0 >= $925 >>> 0 & $939 >>> 0 < $tbase_245_i >>> 0)) {
        break;
       }
       HEAP32[$926 >> 2] = $927 + $tsize_244_i; //@line 85684
       $944 = HEAP32[15736] | 0; //@line 85685
       $946 = (HEAP32[15733] | 0) + $tsize_244_i | 0; //@line 85687
       $947 = $944; //@line 85688
       $949 = $944 + 8 | 0; //@line 85690
       if (($949 & 7 | 0) == 0) {
        $955 = 0; //@line 85694
       } else {
        $955 = -$949 & 7; //@line 85698
       }
       $958 = $946 - $955 | 0; //@line 85703
       HEAP32[15736] = $947 + $955; //@line 85704
       HEAP32[15733] = $958; //@line 85705
       HEAP32[$947 + ($955 + 4) >> 2] = $958 | 1; //@line 85710
       HEAP32[$947 + ($946 + 4) >> 2] = 40; //@line 85714
       HEAP32[15737] = HEAP32[15680]; //@line 85716
       break L26213;
      }
     } while (0);
     if ($tbase_245_i >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      HEAP32[15734] = $tbase_245_i; //@line 85723
     }
     $968 = $tbase_245_i + $tsize_244_i | 0; //@line 85725
     $sp_160_i = 63368; //@line 85726
     while (1) {
      $970 = $sp_160_i | 0; //@line 85729
      if ((HEAP32[$970 >> 2] | 0) == ($968 | 0)) {
       label = 20220; //@line 85733
       break;
      }
      $975 = HEAP32[$sp_160_i + 8 >> 2] | 0; //@line 85737
      if (($975 | 0) == 0) {
       break;
      } else {
       $sp_160_i = $975; //@line 85742
      }
     }
     do {
      if ((label | 0) == 20220) {
       if ((HEAP32[$sp_160_i + 12 >> 2] & 8 | 0) != 0) {
        break;
       }
       HEAP32[$970 >> 2] = $tbase_245_i; //@line 85754
       $982 = $sp_160_i + 4 | 0; //@line 85755
       HEAP32[$982 >> 2] = (HEAP32[$982 >> 2] | 0) + $tsize_244_i; //@line 85758
       $986 = $tbase_245_i + 8 | 0; //@line 85760
       if (($986 & 7 | 0) == 0) {
        $993 = 0; //@line 85764
       } else {
        $993 = -$986 & 7; //@line 85768
       }
       $996 = $tbase_245_i + ($tsize_244_i + 8) | 0; //@line 85774
       if (($996 & 7 | 0) == 0) {
        $1003 = 0; //@line 85778
       } else {
        $1003 = -$996 & 7; //@line 85782
       }
       $1004 = $tbase_245_i + ($1003 + $tsize_244_i) | 0; //@line 85786
       $1005 = $1004; //@line 85787
       $_sum_i21_i = $993 + $nb_0 | 0; //@line 85791
       $1009 = $tbase_245_i + $_sum_i21_i | 0; //@line 85792
       $1010 = $1009; //@line 85793
       $1011 = $1004 - ($tbase_245_i + $993) - $nb_0 | 0; //@line 85794
       HEAP32[$tbase_245_i + ($993 + 4) >> 2] = $nb_0 | 3; //@line 85799
       do {
        if (($1005 | 0) == (HEAP32[15736] | 0)) {
         $1019 = (HEAP32[15733] | 0) + $1011 | 0; //@line 85805
         HEAP32[15733] = $1019; //@line 85806
         HEAP32[15736] = $1010; //@line 85807
         HEAP32[$tbase_245_i + ($_sum_i21_i + 4) >> 2] = $1019 | 1; //@line 85812
        } else {
         if (($1005 | 0) == (HEAP32[15735] | 0)) {
          $1028 = (HEAP32[15732] | 0) + $1011 | 0; //@line 85818
          HEAP32[15732] = $1028; //@line 85819
          HEAP32[15735] = $1010; //@line 85820
          HEAP32[$tbase_245_i + ($_sum_i21_i + 4) >> 2] = $1028 | 1; //@line 85825
          HEAP32[$tbase_245_i + ($1028 + $_sum_i21_i) >> 2] = $1028; //@line 85829
          break;
         }
         $_sum2_i23_i = $tsize_244_i + 4 | 0; //@line 85832
         $1037 = HEAP32[$tbase_245_i + ($_sum2_i23_i + $1003) >> 2] | 0; //@line 85836
         if (($1037 & 3 | 0) == 1) {
          $1041 = $1037 & -8; //@line 85840
          $1042 = $1037 >>> 3; //@line 85841
          L26258 : do {
           if ($1037 >>> 0 < 256) {
            $1047 = HEAP32[$tbase_245_i + (($1003 | 8) + $tsize_244_i) >> 2] | 0; //@line 85849
            $1050 = HEAP32[$tbase_245_i + ($tsize_244_i + 12 + $1003) >> 2] | 0; //@line 85854
            $1053 = 62960 + ($1042 << 1 << 2) | 0; //@line 85857
            do {
             if (($1047 | 0) != ($1053 | 0)) {
              if ($1047 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
               _abort(); //@line 85865
               return 0; //@line 85865
              }
              if ((HEAP32[$1047 + 12 >> 2] | 0) == ($1005 | 0)) {
               break;
              }
              _abort(); //@line 85874
              return 0; //@line 85874
             }
            } while (0);
            if (($1050 | 0) == ($1047 | 0)) {
             HEAP32[15730] = HEAP32[15730] & ~(1 << $1042); //@line 85884
             break;
            }
            do {
             if (($1050 | 0) == ($1053 | 0)) {
              $_pre_phi57_i_i = $1050 + 8 | 0; //@line 85891
             } else {
              if ($1050 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
               _abort(); //@line 85897
               return 0; //@line 85897
              }
              $1076 = $1050 + 8 | 0; //@line 85900
              if ((HEAP32[$1076 >> 2] | 0) == ($1005 | 0)) {
               $_pre_phi57_i_i = $1076; //@line 85904
               break;
              }
              _abort(); //@line 85907
              return 0; //@line 85907
             }
            } while (0);
            HEAP32[$1047 + 12 >> 2] = $1050; //@line 85913
            HEAP32[$_pre_phi57_i_i >> 2] = $1047; //@line 85914
           } else {
            $1081 = $1004; //@line 85916
            $1084 = HEAP32[$tbase_245_i + (($1003 | 24) + $tsize_244_i) >> 2] | 0; //@line 85921
            $1087 = HEAP32[$tbase_245_i + ($tsize_244_i + 12 + $1003) >> 2] | 0; //@line 85926
            do {
             if (($1087 | 0) == ($1081 | 0)) {
              $_sum67_i_i = $1003 | 16; //@line 85930
              $1107 = $tbase_245_i + ($_sum2_i23_i + $_sum67_i_i) | 0; //@line 85933
              $1108 = HEAP32[$1107 >> 2] | 0; //@line 85934
              if (($1108 | 0) == 0) {
               $1112 = $tbase_245_i + ($_sum67_i_i + $tsize_244_i) | 0; //@line 85939
               $1113 = HEAP32[$1112 >> 2] | 0; //@line 85940
               if (($1113 | 0) == 0) {
                $R_1_i_i = 0; //@line 85943
                break;
               } else {
                $R_0_i_i = $1113;
                $RP_0_i_i = $1112;
               }
              } else {
               $R_0_i_i = $1108;
               $RP_0_i_i = $1107;
              }
              while (1) {
               $1115 = $R_0_i_i + 20 | 0; //@line 85954
               $1116 = HEAP32[$1115 >> 2] | 0; //@line 85955
               if (($1116 | 0) != 0) {
                $R_0_i_i = $1116;
                $RP_0_i_i = $1115;
                continue;
               }
               $1119 = $R_0_i_i + 16 | 0; //@line 85961
               $1120 = HEAP32[$1119 >> 2] | 0; //@line 85962
               if (($1120 | 0) == 0) {
                break;
               } else {
                $R_0_i_i = $1120;
                $RP_0_i_i = $1119;
               }
              }
              if ($RP_0_i_i >>> 0 < (HEAP32[15734] | 0) >>> 0) {
               _abort(); //@line 85974
               return 0; //@line 85974
              } else {
               HEAP32[$RP_0_i_i >> 2] = 0; //@line 85977
               $R_1_i_i = $R_0_i_i; //@line 85978
               break;
              }
             } else {
              $1092 = HEAP32[$tbase_245_i + (($1003 | 8) + $tsize_244_i) >> 2] | 0; //@line 85986
              if ($1092 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
               _abort(); //@line 85991
               return 0; //@line 85991
              }
              $1097 = $1092 + 12 | 0; //@line 85994
              if ((HEAP32[$1097 >> 2] | 0) != ($1081 | 0)) {
               _abort(); //@line 85998
               return 0; //@line 85998
              }
              $1101 = $1087 + 8 | 0; //@line 86001
              if ((HEAP32[$1101 >> 2] | 0) == ($1081 | 0)) {
               HEAP32[$1097 >> 2] = $1087; //@line 86005
               HEAP32[$1101 >> 2] = $1092; //@line 86006
               $R_1_i_i = $1087; //@line 86007
               break;
              } else {
               _abort(); //@line 86010
               return 0; //@line 86010
              }
             }
            } while (0);
            if (($1084 | 0) == 0) {
             break;
            }
            $1132 = $tbase_245_i + ($tsize_244_i + 28 + $1003) | 0; //@line 86023
            $1134 = 63224 + (HEAP32[$1132 >> 2] << 2) | 0; //@line 86025
            do {
             if (($1081 | 0) == (HEAP32[$1134 >> 2] | 0)) {
              HEAP32[$1134 >> 2] = $R_1_i_i; //@line 86030
              if (($R_1_i_i | 0) != 0) {
               break;
              }
              HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$1132 >> 2]); //@line 86040
              break L26258;
             } else {
              if ($1084 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
               _abort(); //@line 86047
               return 0; //@line 86047
              }
              $1148 = $1084 + 16 | 0; //@line 86050
              if ((HEAP32[$1148 >> 2] | 0) == ($1081 | 0)) {
               HEAP32[$1148 >> 2] = $R_1_i_i; //@line 86054
              } else {
               HEAP32[$1084 + 20 >> 2] = $R_1_i_i; //@line 86057
              }
              if (($R_1_i_i | 0) == 0) {
               break L26258;
              }
             }
            } while (0);
            if ($R_1_i_i >>> 0 < (HEAP32[15734] | 0) >>> 0) {
             _abort(); //@line 86069
             return 0; //@line 86069
            }
            HEAP32[$R_1_i_i + 24 >> 2] = $1084; //@line 86073
            $_sum3233_i_i = $1003 | 16; //@line 86074
            $1165 = HEAP32[$tbase_245_i + ($_sum3233_i_i + $tsize_244_i) >> 2] | 0; //@line 86078
            do {
             if (($1165 | 0) != 0) {
              if ($1165 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
               _abort(); //@line 86086
               return 0; //@line 86086
              } else {
               HEAP32[$R_1_i_i + 16 >> 2] = $1165; //@line 86090
               HEAP32[$1165 + 24 >> 2] = $R_1_i_i; //@line 86092
               break;
              }
             }
            } while (0);
            $1178 = HEAP32[$tbase_245_i + ($_sum2_i23_i + $_sum3233_i_i) >> 2] | 0; //@line 86100
            if (($1178 | 0) == 0) {
             break;
            }
            if ($1178 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
             _abort(); //@line 86109
             return 0; //@line 86109
            } else {
             HEAP32[$R_1_i_i + 20 >> 2] = $1178; //@line 86113
             HEAP32[$1178 + 24 >> 2] = $R_1_i_i; //@line 86115
             break;
            }
           }
          } while (0);
          $oldfirst_0_i_i = $tbase_245_i + (($1041 | $1003) + $tsize_244_i) | 0;
          $qsize_0_i_i = $1041 + $1011 | 0;
         } else {
          $oldfirst_0_i_i = $1005;
          $qsize_0_i_i = $1011;
         }
         $1194 = $oldfirst_0_i_i + 4 | 0; //@line 86131
         HEAP32[$1194 >> 2] = HEAP32[$1194 >> 2] & -2; //@line 86134
         HEAP32[$tbase_245_i + ($_sum_i21_i + 4) >> 2] = $qsize_0_i_i | 1; //@line 86139
         HEAP32[$tbase_245_i + ($qsize_0_i_i + $_sum_i21_i) >> 2] = $qsize_0_i_i; //@line 86143
         $1202 = $qsize_0_i_i >>> 3; //@line 86144
         if ($qsize_0_i_i >>> 0 < 256) {
          $1205 = $1202 << 1; //@line 86147
          $1207 = 62960 + ($1205 << 2) | 0; //@line 86149
          $1208 = HEAP32[15730] | 0; //@line 86150
          $1209 = 1 << $1202; //@line 86151
          do {
           if (($1208 & $1209 | 0) == 0) {
            HEAP32[15730] = $1208 | $1209; //@line 86157
            $F4_0_i_i = $1207;
            $_pre_phi_i25_i = 62960 + ($1205 + 2 << 2) | 0;
           } else {
            $1215 = 62960 + ($1205 + 2 << 2) | 0; //@line 86163
            $1216 = HEAP32[$1215 >> 2] | 0; //@line 86164
            if ($1216 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
             $F4_0_i_i = $1216;
             $_pre_phi_i25_i = $1215;
             break;
            }
            _abort(); //@line 86172
            return 0; //@line 86172
           }
          } while (0);
          HEAP32[$_pre_phi_i25_i >> 2] = $1010; //@line 86178
          HEAP32[$F4_0_i_i + 12 >> 2] = $1010; //@line 86180
          HEAP32[$tbase_245_i + ($_sum_i21_i + 8) >> 2] = $F4_0_i_i; //@line 86184
          HEAP32[$tbase_245_i + ($_sum_i21_i + 12) >> 2] = $1207; //@line 86188
          break;
         }
         $1228 = $1009; //@line 86191
         $1229 = $qsize_0_i_i >>> 8; //@line 86192
         do {
          if (($1229 | 0) == 0) {
           $I7_0_i_i = 0; //@line 86196
          } else {
           if ($qsize_0_i_i >>> 0 > 16777215) {
            $I7_0_i_i = 31; //@line 86200
            break;
           }
           $1236 = ($1229 + 1048320 | 0) >>> 16 & 8; //@line 86205
           $1237 = $1229 << $1236; //@line 86206
           $1240 = ($1237 + 520192 | 0) >>> 16 & 4; //@line 86209
           $1242 = $1237 << $1240; //@line 86211
           $1245 = ($1242 + 245760 | 0) >>> 16 & 2; //@line 86214
           $1250 = 14 - ($1240 | $1236 | $1245) + ($1242 << $1245 >>> 15) | 0; //@line 86219
           $I7_0_i_i = $qsize_0_i_i >>> (($1250 + 7 | 0) >>> 0) & 1 | $1250 << 1; //@line 86225
          }
         } while (0);
         $1257 = 63224 + ($I7_0_i_i << 2) | 0; //@line 86229
         HEAP32[$tbase_245_i + ($_sum_i21_i + 28) >> 2] = $I7_0_i_i; //@line 86233
         HEAP32[$tbase_245_i + ($_sum_i21_i + 20) >> 2] = 0; //@line 86239
         HEAP32[$tbase_245_i + ($_sum_i21_i + 16) >> 2] = 0; //@line 86241
         $1264 = HEAP32[15731] | 0; //@line 86242
         $1265 = 1 << $I7_0_i_i; //@line 86243
         if (($1264 & $1265 | 0) == 0) {
          HEAP32[15731] = $1264 | $1265; //@line 86248
          HEAP32[$1257 >> 2] = $1228; //@line 86249
          HEAP32[$tbase_245_i + ($_sum_i21_i + 24) >> 2] = $1257; //@line 86254
          HEAP32[$tbase_245_i + ($_sum_i21_i + 12) >> 2] = $1228; //@line 86258
          HEAP32[$tbase_245_i + ($_sum_i21_i + 8) >> 2] = $1228; //@line 86262
          break;
         }
         if (($I7_0_i_i | 0) == 31) {
          $1284 = 0; //@line 86268
         } else {
          $1284 = 25 - ($I7_0_i_i >>> 1) | 0; //@line 86272
         }
         $K8_0_i_i = $qsize_0_i_i << $1284;
         $T_0_i27_i = HEAP32[$1257 >> 2] | 0;
         while (1) {
          if ((HEAP32[$T_0_i27_i + 4 >> 2] & -8 | 0) == ($qsize_0_i_i | 0)) {
           break;
          }
          $1293 = $T_0_i27_i + 16 + ($K8_0_i_i >>> 31 << 2) | 0; //@line 86288
          $1294 = HEAP32[$1293 >> 2] | 0; //@line 86289
          if (($1294 | 0) == 0) {
           label = 20293; //@line 86293
           break;
          } else {
           $K8_0_i_i = $K8_0_i_i << 1;
           $T_0_i27_i = $1294;
          }
         }
         if ((label | 0) == 20293) {
          if ($1293 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
           _abort(); //@line 86304
           return 0; //@line 86304
          } else {
           HEAP32[$1293 >> 2] = $1228; //@line 86307
           HEAP32[$tbase_245_i + ($_sum_i21_i + 24) >> 2] = $T_0_i27_i; //@line 86311
           HEAP32[$tbase_245_i + ($_sum_i21_i + 12) >> 2] = $1228; //@line 86315
           HEAP32[$tbase_245_i + ($_sum_i21_i + 8) >> 2] = $1228; //@line 86319
           break;
          }
         }
         $1310 = $T_0_i27_i + 8 | 0; //@line 86323
         $1311 = HEAP32[$1310 >> 2] | 0; //@line 86324
         $1313 = HEAP32[15734] | 0; //@line 86326
         if ($T_0_i27_i >>> 0 < $1313 >>> 0) {
          _abort(); //@line 86329
          return 0; //@line 86329
         }
         if ($1311 >>> 0 < $1313 >>> 0) {
          _abort(); //@line 86335
          return 0; //@line 86335
         } else {
          HEAP32[$1311 + 12 >> 2] = $1228; //@line 86339
          HEAP32[$1310 >> 2] = $1228; //@line 86340
          HEAP32[$tbase_245_i + ($_sum_i21_i + 8) >> 2] = $1311; //@line 86344
          HEAP32[$tbase_245_i + ($_sum_i21_i + 12) >> 2] = $T_0_i27_i; //@line 86348
          HEAP32[$tbase_245_i + ($_sum_i21_i + 24) >> 2] = 0; //@line 86352
          break;
         }
        }
       } while (0);
       $mem_0 = $tbase_245_i + ($993 | 8) | 0; //@line 86359
       return $mem_0 | 0; //@line 86362
      }
     } while (0);
     $1327 = $890; //@line 86365
     $sp_0_i_i_i = 63368; //@line 86366
     while (1) {
      $1330 = HEAP32[$sp_0_i_i_i >> 2] | 0; //@line 86370
      if ($1330 >>> 0 <= $1327 >>> 0) {
       $1334 = HEAP32[$sp_0_i_i_i + 4 >> 2] | 0; //@line 86374
       $1335 = $1330 + $1334 | 0; //@line 86375
       if ($1335 >>> 0 > $1327 >>> 0) {
        break;
       }
      }
      $sp_0_i_i_i = HEAP32[$sp_0_i_i_i + 8 >> 2] | 0; //@line 86383
     }
     $1341 = $1330 + ($1334 - 39) | 0; //@line 86388
     if (($1341 & 7 | 0) == 0) {
      $1348 = 0; //@line 86392
     } else {
      $1348 = -$1341 & 7; //@line 86396
     }
     $1349 = $1330 + ($1334 - 47 + $1348) | 0; //@line 86400
     $1353 = $1349 >>> 0 < ($890 + 16 | 0) >>> 0 ? $1327 : $1349; //@line 86404
     $1354 = $1353 + 8 | 0; //@line 86405
     $1358 = $tbase_245_i + 8 | 0; //@line 86409
     if (($1358 & 7 | 0) == 0) {
      $1364 = 0; //@line 86413
     } else {
      $1364 = -$1358 & 7; //@line 86417
     }
     $1367 = $tsize_244_i - 40 - $1364 | 0; //@line 86422
     HEAP32[15736] = $tbase_245_i + $1364; //@line 86423
     HEAP32[15733] = $1367; //@line 86424
     HEAP32[$tbase_245_i + ($1364 + 4) >> 2] = $1367 | 1; //@line 86429
     HEAP32[$tbase_245_i + ($tsize_244_i - 36) >> 2] = 40; //@line 86433
     HEAP32[15737] = HEAP32[15680]; //@line 86435
     HEAP32[$1353 + 4 >> 2] = 27; //@line 86438
     HEAP32[$1354 >> 2] = HEAP32[15842]; //@line 86439
     HEAP32[$1354 + 4 >> 2] = HEAP32[63372 >> 2]; //@line 86439
     HEAP32[$1354 + 8 >> 2] = HEAP32[63376 >> 2]; //@line 86439
     HEAP32[$1354 + 12 >> 2] = HEAP32[63380 >> 2]; //@line 86439
     HEAP32[15842] = $tbase_245_i; //@line 86440
     HEAP32[15843] = $tsize_244_i; //@line 86441
     HEAP32[15845] = 0; //@line 86442
     HEAP32[15844] = $1354; //@line 86443
     $1377 = $1353 + 28 | 0; //@line 86445
     HEAP32[$1377 >> 2] = 7; //@line 86446
     if (($1353 + 32 | 0) >>> 0 < $1335 >>> 0) {
      $1380 = $1377; //@line 86450
      while (1) {
       $1381 = $1380 + 4 | 0; //@line 86453
       HEAP32[$1381 >> 2] = 7; //@line 86454
       if (($1380 + 8 | 0) >>> 0 < $1335 >>> 0) {
        $1380 = $1381; //@line 86459
       } else {
        break;
       }
      }
     }
     if (($1353 | 0) == ($1327 | 0)) {
      break;
     }
     $1389 = $1353 - $890 | 0; //@line 86471
     $1392 = $1327 + ($1389 + 4) | 0; //@line 86475
     HEAP32[$1392 >> 2] = HEAP32[$1392 >> 2] & -2; //@line 86478
     HEAP32[$890 + 4 >> 2] = $1389 | 1; //@line 86481
     HEAP32[$1327 + $1389 >> 2] = $1389; //@line 86483
     $1398 = $1389 >>> 3; //@line 86484
     if ($1389 >>> 0 < 256) {
      $1401 = $1398 << 1; //@line 86487
      $1403 = 62960 + ($1401 << 2) | 0; //@line 86489
      $1404 = HEAP32[15730] | 0; //@line 86490
      $1405 = 1 << $1398; //@line 86491
      do {
       if (($1404 & $1405 | 0) == 0) {
        HEAP32[15730] = $1404 | $1405; //@line 86497
        $F_0_i_i = $1403;
        $_pre_phi_i_i = 62960 + ($1401 + 2 << 2) | 0;
       } else {
        $1411 = 62960 + ($1401 + 2 << 2) | 0; //@line 86503
        $1412 = HEAP32[$1411 >> 2] | 0; //@line 86504
        if ($1412 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
         $F_0_i_i = $1412;
         $_pre_phi_i_i = $1411;
         break;
        }
        _abort(); //@line 86512
        return 0; //@line 86512
       }
      } while (0);
      HEAP32[$_pre_phi_i_i >> 2] = $890; //@line 86518
      HEAP32[$F_0_i_i + 12 >> 2] = $890; //@line 86520
      HEAP32[$890 + 8 >> 2] = $F_0_i_i; //@line 86522
      HEAP32[$890 + 12 >> 2] = $1403; //@line 86524
      break;
     }
     $1422 = $890; //@line 86527
     $1423 = $1389 >>> 8; //@line 86528
     do {
      if (($1423 | 0) == 0) {
       $I1_0_i_i = 0; //@line 86532
      } else {
       if ($1389 >>> 0 > 16777215) {
        $I1_0_i_i = 31; //@line 86536
        break;
       }
       $1430 = ($1423 + 1048320 | 0) >>> 16 & 8; //@line 86541
       $1431 = $1423 << $1430; //@line 86542
       $1434 = ($1431 + 520192 | 0) >>> 16 & 4; //@line 86545
       $1436 = $1431 << $1434; //@line 86547
       $1439 = ($1436 + 245760 | 0) >>> 16 & 2; //@line 86550
       $1444 = 14 - ($1434 | $1430 | $1439) + ($1436 << $1439 >>> 15) | 0; //@line 86555
       $I1_0_i_i = $1389 >>> (($1444 + 7 | 0) >>> 0) & 1 | $1444 << 1; //@line 86561
      }
     } while (0);
     $1451 = 63224 + ($I1_0_i_i << 2) | 0; //@line 86565
     HEAP32[$890 + 28 >> 2] = $I1_0_i_i; //@line 86568
     HEAP32[$890 + 20 >> 2] = 0; //@line 86570
     HEAP32[$890 + 16 >> 2] = 0; //@line 86572
     $1455 = HEAP32[15731] | 0; //@line 86573
     $1456 = 1 << $I1_0_i_i; //@line 86574
     if (($1455 & $1456 | 0) == 0) {
      HEAP32[15731] = $1455 | $1456; //@line 86579
      HEAP32[$1451 >> 2] = $1422; //@line 86580
      HEAP32[$890 + 24 >> 2] = $1451; //@line 86583
      HEAP32[$890 + 12 >> 2] = $890; //@line 86585
      HEAP32[$890 + 8 >> 2] = $890; //@line 86587
      break;
     }
     if (($I1_0_i_i | 0) == 31) {
      $1471 = 0; //@line 86593
     } else {
      $1471 = 25 - ($I1_0_i_i >>> 1) | 0; //@line 86597
     }
     $K2_0_i_i = $1389 << $1471;
     $T_0_i_i = HEAP32[$1451 >> 2] | 0;
     while (1) {
      if ((HEAP32[$T_0_i_i + 4 >> 2] & -8 | 0) == ($1389 | 0)) {
       break;
      }
      $1480 = $T_0_i_i + 16 + ($K2_0_i_i >>> 31 << 2) | 0; //@line 86613
      $1481 = HEAP32[$1480 >> 2] | 0; //@line 86614
      if (($1481 | 0) == 0) {
       label = 20328; //@line 86618
       break;
      } else {
       $K2_0_i_i = $K2_0_i_i << 1;
       $T_0_i_i = $1481;
      }
     }
     if ((label | 0) == 20328) {
      if ($1480 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
       _abort(); //@line 86629
       return 0; //@line 86629
      } else {
       HEAP32[$1480 >> 2] = $1422; //@line 86632
       HEAP32[$890 + 24 >> 2] = $T_0_i_i; //@line 86635
       HEAP32[$890 + 12 >> 2] = $890; //@line 86637
       HEAP32[$890 + 8 >> 2] = $890; //@line 86639
       break;
      }
     }
     $1494 = $T_0_i_i + 8 | 0; //@line 86643
     $1495 = HEAP32[$1494 >> 2] | 0; //@line 86644
     $1497 = HEAP32[15734] | 0; //@line 86646
     if ($T_0_i_i >>> 0 < $1497 >>> 0) {
      _abort(); //@line 86649
      return 0; //@line 86649
     }
     if ($1495 >>> 0 < $1497 >>> 0) {
      _abort(); //@line 86655
      return 0; //@line 86655
     } else {
      HEAP32[$1495 + 12 >> 2] = $1422; //@line 86659
      HEAP32[$1494 >> 2] = $1422; //@line 86660
      HEAP32[$890 + 8 >> 2] = $1495; //@line 86663
      HEAP32[$890 + 12 >> 2] = $T_0_i_i; //@line 86666
      HEAP32[$890 + 24 >> 2] = 0; //@line 86668
      break;
     }
    }
   } while (0);
   $1507 = HEAP32[15733] | 0; //@line 86673
   if ($1507 >>> 0 <= $nb_0 >>> 0) {
    break;
   }
   $1510 = $1507 - $nb_0 | 0; //@line 86678
   HEAP32[15733] = $1510; //@line 86679
   $1511 = HEAP32[15736] | 0; //@line 86680
   $1512 = $1511; //@line 86681
   HEAP32[15736] = $1512 + $nb_0; //@line 86684
   HEAP32[$1512 + ($nb_0 + 4) >> 2] = $1510 | 1; //@line 86689
   HEAP32[$1511 + 4 >> 2] = $nb_0 | 3; //@line 86692
   $mem_0 = $1511 + 8 | 0; //@line 86695
   return $mem_0 | 0; //@line 86698
  }
 } while (0);
 HEAP32[(___errno_location() | 0) >> 2] = 12; //@line 86702
 $mem_0 = 0; //@line 86703
 return $mem_0 | 0; //@line 86706
}
function _free($mem) {
 $mem = $mem | 0;
 var $3 = 0, $4 = 0, $5 = 0, $10 = 0, $11 = 0, $14 = 0, $15 = 0, $16 = 0, $21 = 0, $_sum233 = 0, $24 = 0, $25 = 0, $26 = 0, $32 = 0, $37 = 0, $40 = 0, $43 = 0, $64 = 0, $_pre_phi307 = 0, $69 = 0, $72 = 0, $75 = 0, $80 = 0, $84 = 0, $88 = 0, $94 = 0, $95 = 0, $99 = 0, $100 = 0, $RP_0 = 0, $R_0 = 0, $102 = 0, $103 = 0, $106 = 0, $107 = 0, $R_1 = 0, $118 = 0, $120 = 0, $134 = 0, $151 = 0, $164 = 0, $177 = 0, $psize_0 = 0, $p_0 = 0, $189 = 0, $193 = 0, $194 = 0, $204 = 0, $220 = 0, $227 = 0, $228 = 0, $233 = 0, $236 = 0, $239 = 0, $262 = 0, $_pre_phi305 = 0, $267 = 0, $270 = 0, $273 = 0, $278 = 0, $283 = 0, $287 = 0, $293 = 0, $294 = 0, $298 = 0, $299 = 0, $RP9_0 = 0, $R7_0 = 0, $301 = 0, $302 = 0, $305 = 0, $306 = 0, $R7_1 = 0, $318 = 0, $320 = 0, $334 = 0, $351 = 0, $364 = 0, $psize_1 = 0, $390 = 0, $393 = 0, $395 = 0, $396 = 0, $397 = 0, $403 = 0, $404 = 0, $_pre_phi = 0, $F16_0 = 0, $414 = 0, $415 = 0, $422 = 0, $423 = 0, $426 = 0, $428 = 0, $431 = 0, $436 = 0, $I18_0 = 0, $443 = 0, $447 = 0, $448 = 0, $463 = 0, $T_0 = 0, $K19_0 = 0, $472 = 0, $473 = 0, $486 = 0, $487 = 0, $489 = 0, $501 = 0, $sp_0_in_i = 0, $sp_0_i = 0, label = 0;
 if (($mem | 0) == 0) {
  return;
 }
 $3 = $mem - 8 | 0; //@line 86774
 $4 = $3; //@line 86775
 $5 = HEAP32[15734] | 0; //@line 86776
 if ($3 >>> 0 < $5 >>> 0) {
  _abort(); //@line 86779
 }
 $10 = HEAP32[$mem - 4 >> 2] | 0; //@line 86784
 $11 = $10 & 3; //@line 86785
 if (($11 | 0) == 1) {
  _abort(); //@line 86788
 }
 $14 = $10 & -8; //@line 86791
 $15 = $mem + ($14 - 8) | 0; //@line 86793
 $16 = $15; //@line 86794
 L26430 : do {
  if (($10 & 1 | 0) == 0) {
   $21 = HEAP32[$3 >> 2] | 0; //@line 86800
   if (($11 | 0) == 0) {
    return;
   }
   $_sum233 = -8 - $21 | 0; //@line 86806
   $24 = $mem + $_sum233 | 0; //@line 86807
   $25 = $24; //@line 86808
   $26 = $21 + $14 | 0; //@line 86809
   if ($24 >>> 0 < $5 >>> 0) {
    _abort(); //@line 86812
   }
   if (($25 | 0) == (HEAP32[15735] | 0)) {
    $177 = $mem + ($14 - 4) | 0; //@line 86820
    if ((HEAP32[$177 >> 2] & 3 | 0) != 3) {
     $p_0 = $25;
     $psize_0 = $26;
     break;
    }
    HEAP32[15732] = $26; //@line 86828
    HEAP32[$177 >> 2] = HEAP32[$177 >> 2] & -2; //@line 86831
    HEAP32[$mem + ($_sum233 + 4) >> 2] = $26 | 1; //@line 86836
    HEAP32[$15 >> 2] = $26; //@line 86838
    return;
   }
   $32 = $21 >>> 3; //@line 86842
   if ($21 >>> 0 < 256) {
    $37 = HEAP32[$mem + ($_sum233 + 8) >> 2] | 0; //@line 86848
    $40 = HEAP32[$mem + ($_sum233 + 12) >> 2] | 0; //@line 86852
    $43 = 62960 + ($32 << 1 << 2) | 0; //@line 86855
    do {
     if (($37 | 0) != ($43 | 0)) {
      if ($37 >>> 0 < $5 >>> 0) {
       _abort(); //@line 86862
      }
      if ((HEAP32[$37 + 12 >> 2] | 0) == ($25 | 0)) {
       break;
      }
      _abort(); //@line 86871
     }
    } while (0);
    if (($40 | 0) == ($37 | 0)) {
     HEAP32[15730] = HEAP32[15730] & ~(1 << $32); //@line 86881
     $p_0 = $25;
     $psize_0 = $26;
     break;
    }
    do {
     if (($40 | 0) == ($43 | 0)) {
      $_pre_phi307 = $40 + 8 | 0; //@line 86889
     } else {
      if ($40 >>> 0 < $5 >>> 0) {
       _abort(); //@line 86894
      }
      $64 = $40 + 8 | 0; //@line 86897
      if ((HEAP32[$64 >> 2] | 0) == ($25 | 0)) {
       $_pre_phi307 = $64; //@line 86901
       break;
      }
      _abort(); //@line 86904
     }
    } while (0);
    HEAP32[$37 + 12 >> 2] = $40; //@line 86910
    HEAP32[$_pre_phi307 >> 2] = $37; //@line 86911
    $p_0 = $25;
    $psize_0 = $26;
    break;
   }
   $69 = $24; //@line 86915
   $72 = HEAP32[$mem + ($_sum233 + 24) >> 2] | 0; //@line 86919
   $75 = HEAP32[$mem + ($_sum233 + 12) >> 2] | 0; //@line 86923
   do {
    if (($75 | 0) == ($69 | 0)) {
     $94 = $mem + ($_sum233 + 20) | 0; //@line 86929
     $95 = HEAP32[$94 >> 2] | 0; //@line 86930
     if (($95 | 0) == 0) {
      $99 = $mem + ($_sum233 + 16) | 0; //@line 86935
      $100 = HEAP32[$99 >> 2] | 0; //@line 86936
      if (($100 | 0) == 0) {
       $R_1 = 0; //@line 86939
       break;
      } else {
       $R_0 = $100;
       $RP_0 = $99;
      }
     } else {
      $R_0 = $95;
      $RP_0 = $94;
     }
     while (1) {
      $102 = $R_0 + 20 | 0; //@line 86950
      $103 = HEAP32[$102 >> 2] | 0; //@line 86951
      if (($103 | 0) != 0) {
       $R_0 = $103;
       $RP_0 = $102;
       continue;
      }
      $106 = $R_0 + 16 | 0; //@line 86957
      $107 = HEAP32[$106 >> 2] | 0; //@line 86958
      if (($107 | 0) == 0) {
       break;
      } else {
       $R_0 = $107;
       $RP_0 = $106;
      }
     }
     if ($RP_0 >>> 0 < $5 >>> 0) {
      _abort(); //@line 86969
     } else {
      HEAP32[$RP_0 >> 2] = 0; //@line 86972
      $R_1 = $R_0; //@line 86973
      break;
     }
    } else {
     $80 = HEAP32[$mem + ($_sum233 + 8) >> 2] | 0; //@line 86980
     if ($80 >>> 0 < $5 >>> 0) {
      _abort(); //@line 86984
     }
     $84 = $80 + 12 | 0; //@line 86987
     if ((HEAP32[$84 >> 2] | 0) != ($69 | 0)) {
      _abort(); //@line 86991
     }
     $88 = $75 + 8 | 0; //@line 86994
     if ((HEAP32[$88 >> 2] | 0) == ($69 | 0)) {
      HEAP32[$84 >> 2] = $75; //@line 86998
      HEAP32[$88 >> 2] = $80; //@line 86999
      $R_1 = $75; //@line 87000
      break;
     } else {
      _abort(); //@line 87003
     }
    }
   } while (0);
   if (($72 | 0) == 0) {
    $p_0 = $25;
    $psize_0 = $26;
    break;
   }
   $118 = $mem + ($_sum233 + 28) | 0; //@line 87016
   $120 = 63224 + (HEAP32[$118 >> 2] << 2) | 0; //@line 87018
   do {
    if (($69 | 0) == (HEAP32[$120 >> 2] | 0)) {
     HEAP32[$120 >> 2] = $R_1; //@line 87023
     if (($R_1 | 0) != 0) {
      break;
     }
     HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$118 >> 2]); //@line 87033
     $p_0 = $25;
     $psize_0 = $26;
     break L26430;
    } else {
     if ($72 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 87041
     }
     $134 = $72 + 16 | 0; //@line 87044
     if ((HEAP32[$134 >> 2] | 0) == ($69 | 0)) {
      HEAP32[$134 >> 2] = $R_1; //@line 87048
     } else {
      HEAP32[$72 + 20 >> 2] = $R_1; //@line 87051
     }
     if (($R_1 | 0) == 0) {
      $p_0 = $25;
      $psize_0 = $26;
      break L26430;
     }
    }
   } while (0);
   if ($R_1 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
    _abort(); //@line 87064
   }
   HEAP32[$R_1 + 24 >> 2] = $72; //@line 87068
   $151 = HEAP32[$mem + ($_sum233 + 16) >> 2] | 0; //@line 87072
   do {
    if (($151 | 0) != 0) {
     if ($151 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 87080
     } else {
      HEAP32[$R_1 + 16 >> 2] = $151; //@line 87084
      HEAP32[$151 + 24 >> 2] = $R_1; //@line 87086
      break;
     }
    }
   } while (0);
   $164 = HEAP32[$mem + ($_sum233 + 20) >> 2] | 0; //@line 87094
   if (($164 | 0) == 0) {
    $p_0 = $25;
    $psize_0 = $26;
    break;
   }
   if ($164 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
    _abort(); //@line 87104
   } else {
    HEAP32[$R_1 + 20 >> 2] = $164; //@line 87108
    HEAP32[$164 + 24 >> 2] = $R_1; //@line 87110
    $p_0 = $25;
    $psize_0 = $26;
    break;
   }
  } else {
   $p_0 = $4;
   $psize_0 = $14;
  }
 } while (0);
 $189 = $p_0; //@line 87120
 if ($189 >>> 0 >= $15 >>> 0) {
  _abort(); //@line 87123
 }
 $193 = $mem + ($14 - 4) | 0; //@line 87128
 $194 = HEAP32[$193 >> 2] | 0; //@line 87129
 if (($194 & 1 | 0) == 0) {
  _abort(); //@line 87133
 }
 do {
  if (($194 & 2 | 0) == 0) {
   if (($16 | 0) == (HEAP32[15736] | 0)) {
    $204 = (HEAP32[15733] | 0) + $psize_0 | 0; //@line 87144
    HEAP32[15733] = $204; //@line 87145
    HEAP32[15736] = $p_0; //@line 87146
    HEAP32[$p_0 + 4 >> 2] = $204 | 1; //@line 87149
    if (($p_0 | 0) == (HEAP32[15735] | 0)) {
     HEAP32[15735] = 0; //@line 87153
     HEAP32[15732] = 0; //@line 87154
    }
    if ($204 >>> 0 <= (HEAP32[15737] | 0) >>> 0) {
     return;
    }
    _sys_trim(0) | 0; //@line 87162
    return;
   }
   if (($16 | 0) == (HEAP32[15735] | 0)) {
    $220 = (HEAP32[15732] | 0) + $psize_0 | 0; //@line 87170
    HEAP32[15732] = $220; //@line 87171
    HEAP32[15735] = $p_0; //@line 87172
    HEAP32[$p_0 + 4 >> 2] = $220 | 1; //@line 87175
    HEAP32[$189 + $220 >> 2] = $220; //@line 87178
    return;
   }
   $227 = ($194 & -8) + $psize_0 | 0; //@line 87183
   $228 = $194 >>> 3; //@line 87184
   L26535 : do {
    if ($194 >>> 0 < 256) {
     $233 = HEAP32[$mem + $14 >> 2] | 0; //@line 87190
     $236 = HEAP32[$mem + ($14 | 4) >> 2] | 0; //@line 87194
     $239 = 62960 + ($228 << 1 << 2) | 0; //@line 87197
     do {
      if (($233 | 0) != ($239 | 0)) {
       if ($233 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 87205
       }
       if ((HEAP32[$233 + 12 >> 2] | 0) == ($16 | 0)) {
        break;
       }
       _abort(); //@line 87214
      }
     } while (0);
     if (($236 | 0) == ($233 | 0)) {
      HEAP32[15730] = HEAP32[15730] & ~(1 << $228); //@line 87224
      break;
     }
     do {
      if (($236 | 0) == ($239 | 0)) {
       $_pre_phi305 = $236 + 8 | 0; //@line 87231
      } else {
       if ($236 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 87237
       }
       $262 = $236 + 8 | 0; //@line 87240
       if ((HEAP32[$262 >> 2] | 0) == ($16 | 0)) {
        $_pre_phi305 = $262; //@line 87244
        break;
       }
       _abort(); //@line 87247
      }
     } while (0);
     HEAP32[$233 + 12 >> 2] = $236; //@line 87253
     HEAP32[$_pre_phi305 >> 2] = $233; //@line 87254
    } else {
     $267 = $15; //@line 87256
     $270 = HEAP32[$mem + ($14 + 16) >> 2] | 0; //@line 87260
     $273 = HEAP32[$mem + ($14 | 4) >> 2] | 0; //@line 87264
     do {
      if (($273 | 0) == ($267 | 0)) {
       $293 = $mem + ($14 + 12) | 0; //@line 87270
       $294 = HEAP32[$293 >> 2] | 0; //@line 87271
       if (($294 | 0) == 0) {
        $298 = $mem + ($14 + 8) | 0; //@line 87276
        $299 = HEAP32[$298 >> 2] | 0; //@line 87277
        if (($299 | 0) == 0) {
         $R7_1 = 0; //@line 87280
         break;
        } else {
         $R7_0 = $299;
         $RP9_0 = $298;
        }
       } else {
        $R7_0 = $294;
        $RP9_0 = $293;
       }
       while (1) {
        $301 = $R7_0 + 20 | 0; //@line 87291
        $302 = HEAP32[$301 >> 2] | 0; //@line 87292
        if (($302 | 0) != 0) {
         $R7_0 = $302;
         $RP9_0 = $301;
         continue;
        }
        $305 = $R7_0 + 16 | 0; //@line 87298
        $306 = HEAP32[$305 >> 2] | 0; //@line 87299
        if (($306 | 0) == 0) {
         break;
        } else {
         $R7_0 = $306;
         $RP9_0 = $305;
        }
       }
       if ($RP9_0 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 87311
       } else {
        HEAP32[$RP9_0 >> 2] = 0; //@line 87314
        $R7_1 = $R7_0; //@line 87315
        break;
       }
      } else {
       $278 = HEAP32[$mem + $14 >> 2] | 0; //@line 87321
       if ($278 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 87326
       }
       $283 = $278 + 12 | 0; //@line 87329
       if ((HEAP32[$283 >> 2] | 0) != ($267 | 0)) {
        _abort(); //@line 87333
       }
       $287 = $273 + 8 | 0; //@line 87336
       if ((HEAP32[$287 >> 2] | 0) == ($267 | 0)) {
        HEAP32[$283 >> 2] = $273; //@line 87340
        HEAP32[$287 >> 2] = $278; //@line 87341
        $R7_1 = $273; //@line 87342
        break;
       } else {
        _abort(); //@line 87345
       }
      }
     } while (0);
     if (($270 | 0) == 0) {
      break;
     }
     $318 = $mem + ($14 + 20) | 0; //@line 87357
     $320 = 63224 + (HEAP32[$318 >> 2] << 2) | 0; //@line 87359
     do {
      if (($267 | 0) == (HEAP32[$320 >> 2] | 0)) {
       HEAP32[$320 >> 2] = $R7_1; //@line 87364
       if (($R7_1 | 0) != 0) {
        break;
       }
       HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$318 >> 2]); //@line 87374
       break L26535;
      } else {
       if ($270 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 87381
       }
       $334 = $270 + 16 | 0; //@line 87384
       if ((HEAP32[$334 >> 2] | 0) == ($267 | 0)) {
        HEAP32[$334 >> 2] = $R7_1; //@line 87388
       } else {
        HEAP32[$270 + 20 >> 2] = $R7_1; //@line 87391
       }
       if (($R7_1 | 0) == 0) {
        break L26535;
       }
      }
     } while (0);
     if ($R7_1 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 87403
     }
     HEAP32[$R7_1 + 24 >> 2] = $270; //@line 87407
     $351 = HEAP32[$mem + ($14 + 8) >> 2] | 0; //@line 87411
     do {
      if (($351 | 0) != 0) {
       if ($351 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 87419
       } else {
        HEAP32[$R7_1 + 16 >> 2] = $351; //@line 87423
        HEAP32[$351 + 24 >> 2] = $R7_1; //@line 87425
        break;
       }
      }
     } while (0);
     $364 = HEAP32[$mem + ($14 + 12) >> 2] | 0; //@line 87433
     if (($364 | 0) == 0) {
      break;
     }
     if ($364 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 87442
     } else {
      HEAP32[$R7_1 + 20 >> 2] = $364; //@line 87446
      HEAP32[$364 + 24 >> 2] = $R7_1; //@line 87448
      break;
     }
    }
   } while (0);
   HEAP32[$p_0 + 4 >> 2] = $227 | 1; //@line 87455
   HEAP32[$189 + $227 >> 2] = $227; //@line 87458
   if (($p_0 | 0) != (HEAP32[15735] | 0)) {
    $psize_1 = $227; //@line 87462
    break;
   }
   HEAP32[15732] = $227; //@line 87465
   return;
  } else {
   HEAP32[$193 >> 2] = $194 & -2; //@line 87470
   HEAP32[$p_0 + 4 >> 2] = $psize_0 | 1; //@line 87473
   HEAP32[$189 + $psize_0 >> 2] = $psize_0; //@line 87476
   $psize_1 = $psize_0; //@line 87477
  }
 } while (0);
 $390 = $psize_1 >>> 3; //@line 87481
 if ($psize_1 >>> 0 < 256) {
  $393 = $390 << 1; //@line 87484
  $395 = 62960 + ($393 << 2) | 0; //@line 87486
  $396 = HEAP32[15730] | 0; //@line 87487
  $397 = 1 << $390; //@line 87488
  do {
   if (($396 & $397 | 0) == 0) {
    HEAP32[15730] = $396 | $397; //@line 87494
    $F16_0 = $395;
    $_pre_phi = 62960 + ($393 + 2 << 2) | 0;
   } else {
    $403 = 62960 + ($393 + 2 << 2) | 0; //@line 87500
    $404 = HEAP32[$403 >> 2] | 0; //@line 87501
    if ($404 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
     $F16_0 = $404;
     $_pre_phi = $403;
     break;
    }
    _abort(); //@line 87509
   }
  } while (0);
  HEAP32[$_pre_phi >> 2] = $p_0; //@line 87515
  HEAP32[$F16_0 + 12 >> 2] = $p_0; //@line 87517
  HEAP32[$p_0 + 8 >> 2] = $F16_0; //@line 87519
  HEAP32[$p_0 + 12 >> 2] = $395; //@line 87521
  return;
 }
 $414 = $p_0; //@line 87525
 $415 = $psize_1 >>> 8; //@line 87526
 do {
  if (($415 | 0) == 0) {
   $I18_0 = 0; //@line 87530
  } else {
   if ($psize_1 >>> 0 > 16777215) {
    $I18_0 = 31; //@line 87534
    break;
   }
   $422 = ($415 + 1048320 | 0) >>> 16 & 8; //@line 87539
   $423 = $415 << $422; //@line 87540
   $426 = ($423 + 520192 | 0) >>> 16 & 4; //@line 87543
   $428 = $423 << $426; //@line 87545
   $431 = ($428 + 245760 | 0) >>> 16 & 2; //@line 87548
   $436 = 14 - ($426 | $422 | $431) + ($428 << $431 >>> 15) | 0; //@line 87553
   $I18_0 = $psize_1 >>> (($436 + 7 | 0) >>> 0) & 1 | $436 << 1; //@line 87559
  }
 } while (0);
 $443 = 63224 + ($I18_0 << 2) | 0; //@line 87563
 HEAP32[$p_0 + 28 >> 2] = $I18_0; //@line 87566
 HEAP32[$p_0 + 20 >> 2] = 0; //@line 87568
 HEAP32[$p_0 + 16 >> 2] = 0; //@line 87570
 $447 = HEAP32[15731] | 0; //@line 87571
 $448 = 1 << $I18_0; //@line 87572
 do {
  if (($447 & $448 | 0) == 0) {
   HEAP32[15731] = $447 | $448; //@line 87578
   HEAP32[$443 >> 2] = $414; //@line 87579
   HEAP32[$p_0 + 24 >> 2] = $443; //@line 87582
   HEAP32[$p_0 + 12 >> 2] = $p_0; //@line 87584
   HEAP32[$p_0 + 8 >> 2] = $p_0; //@line 87586
  } else {
   if (($I18_0 | 0) == 31) {
    $463 = 0; //@line 87591
   } else {
    $463 = 25 - ($I18_0 >>> 1) | 0; //@line 87595
   }
   $K19_0 = $psize_1 << $463;
   $T_0 = HEAP32[$443 >> 2] | 0;
   while (1) {
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($psize_1 | 0)) {
     break;
    }
    $472 = $T_0 + 16 + ($K19_0 >>> 31 << 2) | 0; //@line 87611
    $473 = HEAP32[$472 >> 2] | 0; //@line 87612
    if (($473 | 0) == 0) {
     label = 20507; //@line 87616
     break;
    } else {
     $K19_0 = $K19_0 << 1;
     $T_0 = $473;
    }
   }
   if ((label | 0) == 20507) {
    if ($472 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
     _abort(); //@line 87627
    } else {
     HEAP32[$472 >> 2] = $414; //@line 87630
     HEAP32[$p_0 + 24 >> 2] = $T_0; //@line 87633
     HEAP32[$p_0 + 12 >> 2] = $p_0; //@line 87635
     HEAP32[$p_0 + 8 >> 2] = $p_0; //@line 87637
     break;
    }
   }
   $486 = $T_0 + 8 | 0; //@line 87641
   $487 = HEAP32[$486 >> 2] | 0; //@line 87642
   $489 = HEAP32[15734] | 0; //@line 87644
   if ($T_0 >>> 0 < $489 >>> 0) {
    _abort(); //@line 87647
   }
   if ($487 >>> 0 < $489 >>> 0) {
    _abort(); //@line 87653
   } else {
    HEAP32[$487 + 12 >> 2] = $414; //@line 87657
    HEAP32[$486 >> 2] = $414; //@line 87658
    HEAP32[$p_0 + 8 >> 2] = $487; //@line 87661
    HEAP32[$p_0 + 12 >> 2] = $T_0; //@line 87664
    HEAP32[$p_0 + 24 >> 2] = 0; //@line 87666
    break;
   }
  }
 } while (0);
 $501 = (HEAP32[15738] | 0) - 1 | 0; //@line 87672
 HEAP32[15738] = $501; //@line 87673
 if (($501 | 0) == 0) {
  $sp_0_in_i = 63376; //@line 87676
 } else {
  return;
 }
 while (1) {
  $sp_0_i = HEAP32[$sp_0_in_i >> 2] | 0; //@line 87683
  if (($sp_0_i | 0) == 0) {
   break;
  } else {
   $sp_0_in_i = $sp_0_i + 8 | 0; //@line 87689
  }
 }
 HEAP32[15738] = -1; //@line 87692
 return;
}
function _realloc($oldmem, $bytes) {
 $oldmem = $oldmem | 0;
 $bytes = $bytes | 0;
 var $14 = 0, $17 = 0, $23 = 0, $28 = 0, $33 = 0, $35 = 0, $mem_0 = 0;
 if (($oldmem | 0) == 0) {
  $mem_0 = _malloc($bytes) | 0; //@line 87710
  return $mem_0 | 0; //@line 87713
 }
 if ($bytes >>> 0 > 4294967231) {
  HEAP32[(___errno_location() | 0) >> 2] = 12; //@line 87718
  $mem_0 = 0; //@line 87719
  return $mem_0 | 0; //@line 87722
 }
 if ($bytes >>> 0 < 11) {
  $14 = 16; //@line 87726
 } else {
  $14 = $bytes + 11 & -8; //@line 87730
 }
 $17 = _try_realloc_chunk($oldmem - 8 | 0, $14) | 0; //@line 87735
 if (($17 | 0) != 0) {
  $mem_0 = $17 + 8 | 0; //@line 87740
  return $mem_0 | 0; //@line 87743
 }
 $23 = _malloc($bytes) | 0; //@line 87745
 if (($23 | 0) == 0) {
  $mem_0 = 0; //@line 87748
  return $mem_0 | 0; //@line 87751
 }
 $28 = HEAP32[$oldmem - 4 >> 2] | 0; //@line 87755
 $33 = ($28 & -8) - (($28 & 3 | 0) == 0 ? 8 : 4) | 0; //@line 87760
 $35 = $33 >>> 0 < $bytes >>> 0 ? $33 : $bytes; //@line 87762
 _memcpy($23 | 0, $oldmem | 0, $35) | 0; //@line 87763
 _free($oldmem); //@line 87764
 $mem_0 = $23; //@line 87765
 return $mem_0 | 0; //@line 87768
}
function _sys_trim($pad) {
 $pad = $pad | 0;
 var $4 = 0, $15 = 0, $19 = 0, $22 = 0, $28 = 0, $29 = 0, $sp_0_i = 0, $32 = 0, $41 = 0, $_0_i = 0, $48 = 0, $51 = 0, $59 = 0, $60 = 0, $66 = 0, $73 = 0, $75 = 0, $76 = 0, $78 = 0, $85 = 0, $88 = 0, $released_2 = 0;
 do {
  if ((HEAP32[15676] | 0) == 0) {
   $4 = _sysconf(8) | 0; //@line 87792
   if (($4 - 1 & $4 | 0) == 0) {
    HEAP32[15678] = $4; //@line 87797
    HEAP32[15677] = $4; //@line 87798
    HEAP32[15679] = -1; //@line 87799
    HEAP32[15680] = 2097152; //@line 87800
    HEAP32[15681] = 0; //@line 87801
    HEAP32[15841] = 0; //@line 87802
    HEAP32[15676] = (_time(0) | 0) & -16 ^ 1431655768; //@line 87806
    break;
   } else {
    _abort(); //@line 87809
    return 0; //@line 87809
   }
  }
 } while (0);
 if ($pad >>> 0 >= 4294967232) {
  $released_2 = 0; //@line 87816
  return $released_2 | 0; //@line 87819
 }
 $15 = HEAP32[15736] | 0; //@line 87821
 if (($15 | 0) == 0) {
  $released_2 = 0; //@line 87824
  return $released_2 | 0; //@line 87827
 }
 $19 = HEAP32[15733] | 0; //@line 87830
 do {
  if ($19 >>> 0 > ($pad + 40 | 0) >>> 0) {
   $22 = HEAP32[15678] | 0; //@line 87834
   $28 = Math_imul((((-40 - $pad - 1 + $19 + $22 | 0) >>> 0) / ($22 >>> 0) | 0) - 1 | 0, $22) | 0; //@line 87841
   $29 = $15; //@line 87842
   $sp_0_i = 63368; //@line 87843
   while (1) {
    $32 = HEAP32[$sp_0_i >> 2] | 0; //@line 87847
    if ($32 >>> 0 <= $29 >>> 0) {
     if (($32 + (HEAP32[$sp_0_i + 4 >> 2] | 0) | 0) >>> 0 > $29 >>> 0) {
      $_0_i = $sp_0_i; //@line 87855
      break;
     }
    }
    $41 = HEAP32[$sp_0_i + 8 >> 2] | 0; //@line 87860
    if (($41 | 0) == 0) {
     $_0_i = 0; //@line 87863
     break;
    } else {
     $sp_0_i = $41; //@line 87866
    }
   }
   if ((HEAP32[$_0_i + 12 >> 2] & 8 | 0) != 0) {
    break;
   }
   $48 = _sbrk(0) | 0; //@line 87877
   $51 = $_0_i + 4 | 0; //@line 87880
   if (($48 | 0) != ((HEAP32[$_0_i >> 2] | 0) + (HEAP32[$51 >> 2] | 0) | 0)) {
    break;
   }
   $59 = _sbrk(-($28 >>> 0 > 2147483646 ? -2147483648 - $22 | 0 : $28) | 0) | 0; //@line 87891
   $60 = _sbrk(0) | 0; //@line 87892
   if (!(($59 | 0) != -1 & $60 >>> 0 < $48 >>> 0)) {
    break;
   }
   $66 = $48 - $60 | 0; //@line 87901
   if (($48 | 0) == ($60 | 0)) {
    break;
   }
   HEAP32[$51 >> 2] = (HEAP32[$51 >> 2] | 0) - $66; //@line 87908
   HEAP32[15838] = (HEAP32[15838] | 0) - $66; //@line 87911
   $73 = HEAP32[15736] | 0; //@line 87912
   $75 = (HEAP32[15733] | 0) - $66 | 0; //@line 87914
   $76 = $73; //@line 87915
   $78 = $73 + 8 | 0; //@line 87917
   if (($78 & 7 | 0) == 0) {
    $85 = 0; //@line 87921
   } else {
    $85 = -$78 & 7; //@line 87925
   }
   $88 = $75 - $85 | 0; //@line 87930
   HEAP32[15736] = $76 + $85; //@line 87931
   HEAP32[15733] = $88; //@line 87932
   HEAP32[$76 + ($85 + 4) >> 2] = $88 | 1; //@line 87937
   HEAP32[$76 + ($75 + 4) >> 2] = 40; //@line 87941
   HEAP32[15737] = HEAP32[15680]; //@line 87943
   $released_2 = ($48 | 0) != ($60 | 0) | 0; //@line 87946
   return $released_2 | 0; //@line 87949
  }
 } while (0);
 if ((HEAP32[15733] | 0) >>> 0 <= (HEAP32[15737] | 0) >>> 0) {
  $released_2 = 0; //@line 87956
  return $released_2 | 0; //@line 87959
 }
 HEAP32[15737] = -1; //@line 87961
 $released_2 = 0; //@line 87962
 return $released_2 | 0; //@line 87965
}
function _try_realloc_chunk($p, $nb) {
 $p = $p | 0;
 $nb = $nb | 0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $10 = 0, $15 = 0, $16 = 0, $34 = 0, $52 = 0, $55 = 0, $69 = 0, $72 = 0, $86 = 0, $94 = 0, $storemerge27 = 0, $storemerge = 0, $103 = 0, $106 = 0, $107 = 0, $112 = 0, $115 = 0, $118 = 0, $139 = 0, $_pre_phi = 0, $144 = 0, $147 = 0, $150 = 0, $155 = 0, $159 = 0, $163 = 0, $169 = 0, $170 = 0, $174 = 0, $175 = 0, $RP_0 = 0, $R_0 = 0, $177 = 0, $178 = 0, $181 = 0, $182 = 0, $R_1 = 0, $193 = 0, $195 = 0, $209 = 0, $226 = 0, $239 = 0, $258 = 0, $272 = 0, $newp_0 = 0;
 $1 = $p + 4 | 0; //@line 88005
 $2 = HEAP32[$1 >> 2] | 0; //@line 88006
 $3 = $2 & -8; //@line 88007
 $4 = $p; //@line 88008
 $5 = $4 + $3 | 0; //@line 88009
 $6 = $5; //@line 88010
 $7 = HEAP32[15734] | 0; //@line 88011
 if ($4 >>> 0 < $7 >>> 0) {
  _abort(); //@line 88014
  return 0; //@line 88014
 }
 $10 = $2 & 3; //@line 88017
 if (!(($10 | 0) != 1 & $4 >>> 0 < $5 >>> 0)) {
  _abort(); //@line 88022
  return 0; //@line 88022
 }
 $15 = $4 + ($3 | 4) | 0; //@line 88027
 $16 = HEAP32[$15 >> 2] | 0; //@line 88028
 if (($16 & 1 | 0) == 0) {
  _abort(); //@line 88032
  return 0; //@line 88032
 }
 if (($10 | 0) == 0) {
  if ($nb >>> 0 < 256) {
   $newp_0 = 0; //@line 88039
   return $newp_0 | 0; //@line 88042
  }
  do {
   if ($3 >>> 0 >= ($nb + 4 | 0) >>> 0) {
    if (($3 - $nb | 0) >>> 0 > HEAP32[15678] << 1 >>> 0) {
     break;
    } else {
     $newp_0 = $p; //@line 88055
    }
    return $newp_0 | 0; //@line 88059
   }
  } while (0);
  $newp_0 = 0; //@line 88062
  return $newp_0 | 0; //@line 88065
 }
 if ($3 >>> 0 >= $nb >>> 0) {
  $34 = $3 - $nb | 0; //@line 88069
  if ($34 >>> 0 <= 15) {
   $newp_0 = $p; //@line 88072
   return $newp_0 | 0; //@line 88075
  }
  HEAP32[$1 >> 2] = $2 & 1 | $nb | 2; //@line 88082
  HEAP32[$4 + ($nb + 4) >> 2] = $34 | 3; //@line 88087
  HEAP32[$15 >> 2] = HEAP32[$15 >> 2] | 1; //@line 88090
  _dispose_chunk($4 + $nb | 0, $34); //@line 88091
  $newp_0 = $p; //@line 88092
  return $newp_0 | 0; //@line 88095
 }
 if (($6 | 0) == (HEAP32[15736] | 0)) {
  $52 = (HEAP32[15733] | 0) + $3 | 0; //@line 88101
  if ($52 >>> 0 <= $nb >>> 0) {
   $newp_0 = 0; //@line 88104
   return $newp_0 | 0; //@line 88107
  }
  $55 = $52 - $nb | 0; //@line 88109
  HEAP32[$1 >> 2] = $2 & 1 | $nb | 2; //@line 88115
  HEAP32[$4 + ($nb + 4) >> 2] = $55 | 1; //@line 88120
  HEAP32[15736] = $4 + $nb; //@line 88121
  HEAP32[15733] = $55; //@line 88122
  $newp_0 = $p; //@line 88123
  return $newp_0 | 0; //@line 88126
 }
 if (($6 | 0) == (HEAP32[15735] | 0)) {
  $69 = (HEAP32[15732] | 0) + $3 | 0; //@line 88132
  if ($69 >>> 0 < $nb >>> 0) {
   $newp_0 = 0; //@line 88135
   return $newp_0 | 0; //@line 88138
  }
  $72 = $69 - $nb | 0; //@line 88140
  if ($72 >>> 0 > 15) {
   HEAP32[$1 >> 2] = $2 & 1 | $nb | 2; //@line 88149
   HEAP32[$4 + ($nb + 4) >> 2] = $72 | 1; //@line 88154
   HEAP32[$4 + $69 >> 2] = $72; //@line 88156
   $86 = $4 + ($69 + 4) | 0; //@line 88159
   HEAP32[$86 >> 2] = HEAP32[$86 >> 2] & -2; //@line 88162
   $storemerge = $4 + $nb | 0;
   $storemerge27 = $72;
  } else {
   HEAP32[$1 >> 2] = $2 & 1 | $69 | 2; //@line 88168
   $94 = $4 + ($69 + 4) | 0; //@line 88171
   HEAP32[$94 >> 2] = HEAP32[$94 >> 2] | 1; //@line 88174
   $storemerge = 0;
   $storemerge27 = 0;
  }
  HEAP32[15732] = $storemerge27; //@line 88179
  HEAP32[15735] = $storemerge; //@line 88180
  $newp_0 = $p; //@line 88181
  return $newp_0 | 0; //@line 88184
 }
 if (($16 & 2 | 0) != 0) {
  $newp_0 = 0; //@line 88189
  return $newp_0 | 0; //@line 88192
 }
 $103 = ($16 & -8) + $3 | 0; //@line 88195
 if ($103 >>> 0 < $nb >>> 0) {
  $newp_0 = 0; //@line 88198
  return $newp_0 | 0; //@line 88201
 }
 $106 = $103 - $nb | 0; //@line 88203
 $107 = $16 >>> 3; //@line 88204
 L26756 : do {
  if ($16 >>> 0 < 256) {
   $112 = HEAP32[$4 + ($3 + 8) >> 2] | 0; //@line 88211
   $115 = HEAP32[$4 + ($3 + 12) >> 2] | 0; //@line 88215
   $118 = 62960 + ($107 << 1 << 2) | 0; //@line 88218
   do {
    if (($112 | 0) != ($118 | 0)) {
     if ($112 >>> 0 < $7 >>> 0) {
      _abort(); //@line 88225
      return 0; //@line 88225
     }
     if ((HEAP32[$112 + 12 >> 2] | 0) == ($6 | 0)) {
      break;
     }
     _abort(); //@line 88234
     return 0; //@line 88234
    }
   } while (0);
   if (($115 | 0) == ($112 | 0)) {
    HEAP32[15730] = HEAP32[15730] & ~(1 << $107); //@line 88244
    break;
   }
   do {
    if (($115 | 0) == ($118 | 0)) {
     $_pre_phi = $115 + 8 | 0; //@line 88251
    } else {
     if ($115 >>> 0 < $7 >>> 0) {
      _abort(); //@line 88256
      return 0; //@line 88256
     }
     $139 = $115 + 8 | 0; //@line 88259
     if ((HEAP32[$139 >> 2] | 0) == ($6 | 0)) {
      $_pre_phi = $139; //@line 88263
      break;
     }
     _abort(); //@line 88266
     return 0; //@line 88266
    }
   } while (0);
   HEAP32[$112 + 12 >> 2] = $115; //@line 88272
   HEAP32[$_pre_phi >> 2] = $112; //@line 88273
  } else {
   $144 = $5; //@line 88275
   $147 = HEAP32[$4 + ($3 + 24) >> 2] | 0; //@line 88279
   $150 = HEAP32[$4 + ($3 + 12) >> 2] | 0; //@line 88283
   do {
    if (($150 | 0) == ($144 | 0)) {
     $169 = $4 + ($3 + 20) | 0; //@line 88289
     $170 = HEAP32[$169 >> 2] | 0; //@line 88290
     if (($170 | 0) == 0) {
      $174 = $4 + ($3 + 16) | 0; //@line 88295
      $175 = HEAP32[$174 >> 2] | 0; //@line 88296
      if (($175 | 0) == 0) {
       $R_1 = 0; //@line 88299
       break;
      } else {
       $R_0 = $175;
       $RP_0 = $174;
      }
     } else {
      $R_0 = $170;
      $RP_0 = $169;
     }
     while (1) {
      $177 = $R_0 + 20 | 0; //@line 88310
      $178 = HEAP32[$177 >> 2] | 0; //@line 88311
      if (($178 | 0) != 0) {
       $R_0 = $178;
       $RP_0 = $177;
       continue;
      }
      $181 = $R_0 + 16 | 0; //@line 88317
      $182 = HEAP32[$181 >> 2] | 0; //@line 88318
      if (($182 | 0) == 0) {
       break;
      } else {
       $R_0 = $182;
       $RP_0 = $181;
      }
     }
     if ($RP_0 >>> 0 < $7 >>> 0) {
      _abort(); //@line 88329
      return 0; //@line 88329
     } else {
      HEAP32[$RP_0 >> 2] = 0; //@line 88332
      $R_1 = $R_0; //@line 88333
      break;
     }
    } else {
     $155 = HEAP32[$4 + ($3 + 8) >> 2] | 0; //@line 88340
     if ($155 >>> 0 < $7 >>> 0) {
      _abort(); //@line 88344
      return 0; //@line 88344
     }
     $159 = $155 + 12 | 0; //@line 88347
     if ((HEAP32[$159 >> 2] | 0) != ($144 | 0)) {
      _abort(); //@line 88351
      return 0; //@line 88351
     }
     $163 = $150 + 8 | 0; //@line 88354
     if ((HEAP32[$163 >> 2] | 0) == ($144 | 0)) {
      HEAP32[$159 >> 2] = $150; //@line 88358
      HEAP32[$163 >> 2] = $155; //@line 88359
      $R_1 = $150; //@line 88360
      break;
     } else {
      _abort(); //@line 88363
      return 0; //@line 88363
     }
    }
   } while (0);
   if (($147 | 0) == 0) {
    break;
   }
   $193 = $4 + ($3 + 28) | 0; //@line 88375
   $195 = 63224 + (HEAP32[$193 >> 2] << 2) | 0; //@line 88377
   do {
    if (($144 | 0) == (HEAP32[$195 >> 2] | 0)) {
     HEAP32[$195 >> 2] = $R_1; //@line 88382
     if (($R_1 | 0) != 0) {
      break;
     }
     HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$193 >> 2]); //@line 88392
     break L26756;
    } else {
     if ($147 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 88399
      return 0; //@line 88399
     }
     $209 = $147 + 16 | 0; //@line 88402
     if ((HEAP32[$209 >> 2] | 0) == ($144 | 0)) {
      HEAP32[$209 >> 2] = $R_1; //@line 88406
     } else {
      HEAP32[$147 + 20 >> 2] = $R_1; //@line 88409
     }
     if (($R_1 | 0) == 0) {
      break L26756;
     }
    }
   } while (0);
   if ($R_1 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
    _abort(); //@line 88421
    return 0; //@line 88421
   }
   HEAP32[$R_1 + 24 >> 2] = $147; //@line 88425
   $226 = HEAP32[$4 + ($3 + 16) >> 2] | 0; //@line 88429
   do {
    if (($226 | 0) != 0) {
     if ($226 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 88437
      return 0; //@line 88437
     } else {
      HEAP32[$R_1 + 16 >> 2] = $226; //@line 88441
      HEAP32[$226 + 24 >> 2] = $R_1; //@line 88443
      break;
     }
    }
   } while (0);
   $239 = HEAP32[$4 + ($3 + 20) >> 2] | 0; //@line 88451
   if (($239 | 0) == 0) {
    break;
   }
   if ($239 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
    _abort(); //@line 88460
    return 0; //@line 88460
   } else {
    HEAP32[$R_1 + 20 >> 2] = $239; //@line 88464
    HEAP32[$239 + 24 >> 2] = $R_1; //@line 88466
    break;
   }
  }
 } while (0);
 if ($106 >>> 0 < 16) {
  HEAP32[$1 >> 2] = $103 | HEAP32[$1 >> 2] & 1 | 2; //@line 88477
  $258 = $4 + ($103 | 4) | 0; //@line 88480
  HEAP32[$258 >> 2] = HEAP32[$258 >> 2] | 1; //@line 88483
  $newp_0 = $p; //@line 88484
  return $newp_0 | 0; //@line 88487
 } else {
  HEAP32[$1 >> 2] = HEAP32[$1 >> 2] & 1 | $nb | 2; //@line 88495
  HEAP32[$4 + ($nb + 4) >> 2] = $106 | 3; //@line 88500
  $272 = $4 + ($103 | 4) | 0; //@line 88503
  HEAP32[$272 >> 2] = HEAP32[$272 >> 2] | 1; //@line 88506
  _dispose_chunk($4 + $nb | 0, $106); //@line 88507
  $newp_0 = $p; //@line 88508
  return $newp_0 | 0; //@line 88511
 }
 return 0;
}
function _dispose_chunk($p, $psize) {
 $p = $p | 0;
 $psize = $psize | 0;
 var $1 = 0, $2 = 0, $3 = 0, $5 = 0, $10 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $24 = 0, $29 = 0, $32 = 0, $35 = 0, $56 = 0, $_pre_phi63 = 0, $61 = 0, $64 = 0, $67 = 0, $72 = 0, $76 = 0, $80 = 0, $_sum28 = 0, $86 = 0, $87 = 0, $91 = 0, $92 = 0, $RP_0 = 0, $R_0 = 0, $94 = 0, $95 = 0, $98 = 0, $99 = 0, $R_1 = 0, $110 = 0, $112 = 0, $126 = 0, $_sum31 = 0, $143 = 0, $156 = 0, $169 = 0, $_0277 = 0, $_0 = 0, $181 = 0, $185 = 0, $186 = 0, $194 = 0, $205 = 0, $213 = 0, $214 = 0, $219 = 0, $222 = 0, $225 = 0, $246 = 0, $_pre_phi61 = 0, $251 = 0, $254 = 0, $257 = 0, $262 = 0, $266 = 0, $270 = 0, $276 = 0, $277 = 0, $281 = 0, $282 = 0, $RP9_0 = 0, $R7_0 = 0, $284 = 0, $285 = 0, $288 = 0, $289 = 0, $R7_1 = 0, $300 = 0, $302 = 0, $316 = 0, $333 = 0, $346 = 0, $_1 = 0, $374 = 0, $377 = 0, $379 = 0, $380 = 0, $381 = 0, $387 = 0, $388 = 0, $_pre_phi = 0, $F16_0 = 0, $398 = 0, $399 = 0, $406 = 0, $407 = 0, $410 = 0, $412 = 0, $415 = 0, $420 = 0, $I19_0 = 0, $427 = 0, $431 = 0, $432 = 0, $447 = 0, $T_0 = 0, $K20_0 = 0, $456 = 0, $457 = 0, $470 = 0, $471 = 0, $473 = 0, label = 0;
 $1 = $p; //@line 88574
 $2 = $1 + $psize | 0; //@line 88575
 $3 = $2; //@line 88576
 $5 = HEAP32[$p + 4 >> 2] | 0; //@line 88578
 L26832 : do {
  if (($5 & 1 | 0) == 0) {
   $10 = HEAP32[$p >> 2] | 0; //@line 88584
   if (($5 & 3 | 0) == 0) {
    return;
   }
   $15 = $1 + (-$10 | 0) | 0; //@line 88592
   $16 = $15; //@line 88593
   $17 = $10 + $psize | 0; //@line 88594
   $18 = HEAP32[15734] | 0; //@line 88595
   if ($15 >>> 0 < $18 >>> 0) {
    _abort(); //@line 88598
   }
   if (($16 | 0) == (HEAP32[15735] | 0)) {
    $169 = $1 + ($psize + 4) | 0; //@line 88606
    if ((HEAP32[$169 >> 2] & 3 | 0) != 3) {
     $_0 = $16;
     $_0277 = $17;
     break;
    }
    HEAP32[15732] = $17; //@line 88614
    HEAP32[$169 >> 2] = HEAP32[$169 >> 2] & -2; //@line 88617
    HEAP32[$1 + (4 - $10) >> 2] = $17 | 1; //@line 88622
    HEAP32[$2 >> 2] = $17; //@line 88624
    return;
   }
   $24 = $10 >>> 3; //@line 88628
   if ($10 >>> 0 < 256) {
    $29 = HEAP32[$1 + (8 - $10) >> 2] | 0; //@line 88634
    $32 = HEAP32[$1 + (12 - $10) >> 2] | 0; //@line 88638
    $35 = 62960 + ($24 << 1 << 2) | 0; //@line 88641
    do {
     if (($29 | 0) != ($35 | 0)) {
      if ($29 >>> 0 < $18 >>> 0) {
       _abort(); //@line 88648
      }
      if ((HEAP32[$29 + 12 >> 2] | 0) == ($16 | 0)) {
       break;
      }
      _abort(); //@line 88657
     }
    } while (0);
    if (($32 | 0) == ($29 | 0)) {
     HEAP32[15730] = HEAP32[15730] & ~(1 << $24); //@line 88667
     $_0 = $16;
     $_0277 = $17;
     break;
    }
    do {
     if (($32 | 0) == ($35 | 0)) {
      $_pre_phi63 = $32 + 8 | 0; //@line 88675
     } else {
      if ($32 >>> 0 < $18 >>> 0) {
       _abort(); //@line 88680
      }
      $56 = $32 + 8 | 0; //@line 88683
      if ((HEAP32[$56 >> 2] | 0) == ($16 | 0)) {
       $_pre_phi63 = $56; //@line 88687
       break;
      }
      _abort(); //@line 88690
     }
    } while (0);
    HEAP32[$29 + 12 >> 2] = $32; //@line 88696
    HEAP32[$_pre_phi63 >> 2] = $29; //@line 88697
    $_0 = $16;
    $_0277 = $17;
    break;
   }
   $61 = $15; //@line 88701
   $64 = HEAP32[$1 + (24 - $10) >> 2] | 0; //@line 88705
   $67 = HEAP32[$1 + (12 - $10) >> 2] | 0; //@line 88709
   do {
    if (($67 | 0) == ($61 | 0)) {
     $_sum28 = 16 - $10 | 0; //@line 88713
     $86 = $1 + ($_sum28 + 4) | 0; //@line 88716
     $87 = HEAP32[$86 >> 2] | 0; //@line 88717
     if (($87 | 0) == 0) {
      $91 = $1 + $_sum28 | 0; //@line 88721
      $92 = HEAP32[$91 >> 2] | 0; //@line 88722
      if (($92 | 0) == 0) {
       $R_1 = 0; //@line 88725
       break;
      } else {
       $R_0 = $92;
       $RP_0 = $91;
      }
     } else {
      $R_0 = $87;
      $RP_0 = $86;
     }
     while (1) {
      $94 = $R_0 + 20 | 0; //@line 88736
      $95 = HEAP32[$94 >> 2] | 0; //@line 88737
      if (($95 | 0) != 0) {
       $R_0 = $95;
       $RP_0 = $94;
       continue;
      }
      $98 = $R_0 + 16 | 0; //@line 88743
      $99 = HEAP32[$98 >> 2] | 0; //@line 88744
      if (($99 | 0) == 0) {
       break;
      } else {
       $R_0 = $99;
       $RP_0 = $98;
      }
     }
     if ($RP_0 >>> 0 < $18 >>> 0) {
      _abort(); //@line 88755
     } else {
      HEAP32[$RP_0 >> 2] = 0; //@line 88758
      $R_1 = $R_0; //@line 88759
      break;
     }
    } else {
     $72 = HEAP32[$1 + (8 - $10) >> 2] | 0; //@line 88766
     if ($72 >>> 0 < $18 >>> 0) {
      _abort(); //@line 88770
     }
     $76 = $72 + 12 | 0; //@line 88773
     if ((HEAP32[$76 >> 2] | 0) != ($61 | 0)) {
      _abort(); //@line 88777
     }
     $80 = $67 + 8 | 0; //@line 88780
     if ((HEAP32[$80 >> 2] | 0) == ($61 | 0)) {
      HEAP32[$76 >> 2] = $67; //@line 88784
      HEAP32[$80 >> 2] = $72; //@line 88785
      $R_1 = $67; //@line 88786
      break;
     } else {
      _abort(); //@line 88789
     }
    }
   } while (0);
   if (($64 | 0) == 0) {
    $_0 = $16;
    $_0277 = $17;
    break;
   }
   $110 = $1 + (28 - $10) | 0; //@line 88802
   $112 = 63224 + (HEAP32[$110 >> 2] << 2) | 0; //@line 88804
   do {
    if (($61 | 0) == (HEAP32[$112 >> 2] | 0)) {
     HEAP32[$112 >> 2] = $R_1; //@line 88809
     if (($R_1 | 0) != 0) {
      break;
     }
     HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$110 >> 2]); //@line 88819
     $_0 = $16;
     $_0277 = $17;
     break L26832;
    } else {
     if ($64 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 88827
     }
     $126 = $64 + 16 | 0; //@line 88830
     if ((HEAP32[$126 >> 2] | 0) == ($61 | 0)) {
      HEAP32[$126 >> 2] = $R_1; //@line 88834
     } else {
      HEAP32[$64 + 20 >> 2] = $R_1; //@line 88837
     }
     if (($R_1 | 0) == 0) {
      $_0 = $16;
      $_0277 = $17;
      break L26832;
     }
    }
   } while (0);
   if ($R_1 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
    _abort(); //@line 88850
   }
   HEAP32[$R_1 + 24 >> 2] = $64; //@line 88854
   $_sum31 = 16 - $10 | 0; //@line 88855
   $143 = HEAP32[$1 + $_sum31 >> 2] | 0; //@line 88858
   do {
    if (($143 | 0) != 0) {
     if ($143 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 88866
     } else {
      HEAP32[$R_1 + 16 >> 2] = $143; //@line 88870
      HEAP32[$143 + 24 >> 2] = $R_1; //@line 88872
      break;
     }
    }
   } while (0);
   $156 = HEAP32[$1 + ($_sum31 + 4) >> 2] | 0; //@line 88880
   if (($156 | 0) == 0) {
    $_0 = $16;
    $_0277 = $17;
    break;
   }
   if ($156 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
    _abort(); //@line 88890
   } else {
    HEAP32[$R_1 + 20 >> 2] = $156; //@line 88894
    HEAP32[$156 + 24 >> 2] = $R_1; //@line 88896
    $_0 = $16;
    $_0277 = $17;
    break;
   }
  } else {
   $_0 = $p;
   $_0277 = $psize;
  }
 } while (0);
 $181 = HEAP32[15734] | 0; //@line 88906
 if ($2 >>> 0 < $181 >>> 0) {
  _abort(); //@line 88909
 }
 $185 = $1 + ($psize + 4) | 0; //@line 88914
 $186 = HEAP32[$185 >> 2] | 0; //@line 88915
 do {
  if (($186 & 2 | 0) == 0) {
   if (($3 | 0) == (HEAP32[15736] | 0)) {
    $194 = (HEAP32[15733] | 0) + $_0277 | 0; //@line 88924
    HEAP32[15733] = $194; //@line 88925
    HEAP32[15736] = $_0; //@line 88926
    HEAP32[$_0 + 4 >> 2] = $194 | 1; //@line 88929
    if (($_0 | 0) != (HEAP32[15735] | 0)) {
     return;
    }
    HEAP32[15735] = 0; //@line 88936
    HEAP32[15732] = 0; //@line 88937
    return;
   }
   if (($3 | 0) == (HEAP32[15735] | 0)) {
    $205 = (HEAP32[15732] | 0) + $_0277 | 0; //@line 88945
    HEAP32[15732] = $205; //@line 88946
    HEAP32[15735] = $_0; //@line 88947
    HEAP32[$_0 + 4 >> 2] = $205 | 1; //@line 88950
    HEAP32[$_0 + $205 >> 2] = $205; //@line 88954
    return;
   }
   $213 = ($186 & -8) + $_0277 | 0; //@line 88959
   $214 = $186 >>> 3; //@line 88960
   L26932 : do {
    if ($186 >>> 0 < 256) {
     $219 = HEAP32[$1 + ($psize + 8) >> 2] | 0; //@line 88967
     $222 = HEAP32[$1 + ($psize + 12) >> 2] | 0; //@line 88971
     $225 = 62960 + ($214 << 1 << 2) | 0; //@line 88974
     do {
      if (($219 | 0) != ($225 | 0)) {
       if ($219 >>> 0 < $181 >>> 0) {
        _abort(); //@line 88981
       }
       if ((HEAP32[$219 + 12 >> 2] | 0) == ($3 | 0)) {
        break;
       }
       _abort(); //@line 88990
      }
     } while (0);
     if (($222 | 0) == ($219 | 0)) {
      HEAP32[15730] = HEAP32[15730] & ~(1 << $214); //@line 89000
      break;
     }
     do {
      if (($222 | 0) == ($225 | 0)) {
       $_pre_phi61 = $222 + 8 | 0; //@line 89007
      } else {
       if ($222 >>> 0 < $181 >>> 0) {
        _abort(); //@line 89012
       }
       $246 = $222 + 8 | 0; //@line 89015
       if ((HEAP32[$246 >> 2] | 0) == ($3 | 0)) {
        $_pre_phi61 = $246; //@line 89019
        break;
       }
       _abort(); //@line 89022
      }
     } while (0);
     HEAP32[$219 + 12 >> 2] = $222; //@line 89028
     HEAP32[$_pre_phi61 >> 2] = $219; //@line 89029
    } else {
     $251 = $2; //@line 89031
     $254 = HEAP32[$1 + ($psize + 24) >> 2] | 0; //@line 89035
     $257 = HEAP32[$1 + ($psize + 12) >> 2] | 0; //@line 89039
     do {
      if (($257 | 0) == ($251 | 0)) {
       $276 = $1 + ($psize + 20) | 0; //@line 89045
       $277 = HEAP32[$276 >> 2] | 0; //@line 89046
       if (($277 | 0) == 0) {
        $281 = $1 + ($psize + 16) | 0; //@line 89051
        $282 = HEAP32[$281 >> 2] | 0; //@line 89052
        if (($282 | 0) == 0) {
         $R7_1 = 0; //@line 89055
         break;
        } else {
         $R7_0 = $282;
         $RP9_0 = $281;
        }
       } else {
        $R7_0 = $277;
        $RP9_0 = $276;
       }
       while (1) {
        $284 = $R7_0 + 20 | 0; //@line 89066
        $285 = HEAP32[$284 >> 2] | 0; //@line 89067
        if (($285 | 0) != 0) {
         $R7_0 = $285;
         $RP9_0 = $284;
         continue;
        }
        $288 = $R7_0 + 16 | 0; //@line 89073
        $289 = HEAP32[$288 >> 2] | 0; //@line 89074
        if (($289 | 0) == 0) {
         break;
        } else {
         $R7_0 = $289;
         $RP9_0 = $288;
        }
       }
       if ($RP9_0 >>> 0 < $181 >>> 0) {
        _abort(); //@line 89085
       } else {
        HEAP32[$RP9_0 >> 2] = 0; //@line 89088
        $R7_1 = $R7_0; //@line 89089
        break;
       }
      } else {
       $262 = HEAP32[$1 + ($psize + 8) >> 2] | 0; //@line 89096
       if ($262 >>> 0 < $181 >>> 0) {
        _abort(); //@line 89100
       }
       $266 = $262 + 12 | 0; //@line 89103
       if ((HEAP32[$266 >> 2] | 0) != ($251 | 0)) {
        _abort(); //@line 89107
       }
       $270 = $257 + 8 | 0; //@line 89110
       if ((HEAP32[$270 >> 2] | 0) == ($251 | 0)) {
        HEAP32[$266 >> 2] = $257; //@line 89114
        HEAP32[$270 >> 2] = $262; //@line 89115
        $R7_1 = $257; //@line 89116
        break;
       } else {
        _abort(); //@line 89119
       }
      }
     } while (0);
     if (($254 | 0) == 0) {
      break;
     }
     $300 = $1 + ($psize + 28) | 0; //@line 89131
     $302 = 63224 + (HEAP32[$300 >> 2] << 2) | 0; //@line 89133
     do {
      if (($251 | 0) == (HEAP32[$302 >> 2] | 0)) {
       HEAP32[$302 >> 2] = $R7_1; //@line 89138
       if (($R7_1 | 0) != 0) {
        break;
       }
       HEAP32[15731] = HEAP32[15731] & ~(1 << HEAP32[$300 >> 2]); //@line 89148
       break L26932;
      } else {
       if ($254 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 89155
       }
       $316 = $254 + 16 | 0; //@line 89158
       if ((HEAP32[$316 >> 2] | 0) == ($251 | 0)) {
        HEAP32[$316 >> 2] = $R7_1; //@line 89162
       } else {
        HEAP32[$254 + 20 >> 2] = $R7_1; //@line 89165
       }
       if (($R7_1 | 0) == 0) {
        break L26932;
       }
      }
     } while (0);
     if ($R7_1 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 89177
     }
     HEAP32[$R7_1 + 24 >> 2] = $254; //@line 89181
     $333 = HEAP32[$1 + ($psize + 16) >> 2] | 0; //@line 89185
     do {
      if (($333 | 0) != 0) {
       if ($333 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
        _abort(); //@line 89193
       } else {
        HEAP32[$R7_1 + 16 >> 2] = $333; //@line 89197
        HEAP32[$333 + 24 >> 2] = $R7_1; //@line 89199
        break;
       }
      }
     } while (0);
     $346 = HEAP32[$1 + ($psize + 20) >> 2] | 0; //@line 89207
     if (($346 | 0) == 0) {
      break;
     }
     if ($346 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
      _abort(); //@line 89216
     } else {
      HEAP32[$R7_1 + 20 >> 2] = $346; //@line 89220
      HEAP32[$346 + 24 >> 2] = $R7_1; //@line 89222
      break;
     }
    }
   } while (0);
   HEAP32[$_0 + 4 >> 2] = $213 | 1; //@line 89229
   HEAP32[$_0 + $213 >> 2] = $213; //@line 89233
   if (($_0 | 0) != (HEAP32[15735] | 0)) {
    $_1 = $213; //@line 89237
    break;
   }
   HEAP32[15732] = $213; //@line 89240
   return;
  } else {
   HEAP32[$185 >> 2] = $186 & -2; //@line 89245
   HEAP32[$_0 + 4 >> 2] = $_0277 | 1; //@line 89248
   HEAP32[$_0 + $_0277 >> 2] = $_0277; //@line 89252
   $_1 = $_0277; //@line 89253
  }
 } while (0);
 $374 = $_1 >>> 3; //@line 89257
 if ($_1 >>> 0 < 256) {
  $377 = $374 << 1; //@line 89260
  $379 = 62960 + ($377 << 2) | 0; //@line 89262
  $380 = HEAP32[15730] | 0; //@line 89263
  $381 = 1 << $374; //@line 89264
  do {
   if (($380 & $381 | 0) == 0) {
    HEAP32[15730] = $380 | $381; //@line 89270
    $F16_0 = $379;
    $_pre_phi = 62960 + ($377 + 2 << 2) | 0;
   } else {
    $387 = 62960 + ($377 + 2 << 2) | 0; //@line 89276
    $388 = HEAP32[$387 >> 2] | 0; //@line 89277
    if ($388 >>> 0 >= (HEAP32[15734] | 0) >>> 0) {
     $F16_0 = $388;
     $_pre_phi = $387;
     break;
    }
    _abort(); //@line 89285
   }
  } while (0);
  HEAP32[$_pre_phi >> 2] = $_0; //@line 89291
  HEAP32[$F16_0 + 12 >> 2] = $_0; //@line 89293
  HEAP32[$_0 + 8 >> 2] = $F16_0; //@line 89295
  HEAP32[$_0 + 12 >> 2] = $379; //@line 89297
  return;
 }
 $398 = $_0; //@line 89301
 $399 = $_1 >>> 8; //@line 89302
 do {
  if (($399 | 0) == 0) {
   $I19_0 = 0; //@line 89306
  } else {
   if ($_1 >>> 0 > 16777215) {
    $I19_0 = 31; //@line 89310
    break;
   }
   $406 = ($399 + 1048320 | 0) >>> 16 & 8; //@line 89315
   $407 = $399 << $406; //@line 89316
   $410 = ($407 + 520192 | 0) >>> 16 & 4; //@line 89319
   $412 = $407 << $410; //@line 89321
   $415 = ($412 + 245760 | 0) >>> 16 & 2; //@line 89324
   $420 = 14 - ($410 | $406 | $415) + ($412 << $415 >>> 15) | 0; //@line 89329
   $I19_0 = $_1 >>> (($420 + 7 | 0) >>> 0) & 1 | $420 << 1; //@line 89335
  }
 } while (0);
 $427 = 63224 + ($I19_0 << 2) | 0; //@line 89339
 HEAP32[$_0 + 28 >> 2] = $I19_0; //@line 89342
 HEAP32[$_0 + 20 >> 2] = 0; //@line 89344
 HEAP32[$_0 + 16 >> 2] = 0; //@line 89346
 $431 = HEAP32[15731] | 0; //@line 89347
 $432 = 1 << $I19_0; //@line 89348
 if (($431 & $432 | 0) == 0) {
  HEAP32[15731] = $431 | $432; //@line 89353
  HEAP32[$427 >> 2] = $398; //@line 89354
  HEAP32[$_0 + 24 >> 2] = $427; //@line 89357
  HEAP32[$_0 + 12 >> 2] = $_0; //@line 89359
  HEAP32[$_0 + 8 >> 2] = $_0; //@line 89361
  return;
 }
 if (($I19_0 | 0) == 31) {
  $447 = 0; //@line 89368
 } else {
  $447 = 25 - ($I19_0 >>> 1) | 0; //@line 89372
 }
 $K20_0 = $_1 << $447;
 $T_0 = HEAP32[$427 >> 2] | 0;
 while (1) {
  if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($_1 | 0)) {
   break;
  }
  $456 = $T_0 + 16 + ($K20_0 >>> 31 << 2) | 0; //@line 89388
  $457 = HEAP32[$456 >> 2] | 0; //@line 89389
  if (($457 | 0) == 0) {
   label = 20813; //@line 89393
   break;
  } else {
   $K20_0 = $K20_0 << 1;
   $T_0 = $457;
  }
 }
 if ((label | 0) == 20813) {
  if ($456 >>> 0 < (HEAP32[15734] | 0) >>> 0) {
   _abort(); //@line 89404
  }
  HEAP32[$456 >> 2] = $398; //@line 89407
  HEAP32[$_0 + 24 >> 2] = $T_0; //@line 89410
  HEAP32[$_0 + 12 >> 2] = $_0; //@line 89412
  HEAP32[$_0 + 8 >> 2] = $_0; //@line 89414
  return;
 }
 $470 = $T_0 + 8 | 0; //@line 89418
 $471 = HEAP32[$470 >> 2] | 0; //@line 89419
 $473 = HEAP32[15734] | 0; //@line 89421
 if ($T_0 >>> 0 < $473 >>> 0) {
  _abort(); //@line 89424
 }
 if ($471 >>> 0 < $473 >>> 0) {
  _abort(); //@line 89430
 }
 HEAP32[$471 + 12 >> 2] = $398; //@line 89434
 HEAP32[$470 >> 2] = $398; //@line 89435
 HEAP32[$_0 + 8 >> 2] = $471; //@line 89438
 HEAP32[$_0 + 12 >> 2] = $T_0; //@line 89441
 HEAP32[$_0 + 24 >> 2] = 0; //@line 89443
 return;
}
function _memset(ptr, value, num) {
 ptr = ptr | 0;
 value = value | 0;
 num = num | 0;
 var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
 stop = ptr + num | 0; //@line 89452
 if ((num | 0) >= 20) {
  value = value & 255; //@line 89455
  unaligned = ptr & 3; //@line 89456
  value4 = value | value << 8 | value << 16 | value << 24; //@line 89457
  stop4 = stop & ~3; //@line 89458
  if (unaligned) {
   unaligned = ptr + 4 - unaligned | 0; //@line 89460
   while ((ptr | 0) < (unaligned | 0)) {
    HEAP8[ptr] = value; //@line 89462
    ptr = ptr + 1 | 0; //@line 89463
   }
  }
  while ((ptr | 0) < (stop4 | 0)) {
   HEAP32[ptr >> 2] = value4; //@line 89467
   ptr = ptr + 4 | 0; //@line 89468
  }
 }
 while ((ptr | 0) < (stop | 0)) {
  HEAP8[ptr] = value; //@line 89472
  ptr = ptr + 1 | 0; //@line 89473
 }
}
function _memcpy(dest, src, num) {
 dest = dest | 0;
 src = src | 0;
 num = num | 0;
 var ret = 0;
 ret = dest | 0; //@line 89479
 if ((dest & 3) == (src & 3)) {
  while (dest & 3) {
   if ((num | 0) == 0) return ret | 0; //@line 89482
   HEAP8[dest] = HEAP8[src] | 0; //@line 89483
   dest = dest + 1 | 0; //@line 89484
   src = src + 1 | 0; //@line 89485
   num = num - 1 | 0; //@line 89486
  }
  while ((num | 0) >= 4) {
   HEAP32[dest >> 2] = HEAP32[src >> 2]; //@line 89489
   dest = dest + 4 | 0; //@line 89490
   src = src + 4 | 0; //@line 89491
   num = num - 4 | 0; //@line 89492
  }
 }
 while ((num | 0) > 0) {
  HEAP8[dest] = HEAP8[src] | 0; //@line 89496
  dest = dest + 1 | 0; //@line 89497
  src = src + 1 | 0; //@line 89498
  num = num - 1 | 0; //@line 89499
 }
 return ret | 0; //@line 89501
}
function _strlen(ptr) {
 ptr = ptr | 0;
 var curr = 0;
 curr = ptr; //@line 89506
 while (HEAP8[curr] | 0) {
  curr = curr + 1 | 0; //@line 89508
 }
 return curr - ptr | 0; //@line 89510
}
function _strcat(pdest, psrc) {
 pdest = pdest | 0;
 psrc = psrc | 0;
 var i = 0, pdestEnd = 0;
 pdestEnd = pdest + (_strlen(pdest) | 0) | 0; //@line 89516
 do {
  HEAP8[pdestEnd + i | 0] = HEAP8[psrc + i | 0]; //@line 89518
  i = i + 1 | 0; //@line 89519
 } while (HEAP8[psrc + (i - 1) | 0] | 0);
 return pdest | 0; //@line 89521
}
function _memcmp(p1, p2, num) {
 p1 = p1 | 0;
 p2 = p2 | 0;
 num = num | 0;
 var i = 0, v1 = 0, v2 = 0;
 while ((i | 0) < (num | 0)) {
  v1 = HEAPU8[p1 + i | 0] | 0;
  v2 = HEAPU8[p2 + i | 0] | 0;
  if ((v1 | 0) != (v2 | 0)) return ((v1 | 0) > (v2 | 0) ? 1 : -1) | 0; //@line 89529
  i = i + 1 | 0; //@line 89530
 }
 return 0; //@line 89532
}
function _strcpy(pdest, psrc) {
 pdest = pdest | 0;
 psrc = psrc | 0;
 var i = 0;
 do {
  HEAP8[pdest + i | 0] = HEAP8[psrc + i | 0]; //@line 89538
  i = i + 1 | 0; //@line 89539
 } while (HEAP8[psrc + (i - 1) | 0] | 0);
 return pdest | 0; //@line 89541
}
function _tolower(chr) {
 chr = chr | 0;
 if ((chr | 0) < 65) return chr | 0; //@line 89545
 if ((chr | 0) > 90) return chr | 0; //@line 89546
 return chr - 65 + 97 | 0; //@line 89547
}
function _strncasecmp(px, py, n) {
 px = px | 0;
 py = py | 0;
 n = n | 0;
 var i = 0, x = 0, y = 0;
 while (i >>> 0 < n >>> 0) {
  x = _tolower(HEAP8[px + i | 0] | 0) | 0; //@line 89553
  y = _tolower(HEAP8[py + i | 0] | 0) | 0; //@line 89554
  if ((x | 0) == (y | 0) & (x | 0) == 0) return 0; //@line 89555
  if ((x | 0) == 0) return -1;
  if ((y | 0) == 0) return 1; //@line 89557
  if ((x | 0) == (y | 0)) {
   i = i + 1 | 0; //@line 89559
   continue;
  } else {
   return (x >>> 0 > y >>> 0 ? 1 : -1) | 0; //@line 89562
  }
 }
 return 0; //@line 89565
}
function _strcasecmp(px, py) {
 px = px | 0;
 py = py | 0;
 return _strncasecmp(px, py, -1) | 0; //@line 89569
}
function _i64Add(a, b, c, d) {
 a = a | 0;
 b = b | 0;
 c = c | 0;
 d = d | 0;
 var l = 0;
 l = a + c >>> 0; //@line 89581
 return (tempRet0 = b + d + (l >>> 0 < a >>> 0 | 0) >>> 0, l | 0) | 0; //@line 89583
}
function _i64Subtract(a, b, c, d) {
 a = a | 0;
 b = b | 0;
 c = c | 0;
 d = d | 0;
 var h = 0;
 h = b - d >>> 0; //@line 89589
 h = b - d - (c >>> 0 > a >>> 0 | 0) >>> 0; //@line 89590
 return (tempRet0 = h, a - c >>> 0 | 0) | 0; //@line 89591
}
function _bitshift64Shl(low, high, bits) {
 low = low | 0;
 high = high | 0;
 bits = bits | 0;
 if ((bits | 0) < 32) {
  tempRet0 = high << bits | (low & (1 << bits) - 1 << 32 - bits) >>> 32 - bits; //@line 89598
  return low << bits; //@line 89599
 }
 tempRet0 = low << bits - 32; //@line 89601
 return 0; //@line 89602
}
function _bitshift64Lshr(low, high, bits) {
 low = low | 0;
 high = high | 0;
 bits = bits | 0;
 if ((bits | 0) < 32) {
  tempRet0 = high >>> bits; //@line 89609
  return low >>> bits | (high & (1 << bits) - 1) << 32 - bits; //@line 89610
 }
 tempRet0 = 0; //@line 89612
 return high >>> bits - 32 | 0; //@line 89613
}
function _bitshift64Ashr(low, high, bits) {
 low = low | 0;
 high = high | 0;
 bits = bits | 0;
 if ((bits | 0) < 32) {
  tempRet0 = high >> bits; //@line 89620
  return low >>> bits | (high & (1 << bits) - 1) << 32 - bits; //@line 89621
 }
 tempRet0 = (high | 0) < 0 ? -1 : 0; //@line 89623
 return high >> bits - 32 | 0; //@line 89624
}
function _llvm_ctlz_i32(x) {
 x = x | 0;
 var ret = 0;
 ret = HEAP8[ctlz_i8 + (x >>> 24) | 0] | 0; //@line 89629
 if ((ret | 0) < 8) return ret | 0; //@line 89630
 ret = HEAP8[ctlz_i8 + (x >> 16 & 255) | 0] | 0;
 if ((ret | 0) < 8) return ret + 8 | 0; //@line 89632
 ret = HEAP8[ctlz_i8 + (x >> 8 & 255) | 0] | 0;
 if ((ret | 0) < 8) return ret + 16 | 0; //@line 89634
 return (HEAP8[ctlz_i8 + (x & 255) | 0] | 0) + 24 | 0; //@line 89635
}
function _llvm_cttz_i32(x) {
 x = x | 0;
 var ret = 0;
 ret = HEAP8[cttz_i8 + (x & 255) | 0] | 0; //@line 89641
 if ((ret | 0) < 8) return ret | 0; //@line 89642
 ret = HEAP8[cttz_i8 + (x >> 8 & 255) | 0] | 0;
 if ((ret | 0) < 8) return ret + 8 | 0; //@line 89644
 ret = HEAP8[cttz_i8 + (x >> 16 & 255) | 0] | 0;
 if ((ret | 0) < 8) return ret + 16 | 0; //@line 89646
 return (HEAP8[cttz_i8 + (x >>> 24) | 0] | 0) + 24 | 0; //@line 89647
}
function ___muldsi3($a, $b) {
 $a = $a | 0;
 $b = $b | 0;
 var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
 $1 = $a & 65535; //@line 89655
 $2 = $b & 65535; //@line 89656
 $3 = Math_imul($2, $1) | 0; //@line 89657
 $6 = $a >>> 16; //@line 89658
 $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0; //@line 89659
 $11 = $b >>> 16; //@line 89660
 $12 = Math_imul($11, $1) | 0; //@line 89661
 return (tempRet0 = ($8 >>> 16) + (Math_imul($11, $6) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, $8 + $12 << 16 | $3 & 65535 | 0) | 0; //@line 89662
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $7$0 = 0, $7$1 = 0, $10$0 = 0;
 $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 89670
 $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 89671
 $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 89672
 $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 89673
 $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0; //@line 89674
 $4$1 = tempRet0; //@line 89675
 $7$0 = $2$0 ^ $1$0; //@line 89677
 $7$1 = $2$1 ^ $1$1; //@line 89678
 $10$0 = _i64Subtract((___udivmoddi4($4$0, $4$1, _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0, tempRet0, 0) | 0) ^ $7$0, tempRet0 ^ $7$1, $7$0, $7$1) | 0; //@line 89680
 return (tempRet0 = tempRet0, $10$0) | 0; //@line 89681
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
 __stackBase__ = STACKTOP; //@line 89689
 STACKTOP = STACKTOP + 8 | 0; //@line 89690
 $rem = __stackBase__ | 0; //@line 89691
 $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 89692
 $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1; //@line 89693
 $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 89694
 $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1; //@line 89695
 $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0; //@line 89696
 $4$1 = tempRet0; //@line 89697
 $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0; //@line 89698
 ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, $rem) | 0; //@line 89699
 $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0, HEAP32[$rem + 4 >> 2] ^ $1$1, $1$0, $1$1) | 0; //@line 89700
 $10$1 = tempRet0; //@line 89701
 STACKTOP = __stackBase__; //@line 89702
 return (tempRet0 = $10$1, $10$0) | 0; //@line 89703
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0;
 $x_sroa_0_0_extract_trunc = $a$0; //@line 89711
 $y_sroa_0_0_extract_trunc = $b$0; //@line 89712
 $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0; //@line 89713
 $1$1 = tempRet0; //@line 89714
 return (tempRet0 = (Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0) + (Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $1$1 | $1$1 & 0, $1$0 | 0 | 0) | 0; //@line 89716
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $1$0 = 0;
 $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0; //@line 89724
 return (tempRet0 = tempRet0, $1$0) | 0; //@line 89725
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 var $rem = 0, __stackBase__ = 0;
 __stackBase__ = STACKTOP; //@line 89733
 STACKTOP = STACKTOP + 8 | 0; //@line 89734
 $rem = __stackBase__ | 0; //@line 89735
 ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0; //@line 89736
 STACKTOP = __stackBase__; //@line 89737
 return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0; //@line 89738
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
 $a$0 = $a$0 | 0;
 $a$1 = $a$1 | 0;
 $b$0 = $b$0 | 0;
 $b$1 = $b$1 | 0;
 $rem = $rem | 0;
 var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $_0$0 = 0, $_0$1 = 0;
 $n_sroa_0_0_extract_trunc = $a$0; //@line 7
 $n_sroa_1_4_extract_shift$0 = $a$1; //@line 8
 $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0; //@line 9
 $d_sroa_0_0_extract_trunc = $b$0; //@line 10
 $d_sroa_1_4_extract_shift$0 = $b$1; //@line 11
 $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0; //@line 12
 if (($n_sroa_1_4_extract_trunc | 0) == 0) {
  $4 = ($rem | 0) != 0; //@line 14
  if (($d_sroa_1_4_extract_trunc | 0) == 0) {
   if ($4) {
    HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0); //@line 17
    HEAP32[$rem + 4 >> 2] = 0; //@line 18
   }
   $_0$1 = 0; //@line 20
   $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0; //@line 21
   return (tempRet0 = $_0$1, $_0$0) | 0; //@line 22
  } else {
   if (!$4) {
    $_0$1 = 0; //@line 25
    $_0$0 = 0; //@line 26
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 27
   }
   HEAP32[$rem >> 2] = $a$0 | 0; //@line 29
   HEAP32[$rem + 4 >> 2] = $a$1 & 0; //@line 30
   $_0$1 = 0; //@line 31
   $_0$0 = 0; //@line 32
   return (tempRet0 = $_0$1, $_0$0) | 0; //@line 33
  }
 }
 $17 = ($d_sroa_1_4_extract_trunc | 0) == 0; //@line 36
 do {
  if (($d_sroa_0_0_extract_trunc | 0) == 0) {
   if ($17) {
    if (($rem | 0) != 0) {
     HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0); //@line 41
     HEAP32[$rem + 4 >> 2] = 0; //@line 42
    }
    $_0$1 = 0; //@line 44
    $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0; //@line 45
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 46
   }
   if (($n_sroa_0_0_extract_trunc | 0) == 0) {
    if (($rem | 0) != 0) {
     HEAP32[$rem >> 2] = 0; //@line 50
     HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0); //@line 51
    }
    $_0$1 = 0; //@line 53
    $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0; //@line 54
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 55
   }
   $37 = $d_sroa_1_4_extract_trunc - 1 | 0; //@line 57
   if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
    if (($rem | 0) != 0) {
     HEAP32[$rem >> 2] = $a$0 | 0; //@line 60
     HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0; //@line 61
    }
    $_0$1 = 0; //@line 63
    $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0); //@line 64
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 65
   }
   $51 = (_llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0) - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0; //@line 68
   if ($51 >>> 0 <= 30) {
    $57 = $51 + 1 | 0; //@line 70
    $58 = 31 - $51 | 0; //@line 71
    $sr_1_ph = $57; //@line 72
    $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0); //@line 73
    $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0); //@line 74
    $q_sroa_0_1_ph = 0; //@line 75
    $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58; //@line 76
    break;
   }
   if (($rem | 0) == 0) {
    $_0$1 = 0; //@line 80
    $_0$0 = 0; //@line 81
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 82
   }
   HEAP32[$rem >> 2] = $a$0 | 0; //@line 84
   HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0; //@line 85
   $_0$1 = 0; //@line 86
   $_0$0 = 0; //@line 87
   return (tempRet0 = $_0$1, $_0$0) | 0; //@line 88
  } else {
   if (!$17) {
    $119 = (_llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0) - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0; //@line 92
    if ($119 >>> 0 <= 31) {
     $125 = $119 + 1 | 0; //@line 94
     $126 = 31 - $119 | 0; //@line 95
     $130 = $119 - 31 >> 31; //@line 96
     $sr_1_ph = $125; //@line 97
     $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126; //@line 98
     $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130; //@line 99
     $q_sroa_0_1_ph = 0; //@line 100
     $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126; //@line 101
     break;
    }
    if (($rem | 0) == 0) {
     $_0$1 = 0; //@line 105
     $_0$0 = 0; //@line 106
     return (tempRet0 = $_0$1, $_0$0) | 0; //@line 107
    }
    HEAP32[$rem >> 2] = $a$0 | 0; //@line 109
    HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0; //@line 110
    $_0$1 = 0; //@line 111
    $_0$0 = 0; //@line 112
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 113
   }
   $66 = $d_sroa_0_0_extract_trunc - 1 | 0; //@line 115
   if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
    $88 = (_llvm_ctlz_i32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0; //@line 118
    $89 = 64 - $88 | 0; //@line 119
    $91 = 32 - $88 | 0; //@line 120
    $92 = $91 >> 31; //@line 121
    $95 = $88 - 32 | 0; //@line 122
    $105 = $95 >> 31; //@line 123
    $sr_1_ph = $88; //@line 124
    $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105; //@line 125
    $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0); //@line 126
    $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92; //@line 127
    $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31; //@line 128
    break;
   }
   if (($rem | 0) != 0) {
    HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc; //@line 132
    HEAP32[$rem + 4 >> 2] = 0; //@line 133
   }
   if (($d_sroa_0_0_extract_trunc | 0) == 1) {
    $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0; //@line 136
    $_0$0 = $a$0 | 0 | 0; //@line 137
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 138
   } else {
    $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0; //@line 140
    $_0$1 = $n_sroa_1_4_extract_trunc >>> ($78 >>> 0) | 0; //@line 141
    $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0; //@line 142
    return (tempRet0 = $_0$1, $_0$0) | 0; //@line 143
   }
  }
 } while (0);
 if (($sr_1_ph | 0) == 0) {
  $q_sroa_1_1_lcssa = $q_sroa_1_1_ph; //@line 148
  $q_sroa_0_1_lcssa = $q_sroa_0_1_ph; //@line 149
  $r_sroa_1_1_lcssa = $r_sroa_1_1_ph; //@line 150
  $r_sroa_0_1_lcssa = $r_sroa_0_1_ph; //@line 151
  $carry_0_lcssa$1 = 0; //@line 152
  $carry_0_lcssa$0 = 0; //@line 153
 } else {
  $d_sroa_0_0_insert_insert99$0 = $b$0 | 0 | 0; //@line 155
  $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0; //@line 156
  $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0, $d_sroa_0_0_insert_insert99$1, -1, -1) | 0; //@line 157
  $137$1 = tempRet0; //@line 158
  $q_sroa_1_1198 = $q_sroa_1_1_ph; //@line 159
  $q_sroa_0_1199 = $q_sroa_0_1_ph; //@line 160
  $r_sroa_1_1200 = $r_sroa_1_1_ph; //@line 161
  $r_sroa_0_1201 = $r_sroa_0_1_ph; //@line 162
  $sr_1202 = $sr_1_ph; //@line 163
  $carry_0203 = 0; //@line 164
  while (1) {
   $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1; //@line 166
   $149 = $carry_0203 | $q_sroa_0_1199 << 1; //@line 167
   $r_sroa_0_0_insert_insert42$0 = $r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31 | 0; //@line 168
   $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0; //@line 169
   _i64Subtract($137$0, $137$1, $r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1) | 0; //@line 170
   $150$1 = tempRet0; //@line 171
   $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1; //@line 172
   $152 = $151$0 & 1; //@line 173
   $r_sroa_0_0_extract_trunc = _i64Subtract($r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1, $151$0 & $d_sroa_0_0_insert_insert99$0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1) | 0; //@line 175
   $r_sroa_1_4_extract_trunc = tempRet0; //@line 176
   $155 = $sr_1202 - 1 | 0; //@line 177
   if (($155 | 0) == 0) {
    break;
   } else {
    $q_sroa_1_1198 = $147; //@line 181
    $q_sroa_0_1199 = $149; //@line 182
    $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc; //@line 183
    $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc; //@line 184
    $sr_1202 = $155; //@line 185
    $carry_0203 = $152; //@line 186
   }
  }
  $q_sroa_1_1_lcssa = $147; //@line 189
  $q_sroa_0_1_lcssa = $149; //@line 190
  $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc; //@line 191
  $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc; //@line 192
  $carry_0_lcssa$1 = 0; //@line 193
  $carry_0_lcssa$0 = $152; //@line 194
 }
 $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa; //@line 196
 $q_sroa_0_0_insert_ext75$1 = 0; //@line 197
 if (($rem | 0) != 0) {
  HEAP32[$rem >> 2] = $r_sroa_0_1_lcssa; //@line 200
  HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa; //@line 201
 }
 $_0$1 = ($q_sroa_0_0_insert_ext75$0 | 0) >>> 31 | ($q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1) << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1; //@line 203
 $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0; //@line 204
 return (tempRet0 = $_0$1, $_0$0) | 0; //@line 205
}
function dynCall_ii(index, a1) {
 index = index | 0;
 a1 = a1 | 0;
 return FUNCTION_TABLE_ii[index & 31](a1 | 0) | 0; //@line 216
}
function dynCall_viiiii(index, a1, a2, a3, a4, a5) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 a5 = a5 | 0;
 FUNCTION_TABLE_viiiii[index & 3](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0); //@line 223
}
function dynCall_vi(index, a1) {
 index = index | 0;
 a1 = a1 | 0;
 FUNCTION_TABLE_vi[index & 1023](a1 | 0); //@line 230
}
function dynCall_vii(index, a1, a2) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 FUNCTION_TABLE_vii[index & 511](a1 | 0, a2 | 0); //@line 237
}
function dynCall_iiii(index, a1, a2, a3) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 return FUNCTION_TABLE_iiii[index & 127](a1 | 0, a2 | 0, a3 | 0) | 0; //@line 244
}
function dynCall_viii(index, a1, a2, a3) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 FUNCTION_TABLE_viii[index & 63](a1 | 0, a2 | 0, a3 | 0); //@line 251
}
function dynCall_v(index) {
 index = index | 0;
 FUNCTION_TABLE_v[index & 7](); //@line 258
}
function dynCall_iiiii(index, a1, a2, a3, a4) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 return FUNCTION_TABLE_iiiii[index & 127](a1 | 0, a2 | 0, a3 | 0, a4 | 0) | 0; //@line 265
}
function dynCall_iii(index, a1, a2) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 return FUNCTION_TABLE_iii[index & 63](a1 | 0, a2 | 0) | 0; //@line 272
}
function dynCall_iiiiii(index, a1, a2, a3, a4, a5) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 a5 = a5 | 0;
 return FUNCTION_TABLE_iiiiii[index & 7](a1 | 0, a2 | 0, a3 | 0, a4 | 0, a5 | 0) | 0; //@line 279
}
function dynCall_viiii(index, a1, a2, a3, a4) {
 index = index | 0;
 a1 = a1 | 0;
 a2 = a2 | 0;
 a3 = a3 | 0;
 a4 = a4 | 0;
 FUNCTION_TABLE_viiii[index & 7](a1 | 0, a2 | 0, a3 | 0, a4 | 0); //@line 286
}
function b0(p0) {
 p0 = p0 | 0;
 abort(0); //@line 289
 return 0; //@line 289
}
function b1(p0, p1, p2, p3, p4) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 p4 = p4 | 0;
 abort(1); //@line 290
}
function b2(p0) {
 p0 = p0 | 0;
 abort(2); //@line 291
}
function b3(p0, p1) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 abort(3); //@line 292
}
function b4(p0, p1, p2) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 abort(4); //@line 293
 return 0; //@line 293
}
function b5(p0, p1, p2) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 abort(5); //@line 294
}
function b6() {
 abort(6); //@line 295
}
function b7(p0, p1, p2, p3) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 abort(7); //@line 296
 return 0; //@line 296
}
function b8(p0, p1) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 abort(8); //@line 297
 return 0; //@line 297
}
function b9(p0, p1, p2, p3, p4) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 p4 = p4 | 0;
 abort(9); //@line 298
 return 0; //@line 298
}
function b10(p0, p1, p2, p3) {
 p0 = p0 | 0;
 p1 = p1 | 0;
 p2 = p2 | 0;
 p3 = p3 | 0;
 abort(10); //@line 299
}
// EMSCRIPTEN_END_FUNCS
  var FUNCTION_TABLE_ii = [b0,b0,_snd_null_open,b0,_chr_stdio_open,b0,_sdl_close,b0,_snd_sdl_open,b0,_chr_posix_open
  ,b0,_chr_pty_open,b0,_chr_null_open,b0,_chr_mouse_open,b0,_e6522_shift_out,b0,_null_close,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0];
  var FUNCTION_TABLE_viiiii = [b1,b1,_mac_ser_set_comm,b1];
  var FUNCTION_TABLE_vi = [b2,b2,_adb_kbd_del,b2,_op6e00,b2,_snd_sdl_close,b2,_adb_kbd_flush,b2,_op00c0
  ,b2,_op4000,b2,_opd080,b2,_op0180,b2,_opf000,b2,_ope080
  ,b2,_mac_scsi_cmd_mode_select,b2,_op4a00,b2,_op8140,b2,_op4e80,b2,_opc080
  ,b2,_op01c0,b2,_opd0c0,b2,_ope100,b2,_chr_posix_close,b2,_ope0c0
  ,b2,_op4680,b2,_op9080,b2,_op0280,b2,_op53c0,b2,_op0c40
  ,b2,_ope3c0,b2,_op40c0,b2,_sdl_del,b2,_adb_dev_flush,b2,_op50c0
  ,b2,_opb1c0,b2,_opd1c0,b2,_null_del,b2,_op6900,b2,_op63001090
  ,b2,_op6d001100,b2,_op4440,b2,_ope5c0,b2,_op9100,b2,_op6400
  ,b2,_dsk_pce_del,b2,_op5ac0,b2,_op0800,b2,_op5080,b2,_op6700
  ,b2,_opebc0,b2,_op9040,b2,_op0240,b2,_op4880,b2,_op0c00
  ,b2,_op4a40,b2,_op42c0,b2,_ope040,b2,_bp_segofs_del,b2,_op0140
  ,b2,_op57c01078,b2,_op8080,b2,_op5dc0,b2,_op6200,b2,_op4080
  ,b2,_chr_null_close,b2,_op5ac01081,b2,_op0480,b2,_op4640,b2,_op6c00
  ,b2,_op5bc01082,b2,_op3040,b2,_null_update,b2,_op4cc0,b2,_op9140
  ,b2,_adb_kbd_reset,b2,_mac_scsi_cmd_write6_finish,b2,_op6a001097,b2,_op51c0,b2,_opc000
  ,b2,_op0840,b2,_op56c01077,b2,_mac_scsi_cmd_read10,b2,_dsk_img_del,b2,_op1000
  ,b2,_op6d00,b2,_adb_dev_reset,b2,_op4a001068,b2,_op54c01075,b2,_op55c01076
  ,b2,_ope4c0,b2,_opd180,b2,_op4840,b2,_mac_scsi_cmd_format_unit,b2,_op66001093
  ,b2,_op56c0,b2,_ope000,b2,_op0100,b2,_op59c01080,b2,_ope180
  ,b2,_op64001091,b2,_op4600,b2,_op51c01072,b2,_ope9c0,b2,_op0200
  ,b2,_op5cc0,b2,_op54c0,b2,_mac_scsi_cmd_read_capacity,b2,_op4180,b2,_opd100
  ,b2,_op91c0,b2,_op4a801070,b2,_sig_int,b2,_op52c01073,b2,_op6000
  ,b2,_opefc0,b2,_opb100,b2,_op9180,b2,_opc040,b2,_op58c01079
  ,b2,_mac_scsi_cmd_read6,b2,_op5bc0,b2,_adb_mouse_reset,b2,_op5ec0,b2,_op6800
  ,b2,_op0a40,b2,_op90c0,b2,_op7000,b2,_opeac0,b2,_op4800
  ,b2,_op5040,b2,_op6a00,b2,_op5ec01085,b2,_chr_mouse_close,b2,_ope140
  ,b2,_op8000,b2,_opc140,b2,_op5dc01084,b2,_opa000,b2,_op5fc01086
  ,b2,_ope8c0,b2,_op6b001098,b2,_opb140,b2,_op2000,b2,_ope2c0
  ,b2,_op41c0,b2,_op50c01071,b2,_op6600,b2,_ope7c0,b2,_op08c0
  ,b2,_op0e80,b2,_bp_addr_del,b2,_op4a80,b2,_op61001088,b2,_mac_scsi_cmd_verify10
  ,b2,_op6100,b2,_opd140,b2,_op65001092,b2,_op55c0,b2,_op69001096
  ,b2,_op4200,b2,_opd040,b2,_adb_mouse_del,b2,_op0600,b2,_op6b00
  ,b2,_op46c0,b2,_op5000,b2,_adb_mouse_flush,b2,_op60001087,b2,_sdl_update
  ,b2,_null_check,b2,_op5180,b2,_op8040,b2,_op48c0,b2,_op4e40
  ,b2,_op6e001101,b2,_op5cc01083,b2,_op2040,b2,_op4ec0,b2,_op52c0
  ,b2,_bp_expr_del,b2,_mac_scsi_cmd_mode_sense,b2,_mac_scsi_cmd_sense,b2,_op6f00,b2,_op4c00
  ,b2,_op58c0,b2,_sdl_check,b2,_mac_scsi_cmd_read_buffer,b2,_op4100,b2,_chr_pty_close
  ,b2,_opecc0,b2,_opd000,b2,_op4240,b2,_dsk_ram_del,b2,_dsk_dosemu_del
  ,b2,_op0640,b2,_opb000,b2,_dsk_part_del,b2,_op4400,b2,_opeec0
  ,b2,_op59c0,b2,_op6f001102,b2,_e68_op_undefined,b2,_op5fc0,b2,_op67001094
  ,b2,_mac_scsi_cmd_test_unit_ready,b2,_op53c01074,b2,_dsk_psi_del,b2,_op3000,b2,_op80c0
  ,b2,_chr_stdio_close,b2,_op6c001099,b2,_sig_term,b2,_opc100,b2,_op4c40
  ,b2,_op0a80,b2,_sig_segv,b2,_opc0c0,b2,_op57c0,b2,_op4040
  ,b2,_op44c0,b2,_op0680,b2,_op0440,b2,_op8100,b2,_ope6c0
  ,b2,_op6500,b2,_opb040,b2,_op0040,b2,_op5140,b2,_op0e00
  ,b2,_op9000,b2,_op4a401069,b2,_mac_scsi_cmd_start_stop,b2,_opc180,b2,_mac_scsi_cmd_inquiry
  ,b2,_dsk_qed_del,b2,_snd_null_close,b2,_op0a00,b2,_op4280,b2,_ope1c0
  ,b2,_opc1c0,b2,_op5100,b2,_op81c0,b2,_dsk_cow_del,b2,_op6300
  ,b2,_op62001089,b2,_opb0c0,b2,_opb180,b2,_op8180,b2,_op0880
  ,b2,_op0400,b2,_mac_scsi_cmd_write6,b2,_op49c0_00,b2,_op0000,b2,_op49c0
  ,b2,_op0080,b2,_op4ac0,b2,_opb080,b2,_op0e40,b2,_op4480
  ,b2,_op68001095,b2,_mac_scsi_cmd_write10,b2,_op0c80,b2,_op4c80,b2,_mac_scsi_cmd_write10_finish,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2];
  var FUNCTION_TABLE_vii = [b3,b3,_d_b040,b3,_d_c100,b3,_d_9080,b3,_d_8000,b3,_d_0000
  ,b3,_d_0c00,b3,_d_0400,b3,_d_0e40,b3,_d_01c0,b3,_d_4280
  ,b3,_d_4e40,b3,_d_4600,b3,_d_b180,b3,_d_4040,b3,_d_0200
  ,b3,_d_9040,b3,_d_80c0,b3,_d_d180,b3,_d_d0c0,b3,_d_0840
  ,b3,_d_6000,b3,_d_ebc0,b3,_mac_interrupt_scc,b3,_d_90c0,b3,_d_0440
  ,b3,_d_e0c0,b3,_d_0e80,b3,_d_46c0,b3,_d_b000,b3,_d_4240
  ,b3,_d_4ac0,b3,_d_7000,b3,_d_4640,b3,_d_50c0,b3,_mac_log_undef
  ,b3,_d_0180,b3,_d_40c0,b3,_d_e7c0,b3,_d_e8c0,b3,_d_8140
  ,b3,_adb_mouse_talk_done,b3,_d_4a80,b3,_d_e9c0,b3,_d_00c0,b3,_d_8040
  ,b3,_d_0c80,b3,_d_e000,b3,_d_0800,b3,_mac_set_rtc_data,b3,_d_0480
  ,b3,_d_0640,b3,_d_c180,b3,_d_0240,b3,_d_9180,b3,_di_und
  ,b3,_d_8100,b3,_d_1000,b3,_d_e180,b3,_mac_interrupt_osi,b3,_d_4200
  ,b3,_d_d100,b3,_d_e040,b3,_d_4180,b3,_adb_kbd_talk_done,b3,_d_0140
  ,b3,_adb_dev_talk_done,b3,_d_4c80,b3,_d_41c0,b3,_d_e6c0,b3,_d_0a80
  ,b3,_mac_kbd_set_uint8,b3,_d_3040,b3,_d_0600,b3,_d_c1c0,b3,_d_d080
  ,b3,_d_c000,b3,_d_42c0,b3,_d_4a00,b3,_d_e4c0,b3,_bp_addr_print
  ,b3,_d_e140,b3,_d_e5c0,b3,_d_4800,b3,_mac_kbd_set_data,b3,_d_e3c0
  ,b3,_d_4e80,b3,_d_5000,b3,_d_d140,b3,_d_e080,b3,_d_0880
  ,b3,_d_04c0,b3,_mac_set_reset,b3,_d_0100,b3,_d_4440,b3,_d_a000
  ,b3,_d_0080,b3,_d_3000,b3,_d_0a40,b3,_d_efc0,b3,_d_9100
  ,b3,_d_c040,b3,_mac_set_adb_int,b3,_bp_expr_print,b3,_d_5180,b3,_d_4a40
  ,b3,_d_e100,b3,_d_4840,b3,_d_eec0,b3,_d_5040,b3,_d_e2c0
  ,b3,_mac_set_iwm_motor,b3,_d_8180,b3,_d_ecc0,b3,_d_4400,b3,_d_0040
  ,b3,_d_c0c0,b3,_d_0a00,b3,_d_b1c0,b3,_mac_interrupt_via,b3,_d_b0c0
  ,b3,_d_4080,b3,_d_b100,b3,_mac_interrupt_vbi,b3,_d_d000,b3,_d_0680
  ,b3,_e6522_shift_in,b3,_d_5140,b3,_mac_ser_set_out,b3,_d_91c0,b3,_d_4880
  ,b3,_d_4cc0,b3,_d_e1c0,b3,_d_08c0,b3,_d_9140,b3,_d_81c0
  ,b3,_d_0280,b3,_mac_ser_set_inp,b3,_d_02c0,b3,_d_4680,b3,_d_5080
  ,b3,_d_d040,b3,_d_4c00,b3,_d_9000,b3,_mac_set_via_port_a,b3,_mac_set_via_port_b
  ,b3,_d_f000,b3,_bp_segofs_print,b3,_d_2040,b3,_d_b080,b3,_d_c140
  ,b3,_d_0e00,b3,_d_49c0,b3,_d_4000,b3,_d_0c40,b3,_mac_ser_set_rts
  ,b3,_d_5100,b3,_d_eac0,b3,_d_b140,b3,_d_d1c0,b3,_d_48c0
  ,b3,_d_c080,b3,_d_4c40,b3,_mac_log_exception,b3,_d_44c0,b3,_d_4480,b3,_e6522_set_shift_inp,b3,_d_8080,b3,_d_4ec0,b3,_d_2000,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3];
  var FUNCTION_TABLE_iiii = [b4,b4,_mac_set_msg_emu_pause,b4,_null_open,b4,_mac_set_msg_emu_iwm_ro,b4,_chr_stdio_read,b4,_mac_set_msg_emu_video_brightness
  ,b4,_mac_set_msg_emu_iwm_rw,b4,_dsk_qed_set_msg,b4,_mac_set_msg_emu_reset,b4,_mac_set_msg_emu_cpu_speed,b4,_cmd_get_sym1833
  ,b4,_chr_mouse_read,b4,_dsk_pce_set_msg,b4,_snd_null_write,b4,_sdl_set_msg_trm,b4,_mac_set_msg_emu_disk_eject
  ,b4,_dsk_psi_set_msg,b4,_mac_set_msg_emu_exit,b4,_chr_null_read,b4,_cmd_set_sym1835,b4,_bp_segofs_match
  ,b4,_mac_set_msg_emu_serport_file,b4,_mac_set_msg_emu_cpu_model,b4,_null_set_msg_trm,b4,_chr_null_write,b4,_mac_set_msg_emu_pause_toggle
  ,b4,_sdl_open,b4,_dsk_cow_set_msg,b4,_chr_posix_read,b4,_bp_expr_match,b4,_mac_set_msg_mac_insert
  ,b4,_mac_set_msg_emu_stop,b4,_chr_posix_write,b4,_mac_set_msg_emu_realtime_toggle,b4,_adb_kbd_talk,b4,_mac_set_msg
  ,b4,_chr_pty_write,b4,_adb_mouse_talk,b4,_mac_set_msg_emu_iwm_status,b4,_mac_set_msg_emu_cpu_speed_step,b4,_mac_set_msg_emu_serport_driver
  ,b4,_snd_sdl_write,b4,_mac_set_msg_emu_disk_insert,b4,_bp_addr_match,b4,_chr_pty_read,b4,_chr_stdio_write
  ,b4,_adb_dev_talk,b4,_mac_set_msg_emu_disk_commit,b4,_mac_set_msg_emu_disk_rw,b4,_mac_set_msg_emu_disk_ro,b4,_mac_set_msg_emu_realtime,b4,_chr_mouse_write,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4];
  var FUNCTION_TABLE_viii = [b5,b5,_e6522_set_uint16,b5,_mac_mem_set_uint8,b5,_mem_blk_set_uint8_null,b5,_snd_sdl_callback,b5,_mac_mem_set_uint32
  ,b5,_mem_set_uint8,b5,_mac_log_mem,b5,_mem_set_uint32_be,b5,_e6522_set_uint32,b5,_mac_interrupt
  ,b5,_mem_set_uint16_be,b5,_e6522_set_uint8,b5,_mem_blk_set_uint32_null,b5,_mac_scc_set_uint8,b5,_mac_scsi_set_uint16
  ,b5,_mac_set_key,b5,_mem_blk_set_uint16_null,b5,_mac_scsi_set_uint8,b5,_mac_mem_set_uint16,b5,_mem_set_uint8_rw,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5];
  var FUNCTION_TABLE_v = [b6,b6,_mac_atexit,b6,_mac_run_emscripten_step,b6,b6,b6];
  var FUNCTION_TABLE_iiiii = [b7,b7,_dsk_ram_write,b7,_snd_sdl_set_params,b7,_e68_ea_101_xxx,b7,_dsk_qed_get_msg,b7,_e68_ea_001_xxx
  ,b7,_dsk_qed_write,b7,_dsk_cow_get_msg,b7,_e68_ea_111_100,b7,_e68_ea_000_xxx,b7,_dsk_cow_read
  ,b7,_e68_ea_011_111,b7,_e68_ea_100_xxx,b7,_dsk_img_write,b7,_e68_ea_110_xxx,b7,_e68_ea_111_001
  ,b7,_e68_ea_111_000,b7,_e68_ea_011_xxx,b7,_e68_ea_111_xxx,b7,_dsk_psi_write,b7,_snd_null_set_params
  ,b7,_dsk_psi_read,b7,_dsk_pce_get_msg,b7,_e68_ea_100_111,b7,_dsk_pce_read,b7,_dsk_part_write
  ,b7,_dsk_ram_read,b7,_dsk_part_read,b7,_e68_ea_010_xxx,b7,_e68_ea_111_010,b7,_e68_ea_111_011
  ,b7,_dsk_qed_read,b7,_dsk_cow_write,b7,_dsk_img_read,b7,_dsk_dosemu_write,b7,_dsk_pce_write,b7,_dsk_dosemu_read,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7];
  var FUNCTION_TABLE_iii = [b8,b8,_mac_mem_get_uint16,b8,_e6522_get_uint8,b8,_mem_blk_get_uint32_null,b8,_mac_scsi_get_uint16,b8,_e6522_get_uint32
  ,b8,_mem_get_uint16_be,b8,_mac_cmd,b8,_chr_null_get_ctl,b8,_mac_mem_get_uint32,b8,_mem_blk_get_uint8_null
  ,b8,_mem_get_uint32_be,b8,_mac_mem_get_uint8,b8,_mem_get_uint8,b8,_mac_scsi_get_uint8,b8,_mac_scc_get_uint8
  ,b8,_e6522_get_uint16,b8,_chr_null_set_ctl,b8,_mac_hook,b8,_chr_mouse_get_ctl,b8,_chr_mouse_set_ctl,b8,_mem_blk_get_uint16_null,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8];
  var FUNCTION_TABLE_iiiiii = [b9,b9,_chr_null_set_params,b9,_chr_mouse_set_params,b9,b9,b9];
  var FUNCTION_TABLE_viiii = [b10,b10,_adb_dev_listen,b10,_mac_set_mouse,b10,_adb_kbd_listen,b10];
  return { _memcmp: _memcmp, _strncasecmp: _strncasecmp, _strcat: _strcat, _free: _free, _main: _main, _realloc: _realloc, _tolower: _tolower, _strlen: _strlen, _memset: _memset, _malloc: _malloc, _memcpy: _memcpy, _strcasecmp: _strcasecmp, _strcpy: _strcpy, runPostSets: runPostSets, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, setTempRet1: setTempRet1, setTempRet2: setTempRet2, setTempRet3: setTempRet3, setTempRet4: setTempRet4, setTempRet5: setTempRet5, setTempRet6: setTempRet6, setTempRet7: setTempRet7, setTempRet8: setTempRet8, setTempRet9: setTempRet9, dynCall_ii: dynCall_ii, dynCall_viiiii: dynCall_viiiii, dynCall_vi: dynCall_vi, dynCall_vii: dynCall_vii, dynCall_iiii: dynCall_iiii, dynCall_viii: dynCall_viii, dynCall_v: dynCall_v, dynCall_iiiii: dynCall_iiiii, dynCall_iii: dynCall_iii, dynCall_iiiiii: dynCall_iiiiii, dynCall_viiii: dynCall_viiii };
})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_ii": invoke_ii, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiii": invoke_iiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiii": invoke_iiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_llvm_dbg_value": _llvm_dbg_value, "_fclose": _fclose, "_SDL_EventState": _SDL_EventState, "_strtoul": _strtoul, "_fflush": _fflush, "_SDL_GetMouseState": _SDL_GetMouseState, "_strtol": _strtol, "_fputc": _fputc, "_fwrite": _fwrite, "_ptsname": _ptsname, "_send": _send, "_tcflush": _tcflush, "_fputs": _fputs, "_emscripten_cancel_main_loop": _emscripten_cancel_main_loop, "_SDL_UnlockAudio": _SDL_UnlockAudio, "_SDL_WasInit": _SDL_WasInit, "_read": _read, "_fileno": _fileno, "_fsync": _fsync, "_signal": _signal, "_SDL_PauseAudio": _SDL_PauseAudio, "_SDL_LockAudio": _SDL_LockAudio, "_strcmp": _strcmp, "_strncmp": _strncmp, "_snprintf": _snprintf, "_fgetc": _fgetc, "_atexit": _atexit, "_close": _close, "_tcsetattr": _tcsetattr, "_strchr": _strchr, "_tcgetattr": _tcgetattr, "_poll": _poll, "___setErrNo": ___setErrNo, "_grantpt": _grantpt, "_ftell": _ftell, "_exit": _exit, "_sprintf": _sprintf, "_fcntl": _fcntl, "_SDL_ShowCursor": _SDL_ShowCursor, "_gmtime": _gmtime, "_symlink": _symlink, "_localtime_r": _localtime_r, "_ftruncate": _ftruncate, "_recv": _recv, "_SDL_PollEvent": _SDL_PollEvent, "_SDL_Init": _SDL_Init, "__exit": __exit, "_SDL_WM_GrabInput": _SDL_WM_GrabInput, "_llvm_va_end": _llvm_va_end, "_tzset": _tzset, "_SDL_CreateRGBSurfaceFrom": _SDL_CreateRGBSurfaceFrom, "_printf": _printf, "_unlockpt": _unlockpt, "_pread": _pread, "_SDL_SetVideoMode": _SDL_SetVideoMode, "_fopen": _fopen, "_open": _open, "_usleep": _usleep, "_SDL_EnableKeyRepeat": _SDL_EnableKeyRepeat, "_puts": _puts, "_SDL_GetVideoInfo": _SDL_GetVideoInfo, "_nanosleep": _nanosleep, "_SDL_Flip": _SDL_Flip, "_SDL_InitSubSystem": _SDL_InitSubSystem, "_strdup": _strdup, "_SDL_GetError": _SDL_GetError, "__formatString": __formatString, "_gettimeofday": _gettimeofday, "_vfprintf": _vfprintf, "_SDL_WM_SetCaption": _SDL_WM_SetCaption, "_sbrk": _sbrk, "___errno_location": ___errno_location, "_SDL_CloseAudio": _SDL_CloseAudio, "_isspace": _isspace, "_llvm_lifetime_start": _llvm_lifetime_start, "__parseInt": __parseInt, "_SDL_OpenAudio": _SDL_OpenAudio, "_localtime": _localtime, "_gmtime_r": _gmtime_r, "_sysconf": _sysconf, "_fread": _fread, "_SDL_WM_ToggleFullScreen": _SDL_WM_ToggleFullScreen, "_abort": _abort, "_fprintf": _fprintf, "_tan": _tan, "__reallyNegative": __reallyNegative, "_posix_openpt": _posix_openpt, "_fseek": _fseek, "_write": _write, "_SDL_UpperBlit": _SDL_UpperBlit, "_truncate": _truncate, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_unlink": _unlink, "_pwrite": _pwrite, "_SDL_FreeSurface": _SDL_FreeSurface, "_time": _time, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stdin": _stdin, "_stderr": _stderr }, buffer);
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
Module['callMain'] = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(!Module['preRun'] || Module['preRun'].length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  var ret;
  var initialStackTop = STACKTOP;
  try {
    ret = Module['_main'](argc, argv, 0);
  }
  catch(e) {
    if (e.name == 'ExitStatus') {
      return e.status;
    } else if (e == 'SimulateInfiniteLoop') {
      Module['noExitRuntime'] = true;
    } else {
      throw e;
    }
  } finally {
    STACKTOP = initialStackTop;
  }
  return ret;
}
function run(args) {
  args = args || Module['arguments'];
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    var ret = 0;
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      ret = Module['callMain'](args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = Module.run = run;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
  // {{MODULE_ADDITIONS}}
//@ sourceMappingURL=pce-macplus.js.map